//region block: polyfills
if (typeof Math.imul === 'undefined') {
  Math.imul = function imul(a, b) {
    return (a & 4.29490176E9) * (b & 65535) + (a & 65535) * (b | 0) | 0;
  };
}
if (typeof ArrayBuffer.isView === 'undefined') {
  ArrayBuffer.isView = function (a) {
    return a != null && a.__proto__ != null && a.__proto__.__proto__ === Int8Array.prototype.__proto__;
  };
}
if (typeof Array.prototype.fill === 'undefined') {
  // Polyfill from https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Array/fill#Polyfill
  Object.defineProperty(Array.prototype, 'fill', {value: function (value) {
    // Steps 1-2.
    if (this == null) {
      throw new TypeError('this is null or not defined');
    }
    var O = Object(this); // Steps 3-5.
    var len = O.length >>> 0; // Steps 6-7.
    var start = arguments[1];
    var relativeStart = start >> 0; // Step 8.
    var k = relativeStart < 0 ? Math.max(len + relativeStart, 0) : Math.min(relativeStart, len); // Steps 9-10.
    var end = arguments[2];
    var relativeEnd = end === undefined ? len : end >> 0; // Step 11.
    var finalValue = relativeEnd < 0 ? Math.max(len + relativeEnd, 0) : Math.min(relativeEnd, len); // Step 12.
    while (k < finalValue) {
      O[k] = value;
      k++;
    }
    ; // Step 13.
    return O;
  }});
}
[Int8Array, Int16Array, Uint16Array, Int32Array, Float32Array, Float64Array].forEach(function (TypedArray) {
  if (typeof TypedArray.prototype.fill === 'undefined') {
    Object.defineProperty(TypedArray.prototype, 'fill', {value: Array.prototype.fill});
  }
});
if (typeof Math.clz32 === 'undefined') {
  Math.clz32 = function (log, LN2) {
    return function (x) {
      var asUint = x >>> 0;
      if (asUint === 0) {
        return 32;
      }
      return 31 - (log(asUint) / LN2 | 0) | 0; // the "| 0" acts like math.floor
    };
  }(Math.log, Math.LN2);
}
if (typeof Math.log10 === 'undefined') {
  Math.log10 = function (x) {
    return Math.log(x) * Math.LOG10E;
  };
}
if (typeof Math.asinh === 'undefined') {
  var epsilon = 2.220446049250313E-16;
  var taylor_2_bound = Math.sqrt(epsilon);
  var taylor_n_bound = Math.sqrt(taylor_2_bound);
  var upper_taylor_2_bound = 1 / taylor_2_bound;
  var upper_taylor_n_bound = 1 / taylor_n_bound;
  var asinh = function (x) {
    if (x >= +taylor_n_bound) {
      if (x > upper_taylor_n_bound) {
        if (x > upper_taylor_2_bound) {
          // approximation by laurent series in 1/x at 0+ order from -1 to 0
          return Math.log(x) + Math.LN2;
        } else {
          // approximation by laurent series in 1/x at 0+ order from -1 to 1
          return Math.log(x * 2 + 1 / (x * 2));
        }
      } else {
        return Math.log(x + Math.sqrt(x * x + 1));
      }
    } else if (x <= -taylor_n_bound) {
      return -asinh(-x);
    } else {
      // approximation by taylor series in x at 0 up to order 2
      var result = x;
      if (Math.abs(x) >= taylor_2_bound) {
        var x3 = x * x * x; // approximation by taylor series in x at 0 up to order 4
        result -= x3 / 6;
      }
      return result;
    }
  };
  Math.asinh = asinh;
}
if (typeof Math.log2 === 'undefined') {
  Math.log2 = function (x) {
    return Math.log(x) * Math.LOG2E;
  };
}
if (typeof Math.expm1 === 'undefined') {
  var epsilon = 2.220446049250313E-16;
  var taylor_2_bound = Math.sqrt(epsilon);
  var taylor_n_bound = Math.sqrt(taylor_2_bound);
  Math.expm1 = function (x) {
    if (Math.abs(x) < taylor_n_bound) {
      var x2 = x * x;
      var x3 = x2 * x;
      var x4 = x3 * x; // approximation by taylor series in x at 0 up to order 4
      return x4 / 24 + x3 / 6 + x2 / 2 + x;
    }
    return Math.exp(x) - 1;
  };
}
if (typeof Math.cosh === 'undefined') {
  Math.cosh = function (x) {
    var y = Math.exp(x);
    var y1 = 1 / y;
    if (!isFinite(y) || !isFinite(y1))
      return Math.exp(Math.abs(x) - Math.LN2);
    return (y + y1) / 2;
  };
}
if (typeof Math.log1p === 'undefined') {
  var epsilon = 2.220446049250313E-16;
  var taylor_2_bound = Math.sqrt(epsilon);
  var taylor_n_bound = Math.sqrt(taylor_2_bound);
  Math.log1p = function (x) {
    if (Math.abs(x) < taylor_n_bound) {
      var x2 = x * x;
      var x3 = x2 * x;
      var x4 = x3 * x; // approximation by taylor series in x at 0 up to order 4
      return -x4 / 4 + x3 / 3 - x2 / 2 + x;
    }
    return Math.log(x + 1);
  };
}
if (typeof Math.sign === 'undefined') {
  Math.sign = function (x) {
    x = +x; // convert to a number
    if (x === 0 || isNaN(x)) {
      return Number(x);
    }
    return x > 0 ? 1 : -1;
  };
}
if (typeof Math.tanh === 'undefined') {
  var epsilon = 2.220446049250313E-16;
  var taylor_2_bound = Math.sqrt(epsilon);
  var taylor_n_bound = Math.sqrt(taylor_2_bound);
  Math.tanh = function (x) {
    if (Math.abs(x) < taylor_n_bound) {
      var result = x;
      if (Math.abs(x) > taylor_2_bound) {
        result -= x * x * x / 3;
      }
      return result;
    } else {
      var a = Math.exp(+x), b = Math.exp(-x);
      return a === Infinity ? 1 : b === Infinity ? -1 : (a - b) / (a + b);
    }
  };
}
if (typeof Math.sinh === 'undefined') {
  var epsilon = 2.220446049250313E-16;
  var taylor_2_bound = Math.sqrt(epsilon);
  var taylor_n_bound = Math.sqrt(taylor_2_bound);
  Math.sinh = function (x) {
    if (Math.abs(x) < taylor_n_bound) {
      var result = x;
      if (Math.abs(x) > taylor_2_bound) {
        result += x * x * x / 6;
      }
      return result;
    } else {
      var y = Math.exp(x);
      var y1 = 1 / y;
      if (!isFinite(y))
        return Math.exp(x - Math.LN2);
      if (!isFinite(y1))
        return -Math.exp(-x - Math.LN2);
      return (y - y1) / 2;
    }
  };
}
//endregion
import {
  createElement as createElement,
  useEffect as useEffect,
  Fragment as Fragment,
  useRef as useRef,
} from 'react';
import { createRoot as createRoot } from 'react-dom/client';
//region block: imports
var imul_0 = Math.imul;
var isView = ArrayBuffer.isView;
var clz32 = Math.clz32;
var log10 = Math.log10;
var asinh_0 = Math.asinh;
var sinh = Math.sinh;
var expm1 = Math.expm1;
var log1p = Math.log1p;
var log2 = Math.log2;
var cosh = Math.cosh;
var constructor = (class IteratorYieldResult {
    static [Symbol.hasInstance](instance) {
        return instance && (typeof instance === 'object') && (instance.done === false)
    }
    }.prototype).constructor;
var sign = Math.sign;
var tanh = Math.tanh;
//endregion
//region block: pre-declaration
class CharSequence {}
class Comparable {}
class Number_0 {}
class asSequence$$inlined$Sequence$1 {
  constructor($this_asSequence) {
    this.w_1 = $this_asSequence;
  }
  x() {
    // Inline function 'kotlin.collections.asSequence.<anonymous>' call
    return arrayIterator(this.w_1);
  }
}
class Iterable {}
class asIterable$$inlined$Iterable$1 {
  constructor($this_asIterable) {
    this.n1_1 = $this_asIterable;
  }
  x() {
    // Inline function 'kotlin.sequences.asIterable.<anonymous>' call
    return this.n1_1.x();
  }
}
class Exception extends Error {
  static nc() {
    var $this = createThis(this);
    init_kotlin_Exception($this);
    setPropertiesToThrowableInstance($this);
    return $this;
  }
  static f5(message) {
    var $this = createThis(this);
    init_kotlin_Exception($this);
    setPropertiesToThrowableInstance($this, message);
    return $this;
  }
  static oc(message, cause) {
    var $this = createThis(this);
    init_kotlin_Exception($this);
    setPropertiesToThrowableInstance($this, message, cause);
    return $this;
  }
  static pc(cause) {
    var $this = createThis(this);
    init_kotlin_Exception($this);
    setPropertiesToThrowableInstance($this, VOID, cause);
    return $this;
  }
}
class RuntimeException extends Exception {
  static u1() {
    var $this = this.nc();
    init_kotlin_RuntimeException($this);
    return $this;
  }
  static ja(message) {
    var $this = this.f5(message);
    init_kotlin_RuntimeException($this);
    return $this;
  }
  static rc(message, cause) {
    var $this = this.oc(message, cause);
    init_kotlin_RuntimeException($this);
    return $this;
  }
  static sc(cause) {
    var $this = this.pc(cause);
    init_kotlin_RuntimeException($this);
    return $this;
  }
}
class KotlinNothingValueException extends RuntimeException {
  static r1() {
    var $this = this.u1();
    init_kotlin_KotlinNothingValueException($this);
    return $this;
  }
}
class Companion {
  constructor() {
    Companion_instance = this;
    this.y1_1 = _Char___init__impl__6a9atx(0);
    this.z1_1 = _Char___init__impl__6a9atx(65535);
    this.a2_1 = _Char___init__impl__6a9atx(55296);
    this.b2_1 = _Char___init__impl__6a9atx(56319);
    this.c2_1 = _Char___init__impl__6a9atx(56320);
    this.d2_1 = _Char___init__impl__6a9atx(57343);
    this.e2_1 = _Char___init__impl__6a9atx(55296);
    this.f2_1 = _Char___init__impl__6a9atx(57343);
    this.g2_1 = 2;
    this.h2_1 = 16;
  }
}
class Char {
  constructor(value) {
    Companion_getInstance();
    this.x1_1 = value;
  }
  i2(other) {
    return Char__compareTo_impl_ypi4mb(this.x1_1, other);
  }
  d(other) {
    return Char__compareTo_impl_ypi4mb_0(this, other);
  }
  toString() {
    return toString(this.x1_1);
  }
  equals(other) {
    return Char__equals_impl_x6719k(this.x1_1, other);
  }
  hashCode() {
    return Char__hashCode_impl_otmys(this.x1_1);
  }
}
class Companion_0 {
  fromJsArray(array) {
    return createListFrom(array);
  }
}
class Collection {}
class KtList_0 {}
function asJsReadonlyArrayView() {
  return createJsReadonlyArrayViewFrom(this);
}
class Companion_1 {
  fromJsSet(set) {
    return createSetFrom(set);
  }
}
class KtSet_0 {}
function asJsReadonlySetView() {
  return createJsReadonlySetViewFrom(this);
}
class Entry {}
class KtMap {}
class MutableIterable {}
class MutableCollection {}
class Companion_2 {}
class Enum {
  constructor(name, ordinal) {
    this.y2_1 = name;
    this.z2_1 = ordinal;
  }
  a3() {
    return this.y2_1;
  }
  b3() {
    return this.z2_1;
  }
  c3(other) {
    return compareTo(this.z2_1, other.z2_1);
  }
  d(other) {
    return this.c3(other instanceof Enum ? other : THROW_CCE());
  }
  equals(other) {
    return this === other;
  }
  hashCode() {
    return identityHashCode(this);
  }
  toString() {
    return this.y2_1;
  }
}
class Companion_3 {
  constructor() {
    Companion_instance_3 = this;
    this.d3_1 = new Long(0, -2147483648);
    this.e3_1 = new Long(-1, 2147483647);
    this.f3_1 = 8;
    this.g3_1 = 64;
  }
}
class Long extends Number_0 {
  constructor(low, high) {
    Companion_getInstance_3();
    super();
    this.j1_1 = low;
    this.k1_1 = high;
  }
  m1(other) {
    return compare(this, other);
  }
  d(other) {
    return this.m1(other instanceof Long ? other : THROW_CCE());
  }
  h3(other) {
    return add(this, other);
  }
  i3(other) {
    return subtract(this, other);
  }
  j3(other) {
    return multiply(this, other);
  }
  k3(other) {
    return divide(this, other);
  }
  l3(other) {
    return modulo(this, other);
  }
  m3() {
    return this.h3(new Long(1, 0));
  }
  n3() {
    return this.i3(new Long(1, 0));
  }
  o3() {
    return this.p3().h3(new Long(1, 0));
  }
  q3(bitCount) {
    return shiftLeft(this, bitCount);
  }
  r3(bitCount) {
    return shiftRight(this, bitCount);
  }
  s3(bitCount) {
    return shiftRightUnsigned(this, bitCount);
  }
  t3(other) {
    return new Long(this.j1_1 & other.j1_1, this.k1_1 & other.k1_1);
  }
  u3(other) {
    return new Long(this.j1_1 | other.j1_1, this.k1_1 | other.k1_1);
  }
  v3(other) {
    return new Long(this.j1_1 ^ other.j1_1, this.k1_1 ^ other.k1_1);
  }
  p3() {
    return new Long(~this.j1_1, ~this.k1_1);
  }
  w3() {
    return toByte(this.j1_1);
  }
  x3() {
    return toShort(this.j1_1);
  }
  l1() {
    return this.j1_1;
  }
  y3() {
    return this;
  }
  z3() {
    return this.a4();
  }
  a4() {
    return toNumber(this);
  }
  toString() {
    return toStringImpl(this, 10);
  }
  equals(other) {
    var tmp;
    if (other instanceof Long) {
      tmp = equalsLong(this, other);
    } else {
      tmp = false;
    }
    return tmp;
  }
  hashCode() {
    return hashCode_0(this);
  }
  valueOf() {
    return this.a4();
  }
}
class FunctionAdapter {}
class arrayIterator$1 {
  constructor($array) {
    this.d4_1 = $array;
    this.c4_1 = 0;
  }
  y() {
    return !(this.c4_1 === this.d4_1.length);
  }
  z() {
    var tmp;
    if (!(this.c4_1 === this.d4_1.length)) {
      var _unary__edvuaz = this.c4_1;
      this.c4_1 = _unary__edvuaz + 1 | 0;
      tmp = this.d4_1[_unary__edvuaz];
    } else {
      throw NoSuchElementException.s('' + this.c4_1);
    }
    return tmp;
  }
}
class JsArrayView extends Array {}
class JsSetView extends Set {}
class Digit {
  constructor() {
    Digit_instance = this;
    var tmp = this;
    // Inline function 'kotlin.intArrayOf' call
    tmp.i5_1 = new Int32Array([48, 1632, 1776, 1984, 2406, 2534, 2662, 2790, 2918, 3046, 3174, 3302, 3430, 3558, 3664, 3792, 3872, 4160, 4240, 6112, 6160, 6470, 6608, 6784, 6800, 6992, 7088, 7232, 7248, 42528, 43216, 43264, 43472, 43504, 43600, 44016, 65296]);
  }
}
class Comparator {}
class Unit {
  toString() {
    return 'kotlin.Unit';
  }
}
class AbstractCollection {
  static l5() {
    return createThis(this);
  }
  j2(element) {
    var tmp$ret$0;
    $l$block_0: {
      // Inline function 'kotlin.collections.any' call
      var tmp;
      if (isInterface(this, Collection)) {
        tmp = this.c1();
      } else {
        tmp = false;
      }
      if (tmp) {
        tmp$ret$0 = false;
        break $l$block_0;
      }
      var _iterator__ex2g4s = this.x();
      while (_iterator__ex2g4s.y()) {
        var element_0 = _iterator__ex2g4s.z();
        // Inline function 'kotlin.collections.AbstractCollection.contains.<anonymous>' call
        if (equals(element_0, element)) {
          tmp$ret$0 = true;
          break $l$block_0;
        }
      }
      tmp$ret$0 = false;
    }
    return tmp$ret$0;
  }
  k2(elements) {
    var tmp$ret$0;
    $l$block_0: {
      // Inline function 'kotlin.collections.all' call
      var tmp;
      if (isInterface(elements, Collection)) {
        tmp = elements.c1();
      } else {
        tmp = false;
      }
      if (tmp) {
        tmp$ret$0 = true;
        break $l$block_0;
      }
      var _iterator__ex2g4s = elements.x();
      while (_iterator__ex2g4s.y()) {
        var element = _iterator__ex2g4s.z();
        // Inline function 'kotlin.collections.AbstractCollection.containsAll.<anonymous>' call
        if (!this.j2(element)) {
          tmp$ret$0 = false;
          break $l$block_0;
        }
      }
      tmp$ret$0 = true;
    }
    return tmp$ret$0;
  }
  c1() {
    return this.a1() === 0;
  }
  toString() {
    return joinToString_1(this, ', ', '[', ']', VOID, VOID, AbstractCollection$toString$lambda(this));
  }
  toArray() {
    return collectionToArray(this);
  }
}
class AbstractMutableCollection extends AbstractCollection {
  static k5() {
    return this.l5();
  }
  w2(element) {
    this.m5();
    var iterator = this.x();
    while (iterator.y()) {
      if (equals(iterator.z(), element)) {
        iterator.n5();
        return true;
      }
    }
    return false;
  }
  x2(elements) {
    this.m5();
    var modified = false;
    var _iterator__ex2g4s = elements.x();
    while (_iterator__ex2g4s.y()) {
      var element = _iterator__ex2g4s.z();
      if (this.o(element))
        modified = true;
    }
    return modified;
  }
  o5() {
    this.m5();
    var iterator = this.x();
    while (iterator.y()) {
      iterator.z();
      iterator.n5();
    }
  }
  toJSON() {
    return this.toArray();
  }
  m5() {
  }
}
class IteratorImpl {
  constructor($outer, $box) {
    boxApply(this, $box);
    this.r5_1 = $outer;
    this.p5_1 = 0;
    this.q5_1 = -1;
  }
  y() {
    return this.p5_1 < this.r5_1.a1();
  }
  z() {
    if (!this.y())
      throw NoSuchElementException.s5();
    var tmp = this;
    var _unary__edvuaz = this.p5_1;
    this.p5_1 = _unary__edvuaz + 1 | 0;
    tmp.q5_1 = _unary__edvuaz;
    return this.r5_1.b1(this.q5_1);
  }
  n5() {
    // Inline function 'kotlin.check' call
    if (!!(this.q5_1 === -1)) {
      // Inline function 'kotlin.collections.IteratorImpl.remove.<anonymous>' call
      var message = 'Call next() or previous() before removing element from the iterator.';
      throw IllegalStateException.n4(toString_1(message));
    }
    this.r5_1.u5(this.q5_1);
    this.p5_1 = this.q5_1;
    this.q5_1 = -1;
  }
}
class ListIteratorImpl extends IteratorImpl {
  constructor($outer, index, $box) {
    if ($box === VOID)
      $box = {};
    $box.y5_1 = $outer;
    super($outer, $box);
    Companion_instance_7.z5(index, this.y5_1.a1());
    this.p5_1 = index;
  }
  a6() {
    return this.p5_1 > 0;
  }
  b6() {
    return this.p5_1;
  }
  c6() {
    if (!this.a6())
      throw NoSuchElementException.s5();
    var tmp = this;
    this.p5_1 = this.p5_1 - 1 | 0;
    tmp.q5_1 = this.p5_1;
    return this.y5_1.b1(this.q5_1);
  }
}
class AbstractMutableList extends AbstractMutableCollection {
  static i6() {
    var $this = this.k5();
    $this.t5_1 = 0;
    return $this;
  }
  m6(_set____db54di) {
    this.t5_1 = _set____db54di;
  }
  n6() {
    return this.t5_1;
  }
  o(element) {
    this.m5();
    this.j6(this.a1(), element);
    return true;
  }
  o5() {
    this.m5();
    this.l6(0, this.a1());
  }
  o6(elements) {
    this.m5();
    return removeAll(this, AbstractMutableList$removeAll$lambda(elements));
  }
  p6(elements) {
    this.m5();
    return removeAll(this, AbstractMutableList$retainAll$lambda(elements));
  }
  x() {
    return new IteratorImpl(this);
  }
  j2(element) {
    return this.l2(element) >= 0;
  }
  l2(element) {
    var tmp$ret$1;
    $l$block: {
      // Inline function 'kotlin.collections.indexOfFirst' call
      var index = 0;
      var _iterator__ex2g4s = this.x();
      while (_iterator__ex2g4s.y()) {
        var item = _iterator__ex2g4s.z();
        // Inline function 'kotlin.collections.AbstractMutableList.indexOf.<anonymous>' call
        if (equals(item, element)) {
          tmp$ret$1 = index;
          break $l$block;
        }
        index = index + 1 | 0;
      }
      tmp$ret$1 = -1;
    }
    return tmp$ret$1;
  }
  m2(element) {
    var tmp$ret$1;
    $l$block: {
      // Inline function 'kotlin.collections.indexOfLast' call
      var iterator = this.o2(this.a1());
      while (iterator.a6()) {
        // Inline function 'kotlin.collections.AbstractMutableList.lastIndexOf.<anonymous>' call
        var it = iterator.c6();
        if (equals(it, element)) {
          tmp$ret$1 = iterator.b6();
          break $l$block;
        }
      }
      tmp$ret$1 = -1;
    }
    return tmp$ret$1;
  }
  n2() {
    return this.o2(0);
  }
  o2(index) {
    return new ListIteratorImpl(this, index);
  }
  p2(fromIndex, toIndex) {
    return SubList.h6(this, fromIndex, toIndex);
  }
  l6(fromIndex, toIndex) {
    var iterator = this.o2(fromIndex);
    // Inline function 'kotlin.repeat' call
    var times = toIndex - fromIndex | 0;
    var inductionVariable = 0;
    if (inductionVariable < times)
      do {
        var index = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        // Inline function 'kotlin.collections.AbstractMutableList.removeRange.<anonymous>' call
        iterator.z();
        iterator.n5();
      }
       while (inductionVariable < times);
  }
  equals(other) {
    if (other === this)
      return true;
    if (!(!(other == null) ? isInterface(other, KtList_0) : false))
      return false;
    return Companion_instance_7.q6(this, other);
  }
  hashCode() {
    return Companion_instance_7.r6(this);
  }
}
class RandomAccess {}
class SubList extends AbstractMutableList {
  static h6(list, fromIndex, toIndex) {
    var $this = this.i6();
    $this.e6_1 = list;
    $this.f6_1 = fromIndex;
    $this.g6_1 = 0;
    Companion_instance_7.h5($this.f6_1, toIndex, $this.e6_1.a1());
    $this.g6_1 = toIndex - $this.f6_1 | 0;
    return $this;
  }
  j6(index, element) {
    Companion_instance_7.z5(index, this.g6_1);
    this.e6_1.j6(this.f6_1 + index | 0, element);
    this.g6_1 = this.g6_1 + 1 | 0;
  }
  b1(index) {
    Companion_instance_7.k6(index, this.g6_1);
    return this.e6_1.b1(this.f6_1 + index | 0);
  }
  u5(index) {
    Companion_instance_7.k6(index, this.g6_1);
    var result = this.e6_1.u5(this.f6_1 + index | 0);
    this.g6_1 = this.g6_1 - 1 | 0;
    return result;
  }
  j5(index, element) {
    Companion_instance_7.k6(index, this.g6_1);
    return this.e6_1.j5(this.f6_1 + index | 0, element);
  }
  l6(fromIndex, toIndex) {
    this.e6_1.l6(this.f6_1 + fromIndex | 0, this.f6_1 + toIndex | 0);
    this.g6_1 = this.g6_1 - (toIndex - fromIndex | 0) | 0;
  }
  a1() {
    return this.g6_1;
  }
  m5() {
    return this.e6_1.m5();
  }
}
class AbstractMap {
  static z6() {
    var $this = createThis(this);
    $this.x6_1 = null;
    $this.y6_1 = null;
    return $this;
  }
  s2(key) {
    return !(implFindEntry(this, key) == null);
  }
  t2(value) {
    var tmp0 = this.v2();
    var tmp$ret$0;
    $l$block_0: {
      // Inline function 'kotlin.collections.any' call
      var tmp;
      if (isInterface(tmp0, Collection)) {
        tmp = tmp0.c1();
      } else {
        tmp = false;
      }
      if (tmp) {
        tmp$ret$0 = false;
        break $l$block_0;
      }
      var _iterator__ex2g4s = tmp0.x();
      while (_iterator__ex2g4s.y()) {
        var element = _iterator__ex2g4s.z();
        // Inline function 'kotlin.collections.AbstractMap.containsValue.<anonymous>' call
        if (equals(element.r2(), value)) {
          tmp$ret$0 = true;
          break $l$block_0;
        }
      }
      tmp$ret$0 = false;
    }
    return tmp$ret$0;
  }
  k7(entry) {
    if (!(!(entry == null) ? isInterface(entry, Entry) : false))
      return false;
    var key = entry.q2();
    var value = entry.r2();
    // Inline function 'kotlin.collections.get' call
    var ourValue = (isInterface(this, KtMap) ? this : THROW_CCE()).u2(key);
    if (!equals(value, ourValue)) {
      return false;
    }
    var tmp;
    if (ourValue == null) {
      // Inline function 'kotlin.collections.containsKey' call
      tmp = !(isInterface(this, KtMap) ? this : THROW_CCE()).s2(key);
    } else {
      tmp = false;
    }
    if (tmp) {
      return false;
    }
    return true;
  }
  equals(other) {
    if (other === this)
      return true;
    if (!(!(other == null) ? isInterface(other, KtMap) : false))
      return false;
    if (!(this.a1() === other.a1()))
      return false;
    var tmp0 = other.v2();
    var tmp$ret$0;
    $l$block_0: {
      // Inline function 'kotlin.collections.all' call
      var tmp;
      if (isInterface(tmp0, Collection)) {
        tmp = tmp0.c1();
      } else {
        tmp = false;
      }
      if (tmp) {
        tmp$ret$0 = true;
        break $l$block_0;
      }
      var _iterator__ex2g4s = tmp0.x();
      while (_iterator__ex2g4s.y()) {
        var element = _iterator__ex2g4s.z();
        // Inline function 'kotlin.collections.AbstractMap.equals.<anonymous>' call
        if (!this.k7(element)) {
          tmp$ret$0 = false;
          break $l$block_0;
        }
      }
      tmp$ret$0 = true;
    }
    return tmp$ret$0;
  }
  u2(key) {
    var tmp0_safe_receiver = implFindEntry(this, key);
    return tmp0_safe_receiver == null ? null : tmp0_safe_receiver.r2();
  }
  hashCode() {
    return hashCode(this.v2());
  }
  a1() {
    return this.v2().a1();
  }
  toString() {
    var tmp = this.v2();
    return joinToString_1(tmp, ', ', '{', '}', VOID, VOID, AbstractMap$toString$lambda(this));
  }
}
class AbstractMutableMap extends AbstractMap {
  static w6() {
    var $this = this.z6();
    $this.u6_1 = null;
    $this.v6_1 = null;
    return $this;
  }
  a7() {
    return HashMapKeysDefault.c7(this);
  }
  d7() {
    return HashMapValuesDefault.f7(this);
  }
  g7() {
    var tmp0_elvis_lhs = this.u6_1;
    var tmp;
    if (tmp0_elvis_lhs == null) {
      // Inline function 'kotlin.also' call
      var this_0 = this.a7();
      // Inline function 'kotlin.collections.AbstractMutableMap.<get-keys>.<anonymous>' call
      this.u6_1 = this_0;
      tmp = this_0;
    } else {
      tmp = tmp0_elvis_lhs;
    }
    return tmp;
  }
  h7() {
    var tmp0_elvis_lhs = this.v6_1;
    var tmp;
    if (tmp0_elvis_lhs == null) {
      // Inline function 'kotlin.also' call
      var this_0 = this.d7();
      // Inline function 'kotlin.collections.AbstractMutableMap.<get-values>.<anonymous>' call
      this.v6_1 = this_0;
      tmp = this_0;
    } else {
      tmp = tmp0_elvis_lhs;
    }
    return tmp;
  }
  o5() {
    this.v2().o5();
  }
  j7(key) {
    this.m5();
    var iter = this.v2().x();
    while (iter.y()) {
      var entry = iter.z();
      var k = entry.q2();
      if (equals(key, k)) {
        var value = entry.r2();
        iter.n5();
        return value;
      }
    }
    return null;
  }
  m5() {
  }
}
class AbstractMutableSet extends AbstractMutableCollection {
  static l7() {
    return this.k5();
  }
  equals(other) {
    if (other === this)
      return true;
    if (!(!(other == null) ? isInterface(other, KtSet_0) : false))
      return false;
    return Companion_instance_9.m7(this, other);
  }
  hashCode() {
    return Companion_instance_9.n7(this);
  }
}
class Companion_4 {
  constructor() {
    Companion_instance_4 = this;
    var tmp = this;
    // Inline function 'kotlin.also' call
    var this_0 = ArrayList.o7(0);
    // Inline function 'kotlin.collections.Companion.Empty.<anonymous>' call
    this_0.k_1 = true;
    tmp.p7_1 = this_0;
  }
}
class ArrayList extends AbstractMutableList {
  static i4(array) {
    Companion_getInstance_4();
    var $this = this.i6();
    $this.j_1 = array;
    $this.k_1 = false;
    return $this;
  }
  static e1() {
    Companion_getInstance_4();
    // Inline function 'kotlin.emptyArray' call
    var tmp$ret$0 = [];
    return this.i4(tmp$ret$0);
  }
  static o7(initialCapacity) {
    Companion_getInstance_4();
    // Inline function 'kotlin.emptyArray' call
    var tmp$ret$0 = [];
    var $this = this.i4(tmp$ret$0);
    // Inline function 'kotlin.require' call
    if (!(initialCapacity >= 0)) {
      // Inline function 'kotlin.collections.ArrayList.<init>.<anonymous>' call
      var message = 'Negative initial capacity: ' + initialCapacity;
      throw IllegalArgumentException.h(toString_1(message));
    }
    return $this;
  }
  static l(elements) {
    Companion_getInstance_4();
    // Inline function 'kotlin.collections.toTypedArray' call
    var tmp$ret$0 = copyToArray(elements);
    return this.i4(tmp$ret$0);
  }
  j4() {
    this.m5();
    this.k_1 = true;
    return this.a1() > 0 ? this : Companion_getInstance_4().p7_1;
  }
  q7() {
  }
  r7(minCapacity) {
  }
  a1() {
    return this.j_1.length;
  }
  b1(index) {
    var tmp = this.j_1[rangeCheck(this, index)];
    return (tmp == null ? true : !(tmp == null)) ? tmp : THROW_CCE();
  }
  j5(index, element) {
    this.m5();
    rangeCheck(this, index);
    // Inline function 'kotlin.apply' call
    var this_0 = this.j_1[index];
    // Inline function 'kotlin.collections.ArrayList.set.<anonymous>' call
    this.j_1[index] = element;
    var tmp = this_0;
    return (tmp == null ? true : !(tmp == null)) ? tmp : THROW_CCE();
  }
  o(element) {
    this.m5();
    // Inline function 'kotlin.js.asDynamic' call
    this.j_1.push(element);
    this.t5_1 = this.t5_1 + 1 | 0;
    return true;
  }
  j6(index, element) {
    this.m5();
    // Inline function 'kotlin.js.asDynamic' call
    this.j_1.splice(insertionRangeCheck(this, index), 0, element);
    this.t5_1 = this.t5_1 + 1 | 0;
  }
  x2(elements) {
    this.m5();
    if (elements.c1())
      return false;
    var offset = increaseLength(this, elements.a1());
    // Inline function 'kotlin.collections.forEachIndexed' call
    var index = 0;
    var _iterator__ex2g4s = elements.x();
    while (_iterator__ex2g4s.y()) {
      var item = _iterator__ex2g4s.z();
      var _unary__edvuaz = index;
      index = _unary__edvuaz + 1 | 0;
      // Inline function 'kotlin.collections.ArrayList.addAll.<anonymous>' call
      var index_0 = checkIndexOverflow(_unary__edvuaz);
      this.j_1[offset + index_0 | 0] = item;
    }
    this.t5_1 = this.t5_1 + 1 | 0;
    return true;
  }
  s7(index, elements) {
    this.m5();
    insertionRangeCheck(this, index);
    if (index === this.a1())
      return this.x2(elements);
    if (elements.c1())
      return false;
    // Inline function 'kotlin.js.asDynamic' call
    // Inline function 'kotlin.js.unsafeCast' call
    var tail = this.j_1.splice(index);
    this.x2(elements);
    var offset = increaseLength(this, tail.length);
    // Inline function 'kotlin.repeat' call
    var times = tail.length;
    var inductionVariable = 0;
    if (inductionVariable < times)
      do {
        var index_0 = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        // Inline function 'kotlin.collections.ArrayList.addAll.<anonymous>' call
        this.j_1[offset + index_0 | 0] = tail[index_0];
      }
       while (inductionVariable < times);
    this.t5_1 = this.t5_1 + 1 | 0;
    return true;
  }
  u5(index) {
    this.m5();
    rangeCheck(this, index);
    this.t5_1 = this.t5_1 + 1 | 0;
    var tmp;
    if (index === get_lastIndex_0(this)) {
      // Inline function 'kotlin.js.asDynamic' call
      tmp = this.j_1.pop();
    } else {
      // Inline function 'kotlin.js.asDynamic' call
      tmp = this.j_1.splice(index, 1)[0];
    }
    return tmp;
  }
  w2(element) {
    this.m5();
    var inductionVariable = 0;
    var last = this.j_1.length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var index = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        if (equals(this.j_1[index], element)) {
          // Inline function 'kotlin.js.asDynamic' call
          this.j_1.splice(index, 1);
          this.t5_1 = this.t5_1 + 1 | 0;
          return true;
        }
      }
       while (inductionVariable <= last);
    return false;
  }
  l6(fromIndex, toIndex) {
    this.m5();
    this.t5_1 = this.t5_1 + 1 | 0;
    // Inline function 'kotlin.js.asDynamic' call
    this.j_1.splice(fromIndex, toIndex - fromIndex | 0);
  }
  o5() {
    this.m5();
    var tmp = this;
    // Inline function 'kotlin.emptyArray' call
    tmp.j_1 = [];
    this.t5_1 = this.t5_1 + 1 | 0;
  }
  l2(element) {
    return indexOf(this.j_1, element);
  }
  m2(element) {
    return lastIndexOf(this.j_1, element);
  }
  toString() {
    return arrayToString(this.j_1);
  }
  t7(array) {
    if (array.length < this.a1()) {
      var tmp = this.u7();
      return isArray(tmp) ? tmp : THROW_CCE();
    }
    var tmp_0 = this.j_1;
    var tmp0 = isArray(tmp_0) ? tmp_0 : THROW_CCE();
    // Inline function 'kotlin.collections.copyInto' call
    var endIndex = tmp0.length;
    arrayCopy(tmp0, array, 0, 0, endIndex);
    return terminateCollectionToArray(this.a1(), array);
  }
  u7() {
    return [].slice.call(this.j_1);
  }
  toArray() {
    return this.u7();
  }
  v7() {
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    return this.j_1;
  }
  m5() {
    if (this.k_1)
      throw UnsupportedOperationException.h4();
  }
}
class HashMap extends AbstractMutableMap {
  static c8(internalMap) {
    var $this = this.w6();
    init_kotlin_collections_HashMap($this);
    $this.a8_1 = internalMap;
    return $this;
  }
  static d8() {
    return this.c8(InternalHashMap.o8());
  }
  static p8(initialCapacity, loadFactor) {
    return this.c8(InternalHashMap.q8(initialCapacity, loadFactor));
  }
  static r8(initialCapacity) {
    return this.p8(initialCapacity, 1.0);
  }
  o5() {
    this.a8_1.o5();
  }
  s2(key) {
    return this.a8_1.s8(key);
  }
  t2(value) {
    return this.a8_1.t2(value);
  }
  a7() {
    return HashMapKeys.u8(this.a8_1);
  }
  d7() {
    return HashMapValues.w8(this.a8_1);
  }
  v2() {
    var tmp0_elvis_lhs = this.b8_1;
    var tmp;
    if (tmp0_elvis_lhs == null) {
      // Inline function 'kotlin.also' call
      var this_0 = HashMapEntrySet.y8(this.a8_1);
      // Inline function 'kotlin.collections.HashMap.<get-entries>.<anonymous>' call
      this.b8_1 = this_0;
      tmp = this_0;
    } else {
      tmp = tmp0_elvis_lhs;
    }
    return tmp;
  }
  u2(key) {
    return this.a8_1.u2(key);
  }
  i7(key, value) {
    return this.a8_1.i7(key, value);
  }
  j7(key) {
    return this.a8_1.j7(key);
  }
  a1() {
    return this.a8_1.a1();
  }
}
class HashMapKeys extends AbstractMutableSet {
  static u8(backing) {
    var $this = this.l7();
    $this.t8_1 = backing;
    return $this;
  }
  a1() {
    return this.t8_1.a1();
  }
  c1() {
    return this.t8_1.a1() === 0;
  }
  j2(element) {
    return this.t8_1.s8(element);
  }
  o5() {
    return this.t8_1.o5();
  }
  o(element) {
    throw UnsupportedOperationException.h4();
  }
  x2(elements) {
    throw UnsupportedOperationException.h4();
  }
  w2(element) {
    return this.t8_1.z8(element);
  }
  x() {
    return this.t8_1.a9();
  }
  m5() {
    return this.t8_1.b9();
  }
}
class HashMapValues extends AbstractMutableCollection {
  static w8(backing) {
    var $this = this.k5();
    $this.v8_1 = backing;
    return $this;
  }
  a1() {
    return this.v8_1.a1();
  }
  c1() {
    return this.v8_1.a1() === 0;
  }
  c9(element) {
    return this.v8_1.t2(element);
  }
  j2(element) {
    if (!(element == null ? true : !(element == null)))
      return false;
    return this.c9((element == null ? true : !(element == null)) ? element : THROW_CCE());
  }
  d9(element) {
    throw UnsupportedOperationException.h4();
  }
  o(element) {
    return this.d9((element == null ? true : !(element == null)) ? element : THROW_CCE());
  }
  e9(elements) {
    throw UnsupportedOperationException.h4();
  }
  x2(elements) {
    return this.e9(elements);
  }
  x() {
    return this.v8_1.f9();
  }
  g9(element) {
    return this.v8_1.h9(element);
  }
  w2(element) {
    if (!(element == null ? true : !(element == null)))
      return false;
    return this.g9((element == null ? true : !(element == null)) ? element : THROW_CCE());
  }
  m5() {
    return this.v8_1.b9();
  }
}
class HashMapEntrySetBase extends AbstractMutableSet {
  static j9(backing) {
    var $this = this.l7();
    $this.i9_1 = backing;
    return $this;
  }
  a1() {
    return this.i9_1.a1();
  }
  c1() {
    return this.i9_1.a1() === 0;
  }
  l9(element) {
    return this.i9_1.o9(element);
  }
  j2(element) {
    if (!(!(element == null) ? isInterface(element, Entry) : false))
      return false;
    return this.l9((!(element == null) ? isInterface(element, Entry) : false) ? element : THROW_CCE());
  }
  o5() {
    return this.i9_1.o5();
  }
  m9(element) {
    throw UnsupportedOperationException.h4();
  }
  o(element) {
    return this.m9((!(element == null) ? isInterface(element, Entry) : false) ? element : THROW_CCE());
  }
  x2(elements) {
    throw UnsupportedOperationException.h4();
  }
  n9(element) {
    return this.i9_1.p9(element);
  }
  w2(element) {
    if (!(!(element == null) ? isInterface(element, Entry) : false))
      return false;
    return this.n9((!(element == null) ? isInterface(element, Entry) : false) ? element : THROW_CCE());
  }
  k2(elements) {
    return this.i9_1.q9(elements);
  }
  m5() {
    return this.i9_1.b9();
  }
}
class HashMapEntrySet extends HashMapEntrySetBase {
  static y8(backing) {
    return this.j9(backing);
  }
  x() {
    return this.i9_1.k9();
  }
}
class HashMapKeysDefault$iterator$1 {
  constructor($entryIterator) {
    this.r9_1 = $entryIterator;
  }
  y() {
    return this.r9_1.y();
  }
  z() {
    return this.r9_1.z().q2();
  }
  n5() {
    return this.r9_1.n5();
  }
}
class HashMapKeysDefault extends AbstractMutableSet {
  static c7(backingMap) {
    var $this = this.l7();
    $this.b7_1 = backingMap;
    return $this;
  }
  s9(element) {
    throw UnsupportedOperationException.t9('Add is not supported on keys');
  }
  o(element) {
    return this.s9((element == null ? true : !(element == null)) ? element : THROW_CCE());
  }
  o5() {
    return this.b7_1.o5();
  }
  s8(element) {
    return this.b7_1.s2(element);
  }
  j2(element) {
    if (!(element == null ? true : !(element == null)))
      return false;
    return this.s8((element == null ? true : !(element == null)) ? element : THROW_CCE());
  }
  x() {
    var entryIterator = this.b7_1.v2().x();
    return new HashMapKeysDefault$iterator$1(entryIterator);
  }
  j7(element) {
    this.m5();
    if (this.b7_1.s2(element)) {
      this.b7_1.j7(element);
      return true;
    }
    return false;
  }
  w2(element) {
    if (!(element == null ? true : !(element == null)))
      return false;
    return this.j7((element == null ? true : !(element == null)) ? element : THROW_CCE());
  }
  a1() {
    return this.b7_1.a1();
  }
  m5() {
    return this.b7_1.m5();
  }
}
class HashMapValuesDefault$iterator$1 {
  constructor($entryIterator) {
    this.u9_1 = $entryIterator;
  }
  y() {
    return this.u9_1.y();
  }
  z() {
    return this.u9_1.z().r2();
  }
  n5() {
    return this.u9_1.n5();
  }
}
class HashMapValuesDefault extends AbstractMutableCollection {
  static f7(backingMap) {
    var $this = this.k5();
    $this.e7_1 = backingMap;
    return $this;
  }
  d9(element) {
    throw UnsupportedOperationException.t9('Add is not supported on values');
  }
  o(element) {
    return this.d9((element == null ? true : !(element == null)) ? element : THROW_CCE());
  }
  c9(element) {
    return this.e7_1.t2(element);
  }
  j2(element) {
    if (!(element == null ? true : !(element == null)))
      return false;
    return this.c9((element == null ? true : !(element == null)) ? element : THROW_CCE());
  }
  x() {
    var entryIterator = this.e7_1.v2().x();
    return new HashMapValuesDefault$iterator$1(entryIterator);
  }
  a1() {
    return this.e7_1.a1();
  }
  m5() {
    return this.e7_1.m5();
  }
}
class HashSet extends AbstractMutableSet {
  static w9(map) {
    var $this = this.l7();
    init_kotlin_collections_HashSet($this);
    $this.v9_1 = map;
    return $this;
  }
  static x9() {
    return this.w9(InternalHashMap.o8());
  }
  static y9(elements) {
    var $this = this.w9(InternalHashMap.z9(elements.a1()));
    var _iterator__ex2g4s = elements.x();
    while (_iterator__ex2g4s.y()) {
      var element = _iterator__ex2g4s.z();
      $this.v9_1.i7(element, true);
    }
    return $this;
  }
  static aa(initialCapacity, loadFactor) {
    return this.w9(InternalHashMap.q8(initialCapacity, loadFactor));
  }
  static ba(initialCapacity) {
    return this.aa(initialCapacity, 1.0);
  }
  o(element) {
    return this.v9_1.i7(element, true) == null;
  }
  o5() {
    this.v9_1.o5();
  }
  j2(element) {
    return this.v9_1.s8(element);
  }
  c1() {
    return this.v9_1.a1() === 0;
  }
  x() {
    return this.v9_1.a9();
  }
  w2(element) {
    return !(this.v9_1.j7(element) == null);
  }
  a1() {
    return this.v9_1.a1();
  }
}
class Companion_5 {
  constructor() {
    this.la_1 = -1640531527;
    this.ma_1 = 8;
    this.na_1 = 2;
    this.oa_1 = -1;
  }
}
class Itr {
  constructor(map) {
    this.pa_1 = map;
    this.qa_1 = 0;
    this.ra_1 = -1;
    this.sa_1 = this.pa_1.l8_1;
    this.ta();
  }
  ta() {
    while (this.qa_1 < this.pa_1.j8_1 && this.pa_1.g8_1[this.qa_1] < 0) {
      this.qa_1 = this.qa_1 + 1 | 0;
    }
  }
  y() {
    return this.qa_1 < this.pa_1.j8_1;
  }
  n5() {
    this.ua();
    // Inline function 'kotlin.check' call
    if (!!(this.ra_1 === -1)) {
      // Inline function 'kotlin.collections.Itr.remove.<anonymous>' call
      var message = 'Call next() before removing element from the iterator.';
      throw IllegalStateException.n4(toString_1(message));
    }
    this.pa_1.b9();
    removeEntryAt(this.pa_1, this.ra_1);
    this.ra_1 = -1;
    this.sa_1 = this.pa_1.l8_1;
  }
  ua() {
    if (!(this.pa_1.l8_1 === this.sa_1))
      throw ConcurrentModificationException.va();
  }
}
class KeysItr extends Itr {
  z() {
    this.ua();
    if (this.qa_1 >= this.pa_1.j8_1)
      throw NoSuchElementException.s5();
    var tmp = this;
    var _unary__edvuaz = this.qa_1;
    this.qa_1 = _unary__edvuaz + 1 | 0;
    tmp.ra_1 = _unary__edvuaz;
    var result = this.pa_1.e8_1[this.ra_1];
    this.ta();
    return result;
  }
}
class ValuesItr extends Itr {
  z() {
    this.ua();
    if (this.qa_1 >= this.pa_1.j8_1)
      throw NoSuchElementException.s5();
    var tmp = this;
    var _unary__edvuaz = this.qa_1;
    this.qa_1 = _unary__edvuaz + 1 | 0;
    tmp.ra_1 = _unary__edvuaz;
    var result = ensureNotNull(this.pa_1.f8_1)[this.ra_1];
    this.ta();
    return result;
  }
}
class EntriesItr extends Itr {
  z() {
    this.ua();
    if (this.qa_1 >= this.pa_1.j8_1)
      throw NoSuchElementException.s5();
    var tmp = this;
    var _unary__edvuaz = this.qa_1;
    this.qa_1 = _unary__edvuaz + 1 | 0;
    tmp.ra_1 = _unary__edvuaz;
    var result = new EntryRef(this.pa_1, this.ra_1);
    this.ta();
    return result;
  }
  ib() {
    if (this.qa_1 >= this.pa_1.j8_1)
      throw NoSuchElementException.s5();
    var tmp = this;
    var _unary__edvuaz = this.qa_1;
    this.qa_1 = _unary__edvuaz + 1 | 0;
    tmp.ra_1 = _unary__edvuaz;
    // Inline function 'kotlin.hashCode' call
    var tmp0_safe_receiver = this.pa_1.e8_1[this.ra_1];
    var tmp1_elvis_lhs = tmp0_safe_receiver == null ? null : hashCode(tmp0_safe_receiver);
    var tmp_0 = tmp1_elvis_lhs == null ? 0 : tmp1_elvis_lhs;
    // Inline function 'kotlin.hashCode' call
    var tmp0_safe_receiver_0 = ensureNotNull(this.pa_1.f8_1)[this.ra_1];
    var tmp1_elvis_lhs_0 = tmp0_safe_receiver_0 == null ? null : hashCode(tmp0_safe_receiver_0);
    var result = tmp_0 ^ (tmp1_elvis_lhs_0 == null ? 0 : tmp1_elvis_lhs_0);
    this.ta();
    return result;
  }
  jb(sb) {
    if (this.qa_1 >= this.pa_1.j8_1)
      throw NoSuchElementException.s5();
    var tmp = this;
    var _unary__edvuaz = this.qa_1;
    this.qa_1 = _unary__edvuaz + 1 | 0;
    tmp.ra_1 = _unary__edvuaz;
    var key = this.pa_1.e8_1[this.ra_1];
    if (equals(key, this.pa_1))
      sb.lb('(this Map)');
    else
      sb.kb(key);
    sb.mb(_Char___init__impl__6a9atx(61));
    var value = ensureNotNull(this.pa_1.f8_1)[this.ra_1];
    if (equals(value, this.pa_1))
      sb.lb('(this Map)');
    else
      sb.kb(value);
    this.ta();
  }
}
class EntryRef {
  constructor(map, index) {
    this.ga_1 = map;
    this.ha_1 = index;
    this.ia_1 = this.ga_1.l8_1;
  }
  q2() {
    checkForComodification(this);
    return this.ga_1.e8_1[this.ha_1];
  }
  r2() {
    checkForComodification(this);
    return ensureNotNull(this.ga_1.f8_1)[this.ha_1];
  }
  equals(other) {
    var tmp;
    var tmp_0;
    if (!(other == null) ? isInterface(other, Entry) : false) {
      tmp_0 = equals(other.q2(), this.q2());
    } else {
      tmp_0 = false;
    }
    if (tmp_0) {
      tmp = equals(other.r2(), this.r2());
    } else {
      tmp = false;
    }
    return tmp;
  }
  hashCode() {
    // Inline function 'kotlin.hashCode' call
    var tmp0_safe_receiver = this.q2();
    var tmp1_elvis_lhs = tmp0_safe_receiver == null ? null : hashCode(tmp0_safe_receiver);
    var tmp = tmp1_elvis_lhs == null ? 0 : tmp1_elvis_lhs;
    // Inline function 'kotlin.hashCode' call
    var tmp0_safe_receiver_0 = this.r2();
    var tmp1_elvis_lhs_0 = tmp0_safe_receiver_0 == null ? null : hashCode(tmp0_safe_receiver_0);
    return tmp ^ (tmp1_elvis_lhs_0 == null ? 0 : tmp1_elvis_lhs_0);
  }
  toString() {
    return toString_0(this.q2()) + '=' + toString_0(this.r2());
  }
}
class InternalMap {}
function containsAllEntries(m) {
  var tmp$ret$0;
  $l$block_0: {
    // Inline function 'kotlin.collections.all' call
    var tmp;
    if (isInterface(m, Collection)) {
      tmp = m.c1();
    } else {
      tmp = false;
    }
    if (tmp) {
      tmp$ret$0 = true;
      break $l$block_0;
    }
    var _iterator__ex2g4s = m.x();
    while (_iterator__ex2g4s.y()) {
      var element = _iterator__ex2g4s.z();
      // Inline function 'kotlin.collections.InternalMap.containsAllEntries.<anonymous>' call
      // Inline function 'kotlin.js.unsafeCast' call
      // Inline function 'kotlin.js.asDynamic' call
      var entry = element;
      var tmp_0;
      if (!(entry == null) ? isInterface(entry, Entry) : false) {
        tmp_0 = this.qb(entry);
      } else {
        tmp_0 = false;
      }
      if (!tmp_0) {
        tmp$ret$0 = false;
        break $l$block_0;
      }
    }
    tmp$ret$0 = true;
  }
  return tmp$ret$0;
}
class InternalHashMap {
  static nb(keysArray, valuesArray, presenceArray, hashArray, maxProbeDistance, length) {
    var $this = createThis(this);
    $this.e8_1 = keysArray;
    $this.f8_1 = valuesArray;
    $this.g8_1 = presenceArray;
    $this.h8_1 = hashArray;
    $this.i8_1 = maxProbeDistance;
    $this.j8_1 = length;
    $this.k8_1 = computeShift(Companion_instance_5, _get_hashSize__tftcho($this));
    $this.l8_1 = 0;
    $this.m8_1 = 0;
    $this.n8_1 = false;
    return $this;
  }
  a1() {
    return this.m8_1;
  }
  static o8() {
    return this.z9(8);
  }
  static z9(initialCapacity) {
    return this.nb(arrayOfUninitializedElements(initialCapacity), null, new Int32Array(initialCapacity), new Int32Array(computeHashSize(Companion_instance_5, initialCapacity)), 2, 0);
  }
  static q8(initialCapacity, loadFactor) {
    var $this = this.z9(initialCapacity);
    // Inline function 'kotlin.require' call
    if (!(loadFactor > 0)) {
      // Inline function 'kotlin.collections.InternalHashMap.<init>.<anonymous>' call
      var message = 'Non-positive load factor: ' + loadFactor;
      throw IllegalArgumentException.h(toString_1(message));
    }
    return $this;
  }
  ob() {
    this.b9();
    this.n8_1 = true;
  }
  t2(value) {
    return findValue(this, value) >= 0;
  }
  u2(key) {
    var index = findKey(this, key);
    if (index < 0)
      return null;
    return ensureNotNull(this.f8_1)[index];
  }
  s8(key) {
    return findKey(this, key) >= 0;
  }
  i7(key, value) {
    var index = addKey(this, key);
    var valuesArray = allocateValuesArray(this);
    if (index < 0) {
      var oldValue = valuesArray[(-index | 0) - 1 | 0];
      valuesArray[(-index | 0) - 1 | 0] = value;
      return oldValue;
    } else {
      valuesArray[index] = value;
      return null;
    }
  }
  j7(key) {
    this.b9();
    var index = findKey(this, key);
    if (index < 0)
      return null;
    var oldValue = ensureNotNull(this.f8_1)[index];
    removeEntryAt(this, index);
    return oldValue;
  }
  o5() {
    this.b9();
    var inductionVariable = 0;
    var last = this.j8_1 - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var hash = this.g8_1[i];
        if (hash >= 0) {
          this.h8_1[hash] = 0;
          this.g8_1[i] = -1;
        }
      }
       while (!(i === last));
    resetRange(this.e8_1, 0, this.j8_1);
    var tmp0_safe_receiver = this.f8_1;
    if (tmp0_safe_receiver == null)
      null;
    else {
      resetRange(tmp0_safe_receiver, 0, this.j8_1);
    }
    this.m8_1 = 0;
    this.j8_1 = 0;
    registerModification(this);
  }
  equals(other) {
    var tmp;
    if (other === this) {
      tmp = true;
    } else {
      var tmp_0;
      if (!(other == null) ? isInterface(other, KtMap) : false) {
        tmp_0 = contentEquals_1(this, other);
      } else {
        tmp_0 = false;
      }
      tmp = tmp_0;
    }
    return tmp;
  }
  hashCode() {
    var result = 0;
    var it = this.k9();
    while (it.y()) {
      result = result + it.ib() | 0;
    }
    return result;
  }
  toString() {
    var sb = StringBuilder.pb(2 + imul_0(this.m8_1, 3) | 0);
    sb.lb('{');
    var i = 0;
    var it = this.k9();
    while (it.y()) {
      if (i > 0) {
        sb.lb(', ');
      }
      it.jb(sb);
      i = i + 1 | 0;
    }
    sb.lb('}');
    return sb.toString();
  }
  b9() {
    if (this.n8_1)
      throw UnsupportedOperationException.h4();
  }
  z8(key) {
    this.b9();
    var index = findKey(this, key);
    if (index < 0)
      return false;
    removeEntryAt(this, index);
    return true;
  }
  o9(entry) {
    var index = findKey(this, entry.q2());
    if (index < 0)
      return false;
    return equals(ensureNotNull(this.f8_1)[index], entry.r2());
  }
  qb(entry) {
    return this.o9(isInterface(entry, Entry) ? entry : THROW_CCE());
  }
  p9(entry) {
    this.b9();
    var index = findKey(this, entry.q2());
    if (index < 0)
      return false;
    if (!equals(ensureNotNull(this.f8_1)[index], entry.r2()))
      return false;
    removeEntryAt(this, index);
    return true;
  }
  h9(value) {
    this.b9();
    var index = findValue(this, value);
    if (index < 0)
      return false;
    removeEntryAt(this, index);
    return true;
  }
  a9() {
    return new KeysItr(this);
  }
  f9() {
    return new ValuesItr(this);
  }
  k9() {
    return new EntriesItr(this);
  }
}
class EmptyHolder {
  constructor() {
    EmptyHolder_instance = this;
    var tmp = this;
    // Inline function 'kotlin.also' call
    var this_0 = InternalHashMap.z9(0);
    // Inline function 'kotlin.collections.EmptyHolder.value.<anonymous>' call
    this_0.ob();
    tmp.rb_1 = LinkedHashSet.sb(this_0);
  }
}
class LinkedHashSet extends HashSet {
  static d1() {
    var $this = this.x9();
    init_kotlin_collections_LinkedHashSet($this);
    return $this;
  }
  static f1(elements) {
    var $this = this.y9(elements);
    init_kotlin_collections_LinkedHashSet($this);
    return $this;
  }
  static tb(initialCapacity, loadFactor) {
    var $this = this.aa(initialCapacity, loadFactor);
    init_kotlin_collections_LinkedHashSet($this);
    return $this;
  }
  static n(initialCapacity) {
    return this.tb(initialCapacity, 1.0);
  }
  static sb(internalMap) {
    var $this = this.w9(internalMap);
    init_kotlin_collections_LinkedHashSet($this);
    return $this;
  }
  j4() {
    this.v9_1.ob();
    return this.a1() > 0 ? this : EmptyHolder_getInstance().rb_1;
  }
  m5() {
    return this.v9_1.b9();
  }
}
class BaseOutput {
  ub() {
    this.vb('\n');
  }
  wb(message) {
    this.vb(message);
    this.ub();
  }
}
class NodeJsOutput extends BaseOutput {
  constructor(outputStream) {
    super();
    this.xb_1 = outputStream;
  }
  vb(message) {
    // Inline function 'kotlin.io.String' call
    var tmp1_elvis_lhs = message == null ? null : toString_1(message);
    var messageString = tmp1_elvis_lhs == null ? 'null' : tmp1_elvis_lhs;
    this.xb_1.write(messageString);
  }
}
class BufferedOutput extends BaseOutput {
  constructor() {
    super();
    this.zb_1 = '';
  }
  vb(message) {
    var tmp = this;
    var tmp_0 = this.zb_1;
    // Inline function 'kotlin.io.String' call
    var tmp1_elvis_lhs = message == null ? null : toString_1(message);
    tmp.zb_1 = tmp_0 + (tmp1_elvis_lhs == null ? 'null' : tmp1_elvis_lhs);
  }
}
class BufferedOutputToConsoleLog extends BufferedOutput {
  vb(message) {
    // Inline function 'kotlin.io.String' call
    var tmp1_elvis_lhs = message == null ? null : toString_1(message);
    var s = tmp1_elvis_lhs == null ? 'null' : tmp1_elvis_lhs;
    // Inline function 'kotlin.text.nativeLastIndexOf' call
    // Inline function 'kotlin.js.asDynamic' call
    var i = s.lastIndexOf('\n', 0);
    if (i >= 0) {
      var tmp = this;
      var tmp_0 = this.zb_1;
      // Inline function 'kotlin.text.substring' call
      // Inline function 'kotlin.js.asDynamic' call
      tmp.zb_1 = tmp_0 + s.substring(0, i);
      this.ac();
      var tmp6 = s;
      // Inline function 'kotlin.text.substring' call
      var startIndex = i + 1 | 0;
      // Inline function 'kotlin.js.asDynamic' call
      s = tmp6.substring(startIndex);
    }
    this.zb_1 = this.zb_1 + s;
  }
  ac() {
    console.log(this.zb_1);
    this.zb_1 = '';
  }
}
class InterceptedCoroutine {
  cc() {
    var tmp0_elvis_lhs = this.bc_1;
    var tmp;
    if (tmp0_elvis_lhs == null) {
      var tmp1_safe_receiver = this.dc().ec(Key_instance);
      var tmp2_elvis_lhs = tmp1_safe_receiver == null ? null : tmp1_safe_receiver.fc(this);
      // Inline function 'kotlin.also' call
      var this_0 = tmp2_elvis_lhs == null ? this : tmp2_elvis_lhs;
      // Inline function 'kotlin.coroutines.InterceptedCoroutine.intercepted.<anonymous>' call
      this.bc_1 = this_0;
      tmp = this_0;
    } else {
      tmp = tmp0_elvis_lhs;
    }
    return tmp;
  }
}
class IllegalStateException extends RuntimeException {
  static lc() {
    var $this = this.u1();
    init_kotlin_IllegalStateException($this);
    return $this;
  }
  static n4(message) {
    var $this = this.ja(message);
    init_kotlin_IllegalStateException($this);
    return $this;
  }
}
class CancellationException extends IllegalStateException {
  static kc() {
    var $this = this.lc();
    init_kotlin_coroutines_cancellation_CancellationException($this);
    return $this;
  }
  static mc(message) {
    var $this = this.n4(message);
    init_kotlin_coroutines_cancellation_CancellationException($this);
    return $this;
  }
}
class IllegalArgumentException extends RuntimeException {
  static qc() {
    var $this = this.u1();
    init_kotlin_IllegalArgumentException($this);
    return $this;
  }
  static h(message) {
    var $this = this.ja(message);
    init_kotlin_IllegalArgumentException($this);
    return $this;
  }
}
class UnsupportedOperationException extends RuntimeException {
  static h4() {
    var $this = this.u1();
    init_kotlin_UnsupportedOperationException($this);
    return $this;
  }
  static t9(message) {
    var $this = this.ja(message);
    init_kotlin_UnsupportedOperationException($this);
    return $this;
  }
}
class NoSuchElementException extends RuntimeException {
  static s5() {
    var $this = this.u1();
    init_kotlin_NoSuchElementException($this);
    return $this;
  }
  static s(message) {
    var $this = this.ja(message);
    init_kotlin_NoSuchElementException($this);
    return $this;
  }
}
class Error_0 extends Error {
  static uc() {
    var $this = createThis(this);
    init_kotlin_Error($this);
    setPropertiesToThrowableInstance($this);
    return $this;
  }
  static vc(message) {
    var $this = createThis(this);
    init_kotlin_Error($this);
    setPropertiesToThrowableInstance($this, message);
    return $this;
  }
  static wc(message, cause) {
    var $this = createThis(this);
    init_kotlin_Error($this);
    setPropertiesToThrowableInstance($this, message, cause);
    return $this;
  }
}
class IndexOutOfBoundsException extends RuntimeException {
  static ad() {
    var $this = this.u1();
    init_kotlin_IndexOutOfBoundsException($this);
    return $this;
  }
  static bd(message) {
    var $this = this.ja(message);
    init_kotlin_IndexOutOfBoundsException($this);
    return $this;
  }
}
class NumberFormatException extends IllegalArgumentException {
  static gd() {
    var $this = this.qc();
    init_kotlin_NumberFormatException($this);
    return $this;
  }
  static hd(message) {
    var $this = this.h(message);
    init_kotlin_NumberFormatException($this);
    return $this;
  }
}
class ArithmeticException extends RuntimeException {
  static ld() {
    var $this = this.u1();
    init_kotlin_ArithmeticException($this);
    return $this;
  }
  static md(message) {
    var $this = this.ja(message);
    init_kotlin_ArithmeticException($this);
    return $this;
  }
}
class AssertionError extends Error_0 {
  static pd() {
    var $this = this.uc();
    init_kotlin_AssertionError($this);
    return $this;
  }
  static qd(message) {
    var $this = this.vc(message);
    init_kotlin_AssertionError($this);
    return $this;
  }
}
class ConcurrentModificationException extends RuntimeException {
  static va() {
    var $this = this.u1();
    init_kotlin_ConcurrentModificationException($this);
    return $this;
  }
  static fa(message) {
    var $this = this.ja(message);
    init_kotlin_ConcurrentModificationException($this);
    return $this;
  }
}
class ClassCastException extends RuntimeException {
  static z4() {
    var $this = this.u1();
    init_kotlin_ClassCastException($this);
    return $this;
  }
}
class NullPointerException extends RuntimeException {
  static r4() {
    var $this = this.u1();
    init_kotlin_NullPointerException($this);
    return $this;
  }
  static rd(message) {
    var $this = this.ja(message);
    init_kotlin_NullPointerException($this);
    return $this;
  }
}
class NoWhenBranchMatchedException extends RuntimeException {
  static v4() {
    var $this = this.u1();
    init_kotlin_NoWhenBranchMatchedException($this);
    return $this;
  }
}
class UninitializedPropertyAccessException extends RuntimeException {
  static sd() {
    var $this = this.u1();
    init_kotlin_UninitializedPropertyAccessException($this);
    return $this;
  }
  static d5(message) {
    var $this = this.ja(message);
    init_kotlin_UninitializedPropertyAccessException($this);
    return $this;
  }
}
class KClass {}
class KClassImpl {
  constructor(jClass) {
    this.ud_1 = jClass;
  }
  vd() {
    return this.ud_1;
  }
  equals(other) {
    var tmp;
    if (other instanceof NothingKClassImpl) {
      tmp = false;
    } else {
      if (other instanceof ErrorKClass) {
        tmp = false;
      } else {
        if (other instanceof KClassImpl) {
          tmp = equals(this.vd(), other.vd());
        } else {
          tmp = false;
        }
      }
    }
    return tmp;
  }
  hashCode() {
    var tmp0_safe_receiver = this.td();
    var tmp1_elvis_lhs = tmp0_safe_receiver == null ? null : getStringHashCode(tmp0_safe_receiver);
    return tmp1_elvis_lhs == null ? 0 : tmp1_elvis_lhs;
  }
  toString() {
    return 'class ' + this.td();
  }
}
class NothingKClassImpl extends KClassImpl {
  constructor() {
    NothingKClassImpl_instance = null;
    super(Object);
    NothingKClassImpl_instance = this;
    this.xd_1 = 'Nothing';
  }
  td() {
    return this.xd_1;
  }
  vd() {
    throw UnsupportedOperationException.t9("There's no native JS class for Nothing type");
  }
  equals(other) {
    return other === this;
  }
  hashCode() {
    return 0;
  }
}
class ErrorKClass {
  td() {
    var message = 'Unknown simpleName for ErrorKClass';
    throw IllegalStateException.n4(toString_1(message));
  }
  equals(other) {
    return other === this;
  }
  hashCode() {
    return 0;
  }
}
class PrimitiveKClassImpl extends KClassImpl {
  constructor(jClass, givenSimpleName, isInstanceFunction) {
    super(jClass);
    this.zd_1 = givenSimpleName;
    this.ae_1 = isInstanceFunction;
  }
  equals(other) {
    if (!(other instanceof PrimitiveKClassImpl))
      return false;
    return super.equals(other) && this.zd_1 === other.zd_1;
  }
  td() {
    return this.zd_1;
  }
}
class SimpleKClassImpl extends KClassImpl {
  constructor(jClass) {
    super(jClass);
    var tmp = this;
    // Inline function 'kotlin.js.asDynamic' call
    var tmp0_safe_receiver = jClass.$metadata$;
    // Inline function 'kotlin.js.unsafeCast' call
    tmp.ce_1 = tmp0_safe_receiver == null ? null : tmp0_safe_receiver.simpleName;
  }
  td() {
    return this.ce_1;
  }
}
class KProperty1 {}
class KMutableProperty1 {}
class PrimitiveClasses {
  constructor() {
    PrimitiveClasses_instance = this;
    var tmp = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_0 = Object;
    tmp.anyClass = new PrimitiveKClassImpl(tmp_0, 'Any', PrimitiveClasses$anyClass$lambda);
    var tmp_1 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_2 = Number;
    tmp_1.numberClass = new PrimitiveKClassImpl(tmp_2, 'Number', PrimitiveClasses$numberClass$lambda);
    this.nothingClass = NothingKClassImpl_getInstance();
    var tmp_3 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_4 = Boolean;
    tmp_3.booleanClass = new PrimitiveKClassImpl(tmp_4, 'Boolean', PrimitiveClasses$booleanClass$lambda);
    var tmp_5 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_6 = Number;
    tmp_5.byteClass = new PrimitiveKClassImpl(tmp_6, 'Byte', PrimitiveClasses$byteClass$lambda);
    var tmp_7 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_8 = Number;
    tmp_7.shortClass = new PrimitiveKClassImpl(tmp_8, 'Short', PrimitiveClasses$shortClass$lambda);
    var tmp_9 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_10 = Number;
    tmp_9.intClass = new PrimitiveKClassImpl(tmp_10, 'Int', PrimitiveClasses$intClass$lambda);
    var tmp_11 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_12 = Number;
    tmp_11.floatClass = new PrimitiveKClassImpl(tmp_12, 'Float', PrimitiveClasses$floatClass$lambda);
    var tmp_13 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_14 = Number;
    tmp_13.doubleClass = new PrimitiveKClassImpl(tmp_14, 'Double', PrimitiveClasses$doubleClass$lambda);
    var tmp_15 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_16 = Array;
    tmp_15.arrayClass = new PrimitiveKClassImpl(tmp_16, 'Array', PrimitiveClasses$arrayClass$lambda);
    var tmp_17 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_18 = String;
    tmp_17.stringClass = new PrimitiveKClassImpl(tmp_18, 'String', PrimitiveClasses$stringClass$lambda);
    var tmp_19 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_20 = Error;
    tmp_19.throwableClass = new PrimitiveKClassImpl(tmp_20, 'Throwable', PrimitiveClasses$throwableClass$lambda);
    var tmp_21 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_22 = Array;
    tmp_21.booleanArrayClass = new PrimitiveKClassImpl(tmp_22, 'BooleanArray', PrimitiveClasses$booleanArrayClass$lambda);
    var tmp_23 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_24 = Uint16Array;
    tmp_23.charArrayClass = new PrimitiveKClassImpl(tmp_24, 'CharArray', PrimitiveClasses$charArrayClass$lambda);
    var tmp_25 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_26 = Int8Array;
    tmp_25.byteArrayClass = new PrimitiveKClassImpl(tmp_26, 'ByteArray', PrimitiveClasses$byteArrayClass$lambda);
    var tmp_27 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_28 = Int16Array;
    tmp_27.shortArrayClass = new PrimitiveKClassImpl(tmp_28, 'ShortArray', PrimitiveClasses$shortArrayClass$lambda);
    var tmp_29 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_30 = Int32Array;
    tmp_29.intArrayClass = new PrimitiveKClassImpl(tmp_30, 'IntArray', PrimitiveClasses$intArrayClass$lambda);
    var tmp_31 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_32 = Array;
    tmp_31.longArrayClass = new PrimitiveKClassImpl(tmp_32, 'LongArray', PrimitiveClasses$longArrayClass$lambda);
    var tmp_33 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_34 = Float32Array;
    tmp_33.floatArrayClass = new PrimitiveKClassImpl(tmp_34, 'FloatArray', PrimitiveClasses$floatArrayClass$lambda);
    var tmp_35 = this;
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp_36 = Float64Array;
    tmp_35.doubleArrayClass = new PrimitiveKClassImpl(tmp_36, 'DoubleArray', PrimitiveClasses$doubleArrayClass$lambda);
  }
  de() {
    return this.anyClass;
  }
  ee() {
    return this.numberClass;
  }
  fe() {
    return this.nothingClass;
  }
  ge() {
    return this.booleanClass;
  }
  he() {
    return this.byteClass;
  }
  ie() {
    return this.shortClass;
  }
  je() {
    return this.intClass;
  }
  ke() {
    return this.floatClass;
  }
  le() {
    return this.doubleClass;
  }
  me() {
    return this.arrayClass;
  }
  ne() {
    return this.stringClass;
  }
  oe() {
    return this.throwableClass;
  }
  pe() {
    return this.booleanArrayClass;
  }
  qe() {
    return this.charArrayClass;
  }
  re() {
    return this.byteArrayClass;
  }
  se() {
    return this.shortArrayClass;
  }
  te() {
    return this.intArrayClass;
  }
  ue() {
    return this.longArrayClass;
  }
  ve() {
    return this.floatArrayClass;
  }
  we() {
    return this.doubleArrayClass;
  }
  functionClass(arity) {
    var tmp0_elvis_lhs = get_functionClasses()[arity];
    var tmp;
    if (tmp0_elvis_lhs == null) {
      // Inline function 'kotlin.run' call
      // Inline function 'kotlin.reflect.js.internal.PrimitiveClasses.functionClass.<anonymous>' call
      // Inline function 'kotlin.js.unsafeCast' call
      var tmp_0 = Function;
      var tmp_1 = 'Function' + arity;
      var result = new PrimitiveKClassImpl(tmp_0, tmp_1, PrimitiveClasses$functionClass$lambda(arity));
      // Inline function 'kotlin.js.asDynamic' call
      get_functionClasses()[arity] = result;
      tmp = result;
    } else {
      tmp = tmp0_elvis_lhs;
    }
    return tmp;
  }
}
class ConstrainedOnceSequence {
  constructor(sequence) {
    this.xe_1 = sequence;
  }
  x() {
    var tmp0_elvis_lhs = this.xe_1;
    var tmp;
    if (tmp0_elvis_lhs == null) {
      throw IllegalStateException.n4('This sequence can be consumed only once.');
    } else {
      tmp = tmp0_elvis_lhs;
    }
    var sequence = tmp;
    this.xe_1 = null;
    return sequence.x();
  }
}
class StringBuilder {
  static ye(content) {
    var $this = createThis(this);
    $this.t_1 = content;
    return $this;
  }
  static pb(capacity) {
    return this.u();
  }
  static ze(content) {
    return this.ye(toString_1(content));
  }
  static u() {
    return this.ye('');
  }
  a() {
    // Inline function 'kotlin.js.asDynamic' call
    return this.t_1.length;
  }
  b(index) {
    // Inline function 'kotlin.text.getOrElse' call
    var this_0 = this.t_1;
    var tmp;
    if (0 <= index ? index <= (charSequenceLength(this_0) - 1 | 0) : false) {
      tmp = charSequenceGet(this_0, index);
    } else {
      throw IndexOutOfBoundsException.bd('index: ' + index + ', length: ' + this.a() + '}');
    }
    return tmp;
  }
  c(startIndex, endIndex) {
    // Inline function 'kotlin.text.substring' call
    // Inline function 'kotlin.js.asDynamic' call
    return this.t_1.substring(startIndex, endIndex);
  }
  mb(value) {
    this.t_1 = this.t_1 + toString(value);
    return this;
  }
  v(value) {
    this.t_1 = this.t_1 + toString_0(value);
    return this;
  }
  kb(value) {
    this.t_1 = this.t_1 + toString_0(value);
    return this;
  }
  af(value) {
    return this.lb(value.toString());
  }
  lb(value) {
    var tmp = this;
    var tmp_0 = this.t_1;
    tmp.t_1 = tmp_0 + (value == null ? 'null' : value);
    return this;
  }
  toString() {
    return this.t_1;
  }
  bf(value, startIndex, endIndex) {
    var stringCsq = toString_1(value);
    Companion_instance_7.cf(startIndex, endIndex, stringCsq.length);
    var tmp = this;
    var tmp_0 = this.t_1;
    // Inline function 'kotlin.text.substring' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp.t_1 = tmp_0 + stringCsq.substring(startIndex, endIndex);
    return this;
  }
}
class Companion_6 {
  constructor() {
    Companion_instance_6 = this;
    this.df_1 = new RegExp('[\\\\^$*+?.()|[\\]{}]', 'g');
    this.ef_1 = new RegExp('[\\\\$]', 'g');
    this.ff_1 = new RegExp('\\$', 'g');
  }
  gf(literal) {
    // Inline function 'kotlin.text.nativeReplace' call
    var pattern = this.df_1;
    // Inline function 'kotlin.js.asDynamic' call
    return literal.replace(pattern, '\\$&');
  }
  hf(literal) {
    // Inline function 'kotlin.text.nativeReplace' call
    var pattern = this.ff_1;
    // Inline function 'kotlin.js.asDynamic' call
    return literal.replace(pattern, '$$$$');
  }
}
class sam$kotlin_Comparator$0 {
  constructor(function_0) {
    this.if_1 = function_0;
  }
  jf(a, b) {
    return this.if_1(a, b);
  }
  compare(a, b) {
    return this.jf(a, b);
  }
  b4() {
    return this.if_1;
  }
  equals(other) {
    var tmp;
    if (!(other == null) ? isInterface(other, Comparator) : false) {
      var tmp_0;
      if (!(other == null) ? isInterface(other, FunctionAdapter) : false) {
        tmp_0 = equals(this.b4(), other.b4());
      } else {
        tmp_0 = false;
      }
      tmp = tmp_0;
    } else {
      tmp = false;
    }
    return tmp;
  }
  hashCode() {
    return hashCode(this.b4());
  }
}
class ExceptionTraceBuilder {
  constructor() {
    this.kf_1 = StringBuilder.u();
    var tmp = this;
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp.lf_1 = [];
    this.mf_1 = '';
    this.nf_1 = 0;
  }
  of(exception) {
    dumpFullTrace(exception, this, '', '');
    return this.kf_1.toString();
  }
}
class AbstractList extends AbstractCollection {
  static tf() {
    return this.l5();
  }
  x() {
    return new IteratorImpl_0(this);
  }
  l2(element) {
    var tmp$ret$1;
    $l$block: {
      // Inline function 'kotlin.collections.indexOfFirst' call
      var index = 0;
      var _iterator__ex2g4s = this.x();
      while (_iterator__ex2g4s.y()) {
        var item = _iterator__ex2g4s.z();
        // Inline function 'kotlin.collections.AbstractList.indexOf.<anonymous>' call
        if (equals(item, element)) {
          tmp$ret$1 = index;
          break $l$block;
        }
        index = index + 1 | 0;
      }
      tmp$ret$1 = -1;
    }
    return tmp$ret$1;
  }
  m2(element) {
    var tmp$ret$1;
    $l$block: {
      // Inline function 'kotlin.collections.indexOfLast' call
      var iterator = this.o2(this.a1());
      while (iterator.a6()) {
        // Inline function 'kotlin.collections.AbstractList.lastIndexOf.<anonymous>' call
        var it = iterator.c6();
        if (equals(it, element)) {
          tmp$ret$1 = iterator.b6();
          break $l$block;
        }
      }
      tmp$ret$1 = -1;
    }
    return tmp$ret$1;
  }
  n2() {
    return new ListIteratorImpl_0(this, 0);
  }
  o2(index) {
    return new ListIteratorImpl_0(this, index);
  }
  p2(fromIndex, toIndex) {
    return SubList_0.sf(this, fromIndex, toIndex);
  }
  equals(other) {
    if (other === this)
      return true;
    if (!(!(other == null) ? isInterface(other, KtList_0) : false))
      return false;
    return Companion_instance_7.q6(this, other);
  }
  hashCode() {
    return Companion_instance_7.r6(this);
  }
}
class SubList_0 extends AbstractList {
  static sf(list, fromIndex, toIndex) {
    var $this = this.tf();
    $this.pf_1 = list;
    $this.qf_1 = fromIndex;
    $this.rf_1 = 0;
    Companion_instance_7.h5($this.qf_1, toIndex, $this.pf_1.a1());
    $this.rf_1 = toIndex - $this.qf_1 | 0;
    return $this;
  }
  b1(index) {
    Companion_instance_7.k6(index, this.rf_1);
    return this.pf_1.b1(this.qf_1 + index | 0);
  }
  a1() {
    return this.rf_1;
  }
}
class IteratorImpl_0 {
  constructor($outer, $box) {
    boxApply(this, $box);
    this.vf_1 = $outer;
    this.uf_1 = 0;
  }
  y() {
    return this.uf_1 < this.vf_1.a1();
  }
  z() {
    if (!this.y())
      throw NoSuchElementException.s5();
    var _unary__edvuaz = this.uf_1;
    this.uf_1 = _unary__edvuaz + 1 | 0;
    return this.vf_1.b1(_unary__edvuaz);
  }
}
class ListIteratorImpl_0 extends IteratorImpl_0 {
  constructor($outer, index, $box) {
    if ($box === VOID)
      $box = {};
    $box.yf_1 = $outer;
    super($outer, $box);
    Companion_instance_7.z5(index, this.yf_1.a1());
    this.uf_1 = index;
  }
  a6() {
    return this.uf_1 > 0;
  }
  b6() {
    return this.uf_1;
  }
  c6() {
    if (!this.a6())
      throw NoSuchElementException.s5();
    this.uf_1 = this.uf_1 - 1 | 0;
    return this.yf_1.b1(this.uf_1);
  }
}
class Companion_7 {
  constructor() {
    this.g5_1 = 2147483639;
  }
  k6(index, size) {
    if (index < 0 || index >= size) {
      throw IndexOutOfBoundsException.bd('index: ' + index + ', size: ' + size);
    }
  }
  z5(index, size) {
    if (index < 0 || index > size) {
      throw IndexOutOfBoundsException.bd('index: ' + index + ', size: ' + size);
    }
  }
  h5(fromIndex, toIndex, size) {
    if (fromIndex < 0 || toIndex > size) {
      throw IndexOutOfBoundsException.bd('fromIndex: ' + fromIndex + ', toIndex: ' + toIndex + ', size: ' + size);
    }
    if (fromIndex > toIndex) {
      throw IllegalArgumentException.h('fromIndex: ' + fromIndex + ' > toIndex: ' + toIndex);
    }
  }
  cf(startIndex, endIndex, size) {
    if (startIndex < 0 || endIndex > size) {
      throw IndexOutOfBoundsException.bd('startIndex: ' + startIndex + ', endIndex: ' + endIndex + ', size: ' + size);
    }
    if (startIndex > endIndex) {
      throw IllegalArgumentException.h('startIndex: ' + startIndex + ' > endIndex: ' + endIndex);
    }
  }
  ka(oldCapacity, minCapacity) {
    var newCapacity = oldCapacity + (oldCapacity >> 1) | 0;
    if ((newCapacity - minCapacity | 0) < 0)
      newCapacity = minCapacity;
    if ((newCapacity - 2147483639 | 0) > 0)
      newCapacity = minCapacity > 2147483639 ? 2147483647 : 2147483639;
    return newCapacity;
  }
  r6(c) {
    var hashCode_0 = 1;
    var _iterator__ex2g4s = c.x();
    while (_iterator__ex2g4s.y()) {
      var e = _iterator__ex2g4s.z();
      var tmp = imul_0(31, hashCode_0);
      var tmp1_elvis_lhs = e == null ? null : hashCode(e);
      hashCode_0 = tmp + (tmp1_elvis_lhs == null ? 0 : tmp1_elvis_lhs) | 0;
    }
    return hashCode_0;
  }
  q6(c, other) {
    if (!(c.a1() === other.a1()))
      return false;
    var otherIterator = other.x();
    var _iterator__ex2g4s = c.x();
    while (_iterator__ex2g4s.y()) {
      var elem = _iterator__ex2g4s.z();
      var elemOther = otherIterator.z();
      if (!equals(elem, elemOther)) {
        return false;
      }
    }
    return true;
  }
}
class Companion_8 {}
class Companion_9 {
  n7(c) {
    var hashCode_0 = 0;
    var _iterator__ex2g4s = c.x();
    while (_iterator__ex2g4s.y()) {
      var element = _iterator__ex2g4s.z();
      var tmp = hashCode_0;
      var tmp1_elvis_lhs = element == null ? null : hashCode(element);
      hashCode_0 = tmp + (tmp1_elvis_lhs == null ? 0 : tmp1_elvis_lhs) | 0;
    }
    return hashCode_0;
  }
  m7(c, other) {
    if (!(c.a1() === other.a1()))
      return false;
    return c.k2(other);
  }
}
class Companion_10 {
  constructor() {
    Companion_instance_10 = this;
    var tmp = this;
    // Inline function 'kotlin.emptyArray' call
    tmp.dg_1 = [];
    this.eg_1 = 10;
  }
}
class ArrayDeque extends AbstractMutableList {
  a1() {
    return this.cg_1;
  }
  static fg() {
    Companion_getInstance_10();
    var $this = this.i6();
    init_kotlin_collections_ArrayDeque($this);
    $this.bg_1 = Companion_getInstance_10().dg_1;
    return $this;
  }
  c1() {
    return this.cg_1 === 0;
  }
  gg(element) {
    registerModification_0(this);
    ensureCapacity_0(this, this.cg_1 + 1 | 0);
    this.ag_1 = decremented(this, this.ag_1);
    this.bg_1[this.ag_1] = element;
    this.cg_1 = this.cg_1 + 1 | 0;
  }
  hg(element) {
    registerModification_0(this);
    ensureCapacity_0(this, this.cg_1 + 1 | 0);
    var tmp = this.bg_1;
    // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
    var index = this.cg_1;
    tmp[positiveMod(this, this.ag_1 + index | 0)] = element;
    this.cg_1 = this.cg_1 + 1 | 0;
  }
  ig() {
    if (this.c1())
      throw NoSuchElementException.s('ArrayDeque is empty.');
    registerModification_0(this);
    // Inline function 'kotlin.collections.ArrayDeque.internalGet' call
    var internalIndex = this.ag_1;
    var tmp = this.bg_1[internalIndex];
    var element = (tmp == null ? true : !(tmp == null)) ? tmp : THROW_CCE();
    this.bg_1[this.ag_1] = null;
    this.ag_1 = incremented(this, this.ag_1);
    this.cg_1 = this.cg_1 - 1 | 0;
    return element;
  }
  jg() {
    return this.c1() ? null : this.ig();
  }
  kg() {
    if (this.c1())
      throw NoSuchElementException.s('ArrayDeque is empty.');
    registerModification_0(this);
    // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
    var index = get_lastIndex_0(this);
    var internalLastIndex = positiveMod(this, this.ag_1 + index | 0);
    // Inline function 'kotlin.collections.ArrayDeque.internalGet' call
    var tmp = this.bg_1[internalLastIndex];
    var element = (tmp == null ? true : !(tmp == null)) ? tmp : THROW_CCE();
    this.bg_1[internalLastIndex] = null;
    this.cg_1 = this.cg_1 - 1 | 0;
    return element;
  }
  o(element) {
    this.hg(element);
    return true;
  }
  j6(index, element) {
    Companion_instance_7.z5(index, this.cg_1);
    if (index === this.cg_1) {
      this.hg(element);
      return Unit_instance;
    } else if (index === 0) {
      this.gg(element);
      return Unit_instance;
    }
    registerModification_0(this);
    ensureCapacity_0(this, this.cg_1 + 1 | 0);
    // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
    var internalIndex = positiveMod(this, this.ag_1 + index | 0);
    if (index < (this.cg_1 + 1 | 0) >> 1) {
      var decrementedInternalIndex = decremented(this, internalIndex);
      var decrementedHead = decremented(this, this.ag_1);
      if (decrementedInternalIndex >= this.ag_1) {
        this.bg_1[decrementedHead] = this.bg_1[this.ag_1];
        var tmp0 = this.bg_1;
        var tmp1 = this.bg_1;
        var tmp2 = this.ag_1;
        var tmp3 = this.ag_1 + 1 | 0;
        // Inline function 'kotlin.collections.copyInto' call
        var endIndex = decrementedInternalIndex + 1 | 0;
        arrayCopy(tmp0, tmp1, tmp2, tmp3, endIndex);
      } else {
        var tmp5 = this.bg_1;
        var tmp6 = this.bg_1;
        var tmp7 = this.ag_1 - 1 | 0;
        var tmp8 = this.ag_1;
        // Inline function 'kotlin.collections.copyInto' call
        var endIndex_0 = this.bg_1.length;
        arrayCopy(tmp5, tmp6, tmp7, tmp8, endIndex_0);
        this.bg_1[this.bg_1.length - 1 | 0] = this.bg_1[0];
        var tmp10 = this.bg_1;
        var tmp11 = this.bg_1;
        // Inline function 'kotlin.collections.copyInto' call
        var endIndex_1 = decrementedInternalIndex + 1 | 0;
        arrayCopy(tmp10, tmp11, 0, 1, endIndex_1);
      }
      this.bg_1[decrementedInternalIndex] = element;
      this.ag_1 = decrementedHead;
    } else {
      // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
      var index_0 = this.cg_1;
      var tail = positiveMod(this, this.ag_1 + index_0 | 0);
      if (internalIndex < tail) {
        var tmp15 = this.bg_1;
        var tmp16 = this.bg_1;
        // Inline function 'kotlin.collections.copyInto' call
        var destinationOffset = internalIndex + 1 | 0;
        arrayCopy(tmp15, tmp16, destinationOffset, internalIndex, tail);
      } else {
        var tmp20 = this.bg_1;
        // Inline function 'kotlin.collections.copyInto' call
        var destination = this.bg_1;
        arrayCopy(tmp20, destination, 1, 0, tail);
        this.bg_1[0] = this.bg_1[this.bg_1.length - 1 | 0];
        var tmp25 = this.bg_1;
        var tmp26 = this.bg_1;
        var tmp27 = internalIndex + 1 | 0;
        // Inline function 'kotlin.collections.copyInto' call
        var endIndex_2 = this.bg_1.length - 1 | 0;
        arrayCopy(tmp25, tmp26, tmp27, internalIndex, endIndex_2);
      }
      this.bg_1[internalIndex] = element;
    }
    this.cg_1 = this.cg_1 + 1 | 0;
  }
  x2(elements) {
    if (elements.c1())
      return false;
    registerModification_0(this);
    ensureCapacity_0(this, this.cg_1 + elements.a1() | 0);
    // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
    var index = this.cg_1;
    var tmp$ret$0 = positiveMod(this, this.ag_1 + index | 0);
    copyCollectionElements(this, tmp$ret$0, elements);
    return true;
  }
  b1(index) {
    Companion_instance_7.k6(index, this.cg_1);
    // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
    // Inline function 'kotlin.collections.ArrayDeque.internalGet' call
    var internalIndex = positiveMod(this, this.ag_1 + index | 0);
    var tmp = this.bg_1[internalIndex];
    return (tmp == null ? true : !(tmp == null)) ? tmp : THROW_CCE();
  }
  j5(index, element) {
    Companion_instance_7.k6(index, this.cg_1);
    // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
    var internalIndex = positiveMod(this, this.ag_1 + index | 0);
    // Inline function 'kotlin.collections.ArrayDeque.internalGet' call
    var tmp = this.bg_1[internalIndex];
    var oldElement = (tmp == null ? true : !(tmp == null)) ? tmp : THROW_CCE();
    this.bg_1[internalIndex] = element;
    return oldElement;
  }
  j2(element) {
    return !(this.l2(element) === -1);
  }
  l2(element) {
    // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
    var index = this.cg_1;
    var tail = positiveMod(this, this.ag_1 + index | 0);
    if (this.ag_1 < tail) {
      var inductionVariable = this.ag_1;
      if (inductionVariable < tail)
        do {
          var index_0 = inductionVariable;
          inductionVariable = inductionVariable + 1 | 0;
          if (equals(element, this.bg_1[index_0]))
            return index_0 - this.ag_1 | 0;
        }
         while (inductionVariable < tail);
    } else if (this.ag_1 >= tail) {
      var inductionVariable_0 = this.ag_1;
      var last = this.bg_1.length;
      if (inductionVariable_0 < last)
        do {
          var index_1 = inductionVariable_0;
          inductionVariable_0 = inductionVariable_0 + 1 | 0;
          if (equals(element, this.bg_1[index_1]))
            return index_1 - this.ag_1 | 0;
        }
         while (inductionVariable_0 < last);
      var inductionVariable_1 = 0;
      if (inductionVariable_1 < tail)
        do {
          var index_2 = inductionVariable_1;
          inductionVariable_1 = inductionVariable_1 + 1 | 0;
          if (equals(element, this.bg_1[index_2]))
            return (index_2 + this.bg_1.length | 0) - this.ag_1 | 0;
        }
         while (inductionVariable_1 < tail);
    }
    return -1;
  }
  m2(element) {
    // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
    var index = this.cg_1;
    var tail = positiveMod(this, this.ag_1 + index | 0);
    if (this.ag_1 < tail) {
      var inductionVariable = tail - 1 | 0;
      var last = this.ag_1;
      if (last <= inductionVariable)
        do {
          var index_0 = inductionVariable;
          inductionVariable = inductionVariable + -1 | 0;
          if (equals(element, this.bg_1[index_0]))
            return index_0 - this.ag_1 | 0;
        }
         while (!(index_0 === last));
    } else if (this.ag_1 > tail) {
      var inductionVariable_0 = tail - 1 | 0;
      if (0 <= inductionVariable_0)
        do {
          var index_1 = inductionVariable_0;
          inductionVariable_0 = inductionVariable_0 + -1 | 0;
          if (equals(element, this.bg_1[index_1]))
            return (index_1 + this.bg_1.length | 0) - this.ag_1 | 0;
        }
         while (0 <= inductionVariable_0);
      var inductionVariable_1 = get_lastIndex(this.bg_1);
      var last_0 = this.ag_1;
      if (last_0 <= inductionVariable_1)
        do {
          var index_2 = inductionVariable_1;
          inductionVariable_1 = inductionVariable_1 + -1 | 0;
          if (equals(element, this.bg_1[index_2]))
            return index_2 - this.ag_1 | 0;
        }
         while (!(index_2 === last_0));
    }
    return -1;
  }
  w2(element) {
    var index = this.l2(element);
    if (index === -1)
      return false;
    this.u5(index);
    return true;
  }
  u5(index) {
    Companion_instance_7.k6(index, this.cg_1);
    if (index === get_lastIndex_0(this)) {
      return this.kg();
    } else if (index === 0) {
      return this.ig();
    }
    registerModification_0(this);
    // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
    var internalIndex = positiveMod(this, this.ag_1 + index | 0);
    // Inline function 'kotlin.collections.ArrayDeque.internalGet' call
    var tmp = this.bg_1[internalIndex];
    var element = (tmp == null ? true : !(tmp == null)) ? tmp : THROW_CCE();
    if (index < this.cg_1 >> 1) {
      if (internalIndex >= this.ag_1) {
        var tmp0 = this.bg_1;
        var tmp1 = this.bg_1;
        var tmp2 = this.ag_1 + 1 | 0;
        // Inline function 'kotlin.collections.copyInto' call
        var startIndex = this.ag_1;
        arrayCopy(tmp0, tmp1, tmp2, startIndex, internalIndex);
      } else {
        var tmp5 = this.bg_1;
        // Inline function 'kotlin.collections.copyInto' call
        var destination = this.bg_1;
        arrayCopy(tmp5, destination, 1, 0, internalIndex);
        this.bg_1[0] = this.bg_1[this.bg_1.length - 1 | 0];
        var tmp10 = this.bg_1;
        var tmp11 = this.bg_1;
        var tmp12 = this.ag_1 + 1 | 0;
        var tmp13 = this.ag_1;
        // Inline function 'kotlin.collections.copyInto' call
        var endIndex = this.bg_1.length - 1 | 0;
        arrayCopy(tmp10, tmp11, tmp12, tmp13, endIndex);
      }
      this.bg_1[this.ag_1] = null;
      this.ag_1 = incremented(this, this.ag_1);
    } else {
      // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
      var index_0 = get_lastIndex_0(this);
      var internalLastIndex = positiveMod(this, this.ag_1 + index_0 | 0);
      if (internalIndex <= internalLastIndex) {
        var tmp15 = this.bg_1;
        var tmp16 = this.bg_1;
        var tmp18 = internalIndex + 1 | 0;
        // Inline function 'kotlin.collections.copyInto' call
        var endIndex_0 = internalLastIndex + 1 | 0;
        arrayCopy(tmp15, tmp16, internalIndex, tmp18, endIndex_0);
      } else {
        var tmp20 = this.bg_1;
        var tmp21 = this.bg_1;
        var tmp23 = internalIndex + 1 | 0;
        // Inline function 'kotlin.collections.copyInto' call
        var endIndex_1 = this.bg_1.length;
        arrayCopy(tmp20, tmp21, internalIndex, tmp23, endIndex_1);
        this.bg_1[this.bg_1.length - 1 | 0] = this.bg_1[0];
        var tmp25 = this.bg_1;
        var tmp26 = this.bg_1;
        // Inline function 'kotlin.collections.copyInto' call
        var endIndex_2 = internalLastIndex + 1 | 0;
        arrayCopy(tmp25, tmp26, 0, 1, endIndex_2);
      }
      this.bg_1[internalLastIndex] = null;
    }
    this.cg_1 = this.cg_1 - 1 | 0;
    return element;
  }
  o5() {
    // Inline function 'kotlin.collections.isNotEmpty' call
    if (!this.c1()) {
      registerModification_0(this);
      // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
      var index = this.cg_1;
      var tail = positiveMod(this, this.ag_1 + index | 0);
      nullifyNonEmpty(this, this.ag_1, tail);
    }
    this.ag_1 = 0;
    this.cg_1 = 0;
  }
  t7(array) {
    var tmp = array.length >= this.cg_1 ? array : arrayOfNulls(array, this.cg_1);
    var dest = isArray(tmp) ? tmp : THROW_CCE();
    // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
    var index = this.cg_1;
    var tail = positiveMod(this, this.ag_1 + index | 0);
    if (this.ag_1 < tail) {
      var tmp0 = this.bg_1;
      // Inline function 'kotlin.collections.copyInto' call
      var startIndex = this.ag_1;
      arrayCopy(tmp0, dest, 0, startIndex, tail);
    } else {
      // Inline function 'kotlin.collections.isNotEmpty' call
      if (!this.c1()) {
        var tmp6 = this.bg_1;
        var tmp9 = this.ag_1;
        // Inline function 'kotlin.collections.copyInto' call
        var endIndex = this.bg_1.length;
        arrayCopy(tmp6, dest, 0, tmp9, endIndex);
        var tmp11 = this.bg_1;
        // Inline function 'kotlin.collections.copyInto' call
        var destinationOffset = this.bg_1.length - this.ag_1 | 0;
        arrayCopy(tmp11, dest, destinationOffset, 0, tail);
      }
    }
    var tmp_0 = terminateCollectionToArray(this.cg_1, dest);
    return isArray(tmp_0) ? tmp_0 : THROW_CCE();
  }
  u7() {
    // Inline function 'kotlin.arrayOfNulls' call
    var size = this.cg_1;
    var tmp$ret$0 = fillArrayVal(Array(size), null);
    return this.t7(tmp$ret$0);
  }
  toArray() {
    return this.u7();
  }
  l6(fromIndex, toIndex) {
    Companion_instance_7.h5(fromIndex, toIndex, this.cg_1);
    var length = toIndex - fromIndex | 0;
    if (length === 0)
      return Unit_instance;
    else if (length === this.cg_1) {
      this.o5();
      return Unit_instance;
    } else if (length === 1) {
      this.u5(fromIndex);
      return Unit_instance;
    }
    registerModification_0(this);
    if (fromIndex < (this.cg_1 - toIndex | 0)) {
      removeRangeShiftPreceding(this, fromIndex, toIndex);
      var newHead = positiveMod(this, this.ag_1 + length | 0);
      nullifyNonEmpty(this, this.ag_1, newHead);
      this.ag_1 = newHead;
    } else {
      removeRangeShiftSucceeding(this, fromIndex, toIndex);
      // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
      var index = this.cg_1;
      var tail = positiveMod(this, this.ag_1 + index | 0);
      nullifyNonEmpty(this, negativeMod(this, tail - length | 0), tail);
    }
    this.cg_1 = this.cg_1 - length | 0;
  }
}
class EmptyIterator {
  y() {
    return false;
  }
  a6() {
    return false;
  }
  b6() {
    return 0;
  }
  z() {
    throw NoSuchElementException.s5();
  }
  c6() {
    throw NoSuchElementException.s5();
  }
}
class EmptyList {
  constructor() {
    EmptyList_instance = this;
    this.lg_1 = new Long(-1478467534, -1720727600);
  }
  equals(other) {
    var tmp;
    if (!(other == null) ? isInterface(other, KtList_0) : false) {
      tmp = other.c1();
    } else {
      tmp = false;
    }
    return tmp;
  }
  hashCode() {
    return 1;
  }
  toString() {
    return '[]';
  }
  a1() {
    return 0;
  }
  c1() {
    return true;
  }
  mg(element) {
    return false;
  }
  j2(element) {
    if (!false)
      return false;
    var tmp;
    if (false) {
      tmp = element;
    } else {
      tmp = THROW_CCE();
    }
    return this.mg(tmp);
  }
  ng(elements) {
    return elements.c1();
  }
  k2(elements) {
    return this.ng(elements);
  }
  b1(index) {
    throw IndexOutOfBoundsException.bd("Empty list doesn't contain element at index " + index + '.');
  }
  og(element) {
    return -1;
  }
  l2(element) {
    if (!false)
      return -1;
    var tmp;
    if (false) {
      tmp = element;
    } else {
      tmp = THROW_CCE();
    }
    return this.og(tmp);
  }
  pg(element) {
    return -1;
  }
  m2(element) {
    if (!false)
      return -1;
    var tmp;
    if (false) {
      tmp = element;
    } else {
      tmp = THROW_CCE();
    }
    return this.pg(tmp);
  }
  x() {
    return EmptyIterator_instance;
  }
  n2() {
    return EmptyIterator_instance;
  }
  o2(index) {
    if (!(index === 0))
      throw IndexOutOfBoundsException.bd('Index: ' + index);
    return EmptyIterator_instance;
  }
  p2(fromIndex, toIndex) {
    if (fromIndex === 0 && toIndex === 0)
      return this;
    throw IndexOutOfBoundsException.bd('fromIndex: ' + fromIndex + ', toIndex: ' + toIndex);
  }
}
class ArrayAsCollection {
  constructor(values, isVarargs) {
    this.qg_1 = values;
    this.rg_1 = isVarargs;
  }
  a1() {
    return this.qg_1.length;
  }
  c1() {
    // Inline function 'kotlin.collections.isEmpty' call
    return this.qg_1.length === 0;
  }
  sg(element) {
    return contains_0(this.qg_1, element);
  }
  j2(element) {
    if (!(element == null ? true : !(element == null)))
      return false;
    return this.sg((element == null ? true : !(element == null)) ? element : THROW_CCE());
  }
  x() {
    return arrayIterator(this.qg_1);
  }
}
class IntIterator {
  z() {
    return this.tg();
  }
}
class GeneratorSequence$iterator$1 {
  constructor(this$0) {
    this.wg_1 = this$0;
    this.ug_1 = null;
    this.vg_1 = -2;
  }
  z() {
    if (this.vg_1 < 0) {
      calcNext(this);
    }
    if (this.vg_1 === 0)
      throw NoSuchElementException.s5();
    var tmp = this.ug_1;
    var result = !(tmp == null) ? tmp : THROW_CCE();
    this.vg_1 = -1;
    return result;
  }
  y() {
    if (this.vg_1 < 0) {
      calcNext(this);
    }
    return this.vg_1 === 1;
  }
}
class GeneratorSequence {
  constructor(getInitialValue, getNextValue) {
    this.xg_1 = getInitialValue;
    this.yg_1 = getNextValue;
  }
  x() {
    return new GeneratorSequence$iterator$1(this);
  }
}
class TransformingSequence$iterator$1 {
  constructor(this$0) {
    this.ah_1 = this$0;
    this.zg_1 = this$0.bh_1.x();
  }
  z() {
    return this.ah_1.ch_1(this.zg_1.z());
  }
  y() {
    return this.zg_1.y();
  }
}
class TransformingSequence {
  constructor(sequence, transformer) {
    this.bh_1 = sequence;
    this.ch_1 = transformer;
  }
  x() {
    return new TransformingSequence$iterator$1(this);
  }
}
class EmptySequence {
  x() {
    return EmptyIterator_instance;
  }
}
class EmptySet {
  constructor() {
    EmptySet_instance = this;
    this.dh_1 = new Long(1993859828, 793161749);
  }
  equals(other) {
    var tmp;
    if (!(other == null) ? isInterface(other, KtSet_0) : false) {
      tmp = other.c1();
    } else {
      tmp = false;
    }
    return tmp;
  }
  hashCode() {
    return 0;
  }
  toString() {
    return '[]';
  }
  a1() {
    return 0;
  }
  c1() {
    return true;
  }
  mg(element) {
    return false;
  }
  j2(element) {
    if (!false)
      return false;
    var tmp;
    if (false) {
      tmp = element;
    } else {
      tmp = THROW_CCE();
    }
    return this.mg(tmp);
  }
  ng(elements) {
    return elements.c1();
  }
  k2(elements) {
    return this.ng(elements);
  }
  x() {
    return EmptyIterator_instance;
  }
}
class NaturalOrderComparator {
  eh(a, b) {
    return compareTo(a, b);
  }
  compare(a, b) {
    var tmp = (!(a == null) ? isComparable(a) : false) ? a : THROW_CCE();
    return this.eh(tmp, (!(b == null) ? isComparable(b) : false) ? b : THROW_CCE());
  }
}
class Key {}
class Element {}
function get(key) {
  var tmp;
  if (equals(this.q2(), key)) {
    tmp = isInterface(this, Element) ? this : THROW_CCE();
  } else {
    tmp = null;
  }
  return tmp;
}
class ContinuationInterceptor {}
function get_0(key) {
  if (key instanceof AbstractCoroutineContextKey) {
    var tmp;
    if (key.ih(this.q2())) {
      var tmp_0 = key.hh(this);
      tmp = (!(tmp_0 == null) ? isInterface(tmp_0, Element) : false) ? tmp_0 : null;
    } else {
      tmp = null;
    }
    return tmp;
  }
  var tmp_1;
  if (Key_instance === key) {
    tmp_1 = isInterface(this, Element) ? this : THROW_CCE();
  } else {
    tmp_1 = null;
  }
  return tmp_1;
}
class AbstractCoroutineContextKey {
  constructor(baseKey, safeCast) {
    this.fh_1 = safeCast;
    var tmp = this;
    var tmp_0;
    if (baseKey instanceof AbstractCoroutineContextKey) {
      tmp_0 = baseKey.gh_1;
    } else {
      tmp_0 = baseKey;
    }
    tmp.gh_1 = tmp_0;
  }
  hh(element) {
    return this.fh_1(element);
  }
  ih(key) {
    return key === this || this.gh_1 === key;
  }
}
class AbstractCoroutineContextElement {
  constructor(key) {
    this.jh_1 = key;
  }
  q2() {
    return this.jh_1;
  }
}
class CoroutineSingletons extends Enum {}
class EnumEntriesList extends AbstractList {
  static lh(entries) {
    var $this = this.tf();
    $this.kh_1 = entries;
    return $this;
  }
  a1() {
    return this.kh_1.length;
  }
  b1(index) {
    Companion_instance_7.k6(index, this.kh_1.length);
    return this.kh_1[index];
  }
  mh(element) {
    if (element === null)
      return false;
    var target = getOrNull(this.kh_1, element.z2_1);
    return target === element;
  }
  j2(element) {
    if (!(element instanceof Enum))
      return false;
    return this.mh(element instanceof Enum ? element : THROW_CCE());
  }
  nh(element) {
    if (element === null)
      return -1;
    var ordinal = element.z2_1;
    var target = getOrNull(this.kh_1, ordinal);
    return target === element ? ordinal : -1;
  }
  l2(element) {
    if (!(element instanceof Enum))
      return -1;
    return this.nh(element instanceof Enum ? element : THROW_CCE());
  }
  oh(element) {
    return this.nh(element);
  }
  m2(element) {
    if (!(element instanceof Enum))
      return -1;
    return this.oh(element instanceof Enum ? element : THROW_CCE());
  }
}
class Delegates {}
class ObservableProperty {
  constructor(initialValue, $box) {
    boxApply(this, $box);
    this.ph_1 = initialValue;
  }
  qh(property, oldValue, newValue) {
    return true;
  }
  rh(property, oldValue, newValue) {
  }
  sh(thisRef, property) {
    return this.ph_1;
  }
  th(thisRef, property) {
    return this.sh((thisRef == null ? true : !(thisRef == null)) ? thisRef : THROW_CCE(), property);
  }
  uh(thisRef, property, value) {
    var oldValue = this.ph_1;
    if (!this.qh(property, oldValue, value)) {
      return Unit_instance;
    }
    this.ph_1 = value;
    this.rh(property, oldValue, value);
  }
  vh(thisRef, property, value) {
    var tmp = (thisRef == null ? true : !(thisRef == null)) ? thisRef : THROW_CCE();
    return this.uh(tmp, property, (value == null ? true : !(value == null)) ? value : THROW_CCE());
  }
  toString() {
    return 'ObservableProperty(value=' + toString_0(this.ph_1) + ')';
  }
}
class Random {
  static yh() {
    Default_getInstance();
    return createThis(this);
  }
  tg() {
    return this.zh(32);
  }
  bi(array, fromIndex, toIndex) {
    // Inline function 'kotlin.require' call
    if (!((0 <= fromIndex ? fromIndex <= array.length : false) && (0 <= toIndex ? toIndex <= array.length : false))) {
      // Inline function 'kotlin.random.Random.nextBytes.<anonymous>' call
      var message = 'fromIndex (' + fromIndex + ') or toIndex (' + toIndex + ') are out of range: 0..' + array.length + '.';
      throw IllegalArgumentException.h(toString_1(message));
    }
    // Inline function 'kotlin.require' call
    if (!(fromIndex <= toIndex)) {
      // Inline function 'kotlin.random.Random.nextBytes.<anonymous>' call
      var message_0 = 'fromIndex (' + fromIndex + ') must be not greater than toIndex (' + toIndex + ').';
      throw IllegalArgumentException.h(toString_1(message_0));
    }
    var steps = (toIndex - fromIndex | 0) / 4 | 0;
    var position = fromIndex;
    // Inline function 'kotlin.repeat' call
    var inductionVariable = 0;
    if (inductionVariable < steps)
      do {
        var index = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        // Inline function 'kotlin.random.Random.nextBytes.<anonymous>' call
        var v = this.tg();
        array[position] = toByte(v);
        array[position + 1 | 0] = toByte(v >>> 8 | 0);
        array[position + 2 | 0] = toByte(v >>> 16 | 0);
        array[position + 3 | 0] = toByte(v >>> 24 | 0);
        position = position + 4 | 0;
      }
       while (inductionVariable < steps);
    var remainder = toIndex - position | 0;
    var vr = this.zh(imul_0(remainder, 8));
    var inductionVariable_0 = 0;
    if (inductionVariable_0 < remainder)
      do {
        var i = inductionVariable_0;
        inductionVariable_0 = inductionVariable_0 + 1 | 0;
        array[position + i | 0] = toByte(vr >>> imul_0(i, 8) | 0);
      }
       while (inductionVariable_0 < remainder);
    return array;
  }
  ai(array) {
    return this.bi(array, 0, array.length);
  }
}
class Default extends Random {
  static xh() {
    Default_instance = null;
    var $this = this.yh();
    Default_instance = $this;
    $this.wh_1 = defaultPlatformRandom();
    return $this;
  }
  zh(bitCount) {
    return this.wh_1.zh(bitCount);
  }
  tg() {
    return this.wh_1.tg();
  }
  ai(array) {
    return this.wh_1.ai(array);
  }
  bi(array, fromIndex, toIndex) {
    return this.wh_1.bi(array, fromIndex, toIndex);
  }
}
class Companion_11 {
  constructor() {
    Companion_instance_11 = this;
    this.ji_1 = new Long(0, 0);
  }
}
class XorWowRandom extends Random {
  static ki(x, y, z, w, v, addend) {
    Companion_getInstance_11();
    var $this = this.yh();
    $this.ci_1 = x;
    $this.di_1 = y;
    $this.ei_1 = z;
    $this.fi_1 = w;
    $this.gi_1 = v;
    $this.hi_1 = addend;
    // Inline function 'kotlin.require' call
    if (!!(($this.ci_1 | $this.di_1 | $this.ei_1 | $this.fi_1 | $this.gi_1) === 0)) {
      // Inline function 'kotlin.random.XorWowRandom.<anonymous>' call
      var message = 'Initial state must have at least one non-zero element.';
      throw IllegalArgumentException.h(toString_1(message));
    }
    // Inline function 'kotlin.repeat' call
    var inductionVariable = 0;
    if (inductionVariable < 64)
      do {
        var index = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        // Inline function 'kotlin.random.XorWowRandom.<anonymous>' call
        $this.tg();
      }
       while (inductionVariable < 64);
    return $this;
  }
  static ii(seed1, seed2) {
    Companion_getInstance_11();
    return this.ki(seed1, seed2, 0, 0, ~seed1, seed1 << 10 ^ (seed2 >>> 4 | 0));
  }
  tg() {
    var t = this.ci_1;
    t = t ^ (t >>> 2 | 0);
    this.ci_1 = this.di_1;
    this.di_1 = this.ei_1;
    this.ei_1 = this.fi_1;
    var v0 = this.gi_1;
    this.fi_1 = v0;
    t = t ^ t << 1 ^ v0 ^ v0 << 4;
    this.gi_1 = t;
    this.hi_1 = this.hi_1 + 362437 | 0;
    return t + this.hi_1 | 0;
  }
  zh(bitCount) {
    return takeUpperBits(this.tg(), bitCount);
  }
}
class Companion_12 {
  constructor() {
    Companion_instance_12 = this;
    this.g1_1 = new IntRange(1, 0);
  }
}
class IntProgression {
  constructor(start, endInclusive, step) {
    if (step === 0)
      throw IllegalArgumentException.h('Step must be non-zero.');
    if (step === -2147483648)
      throw IllegalArgumentException.h('Step must be greater than Int.MIN_VALUE to avoid overflow on negation.');
    this.pi_1 = start;
    this.qi_1 = getProgressionLastElement(start, endInclusive, step);
    this.ri_1 = step;
  }
  x() {
    return new IntProgressionIterator(this.pi_1, this.qi_1, this.ri_1);
  }
  c1() {
    return this.ri_1 > 0 ? this.pi_1 > this.qi_1 : this.pi_1 < this.qi_1;
  }
  equals(other) {
    var tmp;
    if (other instanceof IntProgression) {
      tmp = this.c1() && other.c1() || (this.pi_1 === other.pi_1 && this.qi_1 === other.qi_1 && this.ri_1 === other.ri_1);
    } else {
      tmp = false;
    }
    return tmp;
  }
  hashCode() {
    return this.c1() ? -1 : imul_0(31, imul_0(31, this.pi_1) + this.qi_1 | 0) + this.ri_1 | 0;
  }
  toString() {
    return this.ri_1 > 0 ? '' + this.pi_1 + '..' + this.qi_1 + ' step ' + this.ri_1 : '' + this.pi_1 + ' downTo ' + this.qi_1 + ' step ' + (-this.ri_1 | 0);
  }
}
class ClosedRange {}
function contains(value) {
  return compareTo(value, this.oi()) >= 0 && compareTo(value, this.si()) <= 0;
}
function isEmpty() {
  return compareTo(this.oi(), this.si()) > 0;
}
class IntRange extends IntProgression {
  constructor(start, endInclusive) {
    Companion_getInstance_12();
    super(start, endInclusive, 1);
  }
  oi() {
    return this.pi_1;
  }
  si() {
    return this.qi_1;
  }
  ti(value) {
    return this.pi_1 <= value && value <= this.qi_1;
  }
  i1(value) {
    return this.ti(typeof value === 'number' ? value : THROW_CCE());
  }
  c1() {
    return this.pi_1 > this.qi_1;
  }
  equals(other) {
    var tmp;
    if (other instanceof IntRange) {
      tmp = this.c1() && other.c1() || (this.pi_1 === other.pi_1 && this.qi_1 === other.qi_1);
    } else {
      tmp = false;
    }
    return tmp;
  }
  hashCode() {
    return this.c1() ? -1 : imul_0(31, this.pi_1) + this.qi_1 | 0;
  }
  toString() {
    return '' + this.pi_1 + '..' + this.qi_1;
  }
}
class IntProgressionIterator extends IntIterator {
  constructor(first, last, step) {
    super();
    this.ui_1 = step;
    this.vi_1 = last;
    this.wi_1 = this.ui_1 > 0 ? first <= last : first >= last;
    this.xi_1 = this.wi_1 ? first : this.vi_1;
  }
  y() {
    return this.wi_1;
  }
  tg() {
    var value = this.xi_1;
    if (value === this.vi_1) {
      if (!this.wi_1)
        throw NoSuchElementException.s5();
      this.wi_1 = false;
    } else {
      this.xi_1 = this.xi_1 + this.ui_1 | 0;
    }
    return value;
  }
}
class Companion_13 {
  h1(rangeStart, rangeEnd, step) {
    return new IntProgression(rangeStart, rangeEnd, step);
  }
}
class DelimitedRangesSequence$iterator$1 {
  constructor(this$0) {
    this.dj_1 = this$0;
    this.yi_1 = -1;
    this.zi_1 = coerceIn(this$0.fj_1, 0, charSequenceLength(this$0.ej_1));
    this.aj_1 = this.zi_1;
    this.bj_1 = null;
    this.cj_1 = 0;
  }
  z() {
    if (this.yi_1 === -1) {
      calcNext_0(this);
    }
    if (this.yi_1 === 0)
      throw NoSuchElementException.s5();
    var tmp = this.bj_1;
    var result = tmp instanceof IntRange ? tmp : THROW_CCE();
    this.bj_1 = null;
    this.yi_1 = -1;
    return result;
  }
  y() {
    if (this.yi_1 === -1) {
      calcNext_0(this);
    }
    return this.yi_1 === 1;
  }
}
class DelimitedRangesSequence {
  constructor(input, startIndex, limit, getNextMatch) {
    this.ej_1 = input;
    this.fj_1 = startIndex;
    this.gj_1 = limit;
    this.hj_1 = getNextMatch;
  }
  x() {
    return new DelimitedRangesSequence$iterator$1(this);
  }
}
class State {
  constructor() {
    this.mj_1 = 0;
    this.nj_1 = 1;
    this.oj_1 = 2;
  }
}
class LinesIterator {
  constructor(string) {
    this.pj_1 = string;
    this.qj_1 = 0;
    this.rj_1 = 0;
    this.sj_1 = 0;
    this.tj_1 = 0;
  }
  y() {
    if (!(this.qj_1 === 0)) {
      return this.qj_1 === 1;
    }
    if (this.tj_1 < 0) {
      this.qj_1 = 2;
      return false;
    }
    var _delimiterLength = -1;
    var _delimiterStartIndex = charSequenceLength(this.pj_1);
    var inductionVariable = this.rj_1;
    var last = charSequenceLength(this.pj_1);
    if (inductionVariable < last)
      $l$loop: do {
        var idx = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var c = charSequenceGet(this.pj_1, idx);
        if (c === _Char___init__impl__6a9atx(10) || c === _Char___init__impl__6a9atx(13)) {
          _delimiterLength = c === _Char___init__impl__6a9atx(13) && (idx + 1 | 0) < charSequenceLength(this.pj_1) && charSequenceGet(this.pj_1, idx + 1 | 0) === _Char___init__impl__6a9atx(10) ? 2 : 1;
          _delimiterStartIndex = idx;
          break $l$loop;
        }
      }
       while (inductionVariable < last);
    this.qj_1 = 1;
    this.tj_1 = _delimiterLength;
    this.sj_1 = _delimiterStartIndex;
    return true;
  }
  z() {
    if (!this.y()) {
      throw NoSuchElementException.s5();
    }
    this.qj_1 = 0;
    var lastIndex = this.sj_1;
    var firstIndex = this.rj_1;
    this.rj_1 = this.sj_1 + this.tj_1 | 0;
    // Inline function 'kotlin.text.substring' call
    var this_0 = this.pj_1;
    return toString_1(charSequenceSubSequence(this_0, firstIndex, lastIndex));
  }
}
class lineSequence$$inlined$Sequence$1 {
  constructor($this_lineSequence) {
    this.uj_1 = $this_lineSequence;
  }
  x() {
    // Inline function 'kotlin.text.lineSequence.<anonymous>' call
    return new LinesIterator(this.uj_1);
  }
}
class UnsafeLazyImpl {
  constructor(initializer) {
    this.vj_1 = initializer;
    this.wj_1 = UNINITIALIZED_VALUE_instance;
  }
  r2() {
    if (this.wj_1 === UNINITIALIZED_VALUE_instance) {
      this.wj_1 = ensureNotNull(this.vj_1)();
      this.vj_1 = null;
    }
    var tmp = this.wj_1;
    return (tmp == null ? true : !(tmp == null)) ? tmp : THROW_CCE();
  }
  xj() {
    return !(this.wj_1 === UNINITIALIZED_VALUE_instance);
  }
  toString() {
    return this.xj() ? toString_0(this.r2()) : 'Lazy value not initialized yet.';
  }
}
class UNINITIALIZED_VALUE {}
class Companion_14 {}
class Failure {
  constructor(exception) {
    this.yj_1 = exception;
  }
  equals(other) {
    var tmp;
    if (other instanceof Failure) {
      tmp = equals(this.yj_1, other.yj_1);
    } else {
      tmp = false;
    }
    return tmp;
  }
  hashCode() {
    return hashCode(this.yj_1);
  }
  toString() {
    return 'Failure(' + this.yj_1.toString() + ')';
  }
}
class NotImplementedError extends Error_0 {
  static bk(message) {
    message = message === VOID ? 'An operation is not implemented.' : message;
    var $this = this.vc(message);
    captureStack($this, $this.ak_1);
    return $this;
  }
}
class Pair {
  constructor(first, second) {
    this.ij_1 = first;
    this.jj_1 = second;
  }
  toString() {
    return '(' + toString_0(this.ij_1) + ', ' + toString_0(this.jj_1) + ')';
  }
  kj() {
    return this.ij_1;
  }
  lj() {
    return this.jj_1;
  }
  hashCode() {
    var result = this.ij_1 == null ? 0 : hashCode(this.ij_1);
    result = imul_0(result, 31) + (this.jj_1 == null ? 0 : hashCode(this.jj_1)) | 0;
    return result;
  }
  equals(other) {
    if (this === other)
      return true;
    if (!(other instanceof Pair))
      return false;
    var tmp0_other_with_cast = other instanceof Pair ? other : THROW_CCE();
    if (!equals(this.ij_1, tmp0_other_with_cast.ij_1))
      return false;
    if (!equals(this.jj_1, tmp0_other_with_cast.jj_1))
      return false;
    return true;
  }
}
class EnumMap {
  constructor(enums) {
    this.ck_1 = enums;
    this.dk_1 = booleanArray(this.ck_1.length);
    this.ek_1 = ArrayList.o7(this.ck_1.length);
    var inductionVariable = 0;
    var last = this.ck_1.length;
    if (inductionVariable < last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        this.ek_1.j6(i, null);
      }
       while (inductionVariable < last);
  }
  h7() {
    return this.ek_1;
  }
  v2() {
    var reason = 'Not yet implemented';
    throw NotImplementedError.bk('An operation is not implemented: ' + reason);
  }
  g7() {
    return toMutableSet(this.g7());
  }
  a1() {
    return this.ek_1.a1();
  }
  fk(key) {
    return true;
  }
  s2(key) {
    if (!(key instanceof Enum))
      return false;
    return this.fk(key instanceof Enum ? key : THROW_CCE());
  }
  gk(key) {
    return this.ek_1.b1(key.z2_1);
  }
  u2(key) {
    if (!(key instanceof Enum))
      return null;
    return this.gk(key instanceof Enum ? key : THROW_CCE());
  }
  o5() {
    // Inline function 'kotlin.TODO' call
    var reason = 'Not yet implemented';
    throw NotImplementedError.bk('An operation is not implemented: ' + reason);
  }
  hk(key, value) {
    this.ek_1.j5(key.z2_1, value);
    return this.ek_1.b1(key.z2_1);
  }
  i7(key, value) {
    var tmp = key instanceof Enum ? key : THROW_CCE();
    return this.hk(tmp, (value == null ? true : !(value == null)) ? value : THROW_CCE());
  }
}
class ConcatenateIterator {
  constructor($outer) {
    this.jk_1 = $outer;
    this.ik_1 = this.kk();
  }
  y() {
    return this.ik_1.y();
  }
  z() {
    var next = ensureNotNull(this.ik_1.z());
    this.lk();
    return next;
  }
  kk() {
    return ensureNotNull(this.jk_1.mk_1).z().x();
  }
  lk() {
    $l$loop: while (!this.ik_1.y() && ensureNotNull(this.jk_1.mk_1).y()) {
      this.ik_1 = this.kk();
    }
    return this;
  }
}
class EmptyIterator_0 {
  y() {
    return false;
  }
  z() {
    throw IllegalStateException.lc();
  }
}
class ConcatenateIterable {
  constructor(iterables) {
    this.nk_1 = iterables;
    this.mk_1 = iterables.x();
  }
  x() {
    return !ensureNotNull(this.mk_1).y() ? new EmptyIterator_0() : (new ConcatenateIterator(this)).lk();
  }
}
class Iterables {
  ok(original, condition) {
    // Inline function 'kotlin.collections.filter' call
    // Inline function 'kotlin.collections.filterTo' call
    var destination = ArrayList.e1();
    var _iterator__ex2g4s = original.x();
    while (_iterator__ex2g4s.y()) {
      var element = _iterator__ex2g4s.z();
      // Inline function 'com.macrofocus.common.collection.Iterables.conditional.<anonymous>' call
      if (condition.pk(element)) {
        destination.o(element);
      }
    }
    return destination;
  }
  qk(iterables) {
    return this.rk(toList(iterables));
  }
  rk(iterables) {
    return new ConcatenateIterable(iterables);
  }
}
class SortedSet extends AbstractMutableSet {
  static uk(comparator, collection) {
    collection = collection === VOID ? emptyList() : collection;
    var $this = this.l7();
    $this.sk_1 = comparator;
    var tmp = $this;
    // Inline function 'kotlin.apply' call
    var this_0 = ArrayList.e1();
    // Inline function 'com.macrofocus.common.collection.SortedSet.store.<anonymous>' call
    this_0.x2(toSet_0(collection));
    sortWith_0(this_0, $this.sk_1);
    tmp.tk_1 = this_0;
    return $this;
  }
  a1() {
    return this.tk_1.a1();
  }
  o(element) {
    var index = binarySearch(this.tk_1, element, this.sk_1);
    var tmp;
    if (index >= 0) {
      tmp = false;
    } else {
      this.tk_1.j6(abs_0(index) - 1 | 0, element);
      tmp = true;
    }
    return tmp;
  }
  x() {
    return this.tk_1.x();
  }
}
class UniversalComparator {
  vk(a, b) {
    var tmp;
    if (!(a == null) && !(b == null)) {
      var tmp_0;
      if (getKClassFromExpression(b).equals(getKClassFromExpression(a))) {
        var tmp_1;
        var tmp_2;
        if (!(a == null) ? typeof a === 'string' : false) {
          tmp_2 = !(b == null) ? typeof b === 'string' : false;
        } else {
          tmp_2 = false;
        }
        if (tmp_2) {
          tmp_1 = compareTo(a, b);
        } else {
          var tmp_3;
          if (!(a == null) ? isComparable(a) : false) {
            tmp_3 = !(b == null) ? isComparable(b) : false;
          } else {
            tmp_3 = false;
          }
          if (tmp_3) {
            tmp_1 = compareTo(isComparable(a) ? a : THROW_CCE(), b);
          } else {
            tmp_1 = compareTo(toString_1(a), toString_1(b));
          }
        }
        tmp_0 = tmp_1;
      } else {
        var tmp_4;
        if (isNumber(b)) {
          tmp_4 = isNumber(a);
        } else {
          tmp_4 = false;
        }
        if (tmp_4) {
          var number1 = a;
          var number2 = b;
          if (numberToDouble(number1) < numberToDouble(number2))
            return -1;
          tmp_0 = numberToDouble(number1) > numberToDouble(number2) ? 1 : 0;
        } else {
          tmp_0 = compareTo(toString_1(a), toString_1(b));
        }
      }
      tmp = tmp_0;
    } else {
      var tmp_5;
      if (!(a == null)) {
        tmp_5 = 1;
      } else if (!(b == null)) {
        tmp_5 = -1;
      } else {
        tmp_5 = 0;
      }
      tmp = tmp_5;
    }
    return tmp;
  }
  compare(a, b) {
    var tmp = (a == null ? true : !(a == null)) ? a : THROW_CCE();
    return this.vk(tmp, (b == null ? true : !(b == null)) ? b : THROW_CCE());
  }
}
class WeakReference {
  constructor(referent) {
    this.wk_1 = referent;
  }
  xk() {
    return this.wk_1;
  }
}
class AbstractUICommand {
  static dl(titleProperty, enabledProperty, keystrokeProperty, mnemonicProperty, iconProperty, $box) {
    enabledProperty = enabledProperty === VOID ? new SimpleProperty(true) : enabledProperty;
    keystrokeProperty = keystrokeProperty === VOID ? null : keystrokeProperty;
    mnemonicProperty = mnemonicProperty === VOID ? null : mnemonicProperty;
    iconProperty = iconProperty === VOID ? null : iconProperty;
    var $this = createThis(this, $box);
    $this.yk_1 = titleProperty;
    $this.zk_1 = enabledProperty;
    $this.al_1 = keystrokeProperty;
    $this.bl_1 = mnemonicProperty;
    $this.cl_1 = iconProperty;
    return $this;
  }
  static el(title, $box) {
    return this.dl(new SimpleProperty(title), VOID, VOID, VOID, VOID, $box);
  }
  toString() {
    return ensureNotNull(ensureNotNull(this.yk_1).r2());
  }
}
class HtmlString {
  toString() {
    return ensureNotNull(this.fl_1);
  }
}
class WeakFilterListener {
  hl() {
    return this.gl_1.xk();
  }
}
class Companion_15 {
  constructor() {
    Companion_instance_15 = this;
    this.il_1 = new Long(282232921, 1487329621);
  }
}
class AbstractFilter {
  constructor() {
    Companion_getInstance_15();
    this.jl_1 = true;
    this.kl_1 = CollectionFactory_instance.ll();
  }
  ml(listener) {
    this.kl_1.o(listener);
  }
  nl(listener) {
    if (listener instanceof WeakFilterListener) {
      var removed = this.kl_1.w2(listener);
    } else {
      var toRemove = null;
      var _iterator__ex2g4s = this.kl_1.x();
      while (_iterator__ex2g4s.y()) {
        var filterListener = _iterator__ex2g4s.z();
        var comparable;
        var tmp;
        if (filterListener instanceof WeakFilterListener) {
          tmp = filterListener.hl();
        } else {
          tmp = filterListener;
        }
        comparable = tmp;
        if (equals(listener, comparable)) {
          toRemove = filterListener;
        }
      }
      if (!(toRemove == null)) {
        var removed_0 = this.kl_1.w2(toRemove);
      }
    }
  }
}
class AbstractMutableFilter extends AbstractFilter {
  constructor() {
    super();
    this.rl_1 = true;
  }
}
class SimpleFilter extends AbstractMutableFilter {
  constructor() {
    super();
    this.vl_1 = HashMap.d8();
  }
  ol(element) {
    return this.vl_1.s2(element);
  }
}
class CPFormat {}
class Dimension {
  static am() {
    var $this = createThis(this);
    init_com_macrofocus_common_geom_Dimension($this);
    $this.yl_1 = 0;
    $this.zl_1 = 0;
    return $this;
  }
  static bm(width, height) {
    var $this = createThis(this);
    init_com_macrofocus_common_geom_Dimension($this);
    $this.yl_1 = width;
    $this.zl_1 = height;
    return $this;
  }
  cm() {
    return this.yl_1;
  }
  dm() {
    return this.zl_1;
  }
  toString() {
    return 'Dimension.Integer{width=' + this.cm() + ', height=' + this.dm() + toString(_Char___init__impl__6a9atx(125));
  }
}
class AbstractIndex {
  static em() {
    return createThis(this);
  }
}
class AbstractMutableInterval {
  static km() {
    var $this = createThis(this);
    $this.jm_1 = CollectionFactory_instance.ll();
    return $this;
  }
  nm(listener) {
    this.jm_1.o(listener);
  }
  addIntervalListener(listener) {
    return this.nm(listener);
  }
  om(listener) {
    var weakListener = new WeakIntervalListener(this, listener);
    this.jm_1.o(weakListener);
  }
  addWeakIntervalListener(listener) {
    return this.om(listener);
  }
  pm(listener) {
    if (listener instanceof WeakIntervalListener) {
      var removed = this.jm_1.w2(listener);
    } else {
      var toRemove = null;
      var _iterator__ex2g4s = this.jm_1.x();
      while (_iterator__ex2g4s.y()) {
        var intervalListener = _iterator__ex2g4s.z();
        var comparable;
        if (intervalListener instanceof WeakIntervalListener) {
          comparable = intervalListener.hl();
        } else {
          comparable = intervalListener;
        }
        if (equals(listener, comparable)) {
          toRemove = intervalListener;
        }
      }
      if (!(toRemove == null)) {
        var removed_0 = this.jm_1.w2(toRemove);
      }
    }
  }
  removeIntervalListener(listener) {
    return this.pm(listener);
  }
  qm() {
    this.jm_1.o5();
  }
  removeIntervalListeners() {
    return this.qm();
  }
  rm(event) {
    var _iterator__ex2g4s = this.jm_1.x();
    while (_iterator__ex2g4s.y()) {
      var listener = _iterator__ex2g4s.z();
      listener.fn(event);
    }
  }
}
class AbstractBoundedInterval extends AbstractMutableInterval {
  static im() {
    var $this = this.km();
    $this.hm_1 = CollectionFactory_instance.ll();
    return $this;
  }
  lm(event) {
    var _iterator__ex2g4s = this.hm_1.x();
    while (_iterator__ex2g4s.y()) {
      var listener = _iterator__ex2g4s.z();
      listener.mm(event);
    }
  }
}
class WeakIntervalListener {
  constructor($outer, listener) {
    this.en_1 = $outer;
    this.dn_1 = new WeakReference(listener);
  }
  fn(event) {
    var l = this.hl();
    if (!(l == null)) {
      l.fn(event);
    } else {
      this.en_1.pm(this);
    }
  }
  hl() {
    return this.dn_1.xk();
  }
  toString() {
    var l = this.hl();
    var tmp;
    if (!(l == null)) {
      tmp = 'Weak[' + toString_0(l) + ']';
    } else {
      tmp = toString_1(getKClassFromExpression(this)) + '@' + hashCode(this);
    }
    return tmp;
  }
}
class BoundedIntervalEvent {
  constructor(oldMinimum, oldMaximum, oldMinimumExtent, oldMaximumExtent) {
    this.gn_1 = oldMinimum;
    this.hn_1 = oldMaximum;
    this.in_1 = oldMinimumExtent;
    this.jn_1 = oldMaximumExtent;
    this.kn_1 = 0.0;
    this.ln_1 = 0.0;
    this.mn_1 = 0.0;
    this.nn_1 = 0.0;
  }
  on(newMinimum, newMaximum, newMinimumExtent, newMaximumExtent) {
    this.kn_1 = newMinimum;
    this.ln_1 = newMaximum;
    this.mn_1 = newMinimumExtent;
    this.nn_1 = newMaximumExtent;
  }
}
class ClosedInterval extends AbstractMutableInterval {
  static qn() {
    return this.km();
  }
  xm(value) {
    // Inline function 'kotlin.TODO' call
    var reason = 'Not yet implemented!';
    throw NotImplementedError.bk('An operation is not implemented: ' + reason);
  }
  ym() {
    return this.end - this.start;
  }
  rn(value) {
    return this.start <= value && this.end >= value;
  }
  contains(value) {
    return this.rn(value);
  }
  sn(start, end) {
    return this.rn(start) && this.rn(end);
  }
  containsStartEnd(start, end) {
    return this.sn(start, end);
  }
  tn(interval) {
    return this.rn(ensureNotNull(interval).start) && this.rn(interval.end);
  }
  containsInterval(interval) {
    return this.tn(interval);
  }
  un(start, end) {
    return this.rn(start) || this.rn(end);
  }
  overlaps(start, end) {
    return this.un(start, end);
  }
  vn(interval) {
    return this.rn(ensureNotNull(interval).start) || this.rn(interval.end);
  }
  overlapsInterval(interval) {
    return this.vn(interval);
  }
  an() {
    return this.end < this.start;
  }
  zm() {
    return this.ym() === 0.0;
  }
  get extent() {
    return this.ym();
  }
  set extent(value) {
    this.xm(value);
  }
  get isInverted() {
    return this.an();
  }
  get isDegenerate() {
    return this.zm();
  }
}
class IntervalEvent {
  constructor(oldStart, oldEnd, oldExtent) {
    this.wn_1 = oldStart;
    this.xn_1 = oldEnd;
    this.yn_1 = oldExtent;
    this.zn_1 = 0.0;
    this.ao_1 = 0.0;
    this.bo_1 = 0.0;
  }
  co(newStart, newEnd, newExtent) {
    this.zn_1 = newStart;
    this.ao_1 = newEnd;
    this.bo_1 = newExtent;
  }
  toString() {
    return 'IntervalEvent{newStart=' + this.zn_1 + ', newEnd=' + this.ao_1 + ', newExtent=' + this.bo_1 + ', oldStart=' + this.wn_1 + ', oldEnd=' + this.xn_1 + ', oldExtent=' + this.yn_1 + toString(_Char___init__impl__6a9atx(125));
  }
}
class PropertyClosedInterval extends ClosedInterval {
  static ko(start, extent) {
    var $this = this.qn();
    $this.io_1 = new SimpleProperty(start);
    $this.jo_1 = new SimpleProperty($this.sm().r2() + extent);
    var tmp = $this.sm();
    tmp.uo(new PropertyClosedInterval$1($this, start, extent));
    var tmp_0 = $this.tm();
    tmp_0.uo(new PropertyClosedInterval$2(start, $this, extent));
    return $this;
  }
  sm() {
    return this.io_1;
  }
  tm() {
    return this.jo_1;
  }
  um(value) {
    this.sm().vo(value);
  }
  oi() {
    return this.sm().r2();
  }
  vm(value) {
    this.tm().vo(value);
  }
  wm() {
    return this.tm().r2();
  }
  xm(extent) {
    this.tm().vo(this.oi() + extent);
  }
  ym() {
    return super.ym();
  }
  lo(value, extent) {
    this.sm().vo(value);
    this.tm().vo(value + extent);
  }
  setValue(value, extent) {
    return this.lo(value, extent);
  }
  toString() {
    return 'PropertyClosedInterval{start=' + this.oi() + ', end=' + this.wm() + ', extent=' + this.ym() + toString(_Char___init__impl__6a9atx(125));
  }
  get startProperty() {
    return this.sm();
  }
  get endProperty() {
    return this.tm();
  }
  get start() {
    return this.oi();
  }
  set start(value) {
    this.um(value);
  }
  get end() {
    return this.wm();
  }
  set end(value) {
    this.vm(value);
  }
  get extent() {
    return this.ym();
  }
  set extent(value) {
    this.xm(value);
  }
}
class OpenInterval extends PropertyClosedInterval {
  static go(start, extent) {
    return this.ko(start, extent);
  }
  rn(value) {
    return this.oi() <= value && this.wm() > value;
  }
  contains(value) {
    return this.rn(value);
  }
}
class PropertyListener {}
class PropertyClosedInterval$1 {
  constructor(this$0, $start, $extent) {
    this.mo_1 = this$0;
    this.no_1 = $start;
    this.oo_1 = $extent;
  }
  po(event) {
    var e = new IntervalEvent(event.oldValue, this.mo_1.wm(), this.mo_1.wm() - event.oldValue);
    e.co(this.no_1, this.mo_1.wm(), this.oo_1);
    this.mo_1.rm(e);
  }
  qo(event) {
    return this.po(event);
  }
}
class PropertyClosedInterval$2 {
  constructor($start, this$0, $extent) {
    this.ro_1 = $start;
    this.so_1 = this$0;
    this.to_1 = $extent;
  }
  po(event) {
    var e = new IntervalEvent(this.ro_1, event.oldValue, event.oldValue - this.ro_1);
    e.co(this.ro_1, this.so_1.wm(), this.to_1);
    this.so_1.rm(e);
  }
  qo(event) {
    return this.po(event);
  }
}
class SimpleBoundedInterval$intervalListener$1 {
  constructor(this$0) {
    this.wo_1 = this$0;
  }
  fn(event) {
    this.wo_1.rm(event);
  }
}
class SimpleBoundedInterval extends AbstractBoundedInterval {
  static fp(interval, minimum, maximum) {
    var $this = this.im();
    $this.zo_1 = interval;
    $this.ap_1 = 0.0;
    $this.bp_1 = 0.0;
    $this.cp_1 = 0.0;
    $this.dp_1 = 0.0;
    var tmp = $this;
    tmp.ep_1 = new SimpleBoundedInterval$intervalListener$1($this);
    $this.gp(minimum);
    $this.hp(maximum);
    $this.ip(0.0);
    $this.jp(maximum - minimum);
    $this.zo_1.addWeakIntervalListener($this.ep_1);
    return $this;
  }
  gp(minimum) {
    if (!(this.ap_1 === minimum)) {
      var event = new BoundedIntervalEvent(this.ap_1, this.bp_1, this.cp_1, this.dp_1);
      this.ap_1 = minimum;
      this.jp(this.bp_1 - this.ap_1);
      event.on(this.ap_1, this.bp_1, this.cp_1, this.dp_1);
      this.lm(event);
    }
  }
  bn() {
    return this.ap_1;
  }
  hp(maximum) {
    if (!(this.bp_1 === maximum)) {
      var event = new BoundedIntervalEvent(this.ap_1, this.bp_1, this.cp_1, this.dp_1);
      this.bp_1 = maximum;
      this.jp(this.bp_1 - this.ap_1);
      event.on(this.ap_1, this.bp_1, this.cp_1, this.dp_1);
      this.lm(event);
    }
  }
  cn() {
    return this.bp_1;
  }
  ip(minimumExtent) {
    if (!(this.cp_1 === minimumExtent)) {
      var event = new BoundedIntervalEvent(this.ap_1, this.bp_1, this.cp_1, this.dp_1);
      this.cp_1 = minimumExtent;
      event.on(this.ap_1, this.bp_1, this.cp_1, this.dp_1);
      this.lm(event);
    }
  }
  jp(maximumExtent) {
    if (!(this.dp_1 === maximumExtent)) {
      var event = new BoundedIntervalEvent(this.ap_1, this.bp_1, this.cp_1, this.dp_1);
      this.dp_1 = maximumExtent;
      event.on(this.ap_1, this.bp_1, this.cp_1, this.dp_1);
      this.lm(event);
    }
  }
  kp() {
    return this.dp_1;
  }
  static lp(start, extent, minimum, maximum) {
    minimum = minimum === VOID ? start : minimum;
    maximum = maximum === VOID ? start + extent : maximum;
    return this.fp(PropertyClosedInterval.ko(start, extent), minimum, maximum);
  }
  lo(value, extent) {
    this.zo_1.setValue(value, extent);
  }
  setValue(value, extent) {
    return this.lo(value, extent);
  }
  sm() {
    return this.zo_1.startProperty;
  }
  tm() {
    return this.zo_1.endProperty;
  }
  um(value) {
    this.zo_1.start = value;
  }
  oi() {
    return this.zo_1.start;
  }
  vm(value) {
    this.zo_1.end = value;
  }
  wm() {
    return this.zo_1.end;
  }
  xm(value) {
    this.zo_1.extent = value;
  }
  ym() {
    return this.zo_1.extent;
  }
  rn(value) {
    return this.zo_1.contains(value);
  }
  contains(value) {
    return this.rn(value);
  }
  sn(start, end) {
    return this.zo_1.containsStartEnd(start, end);
  }
  containsStartEnd(start, end) {
    return this.sn(start, end);
  }
  tn(interval) {
    return ensureNotNull(interval).containsInterval(interval);
  }
  containsInterval(interval) {
    return this.tn(interval);
  }
  un(start, end) {
    return this.zo_1.overlaps(start, end);
  }
  overlaps(start, end) {
    return this.un(start, end);
  }
  vn(interval) {
    return ensureNotNull(interval).overlapsInterval(interval);
  }
  overlapsInterval(interval) {
    return this.vn(interval);
  }
  zm() {
    return this.zo_1.isDegenerate;
  }
  an() {
    return this.zo_1.isInverted;
  }
  mp(min, max) {
    if (!(this.ap_1 === min) || !(this.bp_1 === max)) {
      var event = new BoundedIntervalEvent(this.ap_1, this.bp_1, this.cp_1, this.dp_1);
      this.gp(min);
      this.hp(max);
      this.jp(max - min);
      event.on(this.ap_1, this.bp_1, this.cp_1, this.dp_1);
      this.lm(event);
    }
  }
  toString() {
    return 'SimpleBoundedInterval{start=' + this.zo_1.start + ', end=' + this.zo_1.end + ', extent=' + this.zo_1.extent + ', minimum=' + this.ap_1 + ', maximum=' + this.bp_1 + ', minimumExtent=' + this.cp_1 + ', maximumExtent=' + this.dp_1 + toString(_Char___init__impl__6a9atx(125));
  }
  get startProperty() {
    return this.sm();
  }
  get endProperty() {
    return this.tm();
  }
  get start() {
    return this.oi();
  }
  set start(value) {
    this.um(value);
  }
  get end() {
    return this.wm();
  }
  set end(value) {
    this.vm(value);
  }
  get extent() {
    return this.ym();
  }
  set extent(value) {
    this.xm(value);
  }
  get isDegenerate() {
    return this.zm();
  }
  get isInverted() {
    return this.an();
  }
}
class Companion_16 {
  constructor() {
    Companion_instance_16 = this;
    this.ZERO = BigDecimals_getInstance().np_1;
    this.ONE = BigDecimals_getInstance().op_1;
    this.TWO = BigDecimals_getInstance().pp_1;
    this.TEN = BigDecimals_getInstance().qp_1;
    this.ONE_TENTH = BigDecimals_getInstance().rp_1;
    this.ONE_HALF = BigDecimals_getInstance().sp_1;
    this.PI = BigDecimals_getInstance().tp_1;
    this.E = BigDecimals_getInstance().up_1;
  }
  vp() {
    return this.ZERO;
  }
  wp() {
    return this.ONE;
  }
  xp() {
    return this.TWO;
  }
  yp() {
    return this.TEN;
  }
  zp() {
    return this.ONE_TENTH;
  }
  aq() {
    return this.ONE_HALF;
  }
  bq() {
    return this.PI;
  }
  cq() {
    return this.E;
  }
  ofScaledLong(unscaledVal, scale) {
    return bigDecimalOf(unscaledVal, scale);
  }
  ofScaledLongWithPrecision(unscaledVal, scale, prec) {
    return bigDecimalOf_0(unscaledVal, scale, prec);
  }
  ofInt(val) {
    return bigDecimalOf_1(val);
  }
  of(val) {
    return bigDecimalOf_2(val);
  }
  ofScaledBigIntegerWithPrecision(intVal, scale, prec) {
    return bigDecimalOf_3(intVal, scale, prec);
  }
  dq(val, ctx) {
    return bigDecimalOf_4(val, ctx);
  }
  ofDouble(val, ctx, $super) {
    ctx = ctx === VOID ? null : ctx;
    return this.dq(val, ctx);
  }
  eq(val, ctx) {
    return bigDecimalOf_5(val, ctx);
  }
  ofFloat(val, ctx, $super) {
    ctx = ctx === VOID ? null : ctx;
    return this.eq(val, ctx);
  }
  fq(val, ctx) {
    return bigDecimalOf_6(val, ctx);
  }
  parse(val, ctx, $super) {
    ctx = ctx === VOID ? null : ctx;
    return this.fq(val, ctx);
  }
  gq(val, ctx) {
    return bigDecimalOf_7(val, ctx);
  }
  ofBigInteger(val, ctx, $super) {
    ctx = ctx === VOID ? null : ctx;
    return this.gq(val, ctx);
  }
  ofIntWithContext(val, ctx) {
    return bigDecimalOf_8(val, ctx);
  }
  ofWithContext(val, ctx) {
    return bigDecimalOf_9(val, ctx);
  }
}
class BigDecimal_0 {}
function sqrt(mc, $super) {
  mc = mc === VOID ? new MathContext() : mc;
  return this.mq(mc);
}
class Companion_17 {
  constructor() {
    Companion_instance_17 = this;
    this.ZERO = BigIntegers_getInstance().oq_1;
    this.ONE = BigIntegers_getInstance().pq_1;
    this.TWO = BigIntegers_getInstance().qq_1;
    this.NEGATIVE_ONE = BigIntegers_getInstance().sq_1;
    this.TEN = BigIntegers_getInstance().rq_1;
  }
  vp() {
    return this.ZERO;
  }
  wp() {
    return this.ONE;
  }
  xp() {
    return this.TWO;
  }
  tq() {
    return this.NEGATIVE_ONE;
  }
  yp() {
    return this.TEN;
  }
  probablePrime(bitLength, rnd) {
    return bigProbablePrimeInteger(bitLength, rnd);
  }
  ofLong(value) {
    return bigIntegerOf(value);
  }
  of(value) {
    return bigIntegerOf_0(value);
  }
  parse(value) {
    return bigIntegerOf_1(value);
  }
  parseWithRadix(value, radix) {
    return bigIntegerOf_2(value, radix);
  }
  ofIntArray(value) {
    return bigIntegerOf_3(value);
  }
  ofSlideIntArray(signum, magnitude, off, len) {
    return bigIntegerOf_4(signum, magnitude, off, len);
  }
}
class BigInteger_0 {}
function rangeTo(endInclusive) {
  return new BigIntegerRange(this, endInclusive);
}
function rangeToInt(endInclusive) {
  return new BigIntegerRange(this, Companion_getInstance_17().of(endInclusive));
}
function rangeToLong(endInclusive) {
  return new BigIntegerRange(this, Companion_getInstance_17().ofLong(endInclusive));
}
function plusInt(other) {
  return this.plus(Companion_getInstance_17().of(other));
}
function plusLong(other) {
  return this.plus(Companion_getInstance_17().ofLong(other));
}
function minusInt(other) {
  return this.minus(Companion_getInstance_17().of(other));
}
function minusLong(other) {
  return this.minus(Companion_getInstance_17().ofLong(other));
}
function timesInt(other) {
  return this.times(Companion_getInstance_17().of(other));
}
function timesLong(other) {
  return this.times(Companion_getInstance_17().ofLong(other));
}
function divInt(other) {
  return this.div(Companion_getInstance_17().of(other));
}
function divLong(other) {
  return this.div(Companion_getInstance_17().ofLong(other));
}
function divideAndRemainderInt(other) {
  return this.divideAndRemainder(Companion_getInstance_17().of(other));
}
function divideAndRemainderLong(other) {
  return this.divideAndRemainder(Companion_getInstance_17().ofLong(other));
}
function reminderInt(other) {
  return this.reminder(Companion_getInstance_17().of(other));
}
function reminderLong(other) {
  return this.reminder(Companion_getInstance_17().ofLong(other));
}
function gcdInt(other) {
  return this.gcd(Companion_getInstance_17().of(other));
}
function gcdLong(other) {
  return this.gcd(Companion_getInstance_17().ofLong(other));
}
function remInt(modulus) {
  return this.rem(Companion_getInstance_17().of(modulus));
}
function remLong(modulus) {
  return this.rem(Companion_getInstance_17().ofLong(modulus));
}
function modInverseInt(modulus) {
  return this.modInverse(Companion_getInstance_17().of(modulus));
}
function modInverseLong(modulus) {
  return this.modInverse(Companion_getInstance_17().ofLong(modulus));
}
function andInt(other) {
  return this.and(Companion_getInstance_17().of(other));
}
function andLong(other) {
  return this.and(Companion_getInstance_17().ofLong(other));
}
function orInt(other) {
  return this.or(Companion_getInstance_17().of(other));
}
function orLong(other) {
  return this.or(Companion_getInstance_17().ofLong(other));
}
function xorInt(other) {
  return this.xor(Companion_getInstance_17().of(other));
}
function xorLong(other) {
  return this.xor(Companion_getInstance_17().ofLong(other));
}
function andNotInt(other) {
  return this.andNot(Companion_getInstance_17().of(other));
}
function andNotLong(other) {
  return this.andNot(Companion_getInstance_17().ofLong(other));
}
class BigIntegerRange$iterator$1 {
  constructor(this$0) {
    this.yq_1 = this$0;
    this.xq_1 = this$0.zq_1;
  }
  y() {
    return this.xq_1.wq(this.yq_1.ar_1) <= 0;
  }
  z() {
    var temp = this.xq_1;
    this.xq_1 = this.xq_1.plus(Companion_getInstance_17().ONE);
    return temp;
  }
}
class BigIntegerRange {
  constructor(start, endInclusive) {
    this.zq_1 = start;
    this.ar_1 = endInclusive;
  }
  oi() {
    return this.zq_1;
  }
  si() {
    return this.ar_1;
  }
  x() {
    return new BigIntegerRange$iterator$1(this);
  }
  kj() {
    return this.zq_1;
  }
  lj() {
    return this.ar_1;
  }
  br(start, endInclusive) {
    return new BigIntegerRange(start, endInclusive);
  }
  copy(start, endInclusive, $super) {
    start = start === VOID ? this.zq_1 : start;
    endInclusive = endInclusive === VOID ? this.ar_1 : endInclusive;
    return this.br(start, endInclusive);
  }
  toString() {
    return 'BigIntegerRange(start=' + this.zq_1.toString() + ', endInclusive=' + this.ar_1.toString() + ')';
  }
  hashCode() {
    var result = this.zq_1.hashCode();
    result = imul_0(result, 31) + this.ar_1.hashCode() | 0;
    return result;
  }
  equals(other) {
    if (this === other)
      return true;
    if (!(other instanceof BigIntegerRange))
      return false;
    var tmp0_other_with_cast = other instanceof BigIntegerRange ? other : THROW_CCE();
    if (!this.zq_1.equals(tmp0_other_with_cast.zq_1))
      return false;
    if (!this.ar_1.equals(tmp0_other_with_cast.ar_1))
      return false;
    return true;
  }
}
class Companion_18 {
  constructor() {
    Companion_instance_18 = this;
    this.er_1 = BitSieve.fr();
  }
}
class BitSieve {
  static fr() {
    Companion_getInstance_18();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_BitSieve($this);
    $this.dr_1 = 9600;
    $this.cr_1 = longArray(unitIndex(Companion_getInstance_18(), $this.dr_1 - 1 | 0) + 1 | 0);
    set($this, 0);
    var nextIndex = 1;
    var nextPrime = 3;
    do {
      sieveSingle($this, $this.dr_1, nextIndex + nextPrime | 0, nextPrime);
      nextIndex = sieveSearch($this, $this.dr_1, nextIndex + 1 | 0);
      nextPrime = imul_0(2, nextIndex) + 1 | 0;
    }
     while (nextIndex > 0 && nextPrime < $this.dr_1);
    return $this;
  }
  static gr(base, searchLen) {
    Companion_getInstance_18();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_BitSieve($this);
    $this.cr_1 = longArray(unitIndex(Companion_getInstance_18(), searchLen - 1 | 0) + 1 | 0);
    $this.dr_1 = searchLen;
    var start = 0;
    var step = sieveSearch(Companion_getInstance_18().er_1, Companion_getInstance_18().er_1.dr_1, start);
    var convertedStep = imul_0(step, 2) + 1 | 0;
    var b = MutableBigInteger.kr(base);
    var q = MutableBigInteger.lr();
    do {
      start = b.mr(convertedStep, q);
      start = convertedStep - start | 0;
      if ((start % 2 | 0) === 0) {
        start = start + convertedStep | 0;
      }
      sieveSingle($this, searchLen, (start - 1 | 0) / 2 | 0, convertedStep);
      step = sieveSearch(Companion_getInstance_18().er_1, Companion_getInstance_18().er_1.dr_1, step + 1 | 0);
      convertedStep = imul_0(step, 2) + 1 | 0;
    }
     while (step > 0);
    return $this;
  }
  nr(initValue, certainty, random) {
    var offset = 1;
    var inductionVariable = 0;
    var last = ensureNotNull(this.cr_1).length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var nextLong = ensureNotNull(this.cr_1)[i].p3();
        var inductionVariable_0 = 0;
        if (inductionVariable_0 <= 63)
          do {
            var j = inductionVariable_0;
            inductionVariable_0 = inductionVariable_0 + 1 | 0;
            if (nextLong.t3(new Long(1, 0)).equals(new Long(1, 0))) {
              var candidate = initValue.plus(Companion_getInstance_21().ofLong(toLong(offset)));
              if (candidate.vr(certainty, random)) {
                return candidate;
              }
            }
            nextLong = nextLong.s3(1);
            offset = offset + 2 | 0;
          }
           while (inductionVariable_0 <= 63);
      }
       while (inductionVariable <= last);
    return null;
  }
}
class Companion_19 {
  constructor() {
    Companion_instance_19 = this;
    var tmp = this;
    // Inline function 'kotlin.charArrayOf' call
    tmp.wr_1 = charArrayOf([_Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(57)]);
    var tmp_0 = this;
    // Inline function 'kotlin.charArrayOf' call
    tmp_0.xr_1 = charArrayOf([_Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(57), _Char___init__impl__6a9atx(48), _Char___init__impl__6a9atx(49), _Char___init__impl__6a9atx(50), _Char___init__impl__6a9atx(51), _Char___init__impl__6a9atx(52), _Char___init__impl__6a9atx(53), _Char___init__impl__6a9atx(54), _Char___init__impl__6a9atx(55), _Char___init__impl__6a9atx(56), _Char___init__impl__6a9atx(57)]);
  }
}
class LongOverflow {
  constructor() {
    LongOverflow_instance = this;
    this.su_1 = Companion_getInstance_21().ofLong(new Long(0, -2147483648));
    this.tu_1 = Companion_getInstance_21().ofLong(new Long(-1, 2147483647));
  }
  uu(num) {
    var intVal = inflated(num);
    if (intVal.wq(this.su_1) < 0 || intVal.wq(this.tu_1) > 0) {
      throw ArithmeticException.md('Overflow');
    }
  }
}
class StringBuilderHelper {
  constructor(sb, compactCharArray) {
    Companion_getInstance_19();
    sb = sb === VOID ? StringBuilder.u() : sb;
    compactCharArray = compactCharArray === VOID ? charArray(19) : compactCharArray;
    this.vu_1 = sb;
    this.wu_1 = compactCharArray;
  }
  xu() {
    removeRange(this.vu_1, 0, this.vu_1.a());
    return this.vu_1;
  }
  yu(intCompact) {
    var intCompact_0 = intCompact;
    // Inline function 'kotlin.require' call
    // Inline function 'kotlin.require' call
    if (!(intCompact_0.m1(new Long(0, 0)) >= 0)) {
      // Inline function 'kotlin.require.<anonymous>' call
      var message = 'Failed requirement.';
      throw IllegalArgumentException.h(toString_1(message));
    }
    var q;
    var r;
    var charPos = this.wu_1.length;
    while (intCompact_0.m1(new Long(2147483647, 0)) > 0) {
      // Inline function 'kotlin.Long.div' call
      q = intCompact_0.k3(toLong(100));
      var tmp = intCompact_0;
      // Inline function 'kotlin.Long.times' call
      var tmp$ret$2 = q.j3(toLong(100));
      r = tmp.i3(tmp$ret$2).l1();
      intCompact_0 = q;
      charPos = charPos - 1 | 0;
      this.wu_1[charPos] = Companion_getInstance_19().xr_1[r];
      charPos = charPos - 1 | 0;
      this.wu_1[charPos] = Companion_getInstance_19().wr_1[r];
    }
    var q2;
    var i2 = intCompact_0.l1();
    while (i2 >= 100) {
      q2 = i2 / 100 | 0;
      r = i2 - imul_0(q2, 100) | 0;
      i2 = q2;
      charPos = charPos - 1 | 0;
      this.wu_1[charPos] = Companion_getInstance_19().xr_1[r];
      charPos = charPos - 1 | 0;
      this.wu_1[charPos] = Companion_getInstance_19().wr_1[r];
    }
    charPos = charPos - 1 | 0;
    this.wu_1[charPos] = Companion_getInstance_19().xr_1[i2];
    if (i2 >= 10) {
      charPos = charPos - 1 | 0;
      this.wu_1[charPos] = Companion_getInstance_19().wr_1[i2];
    }
    return charPos;
  }
}
class Companion_20 {
  constructor() {
    Companion_instance_20 = this;
    this.at_1 = new Long(0, -2147483648);
    this.bt_1 = Companion_getInstance_21().ofLong(new Long(0, -2147483648));
    this.ct_1 = 18;
    var tmp = this;
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp.dt_1 = [CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 0, 1), CommonBigDecimal.zt(Companion_getInstance_21().ONE, new Long(1, 0), 0, 1), CommonBigDecimal.zt(Companion_getInstance_21().TWO, new Long(2, 0), 0, 1), CommonBigDecimal.zt(Companion_getInstance_21().of(3), new Long(3, 0), 0, 1), CommonBigDecimal.zt(Companion_getInstance_21().of(4), new Long(4, 0), 0, 1), CommonBigDecimal.zt(Companion_getInstance_21().of(5), new Long(5, 0), 0, 1), CommonBigDecimal.zt(Companion_getInstance_21().of(6), new Long(6, 0), 0, 1), CommonBigDecimal.zt(Companion_getInstance_21().of(7), new Long(7, 0), 0, 1), CommonBigDecimal.zt(Companion_getInstance_21().of(8), new Long(8, 0), 0, 1), CommonBigDecimal.zt(Companion_getInstance_21().of(9), new Long(9, 0), 0, 1), CommonBigDecimal.zt(Companion_getInstance_21().TEN, new Long(10, 0), 0, 2)];
    var tmp_0 = this;
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp_0.et_1 = [this.dt_1[0], CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 1, 1), CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 2, 1), CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 3, 1), CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 4, 1), CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 5, 1), CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 6, 1), CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 7, 1), CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 8, 1), CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 9, 1), CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 10, 1), CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 11, 1), CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 12, 1), CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 13, 1), CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 14, 1), CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), 15, 1)];
    this.ft_1 = new Long(-1, 1073741823);
    this.gt_1 = new Long(0, -1073741824);
    this.ZERO = this.dt_1[0];
    this.ONE = this.dt_1[1];
    this.TWO = this.dt_1[2];
    this.TEN = this.dt_1[10];
    this.ONE_TENTH = this.ofScaledLong(new Long(1, 0), 1);
    this.ONE_HALF = this.ofScaledLong(new Long(5, 0), 1);
    this.PI = this.parse('3.141592653589793238462643383279502884197169399375105820974944592307816406286208998628034825342117067982148086513282306647093844609550582231725359408128481117450284102701938521105559644622948954930381964428810975665933446128475648233786783165271201909145648');
    this.E = this.parse('2.718281828459045235360287471352662497757247093699959574966967627724076630353547594571382178525166427427466391932003059921817413596629043572900334295260595630738132328627943490763233829880753195251019011573834187930702154089149934884167509244761460668082264');
    var tmp_1 = this;
    // Inline function 'kotlin.doubleArrayOf' call
    tmp_1.ht_1 = new Float64Array([1.0, 10.0, 100.0, 1000.0, 10000.0, 100000.0, 1000000.0, 1.0E7, 1.0E8, 1.0E9, 1.0E10, 1.0E11, 1.0E12, 1.0E13, 1.0E14, 1.0E15, 1.0E16, 1.0E17, 1.0E18, 1.0E19, 1.0E20, 1.0E21, 1.0E22]);
    var tmp_2 = this;
    // Inline function 'kotlin.floatArrayOf' call
    tmp_2.it_1 = new Float32Array([1.0, 10.0, 100.0, 1000.0, 10000.0, 100000.0, 1000000.0, 1.0E7, 1.0E8, 1.0E9, 1.0E10]);
    var tmp_3 = this;
    // Inline function 'kotlin.longArrayOf' call
    tmp_3.jt_1 = longArrayOf([new Long(1, 0), new Long(10, 0), new Long(100, 0), new Long(1000, 0), new Long(10000, 0), new Long(100000, 0), new Long(1000000, 0), new Long(10000000, 0), new Long(100000000, 0), new Long(1000000000, 0), new Long(1410065408, 2), new Long(1215752192, 23), new Long(-727379968, 232), new Long(1316134912, 2328), new Long(276447232, 23283), new Long(-1530494976, 232830), new Long(1874919424, 2328306), new Long(1569325056, 23283064), new Long(-1486618624, 232830643)]);
    var tmp_4 = this;
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp_4.kt_1 = [Companion_getInstance_21().ONE, Companion_getInstance_21().of(10), Companion_getInstance_21().of(100), Companion_getInstance_21().of(1000), Companion_getInstance_21().of(10000), Companion_getInstance_21().of(100000), Companion_getInstance_21().of(1000000), Companion_getInstance_21().of(10000000), Companion_getInstance_21().of(100000000), Companion_getInstance_21().of(1000000000), Companion_getInstance_21().ofLong(new Long(1410065408, 2)), Companion_getInstance_21().ofLong(new Long(1215752192, 23)), Companion_getInstance_21().ofLong(new Long(-727379968, 232)), Companion_getInstance_21().ofLong(new Long(1316134912, 2328)), Companion_getInstance_21().ofLong(new Long(276447232, 23283)), Companion_getInstance_21().ofLong(new Long(-1530494976, 232830)), Companion_getInstance_21().ofLong(new Long(1874919424, 2328306)), Companion_getInstance_21().ofLong(new Long(1569325056, 23283064)), Companion_getInstance_21().ofLong(new Long(-1486618624, 232830643))];
    this.lt_1 = this.kt_1.length;
    this.mt_1 = imul_0(16, this.lt_1);
    var tmp_5 = this;
    // Inline function 'kotlin.longArrayOf' call
    tmp_5.nt_1 = longArrayOf([new Long(-1, 2147483647), new Long(-858993460, 214748364), new Long(2061584302, 21474836), new Long(-1511828489, 2147483), new Long(1566804069, 214748), new Long(-702313053, 21474), new Long(2077252342, 2147), new Long(-1080764955, 214), new Long(2039407152, 21), new Long(633437444, 2), new Long(922337203, 0), new Long(92233720, 0), new Long(9223372, 0), new Long(922337, 0), new Long(92233, 0), new Long(9223, 0), new Long(922, 0), new Long(92, 0), new Long(9, 0)]);
    this.ot_1 = new Long(0, 1);
    var tmp_6 = this;
    // Inline function 'kotlin.longArrayOf' call
    var tmp_7 = longArrayOf([new Long(0, 0), new Long(-1981284352, -1966660860)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_8 = longArrayOf([new Long(5, 0), new Long(1661992960, 1808227885)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_9 = longArrayOf([new Long(54, 0), new Long(-559939584, 902409669)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_10 = longArrayOf([new Long(542, 0), new Long(-1304428544, 434162106)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_11 = longArrayOf([new Long(5421, 0), new Long(-159383552, 46653770)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_12 = longArrayOf([new Long(54210, 0), new Long(-1593835520, 466537709)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_13 = longArrayOf([new Long(542101, 0), new Long(1241513984, 370409800)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_14 = longArrayOf([new Long(5421010, 0), new Long(-469762048, -590869294)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_15 = longArrayOf([new Long(54210108, 0), new Long(-402653184, -1613725636)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_16 = longArrayOf([new Long(542101086, 0), new Long(268435456, 1042612833)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_17 = longArrayOf([new Long(1126043566, 1), new Long(-1610612736, 1836193738)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_18 = longArrayOf([new Long(-1624466224, 12), new Long(1073741824, 1182068202)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_19 = longArrayOf([new Long(935206946, 126), new Long(-2147483648, -1064219866)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_20 = longArrayOf([new Long(762134875, 1262), new Long(0, -2052264063)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_21 = longArrayOf([new Long(-968585837, 12621), new Long(0, 952195850)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_22 = longArrayOf([new Long(-1095923776, 126217), new Long(0, 932023908)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_23 = longArrayOf([new Long(1925664130, 1262177), new Long(0, 730304488)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_24 = longArrayOf([new Long(2076772117, 12621774), new Long(0, -1286889712)]);
    // Inline function 'kotlin.longArrayOf' call
    var tmp_25 = longArrayOf([new Long(-707115303, 126217744), new Long(0, 16004768)]);
    // Inline function 'kotlin.longArrayOf' call
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp_6.pt_1 = [tmp_7, tmp_8, tmp_9, tmp_10, tmp_11, tmp_12, tmp_13, tmp_14, tmp_15, tmp_16, tmp_17, tmp_18, tmp_19, tmp_20, tmp_21, tmp_22, tmp_23, tmp_24, tmp_25, longArrayOf([new Long(1518781562, 1262177448), new Long(0, 160047680)])];
  }
  vp() {
    return this.ZERO;
  }
  wp() {
    return this.ONE;
  }
  xp() {
    return this.TWO;
  }
  yp() {
    return this.TEN;
  }
  zp() {
    return this.ONE_TENTH;
  }
  aq() {
    return this.ONE_HALF;
  }
  bq() {
    return this.PI;
  }
  cq() {
    return this.E;
  }
  ofScaledLong(unscaledVal, scale) {
    if (scale === 0) {
      return this.of(unscaledVal);
    } else if (unscaledVal.equals(new Long(0, 0))) {
      return this.ru(scale);
    }
    var tmp;
    if (unscaledVal.equals(new Long(0, -2147483648))) {
      tmp = this.bt_1;
    } else {
      tmp = null;
    }
    return CommonBigDecimal.zt(tmp, unscaledVal, scale, 0);
  }
  ofScaledLongWithPrecision(unscaledVal, scale, prec) {
    var tmp;
    if (scale === 0 && unscaledVal.m1(new Long(0, 0)) >= 0 && unscaledVal.m1(toLong(this.dt_1.length)) < 0) {
      tmp = this.dt_1[unscaledVal.l1()];
    } else if (unscaledVal.equals(new Long(0, 0))) {
      tmp = this.ru(scale);
    } else {
      tmp = CommonBigDecimal.zt(unscaledVal.equals(new Long(0, -2147483648)) ? this.bt_1 : null, unscaledVal, scale, prec);
    }
    return tmp;
  }
  ofInt(val) {
    return this.of(toLong(val));
  }
  of(val) {
    var tmp;
    if (val.m1(new Long(0, 0)) >= 0 && val.m1(toLong(this.dt_1.length)) < 0) {
      tmp = this.dt_1[val.l1()];
    } else {
      var tmp_0;
      if (!val.equals(new Long(0, -2147483648))) {
        tmp_0 = CommonBigDecimal.zt((null == null ? true : null instanceof CommonBigInteger) ? null : THROW_CCE(), val, 0, 0);
      } else {
        tmp_0 = CommonBigDecimal.zt(this.bt_1, val, 0, 0);
      }
      tmp = tmp_0;
    }
    return tmp;
  }
  ofScaledBigIntegerWithPrecision(intVal, scale, prec) {
    var val = compactValFor(this, intVal);
    if (val.equals(new Long(0, 0))) {
      return this.ru(scale);
    } else if (scale === 0 && val.m1(new Long(0, 0)) >= 0 && val.m1(toLong(this.dt_1.length)) < 0) {
      return this.dt_1[val.l1()];
    }
    return CommonBigDecimal.zt(intVal, val, scale, prec);
  }
  ru(scale) {
    var tmp;
    if (scale >= 0 && scale < this.et_1.length) {
      tmp = this.et_1[scale];
    } else {
      tmp = CommonBigDecimal.zt(Companion_getInstance_21().ZERO, new Long(0, 0), scale, 1);
    }
    return tmp;
  }
  ofDouble(val, ctx) {
    return CommonBigDecimal.zu(val, ctx);
  }
  ofFloat(val, ctx) {
    return this.ofDouble(val, ctx);
  }
  fq(val, ctx) {
    var tmp;
    if (ctx === null) {
      tmp = CommonBigDecimal.bv(val);
    } else {
      tmp = CommonBigDecimal.av(val, ctx);
    }
    return tmp;
  }
  parse(val, ctx, $super) {
    ctx = ctx === VOID ? null : ctx;
    return $super === VOID ? this.fq(val, ctx) : $super.fq.call(this, val, ctx);
  }
  cv(val, ctx) {
    var tmp;
    if (ctx === null) {
      tmp = CommonBigDecimal.ev(val);
    } else {
      tmp = CommonBigDecimal.dv(val, ctx);
    }
    return tmp;
  }
  ofBigInteger(val, ctx, $super) {
    ctx = ctx === VOID ? null : ctx;
    return $super === VOID ? this.cv(val, ctx) : $super.cv.call(this, val, ctx);
  }
  ofIntWithContext(val, ctx) {
    return CommonBigDecimal.fv(toLong(val), ctx);
  }
  ofWithContext(val, ctx) {
    return CommonBigDecimal.fv(val, ctx);
  }
  yt(x) {
    var x_0 = x;
    // Inline function 'kotlin.require' call
    // Inline function 'kotlin.require' call
    if (!!x_0.equals(new Long(0, -2147483648))) {
      // Inline function 'kotlin.require.<anonymous>' call
      var message = 'Failed requirement.';
      throw IllegalArgumentException.h(toString_1(message));
    }
    if (x_0.m1(new Long(0, 0)) < 0) {
      x_0 = x_0.o3();
    }
    if (x_0.m1(new Long(10, 0)) < 0) {
      return 1;
    }
    var r = imul_0((64 - numberOfLeadingZeros_0(x_0) | 0) + 1 | 0, 1233) >>> 12 | 0;
    var tab = this.jt_1;
    return r >= tab.length || x_0.m1(tab[r]) < 0 ? r : r + 1 | 0;
  }
  qu(n, sign, scale) {
    if (n < this.jt_1.length) {
      return this.ofScaledLong(numberToLong(sign).j3(this.jt_1[n]), scale);
    } else {
      var unscaledVal = bigTenToThe(this, n);
      if (sign === -1) {
        unscaledVal = unscaledVal.unaryMinus();
      }
      return CommonBigDecimal.zt(unscaledVal, new Long(0, -2147483648), scale, n + 1 | 0);
    }
  }
}
class CommonBigDecimal {
  static zt(intVal, val, scale, prec) {
    Companion_getInstance_20();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_CommonBigDecimal($this);
    $this.rt_1 = scale;
    $this.st_1 = prec;
    $this.ut_1 = val;
    $this.qt_1 = intVal;
    return $this;
  }
  static gv(in_0, offset, len, mc) {
    Companion_getInstance_20();
    offset = offset === VOID ? 0 : offset;
    len = len === VOID ? in_0.length : len;
    mc = mc === VOID ? Companion_getInstance_22().UNLIMITED : mc;
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_CommonBigDecimal($this);
    var offset_0 = offset;
    var len_0 = len;
    if ((offset_0 + len_0 | 0) > in_0.length || offset_0 < 0) {
      throw NumberFormatException.hd('Bad offset or len arguments for char[] input.');
    }
    var prec = 0;
    var scl = 0;
    var rs = new Long(0, 0);
    var rb = null;
    try {
      var isneg = false;
      if (in_0[offset_0] === _Char___init__impl__6a9atx(45)) {
        isneg = true;
        offset_0 = offset_0 + 1 | 0;
        len_0 = len_0 - 1 | 0;
      } else if (in_0[offset_0] === _Char___init__impl__6a9atx(43)) {
        offset_0 = offset_0 + 1 | 0;
        len_0 = len_0 - 1 | 0;
      }
      var dot = false;
      var exp = new Long(0, 0);
      var c;
      var isCompact = len_0 <= 18;
      var idx = 0;
      if (isCompact) {
        $l$loop: while (len_0 > 0) {
          c = in_0[offset_0];
          if (c === _Char___init__impl__6a9atx(48)) {
            if (prec === 0) {
              prec = 1;
            } else if (!rs.equals(new Long(0, 0))) {
              // Inline function 'kotlin.Long.times' call
              rs = rs.j3(toLong(10));
              prec = prec + 1 | 0;
            }
            if (dot) {
              scl = scl + 1 | 0;
            }
          } else if (_Char___init__impl__6a9atx(49) <= c ? c <= _Char___init__impl__6a9atx(57) : false) {
            var digit = Char__minus_impl_a2frrh(c, _Char___init__impl__6a9atx(48));
            if (!(prec === 1) || !rs.equals(new Long(0, 0))) {
              prec = prec + 1 | 0;
            }
            // Inline function 'kotlin.Long.times' call
            // Inline function 'kotlin.Long.plus' call
            rs = rs.j3(toLong(10)).h3(toLong(digit));
            if (dot) {
              scl = scl + 1 | 0;
            }
          } else if (c === _Char___init__impl__6a9atx(46)) {
            if (dot) {
              throw NumberFormatException.hd('Character array contains more than one decimal point.');
            }
            dot = true;
          } else if (isDigit(c)) {
            var digit_0 = toDigit(c, 10);
            if (digit_0 === 0) {
              if (prec === 0) {
                prec = 1;
              } else if (!rs.equals(new Long(0, 0))) {
                // Inline function 'kotlin.Long.times' call
                rs = rs.j3(toLong(10));
                prec = prec + 1 | 0;
              }
            } else {
              if (!(prec === 1) || !rs.equals(new Long(0, 0))) {
                prec = prec + 1 | 0;
              }
              // Inline function 'kotlin.Long.times' call
              // Inline function 'kotlin.Long.plus' call
              rs = rs.j3(toLong(10)).h3(toLong(digit_0));
            }
            if (dot) {
              scl = scl + 1 | 0;
            }
          } else if (c === _Char___init__impl__6a9atx(101) || c === _Char___init__impl__6a9atx(69)) {
            exp = parseExp(Companion_getInstance_20(), in_0, offset_0, len_0);
            if (!toLong(exp.l1()).equals(exp)) {
              throw NumberFormatException.hd('Exponent overflow.');
            }
            break $l$loop;
          } else {
            throw NumberFormatException.hd('Character ' + toString(c) + ' is neither a decimal digit number, decimal point, nor' + ' "e" notation exponential mark.');
          }
          offset_0 = offset_0 + 1 | 0;
          len_0 = len_0 - 1 | 0;
        }
        if (prec === 0) {
          throw NumberFormatException.hd('No digits found.');
        }
        if (!exp.equals(new Long(0, 0))) {
          scl = adjustScale($this, scl, exp);
        }
        rs = isneg ? rs.o3() : rs;
        var mcp = mc.precision;
        var drop = prec - mcp | 0;
        if (mcp > 0 && drop > 0) {
          while (drop > 0) {
            var tmp = Companion_getInstance_20();
            var tmp12 = toLong(scl);
            // Inline function 'kotlin.Long.minus' call
            var other = drop;
            var tmp$ret$6 = tmp12.i3(toLong(other));
            scl = checkScaleNonZero(tmp, tmp$ret$6);
            rs = divideAndRound_0(Companion_getInstance_20(), rs, Companion_getInstance_20().jt_1[drop], mc.roundingMode.value);
            prec = Companion_getInstance_20().yt(rs);
            drop = prec - mcp | 0;
          }
        }
      } else {
        var coeff = charArray(len_0);
        $l$loop_1: while (len_0 > 0) {
          c = in_0[offset_0];
          if ((_Char___init__impl__6a9atx(48) <= c ? c <= _Char___init__impl__6a9atx(57) : false) || isDigit(c)) {
            if (c === _Char___init__impl__6a9atx(48) || toDigit(c, 10) === 0) {
              if (prec === 0) {
                coeff[idx] = c;
                prec = 1;
              } else if (!(idx === 0)) {
                var _unary__edvuaz = idx;
                idx = _unary__edvuaz + 1 | 0;
                coeff[_unary__edvuaz] = c;
                prec = prec + 1 | 0;
              }
            } else {
              if (!(prec === 1) || !(idx === 0)) {
                prec = prec + 1 | 0;
              }
              var _unary__edvuaz_0 = idx;
              idx = _unary__edvuaz_0 + 1 | 0;
              coeff[_unary__edvuaz_0] = c;
            }
            if (dot) {
              scl = scl + 1 | 0;
            }
            offset_0 = offset_0 + 1 | 0;
            len_0 = len_0 - 1 | 0;
            continue $l$loop_1;
          }
          if (c === _Char___init__impl__6a9atx(46)) {
            if (dot) {
              throw NumberFormatException.hd('Character array contains more than one decimal point.');
            }
            dot = true;
            offset_0 = offset_0 + 1 | 0;
            len_0 = len_0 - 1 | 0;
            continue $l$loop_1;
          }
          if (!(c === _Char___init__impl__6a9atx(101)) && !(c === _Char___init__impl__6a9atx(69))) {
            throw NumberFormatException.hd('Character array is missing "e" notation exponential mark.');
          }
          exp = parseExp(Companion_getInstance_20(), in_0, offset_0, len_0);
          if (!toLong(exp.l1()).equals(exp)) {
            throw NumberFormatException.hd('Exponent overflow.');
          }
          break $l$loop_1;
        }
        if (prec === 0) {
          throw NumberFormatException.hd('No digits found.');
        }
        if (!exp.equals(new Long(0, 0))) {
          scl = adjustScale($this, scl, exp);
        }
        rb = CommonBigInteger.hv(coeff, isneg ? -1 : 1, prec);
        rs = compactValFor(Companion_getInstance_20(), rb);
        var mcp_0 = mc.precision;
        if (1 <= mcp_0 ? mcp_0 < prec : false) {
          if (rs.equals(new Long(0, -2147483648))) {
            var drop_0 = prec - mcp_0 | 0;
            $l$loop_2: while (drop_0 > 0) {
              var tmp_0 = Companion_getInstance_20();
              var tmp14 = toLong(scl);
              // Inline function 'kotlin.Long.minus' call
              var other_0 = drop_0;
              var tmp$ret$7 = tmp14.i3(toLong(other_0));
              scl = checkScaleNonZero(tmp_0, tmp$ret$7);
              rb = divideAndRoundByTenPow(Companion_getInstance_20(), ensureNotNull(rb), drop_0, mc.roundingMode.value);
              rs = compactValFor(Companion_getInstance_20(), rb);
              if (!rs.equals(new Long(0, -2147483648))) {
                prec = Companion_getInstance_20().yt(rs);
                break $l$loop_2;
              }
              prec = bigDigitLength(Companion_getInstance_20(), rb);
              drop_0 = prec - mcp_0 | 0;
            }
          }
          if (!rs.equals(new Long(0, -2147483648))) {
            var drop_1 = prec - mcp_0 | 0;
            while (drop_1 > 0) {
              var tmp_1 = Companion_getInstance_20();
              var tmp16 = toLong(scl);
              // Inline function 'kotlin.Long.minus' call
              var other_1 = drop_1;
              var tmp$ret$8 = tmp16.i3(toLong(other_1));
              scl = checkScaleNonZero(tmp_1, tmp$ret$8);
              rs = divideAndRound_0(Companion_getInstance_20(), rs, Companion_getInstance_20().jt_1[drop_1], mc.roundingMode.value);
              prec = Companion_getInstance_20().yt(rs);
              drop_1 = prec - mcp_0 | 0;
            }
            rb = null;
          }
        }
      }
    } catch ($p) {
      if ($p instanceof IndexOutOfBoundsException) {
        var e = $p;
        var nfe = NumberFormatException.gd();
        throw nfe;
      } else {
        if ($p instanceof RuntimeException) {
          var e_0 = $p;
          var nfe_0 = NumberFormatException.gd();
          throw nfe_0;
        } else {
          throw $p;
        }
      }
    }
    $this.rt_1 = scl;
    $this.st_1 = prec;
    $this.ut_1 = rs;
    $this.qt_1 = rb;
    return $this;
  }
  static bv(val) {
    Companion_getInstance_20();
    return this.gv(toCharArray(val), 0, val.length);
  }
  static av(val, mc) {
    Companion_getInstance_20();
    return this.gv(toCharArray(val), 0, val.length, mc);
  }
  static zu(val, mc) {
    Companion_getInstance_20();
    mc = mc === VOID ? Companion_getInstance_22().UNLIMITED : mc;
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_CommonBigDecimal($this);
    if (isInfinite(val) || isInfinite(val)) {
      throw NumberFormatException.hd('Infinite or NaN');
    }
    var valBits = toBits(val);
    var sign = valBits.r3(63).equals(new Long(0, 0)) ? 1 : -1;
    var exponent = valBits.r3(52).t3(new Long(2047, 0)).l1();
    var tmp;
    if (exponent === 0) {
      // Inline function 'kotlin.Long.minus' call
      var tmp$ret$0 = (new Long(0, 1048576)).i3(toLong(1));
      tmp = valBits.t3(tmp$ret$0).q3(1);
    } else {
      // Inline function 'kotlin.Long.minus' call
      var tmp$ret$1 = (new Long(0, 1048576)).i3(toLong(1));
      tmp = valBits.t3(tmp$ret$1).u3(new Long(0, 1048576));
    }
    var significand = tmp;
    exponent = exponent - 1075 | 0;
    if (significand.equals(new Long(0, 0))) {
      $this.qt_1 = Companion_getInstance_21().ZERO;
      $this.rt_1 = 0;
      $this.ut_1 = new Long(0, 0);
      $this.st_1 = 1;
      return $this;
    }
    while (significand.t3(new Long(1, 0)).equals(new Long(0, 0))) {
      significand = significand.r3(1);
      exponent = exponent + 1 | 0;
    }
    var scl = 0;
    var rb;
    var compactVal = numberToLong(sign).j3(significand);
    if (exponent === 0) {
      rb = compactVal.equals(new Long(0, -2147483648)) ? Companion_getInstance_20().bt_1 : null;
    } else {
      if (exponent < 0) {
        rb = Companion_getInstance_21().of(5).pow(-exponent | 0).pu(compactVal);
        scl = -exponent | 0;
      } else {
        rb = Companion_getInstance_21().TWO.pow(exponent).pu(compactVal);
      }
      compactVal = compactValFor(Companion_getInstance_20(), rb);
    }
    var prec = 0;
    var mcp = mc.precision;
    if (mcp > 0) {
      var mode = mc.roundingMode.value;
      var drop;
      if (compactVal.equals(new Long(0, -2147483648))) {
        prec = bigDigitLength(Companion_getInstance_20(), ensureNotNull(rb));
        drop = prec - mcp | 0;
        $l$loop: while (drop > 0) {
          var tmp_0 = Companion_getInstance_20();
          var tmp4 = toLong(scl);
          // Inline function 'kotlin.Long.minus' call
          var other = drop;
          var tmp$ret$2 = tmp4.i3(toLong(other));
          scl = checkScaleNonZero(tmp_0, tmp$ret$2);
          rb = divideAndRoundByTenPow(Companion_getInstance_20(), ensureNotNull(rb), drop, mode);
          compactVal = compactValFor(Companion_getInstance_20(), rb);
          if (!compactVal.equals(new Long(0, -2147483648))) {
            break $l$loop;
          }
          prec = bigDigitLength(Companion_getInstance_20(), rb);
          drop = prec - mcp | 0;
        }
      }
      if (!compactVal.equals(new Long(0, -2147483648))) {
        prec = Companion_getInstance_20().yt(compactVal);
        drop = prec - mcp | 0;
        while (drop > 0) {
          var tmp_1 = Companion_getInstance_20();
          var tmp6 = toLong(scl);
          // Inline function 'kotlin.Long.minus' call
          var other_0 = drop;
          var tmp$ret$3 = tmp6.i3(toLong(other_0));
          scl = checkScaleNonZero(tmp_1, tmp$ret$3);
          compactVal = divideAndRound_0(Companion_getInstance_20(), compactVal, Companion_getInstance_20().jt_1[drop], mc.roundingMode.value);
          prec = Companion_getInstance_20().yt(compactVal);
          drop = prec - mcp | 0;
        }
        rb = null;
      }
    }
    $this.qt_1 = rb;
    $this.ut_1 = compactVal;
    $this.rt_1 = scl;
    $this.st_1 = prec;
    return $this;
  }
  static ev(val) {
    Companion_getInstance_20();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_CommonBigDecimal($this);
    $this.rt_1 = 0;
    $this.qt_1 = val;
    $this.ut_1 = compactValFor(Companion_getInstance_20(), val);
    return $this;
  }
  static dv(val, mc) {
    Companion_getInstance_20();
    return this.iv(val, 0, mc);
  }
  static ou(unscaledVal, scale) {
    Companion_getInstance_20();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_CommonBigDecimal($this);
    $this.qt_1 = unscaledVal;
    $this.ut_1 = compactValFor(Companion_getInstance_20(), unscaledVal);
    $this.rt_1 = scale;
    return $this;
  }
  static iv(unscaledVal, scale, mc) {
    Companion_getInstance_20();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_CommonBigDecimal($this);
    var unscaledVal_0 = unscaledVal;
    var scale_0 = scale;
    var compactVal = compactValFor(Companion_getInstance_20(), ensureNotNull(unscaledVal_0));
    var mcp = mc.precision;
    var prec = 0;
    if (mcp > 0) {
      var mode = mc.roundingMode.value;
      if (compactVal.equals(new Long(0, -2147483648))) {
        prec = bigDigitLength(Companion_getInstance_20(), unscaledVal_0);
        var drop = prec - mcp | 0;
        $l$loop: while (drop > 0) {
          var tmp = Companion_getInstance_20();
          var tmp0 = toLong(scale_0);
          // Inline function 'kotlin.Long.minus' call
          var other = drop;
          var tmp$ret$0 = tmp0.i3(toLong(other));
          scale_0 = checkScaleNonZero(tmp, tmp$ret$0);
          unscaledVal_0 = divideAndRoundByTenPow(Companion_getInstance_20(), ensureNotNull(unscaledVal_0), drop, mode);
          compactVal = compactValFor(Companion_getInstance_20(), unscaledVal_0);
          if (!compactVal.equals(new Long(0, -2147483648))) {
            break $l$loop;
          }
          prec = bigDigitLength(Companion_getInstance_20(), unscaledVal_0);
          drop = prec - mcp | 0;
        }
      }
      if (!compactVal.equals(new Long(0, -2147483648))) {
        prec = Companion_getInstance_20().yt(compactVal);
        var drop_0 = prec - mcp | 0;
        while (drop_0 > 0) {
          var tmp_0 = Companion_getInstance_20();
          var tmp2 = toLong(scale_0);
          // Inline function 'kotlin.Long.minus' call
          var other_0 = drop_0;
          var tmp$ret$1 = tmp2.i3(toLong(other_0));
          scale_0 = checkScaleNonZero(tmp_0, tmp$ret$1);
          compactVal = divideAndRound_0(Companion_getInstance_20(), compactVal, Companion_getInstance_20().jt_1[drop_0], mode);
          prec = Companion_getInstance_20().yt(compactVal);
          drop_0 = prec - mcp | 0;
        }
        unscaledVal_0 = null;
      }
    }
    $this.qt_1 = unscaledVal_0;
    $this.ut_1 = compactVal;
    $this.rt_1 = scale_0;
    $this.st_1 = prec;
    return $this;
  }
  static fv(val, mc) {
    Companion_getInstance_20();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_CommonBigDecimal($this);
    var val_0 = val;
    var mcp = mc.precision;
    var mode = mc.roundingMode.value;
    var prec = 0;
    var scl = 0;
    var rb = val_0.equals(new Long(0, -2147483648)) ? Companion_getInstance_20().bt_1 : null;
    if (mcp > 0) {
      if (val_0.equals(new Long(0, -2147483648))) {
        prec = 19;
        var drop = prec - mcp | 0;
        $l$loop: while (drop > 0) {
          var tmp = Companion_getInstance_20();
          var tmp0 = toLong(scl);
          // Inline function 'kotlin.Long.minus' call
          var other = drop;
          var tmp$ret$0 = tmp0.i3(toLong(other));
          scl = checkScaleNonZero(tmp, tmp$ret$0);
          rb = divideAndRoundByTenPow(Companion_getInstance_20(), ensureNotNull(rb), drop, mode);
          val_0 = compactValFor(Companion_getInstance_20(), rb);
          if (!val_0.equals(new Long(0, -2147483648))) {
            break $l$loop;
          }
          prec = bigDigitLength(Companion_getInstance_20(), rb);
          drop = prec - mcp | 0;
        }
      }
      if (!val_0.equals(new Long(0, -2147483648))) {
        prec = Companion_getInstance_20().yt(val_0);
        var drop_0 = prec - mcp | 0;
        while (drop_0 > 0) {
          var tmp_0 = Companion_getInstance_20();
          var tmp2 = toLong(scl);
          // Inline function 'kotlin.Long.minus' call
          var other_0 = drop_0;
          var tmp$ret$1 = tmp2.i3(toLong(other_0));
          scl = checkScaleNonZero(tmp_0, tmp$ret$1);
          val_0 = divideAndRound_0(Companion_getInstance_20(), val_0, Companion_getInstance_20().jt_1[drop_0], mc.roundingMode.value);
          prec = Companion_getInstance_20().yt(val_0);
          drop_0 = prec - mcp | 0;
        }
        rb = null;
      }
    }
    $this.qt_1 = rb;
    $this.ut_1 = val_0;
    $this.rt_1 = scl;
    $this.st_1 = prec;
    return $this;
  }
  plus(augend) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var augend_0 = ensureNotNull(augend);
    var tmp;
    if (!this.ut_1.equals(new Long(0, -2147483648))) {
      var tmp_0;
      if (!augend_0.ut_1.equals(new Long(0, -2147483648))) {
        tmp_0 = sum_1(Companion_getInstance_20(), this.ut_1, this.rt_1, augend_0.ut_1, augend_0.rt_1);
      } else {
        tmp_0 = sum_2(Companion_getInstance_20(), this.ut_1, this.rt_1, ensureNotNull(augend_0.qt_1), augend_0.rt_1);
      }
      tmp = tmp_0;
    } else {
      var tmp_1;
      if (!augend_0.ut_1.equals(new Long(0, -2147483648))) {
        tmp_1 = sum_2(Companion_getInstance_20(), augend_0.ut_1, augend_0.rt_1, ensureNotNull(this.qt_1), this.rt_1);
      } else {
        tmp_1 = sum_3(Companion_getInstance_20(), this.qt_1, this.rt_1, augend_0.qt_1, augend_0.rt_1);
      }
      tmp = tmp_1;
    }
    return tmp;
  }
  plusWithContext(augend, mc) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var augend_0 = ensureNotNull(augend);
    if (mc.precision === 0) {
      return this.plus(augend_0);
    }
    var lhs = this;
    // Inline function 'kotlin.run' call
    // Inline function 'com.macrofocus.common.math.big.CommonBigDecimal.plus.<anonymous>' call
    var lhsIsZero = lhs.signum === 0;
    var augendIsZero = augend_0.signum === 0;
    if (lhsIsZero || augendIsZero) {
      var tmp0 = lhs.scale;
      // Inline function 'kotlin.math.max' call
      var b = augend_0.scale;
      var preferredScale = Math.max(tmp0, b);
      var result = lhsIsZero ? doRound(Companion_getInstance_20(), augend_0, mc) : doRound(Companion_getInstance_20(), lhs, mc);
      if (lhsIsZero && augendIsZero) {
        return Companion_getInstance_20().ru(preferredScale);
      }
      if (ensureNotNull(result).scale === preferredScale) {
        return result;
      } else if (result.scale > preferredScale) {
        return stripZerosToMatchScale(Companion_getInstance_20(), result.qt_1, result.ut_1, result.rt_1, preferredScale);
      } else {
        var precisionDiff = mc.precision - result.precision | 0;
        var scaleDiff = preferredScale - result.scale | 0;
        var tmp;
        if (precisionDiff >= scaleDiff) {
          tmp = result.setScale(preferredScale);
        } else {
          tmp = result.setScale(result.scale + precisionDiff | 0);
        }
        return tmp;
      }
    }
    var tmp3 = toLong(lhs.rt_1);
    // Inline function 'kotlin.Long.minus' call
    var other = augend_0.rt_1;
    var padding = tmp3.i3(toLong(other));
    if (!padding.equals(new Long(0, 0))) {
      var arg = preAlign(this, lhs, augend_0, padding, mc);
      matchScale(Companion_getInstance_20(), arg);
      lhs = arg[0];
      augend_0 = arg[1];
    }
    return doRound_1(Companion_getInstance_20(), inflated(lhs).plus(inflated(augend_0)), lhs.rt_1, mc);
  }
  minus(subtrahend) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var subtrahend_0 = subtrahend;
    var tmp;
    if (!this.ut_1.equals(new Long(0, -2147483648))) {
      var tmp_0;
      if (!subtrahend_0.ut_1.equals(new Long(0, -2147483648))) {
        tmp_0 = sum_1(Companion_getInstance_20(), this.ut_1, this.rt_1, subtrahend_0.ut_1.o3(), subtrahend_0.rt_1);
      } else {
        tmp_0 = sum_2(Companion_getInstance_20(), this.ut_1, this.rt_1, ensureNotNull(subtrahend_0.qt_1).unaryMinus(), subtrahend_0.rt_1);
      }
      tmp = tmp_0;
    } else {
      var tmp_1;
      if (!subtrahend_0.ut_1.equals(new Long(0, -2147483648))) {
        tmp_1 = sum_2(Companion_getInstance_20(), subtrahend_0.ut_1.o3(), subtrahend_0.rt_1, ensureNotNull(this.qt_1), this.rt_1);
      } else {
        tmp_1 = sum_3(Companion_getInstance_20(), this.qt_1, this.rt_1, ensureNotNull(subtrahend_0.qt_1).unaryMinus(), subtrahend_0.rt_1);
      }
      tmp = tmp_1;
    }
    return tmp;
  }
  minusWithContext(subtrahend, mc) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var subtrahend_0 = subtrahend;
    return mc.precision === 0 ? this.minus(subtrahend_0) : this.plusWithContext(subtrahend_0.unaryMinus(), mc);
  }
  times(multiplicand) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var multiplicand_0 = ensureNotNull(multiplicand);
    var tmp1 = toLong(this.rt_1);
    // Inline function 'kotlin.Long.plus' call
    var other = multiplicand_0.rt_1;
    var tmp$ret$3 = tmp1.h3(toLong(other));
    var productScale = checkScale_1(this, tmp$ret$3);
    var tmp;
    if (!this.ut_1.equals(new Long(0, -2147483648))) {
      var tmp_0;
      if (!multiplicand_0.ut_1.equals(new Long(0, -2147483648))) {
        tmp_0 = multiply_1(Companion_getInstance_20(), this.ut_1, multiplicand_0.ut_1, productScale);
      } else {
        tmp_0 = multiply_2(Companion_getInstance_20(), this.ut_1, multiplicand_0.qt_1, productScale);
      }
      tmp = tmp_0;
    } else {
      var tmp_1;
      if (!multiplicand_0.ut_1.equals(new Long(0, -2147483648))) {
        tmp_1 = multiply_2(Companion_getInstance_20(), multiplicand_0.ut_1, this.qt_1, productScale);
      } else {
        tmp_1 = multiply_3(Companion_getInstance_20(), ensureNotNull(this.qt_1), multiplicand_0.qt_1, productScale);
      }
      tmp = tmp_1;
    }
    return tmp;
  }
  timesWithContext(multiplicand, mc) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var multiplicand_0 = multiplicand;
    if (mc.precision === 0) {
      return this.times(multiplicand_0);
    }
    var tmp1 = toLong(this.rt_1);
    // Inline function 'kotlin.Long.plus' call
    var other = multiplicand_0.rt_1;
    var tmp$ret$3 = tmp1.h3(toLong(other));
    var productScale = checkScale_1(this, tmp$ret$3);
    var tmp;
    if (!this.ut_1.equals(new Long(0, -2147483648))) {
      var tmp_0;
      if (!multiplicand_0.ut_1.equals(new Long(0, -2147483648))) {
        tmp_0 = multiplyAndRound(Companion_getInstance_20(), this.ut_1, multiplicand_0.ut_1, productScale, mc);
      } else {
        tmp_0 = multiplyAndRound_0(Companion_getInstance_20(), this.ut_1, multiplicand_0.qt_1, productScale, mc);
      }
      tmp = tmp_0;
    } else {
      var tmp_1;
      if (!multiplicand_0.ut_1.equals(new Long(0, -2147483648))) {
        tmp_1 = multiplyAndRound_0(Companion_getInstance_20(), multiplicand_0.ut_1, this.qt_1, productScale, mc);
      } else {
        tmp_1 = multiplyAndRound_1(Companion_getInstance_20(), ensureNotNull(this.qt_1), multiplicand_0.qt_1, productScale, mc);
      }
      tmp = tmp_1;
    }
    return tmp;
  }
  div(divisor) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var divisor_0 = divisor;
    if (divisor_0.signum === 0) {
      if (this.signum === 0) {
        throw ArithmeticException.md('Division undefined');
      }
      throw ArithmeticException.md('Division by zero');
    }
    var tmp = Companion_getInstance_20();
    var tmp1 = toLong(this.rt_1);
    // Inline function 'kotlin.Long.minus' call
    var other = divisor_0.rt_1;
    var tmp$ret$3 = tmp1.i3(toLong(other));
    var preferredScale = saturateLong(tmp, tmp$ret$3);
    if (this.signum === 0) {
      return Companion_getInstance_20().ru(preferredScale);
    } else {
      var tmp_0 = this.precision;
      // Inline function 'kotlin.math.ceil' call
      var x = 10.0 * divisor_0.precision / 3.0;
      var tmp$ret$4 = Math.ceil(x);
      var tmp4 = numberToLong(tmp_0).h3(numberToLong(tmp$ret$4));
      // Inline function 'kotlin.math.min' call
      var b = new Long(2147483647, 0);
      var tmp$ret$5 = tmp4.m1(b) <= 0 ? tmp4 : b;
      var mc = new MathContext(tmp$ret$5.l1(), RoundingMode_UNNECESSARY_getInstance());
      var quotient;
      try {
        quotient = this.divWithContext(divisor_0, mc);
      } catch ($p) {
        if ($p instanceof ArithmeticException) {
          var e = $p;
          throw ArithmeticException.md('Non-terminating decimal expansion; no exact representable decimal result.');
        } else {
          throw $p;
        }
      }
      var quotientScale = ensureNotNull(quotient).scale;
      var tmp_1;
      if (preferredScale > quotientScale) {
        tmp_1 = quotient.setScaleInt(preferredScale, RoundingMode_UNNECESSARY_getInstance().value);
      } else {
        tmp_1 = quotient;
      }
      return tmp_1;
    }
  }
  divWithContext(divisor, mc) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var divisor_0 = divisor;
    var mcp = mc.precision;
    if (mcp === 0) {
      return this.div(divisor_0);
    }
    var dividend = this;
    var tmp1 = toLong(dividend.rt_1);
    // Inline function 'kotlin.Long.minus' call
    var other = divisor_0.rt_1;
    var preferredScale = tmp1.i3(toLong(other));
    if (divisor_0.signum === 0) {
      if (dividend.signum === 0) {
        throw ArithmeticException.md('Division undefined');
      }
      throw ArithmeticException.md('Division by zero');
    }
    if (dividend.signum === 0) {
      return Companion_getInstance_20().ru(saturateLong(Companion_getInstance_20(), preferredScale));
    }
    var xscale = dividend.precision;
    var yscale = divisor_0.precision;
    var tmp;
    if (!dividend.ut_1.equals(new Long(0, -2147483648))) {
      var tmp_0;
      if (!divisor_0.ut_1.equals(new Long(0, -2147483648))) {
        tmp_0 = divide_0(Companion_getInstance_20(), dividend.ut_1, xscale, divisor_0.ut_1, yscale, preferredScale, mc);
      } else {
        tmp_0 = divide_2(Companion_getInstance_20(), dividend.ut_1, xscale, divisor_0.qt_1, yscale, preferredScale, mc);
      }
      tmp = tmp_0;
    } else {
      var tmp_1;
      if (!divisor_0.ut_1.equals(new Long(0, -2147483648))) {
        tmp_1 = divide_1(Companion_getInstance_20(), dividend.qt_1, xscale, divisor_0.ut_1, yscale, preferredScale, mc);
      } else {
        tmp_1 = divide_3(Companion_getInstance_20(), dividend.qt_1, xscale, divisor_0.qt_1, yscale, preferredScale, mc);
      }
      tmp = tmp_1;
    }
    return tmp;
  }
  divideToIntegralValue(divisor) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var divisor_0 = divisor;
    var tmp = Companion_getInstance_20();
    var tmp1 = toLong(this.rt_1);
    // Inline function 'kotlin.Long.minus' call
    var other = divisor_0.rt_1;
    var tmp$ret$3 = tmp1.i3(toLong(other));
    var preferredScale = saturateLong(tmp, tmp$ret$3);
    if (compareMagnitude(this, divisor_0) < 0) {
      return Companion_getInstance_20().ru(preferredScale);
    }
    if (this.signum === 0 && !(divisor_0.signum === 0)) {
      return this.setScaleInt(preferredScale, RoundingMode_UNNECESSARY_getInstance().value);
    }
    var tmp_0 = toLong(this.precision);
    // Inline function 'kotlin.math.ceil' call
    var x = 10.0 * divisor_0.precision / 3.0;
    var tmp$ret$4 = Math.ceil(x);
    var tmp_1 = tmp_0.h3(numberToLong(tmp$ret$4));
    var tmp4 = toLong(this.scale);
    // Inline function 'kotlin.Long.minus' call
    var other_0 = divisor_0.scale;
    var tmp$ret$5 = tmp4.i3(toLong(other_0));
    // Inline function 'kotlin.Long.plus' call
    var tmp8 = tmp_1.h3(abs(tmp$ret$5)).h3(toLong(2));
    // Inline function 'kotlin.math.min' call
    var b = new Long(2147483647, 0);
    var maxDigits = (tmp8.m1(b) <= 0 ? tmp8 : b).l1();
    var quotient = this.divWithContext(divisor_0, new MathContext(maxDigits, RoundingMode_DOWN_getInstance()));
    if (ensureNotNull(quotient).rt_1 > 0) {
      quotient = quotient.setScaleRounding(0, RoundingMode_DOWN_getInstance());
      quotient = stripZerosToMatchScale(Companion_getInstance_20(), quotient.qt_1, quotient.ut_1, quotient.rt_1, preferredScale);
    }
    if (quotient.rt_1 < preferredScale) {
      quotient = quotient.setScaleInt(preferredScale, RoundingMode_UNNECESSARY_getInstance().value);
    }
    return quotient;
  }
  divideToIntegralValueWithContext(divisor, mc) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var divisor_0 = divisor;
    if (mc.precision === 0 || compareMagnitude(this, divisor_0) < 0) {
      return this.divideToIntegralValue(divisor_0);
    }
    var tmp = Companion_getInstance_20();
    var tmp1 = toLong(this.rt_1);
    // Inline function 'kotlin.Long.minus' call
    var other = divisor_0.rt_1;
    var tmp$ret$3 = tmp1.i3(toLong(other));
    var preferredScale = saturateLong(tmp, tmp$ret$3);
    var result = this.divWithContext(divisor_0, new MathContext(mc.precision, RoundingMode_DOWN_getInstance()));
    if (ensureNotNull(result).scale < 0) {
      var product = result.times(divisor_0);
      if (compareMagnitude(this.minus(product), divisor_0) >= 0) {
        throw ArithmeticException.md('Division impossible');
      }
    } else if (result.scale > 0) {
      result = result.setScaleRounding(0, RoundingMode_DOWN_getInstance());
    }
    var precisionDiff;
    if (preferredScale > result.scale) {
      precisionDiff = mc.precision - result.precision | 0;
      if (precisionDiff > 0) {
        var tmp_0 = result;
        var tmp_1 = result.scale;
        // Inline function 'kotlin.math.min' call
        var b = preferredScale - result.rt_1 | 0;
        var tmp$ret$4 = Math.min(precisionDiff, b);
        return tmp_0.setScale(tmp_1 + tmp$ret$4 | 0);
      }
    }
    return stripZerosToMatchScale(Companion_getInstance_20(), result.qt_1, result.ut_1, result.rt_1, preferredScale);
  }
  rem(divisor) {
    var divrem = this.divideAndRemainder(divisor);
    return divrem.jj_1;
  }
  remWithContext(divisor, mc) {
    var divrem = this.divideAndRemainderWithContext(divisor, mc);
    return divrem.jj_1;
  }
  divideAndRemainder(divisor) {
    var temp = this.divideToIntegralValue(divisor);
    return new Pair(temp, temp.times(divisor));
  }
  divideAndRemainderWithContext(divisor, mc) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var divisor_0 = divisor;
    if (mc.precision === 0) {
      return this.divideAndRemainder(divisor_0);
    }
    var lhs = this;
    var temp = lhs.divideToIntegralValueWithContext(divisor_0, mc);
    return new Pair(temp, lhs.minus(temp.times(divisor_0)));
  }
  mq(mc) {
    var signum = this.signum;
    if (signum === 1) {
      var preferredScale = this.scale / 2 | 0;
      var zeroWithFinalPreferredScale = Companion_getInstance_20().ofScaledLong(new Long(0, 0), preferredScale);
      var stripped = this.stripTrailingZeros();
      var strippedScale = stripped.scale;
      if (_get_isPowerOfTen__mg2oyo(stripped) && (strippedScale % 2 | 0) === 0) {
        var result = Companion_getInstance_20().ofScaledLong(new Long(1, 0), strippedScale / 2 | 0);
        if (!(result.scale === preferredScale)) {
          result = result.plusWithContext(zeroWithFinalPreferredScale, mc);
        }
        return result;
      }
      var scale = (stripped.scale - stripped.precision | 0) + 1 | 0;
      var tmp;
      if ((scale % 2 | 0) === 0) {
        tmp = scale;
      } else {
        tmp = scale - 1 | 0;
      }
      var scaleAdjust = tmp;
      var working = stripped.scaleByPowerOfTen(scaleAdjust);
      // Inline function 'kotlin.require' call
      // Inline function 'kotlin.require' call
      if (!(Companion_getInstance_20().ONE_TENTH.nq(working) <= 0 && working.nq(Companion_getInstance_20().TEN) < 0)) {
        // Inline function 'kotlin.require.<anonymous>' call
        var message = 'Failed requirement.';
        throw IllegalArgumentException.h(toString_1(message));
      }
      // Inline function 'kotlin.math.sqrt' call
      var x = working.toDouble();
      var tmp$ret$1 = Math.sqrt(x);
      var guess = CommonBigDecimal.zu(tmp$ret$1);
      var guessPrecision = 15;
      var originalPrecision = mc.precision;
      var targetPrecision;
      if (originalPrecision === 0) {
        targetPrecision = (stripped.precision / 2 | 0) + 1 | 0;
      } else {
        targetPrecision = originalPrecision;
      }
      var approx = guess;
      var workingPrecision = working.precision;
      do {
        var tmp2 = guessPrecision;
        // Inline function 'kotlin.math.max' call
        var b = targetPrecision + 2 | 0;
        // Inline function 'kotlin.math.max' call
        var a = Math.max(tmp2, b);
        var tmpPrecision = Math.max(a, workingPrecision);
        var mcTmp = new MathContext(tmpPrecision, RoundingMode_HALF_EVEN_getInstance());
        approx = Companion_getInstance_20().ONE_HALF.times(approx.plusWithContext(working.divWithContext(approx, mcTmp), mcTmp));
        guessPrecision = imul_0(guessPrecision, 2);
      }
       while (guessPrecision < (targetPrecision + 2 | 0));
      var result_0;
      var targetRm = mc.roundingMode;
      if (targetRm === RoundingMode_UNNECESSARY_getInstance() || originalPrecision === 0) {
        var tmpRm = targetRm === RoundingMode_UNNECESSARY_getInstance() ? RoundingMode_DOWN_getInstance() : targetRm;
        var mcTmp_0 = new MathContext(targetPrecision, tmpRm);
        result_0 = approx.scaleByPowerOfTen((-scaleAdjust | 0) / 2 | 0).round(mcTmp_0);
        if (!(this.minus(ensureNotNull(result_0).times(result_0)).nq(Companion_getInstance_20().ZERO) === 0)) {
          throw ArithmeticException.md('Computed square root not exact.');
        }
      } else {
        result_0 = approx.scaleByPowerOfTen((-scaleAdjust | 0) / 2 | 0).round(mc);
      }
      if (!(ensureNotNull(result_0).scale === preferredScale)) {
        result_0 = result_0.stripTrailingZeros().plusWithContext(zeroWithFinalPreferredScale, new MathContext(originalPrecision, RoundingMode_UNNECESSARY_getInstance()));
      }
      // Inline function 'kotlin.require' call
      // Inline function 'kotlin.require' call
      if (!squareRootResultAssertions(this, result_0, mc)) {
        // Inline function 'kotlin.require.<anonymous>' call
        var message_0 = 'Failed requirement.';
        throw IllegalArgumentException.h(toString_1(message_0));
      }
      return result_0;
    } else {
      switch (signum) {
        case -1:
          throw ArithmeticException.md('Attempted square root of negative CommonBigDecimal');
        case 0:
          return Companion_getInstance_20().ofScaledLong(new Long(0, 0), this.scale / 2 | 0);
        default:
          throw AssertionError.qd('Bad value from _signum');
      }
    }
  }
  pow(n) {
    if (n < 0 || n > 999999999) {
      throw ArithmeticException.md('Invalid operation');
    }
    // Inline function 'kotlin.Long.times' call
    var tmp$ret$0 = toLong(this.rt_1).j3(toLong(n));
    var newScale = checkScale_1(this, tmp$ret$0);
    return CommonBigDecimal.ou(inflated(this).pow(n), newScale);
  }
  powWithContext(n, mc) {
    if (mc.precision === 0) {
      return this.pow(n);
    }
    if (n < -999999999 || n > 999999999) {
      throw ArithmeticException.md('Invalid operation');
    }
    if (n === 0) {
      return Companion_getInstance_20().ONE;
    }
    var lhs = this;
    var workmc = mc;
    var mag = abs_0(n);
    if (mc.precision > 0) {
      var elength = Companion_getInstance_20().yt(toLong(mag));
      if (elength > mc.precision) {
        throw ArithmeticException.md('Invalid operation');
      }
      workmc = new MathContext((mc.precision + elength | 0) + 1 | 0, mc.roundingMode);
    }
    var acc = Companion_getInstance_20().ONE;
    var seenbit = false;
    var i = 1;
    $l$loop: while (true) {
      mag = mag + mag | 0;
      if (mag < 0) {
        seenbit = true;
        acc = acc.timesWithContext(lhs, workmc);
      }
      if (i === 31) {
        break $l$loop;
      }
      if (seenbit) {
        acc = acc.timesWithContext(acc, workmc);
      }
      i = i + 1 | 0;
    }
    if (n < 0) {
      acc = ensureNotNull(Companion_getInstance_20().ONE.divWithContext(acc, workmc));
    }
    return doRound(Companion_getInstance_20(), acc, mc);
  }
  hq() {
    return this.signum < 0 ? this.unaryMinus() : this;
  }
  absoluteValueWithContext(mc) {
    return this.signum < 0 ? this.unaryMinusWithContext(mc) : this.unaryPlusWithContext(mc);
  }
  unaryMinus() {
    var tmp;
    if (this.ut_1.equals(new Long(0, -2147483648))) {
      tmp = CommonBigDecimal.zt(ensureNotNull(this.qt_1).unaryMinus(), new Long(0, -2147483648), this.rt_1, this.st_1);
    } else {
      tmp = Companion_getInstance_20().ofScaledLongWithPrecision(this.ut_1.o3(), this.rt_1, this.st_1);
    }
    return tmp;
  }
  unaryMinusWithContext(mc) {
    return this.unaryMinus().unaryPlusWithContext(mc);
  }
  unaryPlus() {
    return this;
  }
  unaryPlusWithContext(mc) {
    return mc.precision === 0 ? this : doRound(Companion_getInstance_20(), this, mc);
  }
  iq() {
    var tmp;
    if (!this.ut_1.equals(new Long(0, -2147483648))) {
      tmp = get_sign(this.ut_1);
    } else {
      tmp = ensureNotNull(this.qt_1).signum;
    }
    return tmp;
  }
  jq() {
    return this.rt_1;
  }
  kq() {
    var result = this.st_1;
    if (result === 0) {
      var s = this.ut_1;
      if (!s.equals(new Long(0, -2147483648))) {
        result = Companion_getInstance_20().yt(s);
      } else {
        result = bigDigitLength(Companion_getInstance_20(), ensureNotNull(this.qt_1));
      }
      this.st_1 = result;
    }
    return result;
  }
  lq() {
    return inflated(this);
  }
  round(mc) {
    return this.unaryPlusWithContext(mc);
  }
  setScaleRounding(newScale, roundingMode) {
    return this.setScaleInt(newScale, roundingMode.value);
  }
  setScaleInt(newScale, roundingMode) {
    if (roundingMode < RoundingMode_UP_getInstance().value || roundingMode > RoundingMode_UNNECESSARY_getInstance().value) {
      throw IllegalArgumentException.h('Invalid rounding mode');
    }
    var oldScale = this.rt_1;
    if (newScale === oldScale) {
      return this;
    }
    if (this.signum === 0) {
      return Companion_getInstance_20().ru(newScale);
    }
    if (!this.ut_1.equals(new Long(0, -2147483648))) {
      var rs = this.ut_1;
      if (newScale > oldScale) {
        // Inline function 'kotlin.Long.minus' call
        var tmp$ret$0 = toLong(newScale).i3(toLong(oldScale));
        var raise = checkScale_1(this, tmp$ret$0);
        rs = longMultiplyPowerTen(Companion_getInstance_20(), rs, raise);
        if (!rs.equals(new Long(0, -2147483648))) {
          return Companion_getInstance_20().ofScaledLong(rs, newScale);
        }
        var rb = bigMultiplyPowerTen_1(this, raise);
        return CommonBigDecimal.zt(rb, new Long(0, -2147483648), newScale, this.st_1 > 0 ? this.st_1 + raise | 0 : 0);
      } else {
        // Inline function 'kotlin.Long.minus' call
        var tmp$ret$1 = toLong(oldScale).i3(toLong(newScale));
        var drop = checkScale_1(this, tmp$ret$1);
        var tmp;
        if (drop < Companion_getInstance_20().jt_1.length) {
          tmp = divideAndRound(Companion_getInstance_20(), rs, Companion_getInstance_20().jt_1[drop], newScale, roundingMode, newScale);
        } else {
          tmp = divideAndRound_4(Companion_getInstance_20(), inflated(this), bigTenToThe(Companion_getInstance_20(), drop), newScale, roundingMode, newScale);
        }
        return tmp;
      }
    } else {
      if (newScale > oldScale) {
        // Inline function 'kotlin.Long.minus' call
        var tmp$ret$2 = toLong(newScale).i3(toLong(oldScale));
        var raise_0 = checkScale_1(this, tmp$ret$2);
        var rb_0 = bigMultiplyPowerTen_0(Companion_getInstance_20(), this.qt_1, raise_0);
        return CommonBigDecimal.zt(ensureNotNull(rb_0), new Long(0, -2147483648), newScale, this.st_1 > 0 ? this.st_1 + raise_0 | 0 : 0);
      } else {
        // Inline function 'kotlin.Long.minus' call
        var tmp$ret$3 = toLong(oldScale).i3(toLong(newScale));
        var drop_0 = checkScale_1(this, tmp$ret$3);
        var tmp_0;
        if (drop_0 < Companion_getInstance_20().jt_1.length) {
          tmp_0 = divideAndRound_2(Companion_getInstance_20(), ensureNotNull(this.qt_1), Companion_getInstance_20().jt_1[drop_0], newScale, roundingMode, newScale);
        } else {
          tmp_0 = divideAndRound_4(Companion_getInstance_20(), ensureNotNull(this.qt_1), bigTenToThe(Companion_getInstance_20(), drop_0), newScale, roundingMode, newScale);
        }
        return tmp_0;
      }
    }
  }
  setScale(newScale) {
    return this.setScaleInt(newScale, RoundingMode_UNNECESSARY_getInstance().value);
  }
  movePointLeft(n) {
    // Inline function 'kotlin.Long.plus' call
    var tmp$ret$0 = toLong(this.rt_1).h3(toLong(n));
    var newScale = checkScale_1(this, tmp$ret$0);
    var num = CommonBigDecimal.zt(ensureNotNull(this.qt_1), this.ut_1, newScale, 0);
    return num.rt_1 < 0 ? num.setScaleInt(0, RoundingMode_UNNECESSARY_getInstance().value) : num;
  }
  movePointRight(n) {
    // Inline function 'kotlin.Long.minus' call
    var tmp$ret$0 = toLong(this.rt_1).i3(toLong(n));
    var newScale = checkScale_1(this, tmp$ret$0);
    var num = CommonBigDecimal.zt(ensureNotNull(this.qt_1), this.ut_1, newScale, 0);
    return num.rt_1 < 0 ? num.setScaleInt(0, RoundingMode_UNNECESSARY_getInstance().value) : num;
  }
  scaleByPowerOfTen(n) {
    // Inline function 'kotlin.Long.minus' call
    var tmp$ret$0 = toLong(this.rt_1).i3(toLong(n));
    return CommonBigDecimal.zt(this.qt_1, this.ut_1, checkScale_1(this, tmp$ret$0), this.st_1);
  }
  stripTrailingZeros() {
    var tmp;
    if (this.ut_1.equals(new Long(0, 0)) || (!(this.qt_1 == null) && this.qt_1.signum === 0)) {
      tmp = Companion_getInstance_20().ZERO;
    } else if (!this.ut_1.equals(new Long(0, -2147483648))) {
      tmp = createAndStripZerosToMatchScale_0(Companion_getInstance_20(), this.ut_1, this.rt_1, new Long(0, -2147483648));
    } else {
      tmp = createAndStripZerosToMatchScale(Companion_getInstance_20(), ensureNotNull(this.qt_1), this.rt_1, new Long(0, -2147483648));
    }
    return tmp;
  }
  nq(other) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var other_0 = other;
    if (this.rt_1 === other_0.rt_1) {
      var xs = this.ut_1;
      var ys = other_0.ut_1;
      if (!xs.equals(new Long(0, -2147483648)) && !ys.equals(new Long(0, -2147483648))) {
        var tmp;
        if (!xs.equals(ys)) {
          var tmp_0;
          if (xs.m1(ys) > 0) {
            tmp_0 = 1;
          } else {
            tmp_0 = -1;
          }
          tmp = tmp_0;
        } else {
          tmp = 0;
        }
        return tmp;
      }
    }
    var xsign = this.signum;
    var ysign = other_0.signum;
    if (!(xsign === ysign)) {
      return xsign > ysign ? 1 : -1;
    }
    if (xsign === 0) {
      return 0;
    }
    var cmp = compareMagnitude(this, other_0);
    return xsign > 0 ? cmp : -cmp | 0;
  }
  d(other) {
    return this.nq((!(other == null) ? isInterface(other, BigDecimal_0) : false) ? other : THROW_CCE());
  }
  equals(other) {
    if (!(other instanceof CommonBigDecimal)) {
      return false;
    }
    var xDec = other;
    if (other === this) {
      return true;
    }
    if (!(this.rt_1 === xDec.rt_1)) {
      return false;
    }
    var s = this.ut_1;
    var xs = xDec.ut_1;
    if (!s.equals(new Long(0, -2147483648))) {
      if (xs.equals(new Long(0, -2147483648))) {
        xs = compactValFor(Companion_getInstance_20(), ensureNotNull(xDec.qt_1));
      }
      return xs.equals(s);
    } else if (!xs.equals(new Long(0, -2147483648))) {
      return xs.equals(compactValFor(Companion_getInstance_20(), ensureNotNull(this.qt_1)));
    }
    return inflated(this).equals(inflated(xDec));
  }
  min(val) {
    return this.nq(val) <= 0 ? this : val;
  }
  max(val) {
    return this.nq(val) >= 0 ? this : val;
  }
  hashCode() {
    var tmp;
    if (!this.ut_1.equals(new Long(0, -2147483648))) {
      var val2 = this.ut_1.m1(new Long(0, 0)) < 0 ? this.ut_1.o3() : this.ut_1;
      var temp = numberToLong(imul_0(val2.s3(32).l1(), 31)).h3(val2.t3(new Long(-1, 0))).l1();
      tmp = imul_0(31, this.ut_1.m1(new Long(0, 0)) < 0 ? -temp | 0 : temp) + this.rt_1 | 0;
    } else {
      tmp = imul_0(31, ensureNotNull(this.qt_1).hashCode()) + this.rt_1 | 0;
    }
    return tmp;
  }
  toString() {
    var sc = this.tt_1;
    if (sc == null) {
      sc = layoutChars(this, true);
      this.tt_1 = sc;
    }
    return sc;
  }
  toEngineeringString() {
    return layoutChars(this, false);
  }
  toPlainString() {
    if (this.rt_1 === 0) {
      var tmp;
      if (!this.ut_1.equals(new Long(0, -2147483648))) {
        tmp = this.ut_1.toString();
      } else {
        tmp = ensureNotNull(this.qt_1).toString();
      }
      return tmp;
    }
    if (this.rt_1 < 0) {
      if (this.signum === 0) {
        return '0';
      }
      var trailingZeros = checkScaleNonZero(Companion_getInstance_20(), toLong(this.rt_1).o3());
      var buf;
      if (!this.ut_1.equals(new Long(0, -2147483648))) {
        buf = StringBuilder.pb(20 + trailingZeros | 0);
        buf.af(this.ut_1);
      } else {
        var str = ensureNotNull(this.qt_1).toString();
        buf = StringBuilder.pb(str.length + trailingZeros | 0);
        buf.lb(str);
      }
      var inductionVariable = 0;
      if (inductionVariable < trailingZeros)
        do {
          var i = inductionVariable;
          inductionVariable = inductionVariable + 1 | 0;
          buf.mb(_Char___init__impl__6a9atx(48));
        }
         while (inductionVariable < trailingZeros);
      return buf.toString();
    }
    var str_0;
    if (!this.ut_1.equals(new Long(0, -2147483648))) {
      // Inline function 'kotlin.math.absoluteValue' call
      var this_0 = this.ut_1;
      str_0 = abs(this_0).toString();
    } else {
      str_0 = ensureNotNull(this.qt_1).absoluteValue.toString();
    }
    return getValueString(this, this.signum, str_0, this.rt_1);
  }
  toBigInteger() {
    return inflated(this.setScaleInt(0, RoundingMode_DOWN_getInstance().value));
  }
  toBigIntegerExact() {
    return inflated(this.setScaleInt(0, RoundingMode_UNNECESSARY_getInstance().value));
  }
  toLong() {
    var tmp;
    if (!this.ut_1.equals(new Long(0, -2147483648)) && this.rt_1 === 0) {
      tmp = this.ut_1;
    } else {
      tmp = this.toBigInteger().toLong();
    }
    return tmp;
  }
  toLongExact() {
    if (!this.ut_1.equals(new Long(0, -2147483648)) && this.rt_1 === 0) {
      return this.ut_1;
    }
    if ((this.precision - this.rt_1 | 0) > 19) {
      throw ArithmeticException.md('Overflow');
    }
    if (this.signum === 0) {
      return new Long(0, 0);
    }
    if ((this.precision - this.rt_1 | 0) <= 0) {
      throw ArithmeticException.md('Rounding necessary');
    }
    var num = this.setScaleInt(0, RoundingMode_UNNECESSARY_getInstance().value);
    if (num.precision >= 19) {
      LongOverflow_getInstance().uu(num);
    }
    return inflated(num).toLong();
  }
  toInt() {
    var tmp;
    if (!this.ut_1.equals(new Long(0, -2147483648)) && this.rt_1 === 0) {
      tmp = this.ut_1.l1();
    } else {
      tmp = this.toBigInteger().toInt();
    }
    return tmp;
  }
  toByte() {
    return toByte(this.toInt());
  }
  toChar() {
    return numberToChar(this.toInt());
  }
  toShort() {
    return toShort(this.toInt());
  }
  toIntExact() {
    var num = this.toLongExact();
    if (!toLong(num.l1()).equals(num)) {
      throw ArithmeticException.md('Overflow');
    }
    return num.l1();
  }
  toShortExact() {
    var num = this.toLongExact();
    if (!toLong(num.x3()).equals(num)) {
      throw ArithmeticException.md('Overflow');
    }
    return num.x3();
  }
  toByteExact() {
    var num = this.toLongExact();
    if (!toLong(num.w3()).equals(num)) {
      throw ArithmeticException.md('Overflow');
    }
    return num.w3();
  }
  toFloat() {
    if (!this.ut_1.equals(new Long(0, -2147483648))) {
      if (this.rt_1 === 0) {
        return this.ut_1.z3();
      } else {
        if (abs(this.ut_1).m1(new Long(4194304, 0)) < 0) {
          if (this.rt_1 > 0 && this.rt_1 < Companion_getInstance_20().it_1.length) {
            return this.ut_1.z3() / Companion_getInstance_20().it_1[this.rt_1];
          } else if (this.rt_1 < 0 && this.rt_1 > (-Companion_getInstance_20().it_1.length | 0)) {
            return this.ut_1.z3() * Companion_getInstance_20().it_1[-this.rt_1 | 0];
          }
        }
      }
    }
    // Inline function 'kotlin.text.toFloat' call
    var this_0 = this.toString();
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    return toDouble(this_0);
  }
  toDouble() {
    if (!this.ut_1.equals(new Long(0, -2147483648))) {
      if (this.rt_1 === 0) {
        return this.ut_1.a4();
      } else {
        if (abs(this.ut_1).m1(new Long(0, 1048576)) < 0) {
          if (this.rt_1 > 0 && this.rt_1 < Companion_getInstance_20().ht_1.length) {
            return this.ut_1.a4() / Companion_getInstance_20().ht_1[this.rt_1];
          } else if (this.rt_1 < 0 && this.rt_1 > (-Companion_getInstance_20().ht_1.length | 0)) {
            return this.ut_1.a4() * Companion_getInstance_20().ht_1[-this.rt_1 | 0];
          }
        }
      }
    }
    return toDouble(this.toString());
  }
  ulp() {
    return Companion_getInstance_20().ofScaledLongWithPrecision(new Long(1, 0), this.scale, 1);
  }
  get absoluteValue() {
    return this.hq();
  }
  get signum() {
    return this.iq();
  }
  get scale() {
    return this.jq();
  }
  get precision() {
    return this.kq();
  }
  get unscaledValue() {
    return this.lq();
  }
}
class Companion_21 {
  constructor() {
    Companion_instance_21 = this;
    this.yr_1 = new Long(-1, 0);
    this.zr_1 = 67108864;
    this.as_1 = 500000000;
    this.bs_1 = 80;
    this.cs_1 = 240;
    this.ds_1 = 128;
    this.es_1 = 216;
    this.fs_1 = 80;
    this.gs_1 = 40;
    this.hs_1 = 20;
    this.is_1 = 20;
    this.js_1 = 512;
    var tmp = this;
    // Inline function 'kotlin.longArrayOf' call
    tmp.ks_1 = longArrayOf([new Long(0, 0), new Long(0, 0), new Long(1024, 0), new Long(1624, 0), new Long(2048, 0), new Long(2378, 0), new Long(2648, 0), new Long(2875, 0), new Long(3072, 0), new Long(3247, 0), new Long(3402, 0), new Long(3543, 0), new Long(3672, 0), new Long(3790, 0), new Long(3899, 0), new Long(4001, 0), new Long(4096, 0), new Long(4186, 0), new Long(4271, 0), new Long(4350, 0), new Long(4426, 0), new Long(4498, 0), new Long(4567, 0), new Long(4633, 0), new Long(4696, 0), new Long(4756, 0), new Long(4814, 0), new Long(4870, 0), new Long(4923, 0), new Long(4975, 0), new Long(5025, 0), new Long(5074, 0), new Long(5120, 0), new Long(5166, 0), new Long(5210, 0), new Long(5253, 0), new Long(5295, 0)]);
    this.ls_1 = 95;
    this.ms_1 = 100;
    var tmp_0 = this;
    // Inline function 'kotlin.Long.times' call
    // Inline function 'kotlin.Long.times' call
    // Inline function 'kotlin.Long.times' call
    // Inline function 'kotlin.Long.times' call
    // Inline function 'kotlin.Long.times' call
    // Inline function 'kotlin.Long.times' call
    // Inline function 'kotlin.Long.times' call
    // Inline function 'kotlin.Long.times' call
    // Inline function 'kotlin.Long.times' call
    // Inline function 'kotlin.Long.times' call
    // Inline function 'kotlin.Long.times' call
    var tmp$ret$11 = (new Long(3, 0)).j3(toLong(5)).j3(toLong(7)).j3(toLong(11)).j3(toLong(13)).j3(toLong(17)).j3(toLong(19)).j3(toLong(23)).j3(toLong(29)).j3(toLong(31)).j3(toLong(37)).j3(toLong(41));
    tmp_0.ns_1 = this.ofLong(tmp$ret$11);
    this.os_1 = 16;
    var tmp_1 = this;
    // Inline function 'kotlin.arrayOfNulls' call
    var size = this.os_1 + 1 | 0;
    tmp_1.ps_1 = fillArrayVal(Array(size), null);
    var tmp_2 = this;
    // Inline function 'kotlin.arrayOfNulls' call
    var size_0 = this.os_1 + 1 | 0;
    tmp_2.qs_1 = fillArrayVal(Array(size_0), null);
    var tmp_3 = this;
    // Inline function 'kotlin.arrayOfNulls' call
    tmp_3.rs_1 = fillArrayVal(Array(0), null);
    var tmp_4 = this;
    // Inline function 'kotlin.math.ln' call
    tmp_4.ts_1 = Math.log(2.0);
    var inductionVariable = 1;
    var last = this.os_1;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var magnitude = new Int32Array(1);
        magnitude[0] = i;
        this.ps_1[i] = CommonBigInteger.jv(magnitude, 1);
        this.qs_1[i] = CommonBigInteger.jv(magnitude, -1);
      }
       while (!(i === last));
    var tmp_5 = this;
    // Inline function 'kotlin.arrayOfNulls' call
    tmp_5.rs_1 = fillArrayVal(Array(37), null);
    this.ss_1 = new Float64Array(37);
    var inductionVariable_0 = 2;
    if (inductionVariable_0 <= 36)
      do {
        var i_0 = inductionVariable_0;
        inductionVariable_0 = inductionVariable_0 + 1 | 0;
        var tmp_6 = this.rs_1;
        // Inline function 'kotlin.arrayOf' call
        // Inline function 'kotlin.js.unsafeCast' call
        // Inline function 'kotlin.js.asDynamic' call
        tmp_6[i_0] = [this.ofLong(toLong(i_0))];
        // Inline function 'kotlin.math.ln' call
        var tmp$ret$20 = Math.log(i_0);
        this.ss_1[i_0] = tmp$ret$20;
      }
       while (inductionVariable_0 <= 36);
    this.ZERO = CommonBigInteger.jv(new Int32Array(0), 0);
    this.ONE = this.of(1);
    this.TWO = this.of(2);
    this.NEGATIVE_ONE = this.of(-1);
    this.TEN = this.of(10);
    var tmp_7 = this;
    // Inline function 'kotlin.intArrayOf' call
    tmp_7.us_1 = new Int32Array([7, 25, 81, 241, 673, 1793, 2147483647]);
    var tmp_8 = this;
    // Inline function 'kotlin.arrayOfNulls' call
    tmp_8.vs_1 = fillArrayVal(Array(64), null);
    this.vs_1[63] = '000000000000000000000000000000000000000000000000000000000000000';
    var inductionVariable_1 = 0;
    if (inductionVariable_1 <= 62)
      do {
        var i_1 = inductionVariable_1;
        inductionVariable_1 = inductionVariable_1 + 1 | 0;
        // Inline function 'kotlin.text.substring' call
        // Inline function 'kotlin.js.asDynamic' call
        var tmp$ret$24 = ensureNotNull(this.vs_1[63]).substring(0, i_1);
        this.vs_1[i_1] = tmp$ret$24;
      }
       while (inductionVariable_1 <= 62);
    var tmp_9 = this;
    // Inline function 'kotlin.intArrayOf' call
    tmp_9.ws_1 = new Int32Array([0, 0, 62, 39, 31, 27, 24, 22, 20, 19, 18, 18, 17, 17, 16, 16, 15, 15, 15, 14, 14, 14, 14, 13, 13, 13, 13, 13, 13, 12, 12, 12, 12, 12, 12, 12, 12]);
    var tmp_10 = this;
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp_10.xs_1 = [null, null, this.ofLong(new Long(0, 1073741824)), this.ofLong(new Long(-1201670133, 943559024)), this.ofLong(new Long(0, 1073741824)), this.ofLong(new Long(-99612771, 1734723475)), this.ofLong(new Long(-520093696, 1103240376)), this.ofLong(new Long(1344430353, 910326151)), this.ofLong(new Long(0, 268435456)), this.ofLong(new Long(-400556711, 314519674)), this.ofLong(new Long(-1486618624, 232830643)), this.ofLong(new Long(-1019239111, 1294519126)), this.ofLong(new Long(0, 516560652)), this.ofLong(new Long(1645991757, 2014081906)), this.ofLong(new Long(2105606144, 507094277)), this.ofLong(new Long(1039759105, 1529326745)), this.ofLong(new Long(0, 268435456)), this.ofLong(new Long(2116147697, 666459801)), this.ofLong(new Long(1012695040, 1570824677)), this.ofLong(new Long(-281002215, 186033240)), this.ofLong(new Long(-1879048192, 381469726)), this.ofLong(new Long(-641667255, 755283965)), this.ofLong(new Long(-895336448, 1448630651)), this.ofLong(new Long(-1826982473, 117355110)), this.ofLong(new Long(0, 204073344)), this.ofLong(new Long(839070905, 346944695)), this.ofLong(new Long(2025824256, 577688420)), this.ofLong(new Long(-1201670133, 943559024)), this.ofLong(new Long(-1677721600, 1513890787)), this.ofLong(new Long(-1254200463, 82378923)), this.ofLong(new Long(403968000, 123735750)), this.ofLong(new Long(-293403007, 183392032)), this.ofLong(new Long(0, 268435456)), this.ofLong(new Long(1331628417, 388335789)), this.ofLong(new Long(-802418688, 555631863)), this.ofLong(new Long(-261202831, 786786085)), this.ofLong(new Long(-520093696, 1103240376))];
    var tmp_11 = this;
    // Inline function 'kotlin.intArrayOf' call
    tmp_11.ys_1 = new Int32Array([0, 0, 30, 19, 15, 13, 11, 11, 10, 9, 9, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 5]);
    var tmp_12 = this;
    // Inline function 'kotlin.intArrayOf' call
    tmp_12.zs_1 = new Int32Array([0, 0, 1073741824, 1162261467, 1073741824, 1220703125, 362797056, 1977326743, 1073741824, 387420489, 1000000000, 214358881, 429981696, 815730721, 1475789056, 170859375, 268435456, 410338673, 612220032, 893871739, 1280000000, 1801088541, 113379904, 148035889, 191102976, 244140625, 308915776, 387420489, 481890304, 594823321, 729000000, 887503681, 1073741824, 1291467969, 1544804416, 1838265625, 60466176]);
  }
  probablePrime(bitLength, rnd) {
    if (bitLength < 2) {
      throw ArithmeticException.md('bitLength < 2');
    }
    var tmp;
    if (bitLength < 95) {
      tmp = smallPrime(this, bitLength, 100, rnd);
    } else {
      tmp = largePrime(this, bitLength, 100, rnd);
    }
    return tmp;
  }
  ofLong(other) {
    if (other.equals(new Long(0, 0))) {
      return this.ZERO;
    }
    // Inline function 'kotlin.ranges.contains' call
    var this_0 = numberRangeToNumber(1, this.os_1);
    if (contains_1(isInterface(this_0, ClosedRange) ? this_0 : THROW_CCE(), other)) {
      var tmp0_elvis_lhs = this.ps_1[other.l1()];
      var tmp;
      if (tmp0_elvis_lhs == null) {
        throw IllegalStateException.lc();
      } else {
        tmp = tmp0_elvis_lhs;
      }
      return tmp;
    } else {
      if (other.m1(new Long(0, 0)) < 0 && other.m1(toLong(-this.os_1 | 0)) >= 0) {
        var tmp1_elvis_lhs = this.qs_1[other.o3().l1()];
        var tmp_0;
        if (tmp1_elvis_lhs == null) {
          throw IllegalStateException.lc();
        } else {
          tmp_0 = tmp1_elvis_lhs;
        }
        return tmp_0;
      }
    }
    return CommonBigInteger.tv(other);
  }
  of(value) {
    return this.ofLong(toLong(value));
  }
  parse(value) {
    var radixed = getRadix(value);
    return CommonBigInteger.uv(radixed.jj_1, radixed.ij_1);
  }
  parseWithRadix(value, radix) {
    return CommonBigInteger.uv(value, radix);
  }
  ofIntArray(other) {
    return other[0] > 0 ? CommonBigInteger.jv(other, 1) : CommonBigInteger.vv(other);
  }
  vp() {
    return this.ZERO;
  }
  wp() {
    return this.ONE;
  }
  xp() {
    return this.TWO;
  }
  tq() {
    return this.NEGATIVE_ONE;
  }
  yp() {
    return this.TEN;
  }
  lv(n) {
    return 32 - numberOfLeadingZeros(n) | 0;
  }
}
class CommonBigInteger {
  static vv(other) {
    Companion_getInstance_21();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_CommonBigInteger($this);
    // Inline function 'kotlin.collections.isEmpty' call
    if (other.length === 0) {
      throw NumberFormatException.hd('Zero length BigInteger');
    }
    if (other[0] < 0) {
      $this.qr_1 = makePositive(Companion_getInstance_21(), other);
      $this.pr_1 = -1;
    } else {
      $this.qr_1 = trustedStripLeadingZeroInts(Companion_getInstance_21(), other);
      var tmp = $this;
      var tmp_0;
      // Inline function 'kotlin.collections.isEmpty' call
      if ($this.qr_1.length === 0) {
        tmp_0 = 0;
      } else {
        tmp_0 = 1;
      }
      tmp.pr_1 = tmp_0;
    }
    if ($this.qr_1.length >= 67108864) {
      checkRange($this);
    }
    return $this;
  }
  static wv(signum, magnitude, off, len) {
    Companion_getInstance_21();
    off = off === VOID ? 0 : off;
    len = len === VOID ? magnitude.length : len;
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_CommonBigInteger($this);
    if (signum < -1 || signum > 1) {
      throw NumberFormatException.hd('Invalid _signum value');
    } else if (off < 0 || len < 0 || (len > 0 && (off >= magnitude.length || len > (magnitude.length - off | 0)))) {
      throw IndexOutOfBoundsException.ad();
    }
    $this.qr_1 = stripLeadingZeroBytes(Companion_getInstance_21(), magnitude, off, len);
    // Inline function 'kotlin.collections.isEmpty' call
    if ($this.qr_1.length === 0) {
      $this.pr_1 = 0;
    } else {
      if (signum === 0) {
        throw NumberFormatException.hd('_signum-magnitude mismatch');
      }
      $this.pr_1 = signum;
    }
    if ($this.qr_1.length >= 67108864) {
      checkRange($this);
    }
    return $this;
  }
  static sv(signum, magnitude) {
    Companion_getInstance_21();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_CommonBigInteger($this);
    $this.qr_1 = stripLeadingZeroInts(Companion_getInstance_21(), magnitude);
    if (signum < -1 || signum > 1) {
      throw NumberFormatException.hd('Invalid _signum value');
    }
    // Inline function 'kotlin.collections.isEmpty' call
    if ($this.qr_1.length === 0) {
      $this.pr_1 = 0;
    } else {
      if (signum === 0) {
        throw NumberFormatException.hd('_signum-magnitude mismatch');
      }
      $this.pr_1 = signum;
    }
    if ($this.qr_1.length >= 67108864) {
      checkRange($this);
    }
    return $this;
  }
  static uv(other, radix) {
    Companion_getInstance_21();
    radix = radix === VOID ? 10 : radix;
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_CommonBigInteger($this);
    var cursor = 0;
    var numDigits;
    var len = other.length;
    if (radix < 2 || radix > 36) {
      throw NumberFormatException.hd('Radix out of range');
    }
    if (len === 0) {
      throw NumberFormatException.hd('Zero length BigInteger');
    }
    var sign = 1;
    var index1 = lastIndexOf_0(other, _Char___init__impl__6a9atx(45));
    var index2 = lastIndexOf_0(other, _Char___init__impl__6a9atx(43));
    if (index1 >= 0) {
      if (!(index1 === 0) || index2 >= 0) {
        throw NumberFormatException.hd('Illegal embedded sign character');
      }
      sign = -1;
      cursor = 1;
    } else if (index2 >= 0) {
      if (!(index2 === 0)) {
        throw NumberFormatException.hd('Illegal embedded sign character');
      }
      cursor = 1;
    }
    if (cursor === len) {
      throw NumberFormatException.hd('Zero length BigInteger');
    }
    while (cursor < len && toDigit(charSequenceGet(other, cursor), radix) === 0) {
      cursor = cursor + 1 | 0;
    }
    if (cursor === len) {
      $this.pr_1 = 0;
      $this.qr_1 = Companion_getInstance_21().ZERO.qr_1;
      return $this;
    }
    numDigits = len - cursor | 0;
    $this.pr_1 = sign;
    // Inline function 'kotlin.Long.plus' call
    var numBits = numberToLong(numDigits).j3(Companion_getInstance_21().ks_1[radix]).s3(10).h3(toLong(1));
    // Inline function 'kotlin.Long.plus' call
    if (numBits.h3(toLong(31)).m1(new Long(0, 1)) >= 0) {
      reportOverflow(Companion_getInstance_21());
    }
    // Inline function 'kotlin.Long.plus' call
    var numWords = numBits.h3(toLong(31)).l1() >>> 5 | 0;
    var magnitude = new Int32Array(numWords);
    var firstGroupLen = numDigits % Companion_getInstance_21().ys_1[radix] | 0;
    if (firstGroupLen === 0) {
      firstGroupLen = Companion_getInstance_21().ys_1[radix];
    }
    var tmp7 = cursor;
    // Inline function 'kotlin.text.substring' call
    var endIndex = cursor + firstGroupLen | 0;
    // Inline function 'kotlin.js.asDynamic' call
    var group = other.substring(tmp7, endIndex);
    cursor = cursor + firstGroupLen | 0;
    magnitude[numWords - 1 | 0] = toInt(group, radix);
    if (magnitude[numWords - 1 | 0] < 0) {
      throw NumberFormatException.hd('Illegal digit');
    }
    var superRadix = Companion_getInstance_21().zs_1[radix];
    var groupVal = 0;
    while (cursor < len) {
      var tmp10 = cursor;
      // Inline function 'kotlin.text.substring' call
      var endIndex_0 = cursor + Companion_getInstance_21().ys_1[radix] | 0;
      // Inline function 'kotlin.js.asDynamic' call
      group = other.substring(tmp10, endIndex_0);
      cursor = cursor + Companion_getInstance_21().ys_1[radix] | 0;
      groupVal = toInt(group, radix);
      if (groupVal < 0) {
        throw NumberFormatException.hd('Illegal digit');
      }
      destructiveMulAdd(Companion_getInstance_21(), magnitude, superRadix, groupVal);
    }
    $this.qr_1 = trustedStripLeadingZeroInts(Companion_getInstance_21(), magnitude);
    if ($this.qr_1.length >= 67108864) {
      checkRange($this);
    }
    return $this;
  }
  static hv(other, sign, len) {
    Companion_getInstance_21();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_CommonBigInteger($this);
    var cursor = 0;
    var numDigits;
    while (cursor < len && toDigit(other[cursor], 10) === 0) {
      cursor = cursor + 1 | 0;
    }
    if (cursor === len) {
      $this.pr_1 = 0;
      $this.qr_1 = Companion_getInstance_21().ZERO.qr_1;
      return $this;
    }
    numDigits = len - cursor | 0;
    $this.pr_1 = sign;
    var numWords;
    if (len < 10) {
      numWords = 1;
    } else {
      // Inline function 'kotlin.Long.plus' call
      var numBits = numberToLong(numDigits).j3(Companion_getInstance_21().ks_1[10]).s3(10).h3(toLong(1));
      // Inline function 'kotlin.Long.plus' call
      if (numBits.h3(toLong(31)).m1(new Long(0, 1)) >= 0) {
        reportOverflow(Companion_getInstance_21());
      }
      // Inline function 'kotlin.Long.plus' call
      numWords = numBits.h3(toLong(31)).l1() >>> 5 | 0;
    }
    var magnitude = new Int32Array(numWords);
    var firstGroupLen = numDigits % Companion_getInstance_21().ys_1[10] | 0;
    if (firstGroupLen === 0) {
      firstGroupLen = Companion_getInstance_21().ys_1[10];
    }
    magnitude[numWords - 1 | 0] = parseInt($this, other, cursor, cursor + firstGroupLen | 0);
    cursor = cursor + firstGroupLen | 0;
    while (cursor < len) {
      var groupVal = parseInt($this, other, cursor, cursor + Companion_getInstance_21().ys_1[10] | 0);
      cursor = cursor + Companion_getInstance_21().ys_1[10] | 0;
      destructiveMulAdd(Companion_getInstance_21(), magnitude, Companion_getInstance_21().zs_1[10], groupVal);
    }
    $this.qr_1 = trustedStripLeadingZeroInts(Companion_getInstance_21(), magnitude);
    if ($this.qr_1.length >= 67108864) {
      checkRange($this);
    }
    return $this;
  }
  static kv(numBits, rnd) {
    Companion_getInstance_21();
    return this.wv(1, randomBits(Companion_getInstance_21(), numBits, rnd));
  }
  nextProbablePrime() {
    if (this.pr_1 < 0) {
      throw ArithmeticException.md('start < 0: ' + this.toString());
    }
    if (this.pr_1 === 0 || this.equals(Companion_getInstance_21().ONE)) {
      return Companion_getInstance_21().TWO;
    }
    var result = this.plus(Companion_getInstance_21().ONE);
    if (result.bitLength < 95) {
      if (!result.testBit(0)) {
        result = result.plus(Companion_getInstance_21().ONE);
      }
      $l$loop: while (true) {
        if (result.bitLength > 6) {
          var r = result.reminder(Companion_getInstance_21().ns_1).toLong();
          var tmp;
          var tmp_0;
          var tmp_1;
          var tmp_2;
          var tmp_3;
          var tmp_4;
          var tmp_5;
          var tmp_6;
          var tmp_7;
          var tmp_8;
          var tmp_9;
          // Inline function 'kotlin.Long.rem' call
          if (r.l3(toLong(3)).equals(new Long(0, 0))) {
            tmp_9 = true;
          } else {
            // Inline function 'kotlin.Long.rem' call
            tmp_9 = r.l3(toLong(5)).equals(new Long(0, 0));
          }
          if (tmp_9) {
            tmp_8 = true;
          } else {
            // Inline function 'kotlin.Long.rem' call
            tmp_8 = r.l3(toLong(7)).equals(new Long(0, 0));
          }
          if (tmp_8) {
            tmp_7 = true;
          } else {
            // Inline function 'kotlin.Long.rem' call
            tmp_7 = r.l3(toLong(11)).equals(new Long(0, 0));
          }
          if (tmp_7) {
            tmp_6 = true;
          } else {
            // Inline function 'kotlin.Long.rem' call
            tmp_6 = r.l3(toLong(13)).equals(new Long(0, 0));
          }
          if (tmp_6) {
            tmp_5 = true;
          } else {
            // Inline function 'kotlin.Long.rem' call
            tmp_5 = r.l3(toLong(17)).equals(new Long(0, 0));
          }
          if (tmp_5) {
            tmp_4 = true;
          } else {
            // Inline function 'kotlin.Long.rem' call
            tmp_4 = r.l3(toLong(19)).equals(new Long(0, 0));
          }
          if (tmp_4) {
            tmp_3 = true;
          } else {
            // Inline function 'kotlin.Long.rem' call
            tmp_3 = r.l3(toLong(23)).equals(new Long(0, 0));
          }
          if (tmp_3) {
            tmp_2 = true;
          } else {
            // Inline function 'kotlin.Long.rem' call
            tmp_2 = r.l3(toLong(29)).equals(new Long(0, 0));
          }
          if (tmp_2) {
            tmp_1 = true;
          } else {
            // Inline function 'kotlin.Long.rem' call
            tmp_1 = r.l3(toLong(31)).equals(new Long(0, 0));
          }
          if (tmp_1) {
            tmp_0 = true;
          } else {
            // Inline function 'kotlin.Long.rem' call
            tmp_0 = r.l3(toLong(37)).equals(new Long(0, 0));
          }
          if (tmp_0) {
            tmp = true;
          } else {
            // Inline function 'kotlin.Long.rem' call
            tmp = r.l3(toLong(41)).equals(new Long(0, 0));
          }
          if (tmp) {
            result = result.plus(Companion_getInstance_21().TWO);
            continue $l$loop;
          }
        }
        if (result.bitLength < 4) {
          return result;
        }
        if (result.vr(100, null)) {
          return result;
        }
        result = result.plus(Companion_getInstance_21().TWO);
      }
    }
    if (result.testBit(0)) {
      result = result.minus(Companion_getInstance_21().ONE);
    }
    var searchLen = getPrimeSearchLen(Companion_getInstance_21(), result.bitLength);
    while (true) {
      var searchSieve = BitSieve.gr(result, searchLen);
      var tmp_10 = result;
      ensureNotNull(null);
      var candidate = searchSieve.nr(tmp_10, 100, throwKotlinNothingValueException());
      if (!(candidate == null)) {
        return candidate;
      }
      result = result.plus(Companion_getInstance_21().ofLong(toLong(imul_0(2, searchLen))));
    }
  }
  vr(certainty, random) {
    var rounds = 0;
    // Inline function 'kotlin.math.max' call
    var b = 2147483646;
    var n = (Math.max(certainty, b) + 1 | 0) / 2 | 0;
    var sizeInBits = this.bitLength;
    if (sizeInBits < 100) {
      rounds = 50;
      rounds = n < rounds ? n : rounds;
      return passesMillerRabin(this, rounds, random);
    }
    if (sizeInBits < 256) {
      rounds = 27;
    } else if (sizeInBits < 512) {
      rounds = 15;
    } else if (sizeInBits < 768) {
      rounds = 8;
    } else if (sizeInBits < 1024) {
      rounds = 4;
    } else {
      rounds = 2;
    }
    rounds = n < rounds ? n : rounds;
    return passesMillerRabin(this, rounds, random) && passesLucasLehmer(this);
  }
  static jv(magnitude, signum) {
    Companion_getInstance_21();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_CommonBigInteger($this);
    var tmp = $this;
    var tmp_0;
    // Inline function 'kotlin.collections.isEmpty' call
    if (magnitude.length === 0) {
      tmp_0 = 0;
    } else {
      tmp_0 = signum;
    }
    tmp.pr_1 = tmp_0;
    $this.qr_1 = magnitude;
    if ($this.qr_1.length >= 67108864) {
      checkRange($this);
    }
    return $this;
  }
  static tv(other) {
    Companion_getInstance_21();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_CommonBigInteger($this);
    var other_0 = other;
    if (other_0.m1(new Long(0, 0)) < 0) {
      other_0 = other_0.o3();
      $this.pr_1 = -1;
    } else {
      $this.pr_1 = 1;
    }
    var highWord = other_0.s3(32).l1();
    if (highWord === 0) {
      $this.qr_1 = new Int32Array(1);
      $this.qr_1[0] = other_0.l1();
    } else {
      $this.qr_1 = new Int32Array(2);
      $this.qr_1[0] = highWord;
      $this.qr_1[1] = other_0.l1();
    }
    return $this;
  }
  plus(other) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var other_0 = other;
    if (other_0.signum === 0) {
      return this;
    }
    if (this.pr_1 === 0) {
      return other_0;
    }
    if (other_0.pr_1 === this.pr_1) {
      return CommonBigInteger.jv(sum_5(Companion_getInstance_21(), this.qr_1, other_0.qr_1), this.pr_1);
    }
    var cmp = this.xt(other_0);
    if (cmp === 0) {
      return Companion_getInstance_21().ZERO;
    }
    var tmp;
    if (cmp > 0) {
      tmp = subtract_2(Companion_getInstance_21(), this.qr_1, other_0.qr_1);
    } else {
      tmp = subtract_2(Companion_getInstance_21(), other_0.qr_1, this.qr_1);
    }
    var resultMag = tmp;
    resultMag = trustedStripLeadingZeroInts(Companion_getInstance_21(), resultMag);
    return CommonBigInteger.jv(resultMag, cmp === this.pr_1 ? 1 : -1);
  }
  nu(other) {
    if (other.equals(new Long(0, 0))) {
      return this;
    }
    if (this.pr_1 === 0) {
      return Companion_getInstance_21().ofLong(other);
    }
    if (get_sign(other) === this.pr_1) {
      var tmp = Companion_getInstance_21();
      // Inline function 'kotlin.math.absoluteValue' call
      var tmp$ret$0 = abs(other);
      return CommonBigInteger.jv(sum_4(tmp, this.qr_1, tmp$ret$0), this.pr_1);
    }
    var cmp = compareMagnitude_0(this, other);
    if (cmp === 0) {
      return Companion_getInstance_21().ZERO;
    }
    var tmp_0;
    if (cmp > 0) {
      var tmp_1 = Companion_getInstance_21();
      // Inline function 'kotlin.math.absoluteValue' call
      var tmp$ret$1 = abs(other);
      tmp_0 = subtract_1(tmp_1, this.qr_1, tmp$ret$1);
    } else {
      var tmp_2 = Companion_getInstance_21();
      // Inline function 'kotlin.math.absoluteValue' call
      var tmp$ret$2 = abs(other);
      tmp_0 = subtract_0(tmp_2, tmp$ret$2, this.qr_1);
    }
    var resultMag = tmp_0;
    resultMag = trustedStripLeadingZeroInts(Companion_getInstance_21(), resultMag);
    return CommonBigInteger.jv(resultMag, cmp === this.pr_1 ? 1 : -1);
  }
  minus(other) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var other_0 = other;
    if (other_0.pr_1 === 0) {
      return this;
    }
    if (this.pr_1 === 0) {
      return other_0.unaryMinus();
    }
    if (!(other_0.pr_1 === this.pr_1)) {
      return CommonBigInteger.jv(sum_5(Companion_getInstance_21(), this.qr_1, other_0.qr_1), this.pr_1);
    }
    var cmp = this.xt(other_0);
    if (cmp === 0) {
      return Companion_getInstance_21().ZERO;
    }
    var tmp;
    if (cmp > 0) {
      tmp = subtract_2(Companion_getInstance_21(), this.qr_1, other_0.qr_1);
    } else {
      tmp = subtract_2(Companion_getInstance_21(), other_0.qr_1, this.qr_1);
    }
    var resultMag = tmp;
    resultMag = trustedStripLeadingZeroInts(Companion_getInstance_21(), resultMag);
    return CommonBigInteger.jv(resultMag, cmp === this.pr_1 ? 1 : -1);
  }
  times(other) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var other_0 = other;
    if (other_0.pr_1 === 0 || this.pr_1 === 0) {
      return Companion_getInstance_21().ZERO;
    }
    var xlen = this.qr_1.length;
    if (other_0 === this && xlen > 20) {
      return square(this);
    }
    var ylen = other_0.qr_1.length;
    if (xlen < 80 || ylen < 80) {
      var resultSign = this.pr_1 === other_0.pr_1 ? 1 : -1;
      if (other_0.qr_1.length === 1) {
        return multiplyByInt(Companion_getInstance_21(), this.qr_1, other_0.qr_1[0], resultSign);
      }
      if (this.qr_1.length === 1) {
        return multiplyByInt(Companion_getInstance_21(), other_0.qr_1, this.qr_1[0], resultSign);
      }
      var result = multiplyToLen(Companion_getInstance_21(), this.qr_1, xlen, other_0.qr_1, ylen, null);
      result = trustedStripLeadingZeroInts(Companion_getInstance_21(), result);
      return CommonBigInteger.jv(result, resultSign);
    } else {
      var tmp;
      if (xlen < 240 && ylen < 240) {
        tmp = multiplyKaratsuba(Companion_getInstance_21(), this, other_0);
      } else {
        tmp = multiplyToomCook3(Companion_getInstance_21(), this, other_0);
      }
      return tmp;
    }
  }
  pu(other) {
    var v = other;
    if (v.equals(new Long(0, 0)) || this.pr_1 === 0) {
      return Companion_getInstance_21().ZERO;
    }
    if (v.equals(new Long(0, -2147483648))) {
      return this.times(Companion_getInstance_21().ofLong(v));
    }
    var rsign = v.m1(new Long(0, 0)) > 0 ? this.pr_1 : -this.pr_1 | 0;
    if (v.m1(new Long(0, 0)) < 0) {
      v = v.o3();
    }
    var dh = v.s3(32);
    var dl = v.t3(new Long(-1, 0));
    var xlen = this.qr_1.length;
    var value = this.qr_1;
    var rmag = dh.equals(new Long(0, 0)) ? new Int32Array(xlen + 1 | 0) : new Int32Array(xlen + 2 | 0);
    var carry = new Long(0, 0);
    var rstart = rmag.length - 1 | 0;
    var inductionVariable = xlen - 1 | 0;
    if (0 <= inductionVariable)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + -1 | 0;
        var product = toLong(value[i]).t3(new Long(-1, 0)).j3(dl).h3(carry);
        var tmp = rmag;
        var _unary__edvuaz = rstart;
        rstart = _unary__edvuaz - 1 | 0;
        tmp[_unary__edvuaz] = product.l1();
        carry = product.s3(32);
      }
       while (0 <= inductionVariable);
    rmag[rstart] = carry.l1();
    if (!dh.equals(new Long(0, 0))) {
      carry = new Long(0, 0);
      rstart = rmag.length - 2 | 0;
      var inductionVariable_0 = xlen - 1 | 0;
      if (0 <= inductionVariable_0)
        do {
          var i_0 = inductionVariable_0;
          inductionVariable_0 = inductionVariable_0 + -1 | 0;
          var product_0 = toLong(value[i_0]).t3(new Long(-1, 0)).j3(dh).h3(toLong(rmag[rstart]).t3(new Long(-1, 0))).h3(carry);
          var tmp_0 = rmag;
          var _unary__edvuaz_0 = rstart;
          rstart = _unary__edvuaz_0 - 1 | 0;
          tmp_0[_unary__edvuaz_0] = product_0.l1();
          carry = product_0.s3(32);
        }
         while (0 <= inductionVariable_0);
      rmag[0] = carry.l1();
    }
    if (carry.equals(new Long(0, 0))) {
      rmag = copyOfRange(rmag, 1, rmag.length);
    }
    return CommonBigInteger.jv(rmag, rsign);
  }
  div(other) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var other_0 = other;
    var magSizeBelowThreshold = this.qr_1.length < 80;
    var magSizeDiffIsOffset = (this.qr_1.length - other_0.qr_1.length | 0) < 40;
    var tmp;
    if (magSizeBelowThreshold || magSizeDiffIsOffset) {
      tmp = divideKnuth(this, other_0);
    } else {
      tmp = divideBurnikelZiegler(this, other_0);
    }
    return tmp;
  }
  divideAndRemainder(other) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var other_0 = other;
    var magSizeBelowThreshold = this.qr_1.length < 80;
    var magSizeDiffIsOffset = (this.qr_1.length - other_0.qr_1.length | 0) < 40;
    var tmp;
    if (magSizeBelowThreshold || magSizeDiffIsOffset) {
      tmp = divideAndRemainderKnuth(this, other_0);
    } else {
      tmp = divideAndRemainderBurnikelZiegler(this, other_0);
    }
    return tmp;
  }
  reminder(other) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var other_0 = other;
    var magSizeBelowThreshold = this.qr_1.length < 80;
    var magSizeDiffIsOffset = (this.qr_1.length - other_0.qr_1.length | 0) < 40;
    var tmp;
    if (magSizeBelowThreshold || magSizeDiffIsOffset) {
      tmp = remainderKnuth(this, other_0);
    } else {
      tmp = remainderBurnikelZiegler(this, other_0);
    }
    return tmp;
  }
  pow(exponent) {
    if (exponent < 0) {
      throw ArithmeticException.md('Negative exponent');
    }
    if (this.pr_1 === 0) {
      return exponent === 0 ? Companion_getInstance_21().ONE : this;
    }
    var partToSquare = this.absoluteValue;
    var powersOfTwo = _get_lowestSetBit__xjmtq(partToSquare);
    // Inline function 'kotlin.Long.times' call
    var bitsToShift = toLong(powersOfTwo).j3(toLong(exponent));
    if (bitsToShift.m1(new Long(2147483647, 0)) > 0) {
      reportOverflow(Companion_getInstance_21());
    }
    var remainingBits;
    if (powersOfTwo > 0) {
      partToSquare = partToSquare.shr(powersOfTwo);
      remainingBits = partToSquare.bitLength;
      if (remainingBits === 1) {
        var tmp;
        if (this.pr_1 < 0 && (exponent & 1) === 1) {
          tmp = Companion_getInstance_21().NEGATIVE_ONE.shl(imul_0(powersOfTwo, exponent));
        } else {
          tmp = Companion_getInstance_21().ONE.shl(imul_0(powersOfTwo, exponent));
        }
        return tmp;
      }
    } else {
      remainingBits = partToSquare.bitLength;
      if (remainingBits === 1) {
        var tmp_0;
        if (this.pr_1 < 0 && (exponent & 1) === 1) {
          tmp_0 = Companion_getInstance_21().NEGATIVE_ONE;
        } else {
          tmp_0 = Companion_getInstance_21().ONE;
        }
        return tmp_0;
      }
    }
    // Inline function 'kotlin.Long.times' call
    var scaleFactor = toLong(remainingBits).j3(toLong(exponent));
    if (partToSquare.qr_1.length === 1 && scaleFactor.m1(new Long(62, 0)) <= 0) {
      var newSign = this.pr_1 < 0 && (exponent & 1) === 1 ? -1 : 1;
      var result = new Long(1, 0);
      var baseToPow2 = toLong(partToSquare.qr_1[0]).t3(new Long(-1, 0));
      var workingExponent = exponent;
      while (!(workingExponent === 0)) {
        if ((workingExponent & 1) === 1) {
          result = result.j3(baseToPow2);
        }
        workingExponent = workingExponent >>> 1 | 0;
        if (!(workingExponent === 0)) {
          baseToPow2 = baseToPow2.j3(baseToPow2);
        }
      }
      var tmp_1;
      if (powersOfTwo > 0) {
        var tmp_2;
        if (bitsToShift.h3(scaleFactor).m1(new Long(62, 0)) <= 0) {
          var tmp_3 = Companion_getInstance_21();
          // Inline function 'kotlin.Long.times' call
          var tmp$ret$2 = result.q3(bitsToShift.l1()).j3(toLong(newSign));
          tmp_2 = tmp_3.ofLong(tmp$ret$2);
        } else {
          var tmp_4 = Companion_getInstance_21();
          // Inline function 'kotlin.Long.times' call
          var tmp$ret$3 = result.j3(toLong(newSign));
          tmp_2 = tmp_4.ofLong(tmp$ret$3).shl(bitsToShift.l1());
        }
        tmp_1 = tmp_2;
      } else {
        var tmp_5 = Companion_getInstance_21();
        // Inline function 'kotlin.Long.times' call
        var tmp$ret$4 = result.j3(toLong(newSign));
        tmp_1 = tmp_5.ofLong(tmp$ret$4);
      }
      return tmp_1;
    } else {
      var answer = Companion_getInstance_21().ONE;
      var workingExponent_0 = exponent;
      while (!(workingExponent_0 === 0)) {
        if ((workingExponent_0 & 1) === 1) {
          answer = answer.times(partToSquare);
        }
        workingExponent_0 = workingExponent_0 >>> 1 | 0;
        if (!(workingExponent_0 === 0)) {
          partToSquare = square(partToSquare);
        }
      }
      if (powersOfTwo > 0) {
        answer = answer.shl(imul_0(powersOfTwo, exponent));
      }
      var tmp_6;
      if (this.pr_1 < 0 && (exponent & 1) === 1) {
        tmp_6 = answer.unaryMinus();
      } else {
        tmp_6 = answer;
      }
      return tmp_6;
    }
  }
  sqrt() {
    if (this.pr_1 < 0) {
      throw ArithmeticException.md('Negative BigInteger');
    }
    return MutableBigInteger.au(this.qr_1).xv().yv();
  }
  sqrtAndRemainder() {
    var s = this.sqrt();
    var r = this.minus(square(s));
    // Inline function 'kotlin.require' call
    // Inline function 'kotlin.require' call
    if (!(r.wq(Companion_getInstance_21().ZERO) >= 0)) {
      // Inline function 'kotlin.require.<anonymous>' call
      var message = 'Failed requirement.';
      throw IllegalArgumentException.h(toString_1(message));
    }
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    return [s, r];
  }
  gcd(other) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var other_0 = other;
    if (other_0.pr_1 === 0) {
      return this.absoluteValue;
    } else if (this.pr_1 === 0) {
      return other_0.absoluteValue;
    }
    var a = MutableBigInteger.kr(this);
    var b = MutableBigInteger.kr(other_0);
    var result = a.zv(b);
    return result.gu(1);
  }
  hq() {
    return this.pr_1 >= 0 ? this : this.unaryMinus();
  }
  unaryMinus() {
    return CommonBigInteger.jv(this.qr_1, -this.pr_1 | 0);
  }
  unaryPlus() {
    return this;
  }
  iq() {
    return this.pr_1;
  }
  rem(modulus) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var other = modulus;
    if (other.pr_1 <= 0) {
      throw ArithmeticException.md('BigInteger: modulus not positive');
    }
    var result = this.reminder(other);
    return result.pr_1 >= 0 ? result : result.plus(other);
  }
  modPow(exponent, modulus) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var exponent_0 = exponent;
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var modulus_0 = modulus;
    if (modulus_0.pr_1 <= 0) {
      throw ArithmeticException.md('BigInteger: modulus not positive');
    }
    if (exponent_0.pr_1 === 0) {
      return modulus_0.equals(Companion_getInstance_21().ONE) ? Companion_getInstance_21().ZERO : Companion_getInstance_21().ONE;
    }
    if (this.equals(Companion_getInstance_21().ONE)) {
      return modulus_0.equals(Companion_getInstance_21().ONE) ? Companion_getInstance_21().ZERO : Companion_getInstance_21().ONE;
    }
    if (this.equals(Companion_getInstance_21().ZERO) && exponent_0.pr_1 >= 0) {
      return Companion_getInstance_21().ZERO;
    }
    if (this.equals(Companion_getInstance_21().qs_1[1]) && !exponent_0.testBit(0)) {
      return modulus_0.equals(Companion_getInstance_21().ONE) ? Companion_getInstance_21().ZERO : Companion_getInstance_21().ONE;
    }
    var invertResult = exponent_0.pr_1 < 0;
    if (invertResult) {
      exponent_0 = exponent_0.unaryMinus();
    }
    var tmp;
    if (this.pr_1 < 0 || this.wq(modulus_0) >= 0) {
      tmp = this.rem(modulus_0);
    } else {
      tmp = this;
    }
    var base = tmp;
    var result;
    if (modulus_0.testBit(0)) {
      result = oddModPow(base, exponent_0, modulus_0);
    } else {
      var p = _get_lowestSetBit__xjmtq(modulus_0);
      var m1 = modulus_0.shr(p);
      var m2 = Companion_getInstance_21().ONE.shl(p);
      var tmp_0;
      if (this.pr_1 < 0 || this.wq(m1) >= 0) {
        tmp_0 = this.rem(m1);
      } else {
        tmp_0 = this;
      }
      var base2 = tmp_0;
      var tmp_1;
      if (m1.equals(Companion_getInstance_21().ONE)) {
        tmp_1 = Companion_getInstance_21().ZERO;
      } else {
        tmp_1 = oddModPow(base2, exponent_0, m1);
      }
      var a1 = tmp_1;
      var a2 = modPow2(base, exponent_0, p);
      var y1 = m2.modInverse(m1);
      var y2 = m1.modInverse(m2);
      if (modulus_0.qr_1.length < 33554432) {
        result = a1.times(m2).times(y1).plus(a2.times(m1).times(y2)).rem(modulus_0);
      } else {
        var t1 = MutableBigInteger.lr();
        MutableBigInteger.kr(a1.times(m2)).aw(MutableBigInteger.kr(y1), t1);
        var t2 = MutableBigInteger.lr();
        MutableBigInteger.kr(a2.times(m1)).aw(MutableBigInteger.kr(y2), t2);
        t1.fu(t2);
        var q = MutableBigInteger.lr();
        result = ensureNotNull(t1.ku(MutableBigInteger.kr(modulus_0), q)).yv();
      }
    }
    return invertResult ? result.modInverse(modulus_0) : result;
  }
  modInverse(modulus) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var modulus_0 = modulus;
    if (!(modulus_0.pr_1 === 1)) {
      throw ArithmeticException.md('BigInteger: modulus not positive');
    }
    if (modulus_0.equals(Companion_getInstance_21().ONE)) {
      return Companion_getInstance_21().ZERO;
    }
    var modVal = this;
    if (this.pr_1 < 0 || this.xt(modulus_0) >= 0) {
      modVal = this.rem(modulus_0);
    }
    if (modVal.equals(Companion_getInstance_21().ONE)) {
      return Companion_getInstance_21().ONE;
    }
    var a = MutableBigInteger.kr(modVal);
    var b = MutableBigInteger.kr(modulus_0);
    var result = a.bw(b);
    return ensureNotNull(result).gu(1);
  }
  shl(n) {
    if (this.pr_1 === 0) {
      return Companion_getInstance_21().ZERO;
    }
    var tmp;
    if (n > 0) {
      tmp = CommonBigInteger.jv(shl(Companion_getInstance_21(), this.qr_1, n), this.pr_1);
    } else if (n === 0) {
      tmp = this;
    } else {
      tmp = shiftRightImpl(this, -n | 0);
    }
    return tmp;
  }
  shr(n) {
    if (this.pr_1 === 0) {
      return Companion_getInstance_21().ZERO;
    }
    var tmp;
    if (n > 0) {
      tmp = shiftRightImpl(this, n);
    } else if (n === 0) {
      tmp = this;
    } else {
      tmp = CommonBigInteger.jv(shl(Companion_getInstance_21(), this.qr_1, -n | 0), this.pr_1);
    }
    return tmp;
  }
  and(other) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var other_0 = other;
    var tmp1 = _get_intLength__55caik(this);
    // Inline function 'kotlin.math.max' call
    var b = _get_intLength__55caik(other_0);
    var tmp$ret$3 = Math.max(tmp1, b);
    var result = new Int32Array(tmp$ret$3);
    var inductionVariable = 0;
    var last = result.length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        result[i] = getInt(this, (result.length - i | 0) - 1 | 0) & getInt(other_0, (result.length - i | 0) - 1 | 0);
      }
       while (inductionVariable <= last);
    return Companion_getInstance_21().ofIntArray(result);
  }
  or(other) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var other_0 = other;
    var tmp1 = _get_intLength__55caik(this);
    // Inline function 'kotlin.math.max' call
    var b = _get_intLength__55caik(other_0);
    var tmp$ret$3 = Math.max(tmp1, b);
    var result = new Int32Array(tmp$ret$3);
    var inductionVariable = 0;
    var last = result.length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        result[i] = getInt(this, (result.length - i | 0) - 1 | 0) | getInt(other_0, (result.length - i | 0) - 1 | 0);
      }
       while (inductionVariable <= last);
    return Companion_getInstance_21().ofIntArray(result);
  }
  xor(other) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var other_0 = other;
    var tmp1 = _get_intLength__55caik(this);
    // Inline function 'kotlin.math.max' call
    var b = _get_intLength__55caik(other_0);
    var tmp$ret$3 = Math.max(tmp1, b);
    var result = new Int32Array(tmp$ret$3);
    var inductionVariable = 0;
    var last = result.length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        result[i] = getInt(this, (result.length - i | 0) - 1 | 0) ^ getInt(other_0, (result.length - i | 0) - 1 | 0);
      }
       while (inductionVariable <= last);
    return Companion_getInstance_21().ofIntArray(result);
  }
  not() {
    var result = new Int32Array(_get_intLength__55caik(this));
    var inductionVariable = 0;
    var last = result.length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        result[i] = ~getInt(this, (result.length - i | 0) - 1 | 0);
      }
       while (inductionVariable <= last);
    return Companion_getInstance_21().ofIntArray(result);
  }
  andNot(other) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var other_0 = other;
    var tmp1 = _get_intLength__55caik(this);
    // Inline function 'kotlin.math.max' call
    var b = _get_intLength__55caik(other_0);
    var tmp$ret$3 = Math.max(tmp1, b);
    var result = new Int32Array(tmp$ret$3);
    var inductionVariable = 0;
    var last = result.length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        result[i] = getInt(this, (result.length - i | 0) - 1 | 0) & ~getInt(other_0, (result.length - i | 0) - 1 | 0);
      }
       while (inductionVariable <= last);
    return Companion_getInstance_21().ofIntArray(result);
  }
  testBit(n) {
    if (n < 0) {
      throw ArithmeticException.md('Negative bit address');
    }
    return !((getInt(this, n >>> 5 | 0) & 1 << (n & 31)) === 0);
  }
  get(n) {
    return this.testBit(n);
  }
  set(n, b) {
    return b ? this.setBit(n) : this.clearBit(n);
  }
  setBit(n) {
    if (n < 0) {
      throw ArithmeticException.md('Negative bit address');
    }
    var intNum = n >>> 5 | 0;
    var tmp0 = _get_intLength__55caik(this);
    // Inline function 'kotlin.math.max' call
    var b = intNum + 2 | 0;
    var tmp$ret$0 = Math.max(tmp0, b);
    var result = new Int32Array(tmp$ret$0);
    var inductionVariable = 0;
    var last = result.length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        result[(result.length - i | 0) - 1 | 0] = getInt(this, i);
      }
       while (inductionVariable <= last);
    result[(result.length - intNum | 0) - 1 | 0] = result[(result.length - intNum | 0) - 1 | 0] | 1 << (n & 31);
    return Companion_getInstance_21().ofIntArray(result);
  }
  clearBit(n) {
    if (n < 0) {
      throw ArithmeticException.md('Negative bit address');
    }
    var intNum = n >>> 5 | 0;
    var tmp0 = _get_intLength__55caik(this);
    // Inline function 'kotlin.math.max' call
    var b = ((n + 1 | 0) >>> 5 | 0) + 1 | 0;
    var tmp$ret$0 = Math.max(tmp0, b);
    var result = new Int32Array(tmp$ret$0);
    var inductionVariable = 0;
    var last = result.length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        result[(result.length - i | 0) - 1 | 0] = getInt(this, i);
      }
       while (inductionVariable <= last);
    result[(result.length - intNum | 0) - 1 | 0] = result[(result.length - intNum | 0) - 1 | 0] & ~(1 << (n & 31));
    return Companion_getInstance_21().ofIntArray(result);
  }
  flipBit(n) {
    if (n < 0) {
      throw ArithmeticException.md('Negative bit address');
    }
    var intNum = n >>> 5 | 0;
    var tmp0 = _get_intLength__55caik(this);
    // Inline function 'kotlin.math.max' call
    var b = intNum + 2 | 0;
    var tmp$ret$0 = Math.max(tmp0, b);
    var result = new Int32Array(tmp$ret$0);
    var inductionVariable = 0;
    var last = result.length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        result[(result.length - i | 0) - 1 | 0] = getInt(this, i);
      }
       while (inductionVariable <= last);
    result[(result.length - intNum | 0) - 1 | 0] = result[(result.length - intNum | 0) - 1 | 0] ^ 1 << (n & 31);
    return Companion_getInstance_21().ofIntArray(result);
  }
  uq() {
    var n = this.sr_1 - 1 | 0;
    if (n === -1) {
      var m = this.qr_1;
      var len = m.length;
      if (len === 0) {
        n = 0;
      } else {
        var magBitLength = ((len - 1 | 0) << 5) + Companion_getInstance_21().lv(this.qr_1[0]) | 0;
        if (this.pr_1 < 0) {
          var pow2 = bitCount(this.qr_1[0]) === 1;
          var i = 1;
          while (i < len && pow2) {
            pow2 = this.qr_1[i] === 0;
            i = i + 1 | 0;
          }
          n = pow2 ? magBitLength - 1 | 0 : magBitLength;
        } else {
          n = magBitLength;
        }
      }
      this.sr_1 = n + 1 | 0;
    }
    return n;
  }
  vq() {
    var bc = this.rr_1 - 1 | 0;
    if (bc === -1) {
      bc = 0;
      var inductionVariable = 0;
      var last = this.qr_1.length - 1 | 0;
      if (inductionVariable <= last)
        do {
          var i = inductionVariable;
          inductionVariable = inductionVariable + 1 | 0;
          bc = bc + bitCount(this.qr_1[i]) | 0;
        }
         while (inductionVariable <= last);
      if (this.pr_1 < 0) {
        var magTrailingZeroCount = 0;
        var j;
        j = this.qr_1.length - 1 | 0;
        while (this.qr_1[j] === 0) {
          magTrailingZeroCount = magTrailingZeroCount + 32 | 0;
          j = j - 1 | 0;
        }
        magTrailingZeroCount = magTrailingZeroCount + numberOfTrailingZeros(this.qr_1[j]) | 0;
        bc = bc + (magTrailingZeroCount - 1 | 0) | 0;
      }
      this.rr_1 = bc + 1 | 0;
    }
    return bc;
  }
  isProbablePrime(certainty) {
    if (certainty <= 0) {
      return true;
    }
    var w = this.absoluteValue;
    if (w.equals(Companion_getInstance_21().TWO)) {
      return true;
    }
    return !w.testBit(0) || w.equals(Companion_getInstance_21().ONE) ? false : w.vr(certainty, null);
  }
  wq(other) {
    // Inline function 'com.macrofocus.common.math.big.castTo' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var other_0 = other;
    if (this.pr_1 === other_0.pr_1) {
      switch (this.pr_1) {
        case 1:
          return this.xt(other_0);
        case -1:
          return other_0.xt(this);
        default:
          return 0;
      }
    }
    return this.pr_1 > other_0.pr_1 ? 1 : -1;
  }
  d(other) {
    return this.wq((!(other == null) ? isInterface(other, BigInteger_0) : false) ? other : THROW_CCE());
  }
  xt(other) {
    var m1 = this.qr_1;
    var len1 = m1.length;
    var m2 = other.qr_1;
    var len2 = m2.length;
    if (len1 < len2) {
      return -1;
    }
    if (len1 > len2) {
      return 1;
    }
    var inductionVariable = 0;
    if (inductionVariable < len1)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var a = m1[i];
        var b = m2[i];
        if (!(a === b)) {
          return toLong(a).t3(new Long(-1, 0)).m1(toLong(b).t3(new Long(-1, 0))) < 0 ? -1 : 1;
        }
      }
       while (inductionVariable < len1);
    return 0;
  }
  equals(other) {
    if (other === this) {
      return true;
    }
    if (!(other instanceof CommonBigInteger)) {
      return false;
    }
    var xInt = other instanceof CommonBigInteger ? other : THROW_CCE();
    if (!(ensureNotNull(xInt).pr_1 === this.pr_1)) {
      return false;
    }
    var m = this.qr_1;
    var len = m.length;
    var xm = xInt.qr_1;
    if (!(len === xm.length)) {
      return false;
    }
    var inductionVariable = 0;
    if (inductionVariable < len)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        if (!(xm[i] === m[i])) {
          return false;
        }
      }
       while (inductionVariable < len);
    return true;
  }
  min(other) {
    return this.wq(other) < 0 ? this : other;
  }
  max(other) {
    return this.wq(other) > 0 ? this : other;
  }
  hashCode() {
    var hashCode = 0;
    var inductionVariable = 0;
    var last = this.qr_1.length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        hashCode = imul_0(31, hashCode) + toLong(this.qr_1[i]).t3(new Long(-1, 0)).l1() | 0;
      }
       while (inductionVariable <= last);
    return imul_0(hashCode, this.pr_1);
  }
  toStringWithRadix(radix) {
    var radix_0 = radix;
    if (this.pr_1 === 0) {
      return '0';
    }
    if (radix_0 < 2 || radix_0 > 36) {
      radix_0 = 10;
    }
    if (this.qr_1.length <= 20) {
      return smallToString(this, radix_0);
    }
    var sb = StringBuilder.u();
    if (this.pr_1 < 0) {
      toString_7(Companion_getInstance_21(), this.unaryMinus(), sb, radix_0, 0);
      sb = insertChar(sb, 0, _Char___init__impl__6a9atx(45));
    } else {
      toString_7(Companion_getInstance_21(), this, sb, radix_0, 0);
    }
    return sb.toString();
  }
  toString() {
    return this.toStringWithRadix(10);
  }
  toByteArray() {
    var byteLen = (this.bitLength / 8 | 0) + 1 | 0;
    var byteArray = new Int8Array(byteLen);
    var i = byteLen - 1 | 0;
    var bytesCopied = 4;
    var nextInt = 0;
    var intIndex = 0;
    while (i >= 0) {
      if (bytesCopied === 4) {
        var _unary__edvuaz = intIndex;
        intIndex = _unary__edvuaz + 1 | 0;
        nextInt = getInt(this, _unary__edvuaz);
        bytesCopied = 1;
      } else {
        nextInt = nextInt >>> 8 | 0;
        bytesCopied = bytesCopied + 1 | 0;
      }
      byteArray[i] = toByte(nextInt);
      i = i - 1 | 0;
    }
    return byteArray;
  }
  toInt() {
    var result = 0;
    result = getInt(this, 0);
    return result;
  }
  toLong() {
    var result = new Long(0, 0);
    var inductionVariable = 1;
    if (0 <= inductionVariable)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + -1 | 0;
        result = result.q3(32).h3(toLong(getInt(this, i)).t3(new Long(-1, 0)));
      }
       while (0 <= inductionVariable);
    return result;
  }
  toByte() {
    return toByte(this.toInt());
  }
  toChar() {
    return numberToChar(this.toInt());
  }
  toShort() {
    return toShort(this.toInt());
  }
  toFloat() {
    return this.toInt();
  }
  toDouble() {
    return this.toLong().a4();
  }
  toLongExact() {
    var tmp;
    if (this.qr_1.length <= 2 && this.bitLength <= 63) {
      tmp = this.toLong();
    } else {
      throw ArithmeticException.md('BigInteger out of long range');
    }
    return tmp;
  }
  toIntExact() {
    var tmp;
    if (this.qr_1.length <= 1 && this.bitLength <= 31) {
      tmp = this.toInt();
    } else {
      throw ArithmeticException.md('BigInteger out of int range');
    }
    return tmp;
  }
  toShortExact() {
    if (this.qr_1.length <= 1 && this.bitLength <= 31) {
      var value = this.toInt();
      if (value >= -32768 && value <= 32767) {
        return this.toShort();
      }
    }
    throw ArithmeticException.md('BigInteger out of short range');
  }
  toByteExact() {
    if (this.qr_1.length <= 1 && this.bitLength <= 31) {
      var value = this.toInt();
      if (value >= -128 && value <= 127) {
        return this.toByte();
      }
    }
    throw ArithmeticException.md('BigInteger out of byte range');
  }
  get absoluteValue() {
    return this.hq();
  }
  get signum() {
    return this.iq();
  }
  get bitLength() {
    return this.uq();
  }
  get bitCount() {
    return this.vq();
  }
}
class Companion_22 {
  constructor() {
    Companion_instance_22 = this;
    this.UNLIMITED = new MathContext(0, RoundingMode_HALF_UP_getInstance());
    this.DECIMAL32 = new MathContext(7, RoundingMode_HALF_EVEN_getInstance());
    this.DECIMAL64 = new MathContext(16, RoundingMode_HALF_EVEN_getInstance());
    this.DECIMAL128 = new MathContext(34, RoundingMode_HALF_EVEN_getInstance());
  }
  cw() {
    return this.UNLIMITED;
  }
  dw() {
    return this.DECIMAL32;
  }
  ew() {
    return this.DECIMAL64;
  }
  fw() {
    return this.DECIMAL128;
  }
}
class MathContext {
  constructor(precision, roundingMode) {
    Companion_getInstance_22();
    precision = precision === VOID ? 9 : precision;
    roundingMode = roundingMode === VOID ? RoundingMode_HALF_UP_getInstance() : roundingMode;
    this.precision = precision;
    this.roundingMode = roundingMode;
    // Inline function 'kotlin.require' call
    // Inline function 'kotlin.require' call
    if (!(this.precision >= 0)) {
      // Inline function 'kotlin.require.<anonymous>' call
      var message = 'Failed requirement.';
      throw IllegalArgumentException.h(toString_1(message));
    }
  }
  kq() {
    return this.precision;
  }
  gw() {
    return this.roundingMode;
  }
  kj() {
    return this.precision;
  }
  lj() {
    return this.roundingMode;
  }
  hw(precision, roundingMode) {
    return new MathContext(precision, roundingMode);
  }
  copy(precision, roundingMode, $super) {
    precision = precision === VOID ? this.precision : precision;
    roundingMode = roundingMode === VOID ? this.roundingMode : roundingMode;
    return this.hw(precision, roundingMode);
  }
  toString() {
    return 'MathContext(precision=' + this.precision + ', roundingMode=' + this.roundingMode.toString() + ')';
  }
  hashCode() {
    var result = this.precision;
    result = imul_0(result, 31) + this.roundingMode.hashCode() | 0;
    return result;
  }
  equals(other) {
    if (this === other)
      return true;
    if (!(other instanceof MathContext))
      return false;
    var tmp0_other_with_cast = other instanceof MathContext ? other : THROW_CCE();
    if (!(this.precision === tmp0_other_with_cast.precision))
      return false;
    if (!this.roundingMode.equals(tmp0_other_with_cast.roundingMode))
      return false;
    return true;
  }
}
class Companion_23 {
  constructor() {
    Companion_instance_23 = this;
    this.cu_1 = MutableBigInteger.ex(1);
    this.du_1 = 6;
    this.eu_1 = 3;
  }
  pw(n, d) {
    var dLong = toLong(d).t3(new Long(-1, 0));
    var r;
    var q;
    if (dLong.equals(new Long(1, 0))) {
      q = toLong(n.l1());
      r = new Long(0, 0);
      return r.q3(32).u3(q.t3(new Long(-1, 0)));
    }
    q = n.s3(1).k3(dLong.s3(1));
    r = n.i3(q.j3(dLong));
    while (r.m1(new Long(0, 0)) < 0) {
      r = r.h3(dLong);
      q = q.n3();
    }
    while (r.m1(dLong) >= 0) {
      r = r.i3(dLong);
      q = q.m3();
    }
    return r.q3(32).u3(q.t3(new Long(-1, 0)));
  }
  rw(a, b) {
    var a_0 = a;
    var b_0 = b;
    if (b_0 === 0) {
      return a_0;
    }
    if (a_0 === 0) {
      return b_0;
    }
    var aZeros = numberOfTrailingZeros(a_0);
    var bZeros = numberOfTrailingZeros(b_0);
    a_0 = a_0 >>> aZeros | 0;
    b_0 = b_0 >>> bZeros | 0;
    var t = aZeros < bZeros ? aZeros : bZeros;
    while (!(a_0 === b_0)) {
      if ((a_0 + -2147483648 | 0) > (b_0 + -2147483648 | 0)) {
        a_0 = a_0 - b_0 | 0;
        a_0 = a_0 >>> numberOfTrailingZeros(a_0) | 0;
      } else {
        b_0 = b_0 - a_0 | 0;
        b_0 = b_0 >>> numberOfTrailingZeros(b_0) | 0;
      }
    }
    return a_0 << t;
  }
  fx(val) {
    var t = val;
    t = imul_0(t, 2 - imul_0(val, t) | 0);
    t = imul_0(t, 2 - imul_0(val, t) | 0);
    t = imul_0(t, 2 - imul_0(val, t) | 0);
    t = imul_0(t, 2 - imul_0(val, t) | 0);
    return t;
  }
  pv(val) {
    var t = val;
    t = t.j3(numberToLong(2).i3(val.j3(t)));
    t = t.j3(numberToLong(2).i3(val.j3(t)));
    t = t.j3(numberToLong(2).i3(val.j3(t)));
    t = t.j3(numberToLong(2).i3(val.j3(t)));
    t = t.j3(numberToLong(2).i3(val.j3(t)));
    // Inline function 'kotlin.require' call
    // Inline function 'kotlin.require' call
    if (!t.j3(val).equals(new Long(1, 0))) {
      // Inline function 'kotlin.require.<anonymous>' call
      var message = 'Failed requirement.';
      throw IllegalArgumentException.h(toString_1(message));
    }
    return t;
  }
  gx(mod, k) {
    return this.dx(MutableBigInteger.ex(1), MutableBigInteger.jw(mod), k);
  }
  dx(c, p, k) {
    var temp = MutableBigInteger.lr();
    var r = -this.fx(p.hr_1[(p.jr_1 + p.ir_1 | 0) - 1 | 0]) | 0;
    var i = 0;
    var numWords = k >> 5;
    while (i < numWords) {
      var v = imul_0(r, c.hr_1[(c.jr_1 + c.ir_1 | 0) - 1 | 0]);
      p.hx(v, temp);
      c.fu(temp);
      c.ir_1 = c.ir_1 - 1 | 0;
      i = i + 1 | 0;
    }
    var numBits = k & 31;
    if (!(numBits === 0)) {
      var v_0 = imul_0(r, c.hr_1[(c.jr_1 + c.ir_1 | 0) - 1 | 0]);
      v_0 = v_0 & ((1 << numBits) - 1 | 0);
      p.hx(v_0, temp);
      c.fu(temp);
      c.qw(numBits);
    }
    while (c.iw(p) >= 0) {
      c.nw(p);
    }
    return c;
  }
}
class MutableBigInteger {
  zw() {
    return this.ir_1 === 1 && this.hr_1[this.jr_1] === 1;
  }
  lu() {
    return this.ir_1 === 0;
  }
  yw() {
    return this.ir_1 === 0 || (this.hr_1[(this.jr_1 + this.ir_1 | 0) - 1 | 0] & 1) === 0;
  }
  ju() {
    return this.lu() ? false : (this.hr_1[(this.jr_1 + this.ir_1 | 0) - 1 | 0] & 1) === 1;
  }
  static lr() {
    Companion_getInstance_23();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_MutableBigInteger($this);
    $this.hr_1 = new Int32Array(1);
    $this.ir_1 = 0;
    return $this;
  }
  static ex(val) {
    Companion_getInstance_23();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_MutableBigInteger($this);
    $this.hr_1 = new Int32Array(1);
    $this.ir_1 = 1;
    $this.hr_1[0] = val;
    return $this;
  }
  static au(val) {
    Companion_getInstance_23();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_MutableBigInteger($this);
    $this.hr_1 = val;
    $this.ir_1 = val.length;
    return $this;
  }
  static kr(b) {
    Companion_getInstance_23();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_MutableBigInteger($this);
    $this.ir_1 = b.qr_1.length;
    $this.hr_1 = copyOf(b.qr_1, $this.ir_1);
    return $this;
  }
  static jw(val) {
    Companion_getInstance_23();
    var $this = createThis(this);
    init_com_macrofocus_common_math_big_MutableBigInteger($this);
    $this.ir_1 = val.ir_1;
    $this.hr_1 = copyOfRange(val.hr_1, val.jr_1, val.jr_1 + $this.ir_1 | 0);
    return $this;
  }
  gu(sign) {
    var tmp;
    if (this.ir_1 === 0 || sign === 0) {
      tmp = Companion_getInstance_21().ZERO;
    } else {
      tmp = CommonBigInteger.jv(_get_magnitudeArray__ns4ohu(this), sign);
    }
    return tmp;
  }
  yv() {
    this.qv();
    return this.gu(this.lu() ? 0 : 1);
  }
  hu(sign, scale) {
    if (this.ir_1 === 0 || sign === 0) {
      return Companion_getInstance_20().ru(scale);
    }
    var mag = _get_magnitudeArray__ns4ohu(this);
    var len = mag.length;
    var d = mag[0];
    if (len > 2 || (d < 0 && len === 2)) {
      return CommonBigDecimal.zt(CommonBigInteger.jv(mag, sign), new Long(0, -2147483648), scale, 0);
    }
    var tmp;
    if (len === 2) {
      tmp = toLong(mag[1]).t3(new Long(-1, 0)).u3(toLong(d).t3(new Long(-1, 0)).q3(32));
    } else {
      tmp = toLong(d).t3(new Long(-1, 0));
    }
    var v = tmp;
    return Companion_getInstance_20().ofScaledLong(sign === -1 ? v.o3() : v, scale);
  }
  iu(sign) {
    if (this.ir_1 === 0 || sign === 0) {
      return new Long(0, 0);
    }
    var mag = _get_magnitudeArray__ns4ohu(this);
    var len = mag.length;
    var d = mag[0];
    if (len > 2 || (d < 0 && len === 2)) {
      return new Long(0, -2147483648);
    }
    var tmp;
    if (len === 2) {
      tmp = toLong(mag[1]).t3(new Long(-1, 0)).u3(toLong(d).t3(new Long(-1, 0)).q3(32));
    } else {
      tmp = toLong(d).t3(new Long(-1, 0));
    }
    var v = tmp;
    return sign === -1 ? v.o3() : v;
  }
  o5() {
    this.ir_1 = 0;
    this.jr_1 = this.ir_1;
    var index = 0;
    var n = this.hr_1.length;
    while (index < n) {
      this.hr_1[index] = 0;
      index = index + 1 | 0;
    }
  }
  ix() {
    this.ir_1 = 0;
    this.jr_1 = this.ir_1;
  }
  iw(b) {
    var blen = b.ir_1;
    if (this.ir_1 < blen) {
      return -1;
    }
    if (this.ir_1 > blen) {
      return 1;
    }
    var bval = b.hr_1;
    var i = this.jr_1;
    var j = b.jr_1;
    while (i < (this.ir_1 + this.jr_1 | 0)) {
      var b1 = this.hr_1[i] + -2147483648 | 0;
      var b2 = bval[j] + -2147483648 | 0;
      if (b1 < b2) {
        return -1;
      }
      if (b1 > b2) {
        return 1;
      }
      i = i + 1 | 0;
      j = j + 1 | 0;
    }
    return 0;
  }
  mu(b) {
    var blen = b.ir_1;
    var len = this.ir_1;
    if (len <= 0) {
      return blen <= 0 ? 0 : -1;
    }
    if (len > blen) {
      return 1;
    }
    if (len < (blen - 1 | 0)) {
      return -1;
    }
    var bval = b.hr_1;
    var bstart = 0;
    var carry = 0;
    if (!(len === blen)) {
      if (bval[bstart] === 1) {
        bstart = bstart + 1 | 0;
        carry = -2147483648;
      } else {
        return -1;
      }
    }
    var val = this.hr_1;
    var i = this.jr_1;
    var j = bstart;
    while (i < (len + this.jr_1 | 0)) {
      var _unary__edvuaz = j;
      j = _unary__edvuaz + 1 | 0;
      var bv = bval[_unary__edvuaz];
      var tmp0 = toLong(bv >>> 1 | 0);
      // Inline function 'kotlin.Long.plus' call
      var other = carry;
      var hb = tmp0.h3(toLong(other)).t3(new Long(-1, 0));
      var _unary__edvuaz_0 = i;
      i = _unary__edvuaz_0 + 1 | 0;
      var v = toLong(val[_unary__edvuaz_0]).t3(new Long(-1, 0));
      if (!v.equals(hb)) {
        return v.m1(hb) < 0 ? -1 : 1;
      }
      carry = (bv & 1) << 31;
    }
    return carry === 0 ? 0 : -1;
  }
  qv() {
    if (this.ir_1 === 0) {
      this.jr_1 = 0;
      return Unit_instance;
    }
    var index = this.jr_1;
    if (!(this.hr_1[index] === 0)) {
      return Unit_instance;
    }
    var indexBound = index + this.ir_1 | 0;
    do {
      index = index + 1 | 0;
    }
     while (index < indexBound && this.hr_1[index] === 0);
    var numZeros = index - this.jr_1 | 0;
    this.ir_1 = this.ir_1 - numZeros | 0;
    this.jr_1 = this.ir_1 === 0 ? 0 : this.jr_1 + numZeros | 0;
  }
  rv() {
    var result = new Int32Array(this.ir_1);
    var inductionVariable = 0;
    var last = this.ir_1;
    if (inductionVariable < last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        result[i] = this.hr_1[this.jr_1 + i | 0];
      }
       while (inductionVariable < last);
    return result;
  }
  jx(val, length) {
    this.hr_1 = val;
    this.ir_1 = length;
    this.jr_1 = 0;
  }
  kx(src) {
    var len = src.ir_1;
    if (this.hr_1.length < len) {
      this.hr_1 = new Int32Array(len);
    }
    arrayCopy_0(src.hr_1, src.jr_1, this.hr_1, 0, len);
    this.ir_1 = len;
    this.jr_1 = 0;
  }
  toString() {
    var b = this.gu(1);
    return b.toString();
  }
  kw(n) {
    if ((n / 32 | 0) >= this.ir_1) {
      this.ix();
    } else {
      this.qw(n);
    }
  }
  qw(n) {
    if (this.ir_1 === 0) {
      return Unit_instance;
    }
    var nInts = n >>> 5 | 0;
    var nBits = n & 31;
    this.ir_1 = this.ir_1 - nInts | 0;
    if (nBits === 0) {
      return Unit_instance;
    }
    var bitsInHighWord = Companion_getInstance_21().lv(this.hr_1[this.jr_1]);
    if (nBits >= bitsInHighWord) {
      primitiveLeftShift_0(this, 32 - nBits | 0);
      this.ir_1 = this.ir_1 - 1 | 0;
    } else {
      primitiveRightShift_0(this, nBits);
    }
  }
  lx(n) {
    if (n > 0) {
      this.mw(n);
    }
  }
  mw(n) {
    if (this.ir_1 === 0) {
      return Unit_instance;
    }
    var nInts = n >>> 5 | 0;
    var nBits = n & 31;
    var bitsInHighWord = Companion_getInstance_21().lv(this.hr_1[this.jr_1]);
    if (n <= (32 - bitsInHighWord | 0)) {
      primitiveLeftShift_0(this, nBits);
      return Unit_instance;
    }
    var newLen = (this.ir_1 + nInts | 0) + 1 | 0;
    if (nBits <= (32 - bitsInHighWord | 0)) {
      newLen = newLen - 1 | 0;
    }
    if (this.hr_1.length < newLen) {
      var result = new Int32Array(newLen);
      var inductionVariable = 0;
      var last = this.ir_1;
      if (inductionVariable < last)
        do {
          var i = inductionVariable;
          inductionVariable = inductionVariable + 1 | 0;
          result[i] = this.hr_1[this.jr_1 + i | 0];
        }
         while (inductionVariable < last);
      this.jx(result, newLen);
    } else if ((this.hr_1.length - this.jr_1 | 0) >= newLen) {
      var inductionVariable_0 = 0;
      var last_0 = newLen - this.ir_1 | 0;
      if (inductionVariable_0 < last_0)
        do {
          var i_0 = inductionVariable_0;
          inductionVariable_0 = inductionVariable_0 + 1 | 0;
          this.hr_1[(this.jr_1 + this.ir_1 | 0) + i_0 | 0] = 0;
        }
         while (inductionVariable_0 < last_0);
    } else {
      var inductionVariable_1 = 0;
      var last_1 = this.ir_1;
      if (inductionVariable_1 < last_1)
        do {
          var i_1 = inductionVariable_1;
          inductionVariable_1 = inductionVariable_1 + 1 | 0;
          this.hr_1[i_1] = this.hr_1[this.jr_1 + i_1 | 0];
        }
         while (inductionVariable_1 < last_1);
      var inductionVariable_2 = this.ir_1;
      var last_2 = newLen;
      if (inductionVariable_2 < last_2)
        do {
          var i_2 = inductionVariable_2;
          inductionVariable_2 = inductionVariable_2 + 1 | 0;
          this.hr_1[i_2] = 0;
        }
         while (inductionVariable_2 < last_2);
      this.jr_1 = 0;
    }
    this.ir_1 = newLen;
    if (nBits === 0) {
      return Unit_instance;
    }
    if (nBits <= (32 - bitsInHighWord | 0)) {
      primitiveLeftShift_0(this, nBits);
    } else {
      primitiveRightShift_0(this, 32 - nBits | 0);
    }
  }
  fu(addend) {
    var x = this.ir_1;
    var y = addend.ir_1;
    var resultLen = this.ir_1 > addend.ir_1 ? this.ir_1 : addend.ir_1;
    var result = this.hr_1.length < resultLen ? new Int32Array(resultLen) : this.hr_1;
    var rstart = result.length - 1 | 0;
    var sum;
    var carry = new Long(0, 0);
    while (x > 0 && y > 0) {
      x = x - 1 | 0;
      y = y - 1 | 0;
      sum = toLong(this.hr_1[x + this.jr_1 | 0]).t3(new Long(-1, 0)).h3(toLong(addend.hr_1[y + addend.jr_1 | 0]).t3(new Long(-1, 0))).h3(carry);
      var tmp = result;
      var _unary__edvuaz = rstart;
      rstart = _unary__edvuaz - 1 | 0;
      tmp[_unary__edvuaz] = sum.l1();
      carry = sum.s3(32);
    }
    while (x > 0) {
      x = x - 1 | 0;
      if (carry.equals(new Long(0, 0)) && equals(result, this.hr_1) && rstart === (x + this.jr_1 | 0)) {
        return Unit_instance;
      }
      sum = toLong(this.hr_1[x + this.jr_1 | 0]).t3(new Long(-1, 0)).h3(carry);
      var tmp_0 = result;
      var _unary__edvuaz_0 = rstart;
      rstart = _unary__edvuaz_0 - 1 | 0;
      tmp_0[_unary__edvuaz_0] = sum.l1();
      carry = sum.s3(32);
    }
    while (y > 0) {
      y = y - 1 | 0;
      sum = toLong(addend.hr_1[y + addend.jr_1 | 0]).t3(new Long(-1, 0)).h3(carry);
      var tmp_1 = result;
      var _unary__edvuaz_1 = rstart;
      rstart = _unary__edvuaz_1 - 1 | 0;
      tmp_1[_unary__edvuaz_1] = sum.l1();
      carry = sum.s3(32);
    }
    if (carry.m1(new Long(0, 0)) > 0) {
      resultLen = resultLen + 1 | 0;
      if (result.length < resultLen) {
        var temp = new Int32Array(resultLen);
        arrayCopy_0(result, 0, temp, 1, result.length);
        temp[0] = 1;
        result = temp;
      } else {
        var tmp_2 = result;
        var _unary__edvuaz_2 = rstart;
        rstart = _unary__edvuaz_2 - 1 | 0;
        tmp_2[_unary__edvuaz_2] = 1;
      }
    }
    this.hr_1 = result;
    this.ir_1 = resultLen;
    this.jr_1 = result.length - resultLen | 0;
  }
  mx(addend, n) {
    if (addend.lu()) {
      return Unit_instance;
    }
    var x = this.ir_1;
    var y = addend.ir_1 + n | 0;
    var resultLen = this.ir_1 > y ? this.ir_1 : y;
    var result = this.hr_1.length < resultLen ? new Int32Array(resultLen) : this.hr_1;
    var rstart = result.length - 1 | 0;
    var sum;
    var carry = new Long(0, 0);
    while (x > 0 && y > 0) {
      x = x - 1 | 0;
      y = y - 1 | 0;
      var bval = (y + addend.jr_1 | 0) < addend.hr_1.length ? addend.hr_1[y + addend.jr_1 | 0] : 0;
      sum = toLong(this.hr_1[x + this.jr_1 | 0]).t3(new Long(-1, 0)).h3(toLong(bval).t3(new Long(-1, 0))).h3(carry);
      var tmp = result;
      var _unary__edvuaz = rstart;
      rstart = _unary__edvuaz - 1 | 0;
      tmp[_unary__edvuaz] = sum.l1();
      carry = sum.s3(32);
    }
    while (x > 0) {
      x = x - 1 | 0;
      if (carry.equals(new Long(0, 0)) && equals(result, this.hr_1) && rstart === (x + this.jr_1 | 0)) {
        return Unit_instance;
      }
      sum = toLong(this.hr_1[x + this.jr_1 | 0]).t3(new Long(-1, 0)).h3(carry);
      var tmp_0 = result;
      var _unary__edvuaz_0 = rstart;
      rstart = _unary__edvuaz_0 - 1 | 0;
      tmp_0[_unary__edvuaz_0] = sum.l1();
      carry = sum.s3(32);
    }
    while (y > 0) {
      y = y - 1 | 0;
      var bval_0 = (y + addend.jr_1 | 0) < addend.hr_1.length ? addend.hr_1[y + addend.jr_1 | 0] : 0;
      sum = toLong(bval_0).t3(new Long(-1, 0)).h3(carry);
      var tmp_1 = result;
      var _unary__edvuaz_1 = rstart;
      rstart = _unary__edvuaz_1 - 1 | 0;
      tmp_1[_unary__edvuaz_1] = sum.l1();
      carry = sum.s3(32);
    }
    if (carry.m1(new Long(0, 0)) > 0) {
      resultLen = resultLen + 1 | 0;
      if (result.length < resultLen) {
        var temp = new Int32Array(resultLen);
        arrayCopy_0(result, 0, temp, 1, result.length);
        temp[0] = 1;
        result = temp;
      } else {
        var tmp_2 = result;
        var _unary__edvuaz_2 = rstart;
        rstart = _unary__edvuaz_2 - 1 | 0;
        tmp_2[_unary__edvuaz_2] = 1;
      }
    }
    this.hr_1 = result;
    this.ir_1 = resultLen;
    this.jr_1 = result.length - resultLen | 0;
  }
  lw(addend, n) {
    if (ensureNotNull(addend).lu()) {
      return Unit_instance;
    }
    var x = this.ir_1;
    var y = addend.ir_1 + n | 0;
    var resultLen = this.ir_1 > y ? this.ir_1 : y;
    var result;
    if (this.hr_1.length < resultLen) {
      result = new Int32Array(resultLen);
    } else {
      result = this.hr_1;
      fill_1(this.hr_1, this.jr_1 + this.ir_1 | 0, this.hr_1.length, 0);
    }
    var rstart = result.length - 1 | 0;
    arrayCopy_0(this.hr_1, this.jr_1, result, (rstart + 1 | 0) - x | 0, x);
    y = y - x | 0;
    rstart = rstart - x | 0;
    var tmp0 = y;
    // Inline function 'kotlin.math.min' call
    var b = addend.hr_1.length - addend.jr_1 | 0;
    var len = Math.min(tmp0, b);
    arrayCopy_0(addend.hr_1, addend.jr_1, result, (rstart + 1 | 0) - y | 0, len);
    var inductionVariable = ((rstart + 1 | 0) - y | 0) + len | 0;
    var last = rstart + 1 | 0;
    if (inductionVariable < last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        result[i] = 0;
      }
       while (inductionVariable < last);
    this.hr_1 = result;
    this.ir_1 = resultLen;
    this.jr_1 = result.length - resultLen | 0;
  }
  ow(addend, n) {
    var a = MutableBigInteger.jw(addend);
    if ((a.jr_1 + a.ir_1 | 0) >= n) {
      a.jr_1 = (a.jr_1 + a.ir_1 | 0) - n | 0;
      a.ir_1 = n;
    }
    a.qv();
    this.fu(a);
  }
  nw(b) {
    var b_0 = b;
    var a = this;
    var result = this.hr_1;
    var sign = a.iw(b_0);
    if (sign === 0) {
      this.ix();
      return 0;
    }
    if (sign < 0) {
      var tmp = a;
      a = b_0;
      b_0 = tmp;
    }
    var resultLen = a.ir_1;
    if (result.length < resultLen) {
      result = new Int32Array(resultLen);
    }
    var diff = new Long(0, 0);
    var x = a.ir_1;
    var y = b_0.ir_1;
    var rstart = result.length - 1 | 0;
    while (y > 0) {
      x = x - 1 | 0;
      y = y - 1 | 0;
      diff = toLong(a.hr_1[x + a.jr_1 | 0]).t3(new Long(-1, 0)).i3(toLong(b_0.hr_1[y + b_0.jr_1 | 0]).t3(new Long(-1, 0))).i3(toLong(diff.r3(32).o3().l1()));
      var tmp_0 = result;
      var _unary__edvuaz = rstart;
      rstart = _unary__edvuaz - 1 | 0;
      tmp_0[_unary__edvuaz] = diff.l1();
    }
    while (x > 0) {
      x = x - 1 | 0;
      var tmp0 = toLong(a.hr_1[x + a.jr_1 | 0]).t3(new Long(-1, 0));
      // Inline function 'kotlin.Long.minus' call
      var other = diff.r3(32).o3().l1();
      diff = tmp0.i3(toLong(other));
      var tmp_1 = result;
      var _unary__edvuaz_0 = rstart;
      rstart = _unary__edvuaz_0 - 1 | 0;
      tmp_1[_unary__edvuaz_0] = diff.l1();
    }
    this.hr_1 = result;
    this.ir_1 = resultLen;
    this.jr_1 = this.hr_1.length - resultLen | 0;
    this.qv();
    return sign;
  }
  aw(y, z) {
    var xLen = this.ir_1;
    var yLen = y.ir_1;
    var newLen = xLen + yLen | 0;
    if (z.hr_1.length < newLen) {
      z.hr_1 = new Int32Array(newLen);
    }
    z.jr_1 = 0;
    z.ir_1 = newLen;
    var carry = new Long(0, 0);
    // Inline function 'kotlin.run' call
    // Inline function 'com.macrofocus.common.math.big.MutableBigInteger.multiply.<anonymous>' call
    var j = yLen - 1 | 0;
    var k = (yLen + xLen | 0) - 1 | 0;
    while (j >= 0) {
      var product = toLong(y.hr_1[j + y.jr_1 | 0]).t3(new Long(-1, 0)).j3(toLong(this.hr_1[(xLen - 1 | 0) + this.jr_1 | 0]).t3(new Long(-1, 0))).h3(carry);
      z.hr_1[k] = product.l1();
      carry = product.s3(32);
      j = j - 1 | 0;
      k = k - 1 | 0;
    }
    z.hr_1[xLen - 1 | 0] = carry.l1();
    var inductionVariable = xLen - 2 | 0;
    if (0 <= inductionVariable)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + -1 | 0;
        carry = new Long(0, 0);
        var j_0 = yLen - 1 | 0;
        var k_0 = yLen + i | 0;
        while (j_0 >= 0) {
          var product_0 = toLong(y.hr_1[j_0 + y.jr_1 | 0]).t3(new Long(-1, 0)).j3(toLong(this.hr_1[i + this.jr_1 | 0]).t3(new Long(-1, 0))).h3(toLong(z.hr_1[k_0]).t3(new Long(-1, 0))).h3(carry);
          z.hr_1[k_0] = product_0.l1();
          carry = product_0.s3(32);
          j_0 = j_0 - 1 | 0;
          k_0 = k_0 - 1 | 0;
        }
        z.hr_1[i] = carry.l1();
      }
       while (0 <= inductionVariable);
    z.qv();
  }
  hx(y, z) {
    if (y === 1) {
      z.kx(this);
      return Unit_instance;
    }
    if (y === 0) {
      z.o5();
      return Unit_instance;
    }
    var ylong = toLong(y).t3(new Long(-1, 0));
    var tmp;
    if (z.hr_1.length < (this.ir_1 + 1 | 0)) {
      tmp = new Int32Array(this.ir_1 + 1 | 0);
    } else {
      tmp = z.hr_1;
    }
    var zval = tmp;
    var carry = new Long(0, 0);
    var inductionVariable = this.ir_1 - 1 | 0;
    if (0 <= inductionVariable)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + -1 | 0;
        var product = ylong.j3(toLong(this.hr_1[i + this.jr_1 | 0]).t3(new Long(-1, 0))).h3(carry);
        zval[i + 1 | 0] = product.l1();
        carry = product.s3(32);
      }
       while (0 <= inductionVariable);
    if (carry.equals(new Long(0, 0))) {
      z.jr_1 = 1;
      z.ir_1 = this.ir_1;
    } else {
      z.jr_1 = 0;
      z.ir_1 = this.ir_1 + 1 | 0;
      zval[0] = carry.l1();
    }
    z.hr_1 = zval;
  }
  mr(divisor, quotient) {
    var divisorLong = toLong(divisor).t3(new Long(-1, 0));
    if (this.ir_1 === 1) {
      var dividendValue = toLong(this.hr_1[this.jr_1]).t3(new Long(-1, 0));
      var q = dividendValue.k3(divisorLong).l1();
      var r = dividendValue.i3(numberToLong(q).j3(divisorLong)).l1();
      quotient.hr_1[0] = q;
      quotient.ir_1 = q === 0 ? 0 : 1;
      quotient.jr_1 = 0;
      return r;
    }
    if (quotient.hr_1.length < this.ir_1) {
      quotient.hr_1 = new Int32Array(this.ir_1);
    }
    quotient.jr_1 = 0;
    quotient.ir_1 = this.ir_1;
    var shift = numberOfLeadingZeros(divisor);
    var rem = this.hr_1[this.jr_1];
    var remLong = toLong(rem).t3(new Long(-1, 0));
    if (remLong.m1(divisorLong) < 0) {
      quotient.hr_1[0] = 0;
    } else {
      quotient.hr_1[0] = remLong.k3(divisorLong).l1();
      rem = remLong.i3(numberToLong(quotient.hr_1[0]).j3(divisorLong)).l1();
      remLong = toLong(rem).t3(new Long(-1, 0));
    }
    var xlen = this.ir_1;
    $l$loop: while (true) {
      xlen = xlen - 1 | 0;
      if (!(xlen > 0)) {
        break $l$loop;
      }
      var dividendEstimate = remLong.q3(32).u3(toLong(this.hr_1[(this.jr_1 + this.ir_1 | 0) - xlen | 0]).t3(new Long(-1, 0)));
      var q_0;
      if (dividendEstimate.m1(new Long(0, 0)) >= 0) {
        q_0 = dividendEstimate.k3(divisorLong).l1();
        rem = dividendEstimate.i3(numberToLong(q_0).j3(divisorLong)).l1();
      } else {
        var tmp = Companion_getInstance_23().pw(dividendEstimate, divisor);
        q_0 = tmp.t3(new Long(-1, 0)).l1();
        rem = tmp.s3(32).l1();
      }
      quotient.hr_1[this.ir_1 - xlen | 0] = q_0;
      remLong = toLong(rem).t3(new Long(-1, 0));
    }
    quotient.qv();
    var tmp_0;
    if (shift > 0) {
      tmp_0 = rem % divisor | 0;
    } else {
      tmp_0 = rem;
    }
    return tmp_0;
  }
  nx(b, quotient, needRemainder) {
    var bLenBelowThreshold = b.ir_1 < 80;
    var lenDiffIsZieglerOffset = (this.ir_1 - b.ir_1 | 0) < 40;
    var tmp;
    if (bLenBelowThreshold || lenDiffIsZieglerOffset) {
      tmp = this.mv(b, quotient, needRemainder);
    } else {
      tmp = this.ov(b, quotient);
    }
    return tmp;
  }
  ku(b, quotient, needRemainder, $super) {
    needRemainder = needRemainder === VOID ? true : needRemainder;
    return $super === VOID ? this.nx(b, quotient, needRemainder) : $super.nx.call(this, b, quotient, needRemainder);
  }
  mv(b, quotient, needRemainder) {
    var b_0 = b;
    if (b_0.ir_1 === 0) {
      throw ArithmeticException.md('BigInteger div by zero');
    }
    if (this.ir_1 === 0) {
      quotient.jr_1 = 0;
      quotient.ir_1 = quotient.jr_1;
      return needRemainder ? MutableBigInteger.lr() : null;
    }
    var cmp = this.iw(b_0);
    if (cmp < 0) {
      quotient.jr_1 = 0;
      quotient.ir_1 = quotient.jr_1;
      return needRemainder ? MutableBigInteger.jw(this) : null;
    }
    if (cmp === 0) {
      quotient.ir_1 = 1;
      quotient.hr_1[0] = quotient.ir_1;
      quotient.jr_1 = 0;
      return needRemainder ? MutableBigInteger.lr() : null;
    }
    quotient.o5();
    if (b_0.ir_1 === 1) {
      var r = this.mr(b_0.hr_1[b_0.jr_1], quotient);
      var tmp;
      if (needRemainder) {
        tmp = r === 0 ? MutableBigInteger.lr() : MutableBigInteger.ex(r);
      } else {
        tmp = null;
      }
      return tmp;
    }
    if (this.ir_1 >= Companion_getInstance_23().du_1) {
      var tmp0 = _get_lowestSetBit__xjmtq_0(this);
      // Inline function 'kotlin.math.min' call
      var b_1 = _get_lowestSetBit__xjmtq_0(b_0);
      var trailingZeroBits = Math.min(tmp0, b_1);
      if (trailingZeroBits >= imul_0(Companion_getInstance_23().eu_1, 32)) {
        var a = MutableBigInteger.jw(this);
        b_0 = MutableBigInteger.jw(b_0);
        a.qw(trailingZeroBits);
        b_0.qw(trailingZeroBits);
        var r_0 = a.nv(b_0, quotient);
        ensureNotNull(r_0).mw(trailingZeroBits);
        return r_0;
      }
    }
    return divideMagnitude(this, b_0, quotient, needRemainder);
  }
  nv(b, quotient, needRemainder, $super) {
    needRemainder = needRemainder === VOID ? true : needRemainder;
    return $super === VOID ? this.mv(b, quotient, needRemainder) : $super.mv.call(this, b, quotient, needRemainder);
  }
  ov(b, quotient) {
    var r = this.ir_1;
    var s = b.ir_1;
    quotient.ir_1 = 0;
    quotient.jr_1 = quotient.ir_1;
    if (r < s) {
      return this;
    } else {
      var m = 1 << (32 - numberOfLeadingZeros(s / 80 | 0) | 0);
      var j = ((s + m | 0) - 1 | 0) / m | 0;
      var n = imul_0(j, m);
      // Inline function 'kotlin.Long.times' call
      var n32 = (new Long(32, 0)).j3(toLong(n));
      var tmp2 = new Long(0, 0);
      // Inline function 'kotlin.math.max' call
      var b_0 = n32.i3(b.ox());
      var sigma = (tmp2.m1(b_0) >= 0 ? tmp2 : b_0).l1();
      var bShifted = MutableBigInteger.jw(b);
      bShifted.lx(sigma);
      var aShifted = MutableBigInteger.jw(this);
      aShifted.lx(sigma);
      var t = aShifted.ox().h3(n32).k3(n32).l1();
      if (t < 2) {
        t = 2;
      }
      var a1 = getBlock(aShifted, t - 1 | 0, t, n);
      var z = getBlock(aShifted, t - 2 | 0, t, n);
      z.lw(a1, n);
      var qi = MutableBigInteger.lr();
      var ri;
      var inductionVariable = t - 2 | 0;
      if (1 <= inductionVariable)
        do {
          var i = inductionVariable;
          inductionVariable = inductionVariable + -1 | 0;
          ri = divide2n1n(z, bShifted, qi);
          z = getBlock(aShifted, i - 1 | 0, t, n);
          z.lw(ri, n);
          quotient.mx(qi, imul_0(i, n));
        }
         while (1 <= inductionVariable);
      ri = divide2n1n(z, bShifted, qi);
      quotient.fu(qi);
      ensureNotNull(ri).qw(sigma);
      return ri;
    }
  }
  ox() {
    var tmp;
    if (this.ir_1 === 0) {
      tmp = new Long(0, 0);
    } else {
      var tmp0 = numberToLong(this.ir_1).j3(new Long(32, 0));
      // Inline function 'kotlin.Long.minus' call
      var other = numberOfLeadingZeros(this.hr_1[this.jr_1]);
      tmp = tmp0.i3(toLong(other));
    }
    return tmp;
  }
  bu(v, quotient) {
    var v_0 = v;
    if (v_0.equals(new Long(0, 0))) {
      throw ArithmeticException.md('BigInteger div by zero');
    }
    if (this.ir_1 === 0) {
      quotient.jr_1 = 0;
      quotient.ir_1 = quotient.jr_1;
      return new Long(0, 0);
    }
    if (v_0.m1(new Long(0, 0)) < 0) {
      v_0 = v_0.o3();
    }
    var d = v_0.s3(32).l1();
    quotient.o5();
    var tmp;
    if (d === 0) {
      tmp = toLong(this.mr(v_0.l1(), quotient)).t3(new Long(-1, 0));
    } else {
      tmp = toLong_0(divideLongMagnitude(this, v_0, quotient));
    }
    return tmp;
  }
  xv() {
    if (this.lu()) {
      return MutableBigInteger.ex(0);
    } else if (this.hr_1.length === 1 && toLong(this.hr_1[0]).t3(new Long(-1, 0)).m1(new Long(4, 0)) < 0) {
      return Companion_getInstance_23().cu_1;
    }
    if (this.ox().m1(new Long(63, 0)) <= 0) {
      var v = CommonBigInteger.jv(this.hr_1, 1).toLongExact();
      // Inline function 'kotlin.math.sqrt' call
      var x = v.a4();
      // Inline function 'kotlin.math.floor' call
      var x_0 = Math.sqrt(x);
      var tmp$ret$1 = Math.floor(x_0);
      var xk = numberToLong(tmp$ret$1);
      do {
        // Inline function 'kotlin.Long.div' call
        var xk1 = xk.h3(v.k3(xk)).k3(toLong(2));
        if (xk1.m1(xk) >= 0) {
          // Inline function 'kotlin.intArrayOf' call
          var tmp$ret$3 = new Int32Array([xk.s3(32).l1(), xk.y3().t3(new Long(-1, 0)).l1()]);
          return MutableBigInteger.au(tmp$ret$3);
        }
        xk = xk1;
      }
       while (true);
    } else {
      var bitLength = this.ox().l1();
      if (!toLong(bitLength).equals(this.ox())) {
        throw ArithmeticException.md('bitLength() integer overflow');
      }
      var shift = bitLength - 63 | 0;
      if ((shift % 2 | 0) === 1) {
        shift = shift + 1 | 0;
      }
      var xk_0 = MutableBigInteger.jw(this);
      xk_0.qw(shift);
      xk_0.qv();
      var d = CommonBigInteger.jv(xk_0.hr_1, 1).toDouble();
      var tmp = Companion_getInstance_21();
      // Inline function 'kotlin.math.sqrt' call
      // Inline function 'kotlin.math.ceil' call
      var x_1 = Math.sqrt(d);
      var tmp$ret$5 = Math.ceil(x_1);
      var bi = tmp.ofLong(numberToLong(tmp$ret$5));
      xk_0 = MutableBigInteger.au(bi.qr_1);
      xk_0.mw(shift / 2 | 0);
      var xk1_0 = MutableBigInteger.lr();
      do {
        this.nx(xk_0, xk1_0, false);
        xk1_0.fu(xk_0);
        xk1_0.qw(1);
        if (xk1_0.iw(xk_0) >= 0) {
          return xk_0;
        }
        xk_0.kx(xk1_0);
        xk1_0.ix();
      }
       while (true);
    }
  }
  zv(b) {
    var b_0 = b;
    var a = this;
    var q = MutableBigInteger.lr();
    while (!(ensureNotNull(b_0).ir_1 === 0)) {
      if (abs_0(a.ir_1 - b_0.ir_1 | 0) < 2) {
        return binaryGCD(a, b_0);
      }
      var r = a.ku(b_0, q);
      a = b_0;
      b_0 = r;
    }
    return a;
  }
  bw(p) {
    if (p.ju()) {
      return modInverse(this, p);
    }
    if (this.yw()) {
      throw ArithmeticException.md('BigInteger not invertible.');
    }
    var powersOf2 = _get_lowestSetBit__xjmtq_0(p);
    var oddMod = MutableBigInteger.jw(p);
    oddMod.qw(powersOf2);
    if (oddMod.zw()) {
      return this.px(powersOf2);
    }
    var oddPart = modInverse(this, oddMod);
    var evenPart = this.px(powersOf2);
    var y1 = Companion_getInstance_23().gx(oddMod, powersOf2);
    var y2 = oddMod.px(powersOf2);
    var temp1 = MutableBigInteger.lr();
    var temp2 = MutableBigInteger.lr();
    var result = MutableBigInteger.lr();
    oddPart.mw(powersOf2);
    oddPart.aw(y1, result);
    evenPart.aw(oddMod, temp1);
    temp1.aw(y2, temp2);
    result.fu(temp2);
    return result.ku(p, temp1);
  }
  px(k) {
    if (this.yw()) {
      throw ArithmeticException.md('Non-invertible. (GCD != 1)');
    }
    if (k > 64) {
      return this.qx(k);
    }
    var t = Companion_getInstance_23().fx(this.hr_1[(this.jr_1 + this.ir_1 | 0) - 1 | 0]);
    if (k < 33) {
      t = k === 32 ? t : t & ((1 << k) - 1 | 0);
      return MutableBigInteger.ex(t);
    }
    var pLong = toLong(this.hr_1[(this.jr_1 + this.ir_1 | 0) - 1 | 0]).t3(new Long(-1, 0));
    if (this.ir_1 > 1) {
      pLong = pLong.u3(toLong(this.hr_1[(this.jr_1 + this.ir_1 | 0) - 2 | 0]).q3(32));
    }
    var tLong = toLong(t).t3(new Long(-1, 0));
    tLong = tLong.j3(numberToLong(2).i3(pLong.j3(tLong)));
    var tmp;
    if (k === 64) {
      tmp = tLong;
    } else {
      var tmp_0 = tLong;
      // Inline function 'kotlin.Long.minus' call
      var tmp$ret$0 = (new Long(1, 0)).q3(k).i3(toLong(1));
      tmp = tmp_0.t3(tmp$ret$0);
    }
    tLong = tmp;
    var result = MutableBigInteger.au(new Int32Array(2));
    result.hr_1[0] = tLong.s3(32).l1();
    result.hr_1[1] = tLong.l1();
    result.ir_1 = 2;
    result.qv();
    return result;
  }
  qx(k) {
    var b = MutableBigInteger.ex(1);
    ensureNotNull(b).mw(k);
    var mod = MutableBigInteger.jw(b);
    var a = MutableBigInteger.jw(this);
    var q = MutableBigInteger.lr();
    var r = b.ku(a, q);
    var swapper = b;
    b = r;
    r = swapper;
    var t1 = MutableBigInteger.jw(q);
    var t0 = MutableBigInteger.ex(1);
    var temp = MutableBigInteger.lr();
    while (!ensureNotNull(b).zw()) {
      r = a.ku(b, q);
      if (ensureNotNull(r).ir_1 === 0) {
        throw ArithmeticException.md('BigInteger not invertible.');
      }
      swapper = r;
      a = swapper;
      if (q.ir_1 === 1) {
        t1.hx(q.hr_1[q.jr_1], temp);
      } else {
        q.aw(t1, temp);
      }
      swapper = q;
      q = temp;
      temp = swapper;
      t0.fu(q);
      if (a.zw()) {
        return t0;
      }
      r = b.ku(a, q);
      if (ensureNotNull(r).ir_1 === 0) {
        throw ArithmeticException.md('BigInteger not invertible.');
      }
      swapper = b;
      b = r;
      if (q.ir_1 === 1) {
        t0.hx(q.hr_1[q.jr_1], temp);
      } else {
        q.aw(t0, temp);
      }
      swapper = q;
      q = temp;
      temp = swapper;
      t1.fu(q);
    }
    mod.nw(t1);
    return mod;
  }
}
class Companion_24 {
  valueOfInt(rm) {
    return values()[rm];
  }
}
class RoundingMode extends Enum {
  constructor(name, ordinal, value) {
    super(name, ordinal);
    this.value = value;
  }
  r2() {
    return this.value;
  }
  get name() {
    return this.a3();
  }
  get ordinal() {
    return this.b3();
  }
}
class SignedMutableBigInteger extends MutableBigInteger {
  static xw() {
    var $this = this.lr();
    init_com_macrofocus_common_math_big_SignedMutableBigInteger($this);
    return $this;
  }
  static ww(val) {
    var $this = this.ex(val);
    init_com_macrofocus_common_math_big_SignedMutableBigInteger($this);
    return $this;
  }
  ax(addend) {
    if (this.vw_1 === addend.vw_1) {
      this.fu(addend);
    } else {
      this.vw_1 = imul_0(this.vw_1, this.nw(addend));
    }
  }
  cx(addend) {
    if (this.vw_1 === 1) {
      this.fu(addend);
    } else {
      this.vw_1 = imul_0(this.vw_1, this.nw(addend));
    }
  }
  bx(addend) {
    if (this.vw_1 === addend.vw_1) {
      this.vw_1 = imul_0(this.vw_1, this.nw(addend));
    } else {
      this.fu(addend);
    }
  }
  toString() {
    return this.gu(this.vw_1).toString();
  }
}
class AbstractProperty {
  constructor($box) {
    boxApply(this, $box);
    var tmp = this;
    tmp.rx_1 = lazy(AbstractProperty$listernersDelegate$lambda);
    this.sx_1 = this.rx_1;
  }
  uo(listener) {
    _get_listeners__760gzy(this).o(listener);
  }
  tx(listener) {
    var weakListener = new WeakPropertyListener(this, listener);
    this.uo(weakListener);
  }
  ux(listener) {
    _get_listeners__760gzy(this).w2(listener);
  }
  vx(event) {
    if (this.rx_1.xj()) {
      var _iterator__ex2g4s = _get_listeners__760gzy(this).x();
      while (_iterator__ex2g4s.y()) {
        var listener = _iterator__ex2g4s.z();
        listener.qo(event);
      }
    }
  }
}
class MutableProperty {}
function getValue(thisRef, property) {
  return this.r2();
}
function setValue(thisRef, property, value) {
  this.vo(value);
}
class AbstractMutableProperty extends AbstractProperty {}
class WeakPropertiesListener {
  constructor($outer, listener) {
    this.yx_1 = $outer;
    this.xx_1 = new WeakReference(listener);
  }
  zx(name, event) {
    var l = this.hl();
    if (!(l == null)) {
      l.zx(name, event);
    } else {
      this.yx_1.by(this);
    }
  }
  hl() {
    return this.xx_1.xk();
  }
  toString() {
    var l = this.hl();
    var tmp;
    if (!(l == null)) {
      tmp = 'Weak[' + toString_0(l) + ']';
    } else {
      tmp = toString_0(l);
    }
    return tmp;
  }
}
class AbstractProperties {
  constructor() {
    this.ay_1 = CollectionFactory_instance.ll();
  }
  cy(listener) {
    this.ay_1.o(listener);
  }
  dy(listener) {
    var weakListener = new WeakPropertiesListener(this, listener);
    this.ay_1.o(weakListener);
  }
  by(listener) {
    if (listener instanceof WeakPropertiesListener) {
      var removed = this.ay_1.w2(listener);
    } else {
      var toRemove = null;
      var _iterator__ex2g4s = this.ay_1.x();
      while (_iterator__ex2g4s.y()) {
        var propertiesListener = _iterator__ex2g4s.z();
        var comparable;
        if (propertiesListener instanceof WeakPropertiesListener) {
          comparable = propertiesListener.hl();
        } else {
          comparable = propertiesListener;
        }
        if (equals(listener, comparable)) {
          toRemove = propertiesListener;
        }
      }
      if (!(toRemove == null)) {
        var removed_0 = this.ay_1.w2(toRemove);
      }
    }
    this.ay_1.w2(listener);
  }
  ey(name, event) {
    var _iterator__ex2g4s = this.ay_1.x();
    while (_iterator__ex2g4s.y()) {
      var listener = _iterator__ex2g4s.z();
      listener.zx(name, event);
    }
  }
}
class WeakPropertyListener {
  constructor($outer, listener) {
    this.gy_1 = $outer;
    this.fy_1 = new WeakReference(listener);
  }
  qo(event) {
    var l = _get_reference__19y5ba(this);
    if (!(l == null)) {
      l.qo(event);
    } else {
      this.gy_1.ux(isInterface(this, PropertyListener) ? this : THROW_CCE());
    }
  }
  toString() {
    var l = _get_reference__19y5ba(this);
    var tmp;
    if (!(l == null)) {
      tmp = 'Weak[' + toString_0(l) + ']';
    } else {
      tmp = toString_0(l);
    }
    return tmp;
  }
}
class EnumProperties$ExposedProperty$listener$1 {
  constructor(this$0) {
    this.hy_1 = this$0;
  }
  qo(event) {
    this.hy_1.vx(event);
  }
}
class NamedPropertyListener {
  constructor($outer, name) {
    this.jy_1 = $outer;
    this.iy_1 = name;
  }
  ky(event) {
    this.jy_1.ey(this.iy_1, event);
  }
  qo(event) {
    return this.ky(event);
  }
}
class ExposedProperty extends AbstractMutableProperty {
  constructor($outer, secret, $box) {
    if ($box === VOID)
      $box = {};
    $box.py_1 = $outer;
    super($box);
    var tmp = this;
    tmp.oy_1 = new EnumProperties$ExposedProperty$listener$1(this);
    this.ny_1 = secret;
    this.ny_1.uo(this.oy_1);
  }
  vo(value) {
    this.ny_1.vo(value);
  }
  r2() {
    return this.ny_1.r2();
  }
}
class EnumProperties extends AbstractProperties {
  constructor(enums) {
    super();
    this.ry_1 = new EnumMap(enums);
    this.sy_1 = new EnumMap(enums);
  }
  x() {
    return this.ry_1.g7().x();
  }
  ty(name, value) {
    var property = Companion_instance_26.newInstance(value);
    return this.uy(name, property);
  }
  vy(name, value) {
    var tmp = name instanceof Enum ? name : THROW_CCE();
    return this.ty(tmp, (value == null ? true : !(value == null)) ? value : THROW_CCE());
  }
  uy(name, property) {
    var exposedProperty = new ExposedProperty(this, isInterface(property, MutableProperty) ? property : THROW_CCE());
    // Inline function 'kotlin.collections.set' call
    this.ry_1.i7(name, exposedProperty);
    var listener = new NamedPropertyListener(this, name);
    exposedProperty.uo(listener);
    // Inline function 'kotlin.collections.set' call
    this.sy_1.i7(name, listener);
    return isInterface(exposedProperty, MutableProperty) ? exposedProperty : THROW_CCE();
  }
  wy(name, property) {
    return this.uy(name instanceof Enum ? name : THROW_CCE(), property);
  }
  xy(name) {
    return ensureNotNull(this.ry_1.gk(name)).r2();
  }
  yy(name) {
    return this.xy(name instanceof Enum ? name : THROW_CCE());
  }
  zy(name) {
    return ensureNotNull(this.ry_1.gk(name));
  }
  az(name) {
    return this.zy(name instanceof Enum ? name : THROW_CCE());
  }
}
class KReadWriteProperty {
  constructor(property) {
    this.bz_1 = property;
  }
  sh(thisRef, property) {
    return this.bz_1.r2();
  }
  th(thisRef, property) {
    return this.sh((thisRef == null ? true : !(thisRef == null)) ? thisRef : THROW_CCE(), property);
  }
  wx(thisRef, property, value) {
    this.bz_1.vo(value);
  }
  vh(thisRef, property, value) {
    var tmp = (thisRef == null ? true : !(thisRef == null)) ? thisRef : THROW_CCE();
    return this.wx(tmp, property, (value == null ? true : !(value == null)) ? value : THROW_CCE());
  }
}
class Companion_25 {
  constructor() {
    this.cz_1 = 'overrideDefaults';
  }
}
class OverrideProperties$registerPropertyListener$1 {
  constructor(this$0, $name) {
    this.dz_1 = this$0;
    this.ez_1 = $name;
  }
  ky(event) {
    this.dz_1.ey(this.ez_1, new PropertyEvent(event.oldValue, event.newValue));
  }
  qo(event) {
    return this.ky(event);
  }
}
class OverrideProperties extends AbstractProperties {
  constructor(defaults, overrideDefaults) {
    super();
    this.gz_1 = defaults;
    this.hz_1 = overrideDefaults;
    this.iz_1 = HashMap.d8();
    this.jz_1 = HashMap.d8();
  }
  x() {
    return this.gz_1.x();
  }
  kz(name, value) {
    throw UnsupportedOperationException.h4();
  }
  vy(name, value) {
    var tmp = (name == null ? true : typeof name === 'string') ? name : THROW_CCE();
    return this.kz(tmp, (value == null ? true : !(value == null)) ? value : THROW_CCE());
  }
  lz(name, property) {
    throw UnsupportedOperationException.h4();
  }
  wy(name, property) {
    return this.lz((name == null ? true : typeof name === 'string') ? name : THROW_CCE(), property);
  }
  mz(name) {
    return this.hz_1.r2() && this.iz_1.s2(name) ? ensureNotNull(this.iz_1.u2(name)).r2() : this.gz_1.yy(name);
  }
  yy(name) {
    return this.mz((name == null ? true : typeof name === 'string') ? name : THROW_CCE());
  }
  tz(name) {
    var tmp;
    if (this.iz_1.s2(name)) {
      tmp = ensureNotNull(this.iz_1.u2(name));
    } else {
      var property = this.uz(name, this.hz_1, this.gz_1.az(name));
      this.vz(name, property);
      // Inline function 'kotlin.collections.set' call
      this.iz_1.i7(name, property);
      tmp = property;
    }
    return tmp;
  }
  az(name) {
    return this.tz((name == null ? true : typeof name === 'string') ? name : THROW_CCE());
  }
  vz(name, property) {
    property.uo(new OverrideProperties$registerPropertyListener$1(this, name));
  }
  uz(name, overrideDefaults, defaultProperty) {
    return new OverrideProperty(overrideDefaults, defaultProperty);
  }
  ix() {
    var _iterator__ex2g4s = this.iz_1.h7().x();
    while (_iterator__ex2g4s.y()) {
      var property = _iterator__ex2g4s.z();
      if (property instanceof OverrideProperty) {
        ensureNotNull((property == null ? true : property instanceof OverrideProperty) ? property : THROW_CCE()).ix();
      }
    }
  }
}
class OverrideProperty$overridePropertyListener$1 {
  constructor($overrideDefaults, this$0) {
    this.wz_1 = $overrideDefaults;
    this.xz_1 = this$0;
  }
  qo(event) {
    if (this.wz_1.r2()) {
      this.xz_1.vx(new PropertyEvent(event.oldValue, event.newValue));
    }
  }
}
class OverrideProperty$1 {
  constructor($defaultProperty, this$0) {
    this.yz_1 = $defaultProperty;
    this.zz_1 = this$0;
  }
  a10(event) {
    var defaultValue = this.yz_1.r2();
    var overrideValue = !(this.zz_1.rz_1 == null) ? ensureNotNull(this.zz_1.rz_1).r2() : defaultValue;
    if (!(defaultValue === overrideValue)) {
      if (event.newValue) {
        this.zz_1.vx(new PropertyEvent(defaultValue, overrideValue));
      } else {
        this.zz_1.vx(new PropertyEvent(overrideValue, defaultValue));
      }
    }
  }
  qo(event) {
    return this.a10(event);
  }
}
class OverrideProperty$2 {
  constructor($overrideDefaults, this$0) {
    this.b10_1 = $overrideDefaults;
    this.c10_1 = this$0;
  }
  qo(event) {
    if (!this.b10_1.r2()) {
      this.c10_1.vx(new PropertyEvent(event.oldValue, event.newValue));
    }
  }
}
class OverrideProperty extends AbstractMutableProperty {
  constructor(overrideDefaults, defaultProperty) {
    super();
    this.pz_1 = overrideDefaults;
    this.qz_1 = defaultProperty;
    this.rz_1 = null;
    var tmp = this;
    tmp.sz_1 = new OverrideProperty$overridePropertyListener$1(overrideDefaults, this);
    overrideDefaults.uo(new OverrideProperty$1(defaultProperty, this));
    defaultProperty.uo(new OverrideProperty$2(overrideDefaults, this));
  }
  d10() {
    return this.qz_1;
  }
  e10() {
    if (this.rz_1 == null) {
      this.rz_1 = this.f10();
    }
    return this.rz_1;
  }
  f10() {
    var overrideProperty = Companion_instance_26.newInstance(this.d10().r2());
    return this.g10(overrideProperty);
  }
  g10(overrideProperty) {
    overrideProperty.uo(this.sz_1);
    return overrideProperty;
  }
  h10(overrideProperty) {
    overrideProperty.ux(this.sz_1);
  }
  vo(value) {
    if (this.pz_1.r2()) {
      ensureNotNull(this.e10()).vo(value);
    } else {
      this.d10().vo(value);
    }
  }
  r2() {
    var tmp;
    if (this.pz_1.r2() && !(this.rz_1 == null)) {
      tmp = ensureNotNull(this.rz_1).r2();
    } else {
      tmp = this.d10().r2();
    }
    return tmp;
  }
  i10() {
    var tmp;
    if (this.pz_1.r2() && !(this.rz_1 == null)) {
      tmp = ensureNotNull(this.rz_1).r2();
    } else {
      tmp = null;
    }
    return tmp;
  }
  ix() {
    if (this.pz_1.r2() && !(this.rz_1 == null)) {
      var oldValue = ensureNotNull(this.rz_1).r2();
      var newValue = this.d10().r2();
      this.h10(ensureNotNull(this.rz_1));
      this.rz_1 = null;
      if (!(oldValue === newValue)) {
        this.vx(new PropertyEvent(oldValue, newValue));
      }
    }
    this.rz_1 = null;
  }
}
class PropertyDelegates$mutable$1 extends KReadWriteProperty {}
class PropertyDelegates {
  j10(property) {
    return new PropertyDelegates$mutable$1(property);
  }
}
class PropertyEvent {
  constructor(oldValue, newValue) {
    this.oldValue = oldValue;
    this.newValue = newValue;
  }
  k10() {
    return this.oldValue;
  }
  l10() {
    return this.newValue;
  }
  toString() {
    return 'PropertyEvent{oldValue=' + this.oldValue + ', newValue=' + this.newValue + toString(_Char___init__impl__6a9atx(125));
  }
  kj() {
    return this.oldValue;
  }
  lj() {
    return this.newValue;
  }
  m10(oldValue, newValue) {
    return new PropertyEvent(oldValue, newValue);
  }
  copy(oldValue, newValue, $super) {
    oldValue = oldValue === VOID ? this.oldValue : oldValue;
    newValue = newValue === VOID ? this.newValue : newValue;
    return this.m10(oldValue, newValue);
  }
  hashCode() {
    var result = this.oldValue == null ? 0 : hashCode(this.oldValue);
    result = imul_0(result, 31) + (this.newValue == null ? 0 : hashCode(this.newValue)) | 0;
    return result;
  }
  equals(other) {
    if (this === other)
      return true;
    if (!(other instanceof PropertyEvent))
      return false;
    var tmp0_other_with_cast = other instanceof PropertyEvent ? other : THROW_CCE();
    if (!equals(this.oldValue, tmp0_other_with_cast.oldValue))
      return false;
    if (!equals(this.newValue, tmp0_other_with_cast.newValue))
      return false;
    return true;
  }
}
class SimpleProperties$ExposedProperty$listener$1 {
  constructor(this$0) {
    this.n10_1 = this$0;
  }
  qo(event) {
    this.n10_1.vx(event);
  }
}
class NamedPropertyListener_0 {
  constructor($outer, name) {
    this.p10_1 = $outer;
    this.o10_1 = name;
  }
  ky(event) {
    this.p10_1.ey(this.o10_1, event);
  }
  qo(event) {
    return this.ky(event);
  }
}
class ExposedProperty_0 extends AbstractMutableProperty {
  constructor($outer, secret, $box) {
    if ($box === VOID)
      $box = {};
    $box.u10_1 = $outer;
    super($box);
    var tmp = this;
    tmp.t10_1 = new SimpleProperties$ExposedProperty$listener$1(this);
    this.s10_1 = secret;
    this.s10_1.uo(this.t10_1);
  }
  vo(value) {
    this.s10_1.vo(value);
  }
  r2() {
    return this.s10_1.r2();
  }
}
class SimpleProperties extends AbstractProperties {
  constructor() {
    super();
    this.w10_1 = HashMap.d8();
    this.x10_1 = HashMap.d8();
  }
  x() {
    return this.w10_1.g7().x();
  }
  kz(name, value) {
    var property = Companion_instance_26.newInstance(value);
    return this.lz(name, property);
  }
  vy(name, value) {
    var tmp = (name == null ? true : typeof name === 'string') ? name : THROW_CCE();
    return this.kz(tmp, (value == null ? true : !(value == null)) ? value : THROW_CCE());
  }
  lz(name, property) {
    var exposedProperty = new ExposedProperty_0(this, isInterface(property, MutableProperty) ? property : THROW_CCE());
    // Inline function 'kotlin.collections.set' call
    this.w10_1.i7(name, exposedProperty);
    var listener = new NamedPropertyListener_0(this, name);
    exposedProperty.uo(listener);
    // Inline function 'kotlin.collections.set' call
    this.x10_1.i7(name, listener);
    return isInterface(exposedProperty, MutableProperty) ? exposedProperty : THROW_CCE();
  }
  wy(name, property) {
    return this.lz((name == null ? true : typeof name === 'string') ? name : THROW_CCE(), property);
  }
  mz(name) {
    return ensureNotNull(this.w10_1.u2(name)).r2();
  }
  yy(name) {
    return this.mz((name == null ? true : typeof name === 'string') ? name : THROW_CCE());
  }
  tz(name) {
    return ensureNotNull(this.w10_1.u2(name));
  }
  az(name) {
    return this.tz((name == null ? true : typeof name === 'string') ? name : THROW_CCE());
  }
}
class Companion_26 {
  newInstance(value) {
    return new SimpleProperty(value);
  }
}
class SimpleProperty$value$$inlined$observable$1 extends ObservableProperty {
  constructor($initialValue, this$0, $box) {
    if ($box === VOID)
      $box = {};
    $box.z10_1 = this$0;
    super($initialValue, $box);
  }
  a11(property, oldValue, newValue) {
    var tmp;
    if (!equals(oldValue, newValue)) {
      this.z10_1.vx(new PropertyEvent(oldValue, newValue));
      tmp = Unit_instance;
    }
    return tmp;
  }
  rh(property, oldValue, newValue) {
    var tmp = (oldValue == null ? true : !(oldValue == null)) ? oldValue : THROW_CCE();
    return this.a11(property, tmp, (newValue == null ? true : !(newValue == null)) ? newValue : THROW_CCE());
  }
}
class SimpleProperty extends AbstractMutableProperty {
  constructor(value) {
    super();
    var tmp = this;
    // Inline function 'kotlin.properties.Delegates.observable' call
    tmp.d11_1 = new SimpleProperty$value$$inlined$observable$1(value, this);
  }
  vo(_set____db54di) {
    return this.d11_1.vh(this, value$factory(), _set____db54di);
  }
  r2() {
    return this.d11_1.th(this, value$factory_0());
  }
  toString() {
    return 'SimpleProperty{value=' + this.r2() + toString(_Char___init__impl__6a9atx(125));
  }
}
class StartEnd extends Enum {}
class BoundedIntervalProperty$1 {
  constructor(this$0) {
    this.e11_1 = this$0;
  }
  fn(event) {
    switch (this.e11_1.i11_1.z2_1) {
      case 0:
        this.e11_1.vx(new PropertyEvent(event.wn_1, event.zn_1));
        break;
      case 1:
        this.e11_1.vx(new PropertyEvent(ensureNotNull(event).xn_1, event.ao_1));
        break;
      default:
        noWhenBranchMatchedException();
        break;
    }
  }
}
class BoundedIntervalProperty extends AbstractMutableProperty {
  constructor(interval, startEnd) {
    super();
    this.h11_1 = interval;
    this.i11_1 = startEnd;
    this.h11_1.addIntervalListener(new BoundedIntervalProperty$1(this));
  }
  j11(value) {
    switch (this.i11_1.z2_1) {
      case 0:
        this.h11_1.start = ensureNotNull(value);
        break;
      case 1:
        this.h11_1.end = ensureNotNull(value);
        break;
      default:
        noWhenBranchMatchedException();
        break;
    }
  }
  vo(_set____db54di) {
    return this.j11((_set____db54di == null ? true : typeof _set____db54di === 'number') ? _set____db54di : THROW_CCE());
  }
  r2() {
    var tmp;
    switch (this.i11_1.z2_1) {
      case 0:
        tmp = this.h11_1.start;
        break;
      case 1:
        tmp = this.h11_1.end;
        break;
      default:
        noWhenBranchMatchedException();
        break;
    }
    return tmp;
  }
}
class NumericTransform extends Enum {
  constructor(name, ordinal, shortName, transform, inverse, dtransform, dinverse, domain) {
    super(name, ordinal);
    this.k12_1 = shortName;
    this.l12_1 = transform;
    this.m12_1 = inverse;
    this.n12_1 = dtransform;
    this.o12_1 = dinverse;
    this.p12_1 = domain;
  }
}
class Probit {
  constructor() {
    this.k11_1 = 0.02425;
    this.l11_1 = 0.97575;
    this.m11_1 = -39.69683028665376;
    this.n11_1 = 220.9460984245205;
    this.o11_1 = -275.9285104469687;
    this.p11_1 = 138.357751867269;
    this.q11_1 = -30.66479806614716;
    this.r11_1 = 2.506628277459239;
    this.s11_1 = -54.47609879822406;
    this.t11_1 = 161.5858368580409;
    this.u11_1 = -155.6989798598866;
    this.v11_1 = 66.80131188771972;
    this.w11_1 = -13.28068155288572;
    this.x11_1 = -0.007784894002430293;
    this.y11_1 = -0.3223964580411365;
    this.z11_1 = -2.400758277161838;
    this.a12_1 = -2.549732539343734;
    this.b12_1 = 4.374664141464968;
    this.c12_1 = 2.938163982698783;
    this.d12_1 = 0.007784695709041462;
    this.e12_1 = 0.3224671290700398;
    this.f12_1 = 2.445134137142996;
    this.g12_1 = 3.754408661907416;
  }
  h12(d) {
    if (d <= 0 || d >= 1) {
      return (d - 0.5) / 0.0;
    } else if (d < 0.02425) {
      // Inline function 'kotlin.math.ln' call
      // Inline function 'kotlin.math.sqrt' call
      var x = -2 * Math.log(d);
      var q = Math.sqrt(x);
      return (((((-0.007784894002430293 * q + -0.3223964580411365) * q + -2.400758277161838) * q + -2.549732539343734) * q + 4.374664141464968) * q + 2.938163982698783) / ((((0.007784695709041462 * q + 0.3224671290700398) * q + 2.445134137142996) * q + 3.754408661907416) * q + 1);
    } else if (0.97575 < d) {
      // Inline function 'kotlin.math.ln' call
      var x_0 = 1 - d;
      // Inline function 'kotlin.math.sqrt' call
      var x_1 = -2 * Math.log(x_0);
      var q_0 = Math.sqrt(x_1);
      return -(((((-0.007784894002430293 * q_0 + -0.3223964580411365) * q_0 + -2.400758277161838) * q_0 + -2.549732539343734) * q_0 + 4.374664141464968) * q_0 + 2.938163982698783) / ((((0.007784695709041462 * q_0 + 0.3224671290700398) * q_0 + 2.445134137142996) * q_0 + 3.754408661907416) * q_0 + 1);
    } else {
      var q_1 = d - 0.5;
      var r = q_1 * q_1;
      return (((((-39.69683028665376 * r + 220.9460984245205) * r + -275.9285104469687) * r + 138.357751867269) * r + -30.66479806614716) * r + 2.506628277459239) * q_1 / (((((-54.47609879822406 * r + 161.5858368580409) * r + -155.6989798598866) * r + 66.80131188771972) * r + -13.28068155288572) * r + 1);
    }
  }
}
class AbstractSelection {
  static v12() {
    var $this = createThis(this);
    $this.t12_1 = true;
    $this.u12_1 = CollectionFactory_instance.ll();
    return $this;
  }
  w12() {
    return this.t12_1;
  }
  x12(listener) {
    this.u12_1.o(listener);
  }
  y12(listener) {
    if (listener instanceof WeakSelectionListener) {
      var removed = this.u12_1.w2(listener);
    } else {
      var toRemove = null;
      var _iterator__ex2g4s = this.u12_1.x();
      while (_iterator__ex2g4s.y()) {
        var selectionListener = _iterator__ex2g4s.z();
        var comparable;
        if (selectionListener instanceof WeakSelectionListener) {
          comparable = selectionListener.hl();
        } else {
          comparable = selectionListener;
        }
        if (equals(listener, comparable)) {
          toRemove = selectionListener;
        }
      }
      if (!(toRemove == null)) {
        var removed_0 = this.u12_1.w2(toRemove);
      }
    }
  }
  z12(event) {
    var _iterator__ex2g4s = this.u12_1.x();
    while (_iterator__ex2g4s.y()) {
      var listener = _iterator__ex2g4s.z();
      listener.x13(event);
    }
  }
}
class AbstractMutableSelection extends AbstractSelection {
  static s12() {
    return this.v12();
  }
  w12() {
    return super.w12();
  }
}
class WeakSingleSelectionListener {
  l13() {
    return this.k13_1.xk();
  }
}
class AbstractMutableSingleSelection extends AbstractMutableSelection {
  static p13() {
    var $this = this.s12();
    $this.o13_1 = CollectionFactory_instance.ll();
    return $this;
  }
  q13(listener) {
    this.o13_1.o(listener);
  }
  r13(listener) {
    if (listener instanceof WeakSingleSelectionListener) {
      var removed = this.o13_1.w2(listener);
    } else {
      var toRemove = null;
      var _iterator__ex2g4s = this.o13_1.x();
      while (_iterator__ex2g4s.y()) {
        var selectionListener = _iterator__ex2g4s.z();
        var comparable;
        var tmp;
        if (selectionListener instanceof WeakSingleSelectionListener) {
          tmp = selectionListener.l13();
        } else {
          tmp = selectionListener;
        }
        comparable = tmp;
        if (equals(listener, comparable)) {
          toRemove = selectionListener;
        }
      }
      if (!(toRemove == null)) {
        var removed_0 = this.o13_1.w2(toRemove);
      }
    }
  }
  s13(event) {
    var _iterator__ex2g4s = this.o13_1.x();
    while (_iterator__ex2g4s.y()) {
      var listener = _iterator__ex2g4s.z();
      listener.t13(event);
    }
    super.z12(event);
  }
}
class WeakSelectionListener {
  hl() {
    return this.w13_1.xk();
  }
}
class AbstractSelectionEvent {}
class PropertySingleSelection$iterator$1 {
  constructor(this$0) {
    this.z13_1 = this$0;
    this.y13_1 = this$0.a13();
  }
  y() {
    return !this.y13_1;
  }
  z() {
    this.y13_1 = true;
    return ensureNotNull(this.z13_1.v13());
  }
}
class PropertySingleSelection$1 {
  constructor(this$0, $self) {
    this.e14_1 = this$0;
    this.f14_1 = $self;
  }
  g14(event) {
    this.e14_1.s13(new SingleSelectionEvent(this.f14_1, !(event.oldValue == null), !(event.newValue == null), event.oldValue, event.newValue));
  }
  qo(event) {
    return this.g14(event);
  }
}
class PropertySingleSelection extends AbstractMutableSingleSelection {
  static h14(property) {
    var $this = this.p13();
    $this.d14_1 = property;
    var self_0 = $this;
    $this.d14_1.uo(new PropertySingleSelection$1($this, self_0));
    return $this;
  }
  e13() {
    var tmp;
    if (this.w12() && this.a13()) {
      this.i14(null);
      tmp = true;
    } else {
      tmp = false;
    }
    return tmp;
  }
  a13() {
    return !(this.v13() == null) && this.w12();
  }
  b13(element) {
    return equals(this.d14_1.r2(), element);
  }
  f13(element) {
    this.u13(element);
  }
  g13(element, selected) {
    if (this.w12()) {
      if (selected) {
        this.u13(element);
      } else {
        if (this.b13(element)) {
          this.e13();
        }
      }
    }
  }
  h13(element, selected) {
    throw UnsupportedOperationException.h4();
  }
  i13(elements) {
    throw UnsupportedOperationException.h4();
  }
  j13(elements) {
    throw UnsupportedOperationException.h4();
  }
  u13(element) {
    this.i14(element);
  }
  v13() {
    return this.d14_1.r2();
  }
  i14(element) {
    if (this.w12()) {
      if (!(this.v13() === element)) {
        var previousSelected = this.v13();
        var previousActive = !(previousSelected == null);
        this.d14_1.vo(ensureNotNull(element));
        this.s13(new SingleSelectionEvent(this, previousActive, !(element == null), previousSelected, element));
      }
    }
  }
  d13() {
    return this.a13() ? 1 : 0;
  }
  c13() {
    return this.a13() ? setOf(ensureNotNull(this.v13())) : emptySet();
  }
  x() {
    return new PropertySingleSelection$iterator$1(this);
  }
}
class SimpleSelection extends AbstractMutableSelection {
  static m14() {
    var $this = this.s12();
    $this.l14_1 = CollectionFactory_instance.n14();
    return $this;
  }
  e13() {
    var tmp;
    if (this.w12() && this.a13()) {
      var changes = HashSet.x9();
      changes.x2(this.l14_1);
      this.l14_1.o5();
      this.z12(new SimpleSelectionEvent(this, changes));
      tmp = true;
    } else {
      tmp = false;
    }
    return tmp;
  }
  a13() {
    return !this.l14_1.c1() && this.w12();
  }
  b13(element) {
    return !(element == null) && this.l14_1.j2(element);
  }
  f13(e) {
    if (this.w12()) {
      if (!(e == null)) {
        var changes = HashSet.x9();
        var _iterator__ex2g4s = this.l14_1.x();
        while (_iterator__ex2g4s.y()) {
          var element = _iterator__ex2g4s.z();
          changes.o(element);
        }
        if (!this.b13(e)) {
          changes.o(e);
          this.l14_1.o(e);
        } else {
          changes.w2(e);
        }
        if (changes.a1() > 0) {
          this.l14_1.o5();
          this.l14_1.o(e);
          this.z12(new SimpleSelectionEvent(this, changes));
        }
      } else {
        this.e13();
      }
    }
  }
  g13(element, selected) {
    if (this.w12() && !(element == null)) {
      if (selected) {
        if (!this.b13(element)) {
          var changes = HashSet.x9();
          changes.o(element);
          this.l14_1.o(element);
          this.z12(new SimpleSelectionEvent(this, changes));
        }
      } else {
        if (this.b13(element)) {
          var changes_0 = HashSet.x9();
          changes_0.o(element);
          this.l14_1.w2(element);
          this.z12(new SimpleSelectionEvent(this, changes_0));
        }
      }
    }
  }
  h13(elements, selected) {
    if (this.w12() && !(elements == null)) {
      if (selected) {
        var changes = HashSet.x9();
        var _iterator__ex2g4s = elements.x();
        while (_iterator__ex2g4s.y()) {
          var element = _iterator__ex2g4s.z();
          if (!this.b13(element)) {
            changes.o(element);
            this.l14_1.o(element);
          }
        }
        if (changes.a1() > 0) {
          this.z12(new SimpleSelectionEvent(this, changes));
          return true;
        }
      } else {
        var changes_0 = HashSet.x9();
        var _iterator__ex2g4s_0 = elements.x();
        while (_iterator__ex2g4s_0.y()) {
          var element_0 = _iterator__ex2g4s_0.z();
          if (this.b13(element_0)) {
            changes_0.o(element_0);
            this.l14_1.w2(element_0);
          }
        }
        if (changes_0.a1() > 0) {
          this.z12(new SimpleSelectionEvent(this, changes_0));
          return true;
        }
      }
    }
    return false;
  }
  i13(elements) {
    if (this.w12() && !(elements == null)) {
      var changes = HashSet.x9();
      var _iterator__ex2g4s = this.l14_1.x();
      while (_iterator__ex2g4s.y()) {
        var element = _iterator__ex2g4s.z();
        changes.o(element);
      }
      var inductionVariable = 0;
      var last = elements.length;
      while (inductionVariable < last) {
        var element_0 = elements[inductionVariable];
        inductionVariable = inductionVariable + 1 | 0;
        if (!this.b13(element_0)) {
          changes.o(element_0);
          this.l14_1.o(element_0);
        } else {
          changes.w2(element_0);
        }
      }
      if (changes.a1() > 0) {
        this.l14_1.o5();
        addAll(this.l14_1, elements);
        this.z12(new SimpleSelectionEvent(this, changes));
      }
    }
  }
  j13(elements) {
    if (this.w12()) {
      if (!(elements == null)) {
        var changes = HashSet.x9();
        var _iterator__ex2g4s = this.l14_1.x();
        while (_iterator__ex2g4s.y()) {
          var element = _iterator__ex2g4s.z();
          changes.o(element);
        }
        var _iterator__ex2g4s_0 = elements.x();
        while (_iterator__ex2g4s_0.y()) {
          var element_0 = _iterator__ex2g4s_0.z();
          if (!this.b13(element_0)) {
            changes.o(element_0);
            this.l14_1.o(element_0);
          } else {
            changes.w2(element_0);
          }
        }
        if (changes.a1() > 0) {
          this.l14_1.o5();
          var _iterator__ex2g4s_1 = elements.x();
          while (_iterator__ex2g4s_1.y()) {
            var element_1 = _iterator__ex2g4s_1.z();
            this.l14_1.o(element_1);
          }
          this.z12(new SimpleSelectionEvent(this, changes));
        }
      } else {
        if (!this.l14_1.c1()) {
          var changes_0 = HashSet.x9();
          var _iterator__ex2g4s_2 = this.l14_1.x();
          while (_iterator__ex2g4s_2.y()) {
            var element_2 = _iterator__ex2g4s_2.z();
            changes_0.o(element_2);
          }
          this.l14_1.o5();
          this.z12(new SimpleSelectionEvent(this, changes_0));
        }
      }
    }
  }
  d13() {
    return this.l14_1.a1();
  }
  c13() {
    return this.l14_1;
  }
  x() {
    return this.l14_1.x();
  }
  toString() {
    var selected = '';
    var first = true;
    var _iterator__ex2g4s = this.l14_1.x();
    while (_iterator__ex2g4s.y()) {
      var s = _iterator__ex2g4s.z();
      if (!first) {
        selected = selected + ',';
      } else {
        first = false;
      }
      selected = selected + toString_0(s);
    }
    return 'SimpleSelection{selected=' + selected + toString(_Char___init__impl__6a9atx(125));
  }
}
class SimpleSelectionEvent extends AbstractSelectionEvent {
  constructor(model, changes) {
    super();
    this.o14_1 = model;
    this.p14_1 = changes;
  }
  toString() {
    var s = 'SimpleSelectionEvent{model=' + toString_1(this.o14_1) + ', changes=';
    var _iterator__ex2g4s = this.p14_1.x();
    while (_iterator__ex2g4s.y()) {
      var change = _iterator__ex2g4s.z();
      s = s + (toString_0(change) + '(' + this.o14_1.b13(change) + '),');
    }
    s = s + toString(_Char___init__impl__6a9atx(125));
    return s;
  }
  hashCode() {
    var result = hashCode(this.o14_1);
    result = imul_0(result, 31) + hashCode(this.p14_1) | 0;
    return result;
  }
  equals(other) {
    if (this === other)
      return true;
    if (!(other instanceof SimpleSelectionEvent))
      return false;
    var tmp0_other_with_cast = other instanceof SimpleSelectionEvent ? other : THROW_CCE();
    if (!equals(this.o14_1, tmp0_other_with_cast.o14_1))
      return false;
    if (!equals(this.p14_1, tmp0_other_with_cast.p14_1))
      return false;
    return true;
  }
}
class SimpleSingleSelection$iterator$1 {
  constructor(this$0) {
    this.r14_1 = this$0;
    this.q14_1 = !this$0.a13();
  }
  y() {
    return !this.q14_1;
  }
  z() {
    this.q14_1 = true;
    var s = this.r14_1.v14_1;
    if (!(s == null)) {
      return s;
    } else {
      throw IllegalStateException.lc();
    }
  }
}
class SimpleSingleSelection extends AbstractMutableSingleSelection {
  u13(element) {
    if (this.w12()) {
      if (!(this.v14_1 === element)) {
        if (this.v14_1 == null || !equals(this.v14_1, element)) {
          var previousSelected = this.v14_1;
          var previousActive = !(this.v14_1 == null);
          this.v14_1 = element;
          this.s13(new SingleSelectionEvent(this, previousActive, !(element == null), previousSelected, element));
        }
      }
    }
  }
  v13() {
    return this.v14_1;
  }
  static w14() {
    var $this = this.p13();
    init_com_macrofocus_common_selection_SimpleSingleSelection($this);
    $this.u13(null);
    return $this;
  }
  static x14(selected) {
    var $this = this.p13();
    init_com_macrofocus_common_selection_SimpleSingleSelection($this);
    $this.u13(selected);
    return $this;
  }
  e13() {
    var tmp;
    if (this.w12() && this.a13()) {
      this.u13(null);
      tmp = true;
    } else {
      tmp = false;
    }
    return tmp;
  }
  a13() {
    return !(this.v14_1 == null) && this.w12();
  }
  b13(element) {
    return !(this.v14_1 == null) && equals(this.v14_1, element);
  }
  g13(element, selected) {
    if (this.w12()) {
      if (selected) {
        this.u13(element);
      } else {
        if (this.b13(element)) {
          this.e13();
        }
      }
    }
  }
  h13(element, selected) {
    throw UnsupportedOperationException.h4();
  }
  i13(elements) {
    throw UnsupportedOperationException.h4();
  }
  j13(elements) {
    throw UnsupportedOperationException.h4();
  }
  f13(element) {
    this.u13(element);
  }
  d13() {
    return this.a13() ? 1 : 0;
  }
  c13() {
    return !(this.v14_1 == null) ? setOf(ensureNotNull(this.v14_1)) : emptySet();
  }
  x() {
    return new SimpleSingleSelection$iterator$1(this);
  }
  toString() {
    return 'SimpleSingleSelection{selected=' + this.v14_1 + toString(_Char___init__impl__6a9atx(125));
  }
}
class SingleSelectionEvent extends AbstractSelectionEvent {
  constructor(model, previousActive, currentActive, previousSelection, currentSelection) {
    super();
    this.d15_1 = null;
    this.y14_1 = model;
    this.z14_1 = previousActive;
    this.a15_1 = currentActive;
    this.b15_1 = previousSelection;
    this.c15_1 = currentSelection;
  }
}
class AbstractCPTimer {
  constructor() {
    this.e15_1 = ArrayList.e1();
  }
  f15(listener) {
    this.e15_1.o(listener);
  }
}
class AbstractMutableOneDScreenTransform {
  static i15() {
    var $this = createThis(this);
    $this.h15_1 = CollectionFactory_instance.ll();
    return $this;
  }
  j15(event) {
    var _iterator__ex2g4s = this.h15_1.x();
    while (_iterator__ex2g4s.y()) {
      var listener = _iterator__ex2g4s.z();
      listener.k15(event);
    }
  }
}
class RangesScreenTransformCoordinator$xRangeListener$1 {
  constructor(this$0, $xRange, $yRange) {
    this.v15_1 = this$0;
    this.w15_1 = $xRange;
    this.x15_1 = $yRange;
  }
  fn(event) {
    if (!this.v15_1.a16_1) {
      this.v15_1.a16_1 = true;
      if (!(event.bo_1 === event.yn_1)) {
        var xRangeRatio = this.w15_1.extent / this.w15_1.kp();
        var yDiff = this.x15_1.extent - this.x15_1.kp() * xRangeRatio;
        adjustValues(this.v15_1, this.x15_1, yDiff);
      }
      this.v15_1.a16_1 = false;
    }
  }
}
class RangesScreenTransformCoordinator$yRangeListener$1 {
  constructor(this$0, $yRange, $xRange) {
    this.d16_1 = this$0;
    this.e16_1 = $yRange;
    this.f16_1 = $xRange;
  }
  fn(event) {
    if (!this.d16_1.a16_1) {
      this.d16_1.a16_1 = true;
      if (!(event.bo_1 === event.yn_1)) {
        var yRangeRatio = this.e16_1.extent / this.e16_1.kp();
        var xDiff = this.f16_1.extent - this.f16_1.kp() * yRangeRatio;
        adjustValues(this.d16_1, this.f16_1, xDiff);
      }
      this.d16_1.a16_1 = false;
    }
  }
}
class RangesScreenTransformCoordinator {
  constructor(xRange, yRange) {
    this.a16_1 = false;
    var tmp = this;
    tmp.b16_1 = new RangesScreenTransformCoordinator$xRangeListener$1(this, xRange, yRange);
    var tmp_0 = this;
    tmp_0.c16_1 = new RangesScreenTransformCoordinator$yRangeListener$1(this, yRange, xRange);
    this.y15_1 = xRange;
    this.z15_1 = yRange;
    xRange.addIntervalListener(this.b16_1);
    yRange.addIntervalListener(this.c16_1);
  }
}
class ScreenTransformEvent {}
class SimpleOneDScreenTransform$intervalListener$1 {
  constructor(this$0) {
    this.g16_1 = this$0;
  }
  fn(event) {
    this.g16_1.j15(new ScreenTransformEvent());
  }
}
class SimpleOneDScreenTransform extends AbstractMutableOneDScreenTransform {
  static o16(world, screenSize) {
    var $this = this.i15();
    $this.i16_1 = world;
    $this.j16_1 = 0;
    $this.k16_1 = 0;
    $this.l16_1 = false;
    $this.m16_1 = false;
    var tmp = $this;
    tmp.n16_1 = new SimpleOneDScreenTransform$intervalListener$1($this);
    $this.i16_1.addWeakIntervalListener($this.n16_1);
    $this.l15(screenSize);
    return $this;
  }
  l15(screenSize) {
    if (!(this.k16_1 === screenSize)) {
      this.k16_1 = screenSize;
      this.j15(new ScreenTransformEvent());
    }
  }
  m15() {
    return this.k16_1;
  }
  u15() {
    return this.m16_1;
  }
  static p16(world, screenSize, invertDeviceCoordinates, invertWorldCoordinates) {
    var $this = this.o16(world, screenSize);
    $this.l16_1 = invertDeviceCoordinates;
    $this.m16_1 = invertWorldCoordinates;
    return $this;
  }
  o15(screen) {
    var normalized;
    normalized = (screen - (this.j16_1 / 2 | 0) | 0) / (this.k16_1 - this.j16_1 | 0);
    if (this.l16_1)
      normalized = 1.0 - normalized;
    if (this.m16_1) {
      normalized = 1.0 - normalized;
    }
    normalized = normalized * this.t15() + this.s15();
    return normalized;
  }
  p15(world) {
    return numberToInt(this.q15(world));
  }
  q15(world) {
    var tmp;
    if (!!(this.m16_1 ^ this.l16_1)) {
      tmp = (this.q16() - world) * (this.k16_1 - this.j16_1 | 0) / this.t15() + this.j16_1 / 2.0;
    } else {
      tmp = (world - this.s15()) * (this.k16_1 - this.j16_1 | 0) / this.t15() + this.j16_1 / 2.0;
    }
    return tmp;
  }
  r15() {
    return this.i16_1;
  }
  s15() {
    var tmp;
    if (this.m16_1) {
      tmp = this.i16_1.bn() + (this.i16_1.cn() - (this.i16_1.start + this.i16_1.extent));
    } else {
      tmp = this.i16_1.start;
    }
    return tmp;
  }
  q16() {
    var tmp;
    if (this.m16_1) {
      tmp = this.i16_1.bn() + (this.i16_1.cn() - this.i16_1.start);
    } else {
      tmp = this.i16_1.start + this.i16_1.extent;
    }
    return tmp;
  }
  t15() {
    return this.i16_1.extent;
  }
  n15(screenMargins) {
    if (!(this.j16_1 === screenMargins)) {
      this.j16_1 = screenMargins;
      this.j15(new ScreenTransformEvent());
    }
  }
  toString() {
    return 'SimpleOneDScreenTransform{world=' + this.i16_1 + ', screenMargins=' + this.j16_1 + ', screenSize=' + this.k16_1 + ', invertDeviceCoordinates=' + this.l16_1 + ', invertWorldCoordinates=' + this.m16_1 + toString(_Char___init__impl__6a9atx(125));
  }
}
class Quantity {}
class CollectionFactory {
  ll() {
    return ArrayList.e1();
  }
  r16() {
    return HashMap.d8();
  }
  n14() {
    return LinkedHashSet.d1();
  }
}
class JsArrayList extends ArrayList {
  constructor(elements) {
    return new.target.v16(elements);
  }
  static v16(elements) {
    return this.l(toList(elements));
  }
}
class SoftReference {
  constructor(referent) {
    this.w16_1 = referent;
  }
  xk() {
    return this.w16_1;
  }
}
class CallableFuture {
  constructor(task) {
    this.x16_1 = false;
    this.y16_1 = null;
    this.z16_1 = null;
    try {
      this.y16_1 = task.a17();
      this.x16_1 = true;
    } catch ($p) {
      if ($p instanceof Exception) {
        var e = $p;
        this.z16_1 = e;
      } else {
        throw $p;
      }
    }
  }
  b17() {
    return this.x16_1;
  }
  c17(mayInterruptIfRunning) {
    return false;
  }
  d17() {
    return false;
  }
  xk() {
    if (!(this.z16_1 == null)) {
      throw RuntimeException.sc(this.z16_1);
    } else {
      return this.y16_1;
    }
  }
}
class ExecutorService {
  e17(task) {
    var future = new CallableFuture(ensureNotNull(task));
    return future;
  }
}
class Companion_27 {
  f17() {
    return new Runtime();
  }
}
class Runtime {
  g17() {
    return 1;
  }
}
class Companion_28 {
  constructor() {
    Companion_instance_28 = this;
    this.h17_1 = new CPHelper();
  }
}
class CPHelper {
  constructor() {
    Companion_getInstance_28();
    var tmp = this;
    tmp.i17_1 = lazy(CPHelper$visualizationExecutorService$delegate$lambda(this));
    this.j17_1 = false;
  }
  k17(name, corePoolSize, maximumPoolSize) {
    return new ExecutorService();
  }
  l17(name, delay, postponing) {
    return new GWTTimer(name, delay, postponing);
  }
  m17(name, delay, postponing, timerListener) {
    var timer = this.l17(name, delay, postponing);
    timer.f15(timerListener);
    return timer;
  }
  n17(millis) {
  }
  o17(a, b) {
    return a.equals(b);
  }
  p17(cl) {
    return !(cl == null) && (this.o17(PrimitiveClasses_getInstance().ee(), cl) || cl.equals(PrimitiveClasses_getInstance().le()) || cl.equals(PrimitiveClasses_getInstance().je()) || cl.equals(PrimitiveClasses_getInstance().ke()) || cl.equals(PrimitiveClasses_getInstance().ie()) || cl.equals(getKClass(Long)));
  }
  q17(cl) {
    return false;
  }
  r17(cl) {
    return false;
  }
  s17(cl) {
    return PrimitiveClasses_getInstance().me().equals(cl);
  }
  t17() {
    return numberToLong(Date.now());
  }
}
class Timer {
  constructor($box) {
    boxApply(this, $box);
    this.z17_1 = false;
    this.a18_1 = null;
  }
  b18() {
    return !(this.a18_1 == null);
  }
  c18() {
    if (!this.b18()) {
      return Unit_instance;
    }
    if (this.z17_1) {
      window.clearInterval(ensureNotNull(this.a18_1));
    } else {
      window.clearTimeout(ensureNotNull(this.a18_1));
    }
    this.a18_1 = null;
  }
  d18(delayMillis) {
    // Inline function 'kotlin.require' call
    if (!(delayMillis >= 0)) {
      // Inline function 'com.macrofocus.common.crossplatform.Timer.schedule.<anonymous>' call
      var message = 'must be non-negative';
      throw IllegalArgumentException.h(toString_1(message));
    }
    if (this.b18()) {
      this.c18();
    }
    this.z17_1 = false;
    this.a18_1 = window.setTimeout(createTimeoutCallback(this, this), delayMillis);
  }
  e18() {
    if (!this.z17_1) {
      this.a18_1 = null;
    }
    this.x17();
  }
}
class GWTTimer$1 extends Timer {
  constructor(this$0, $box) {
    if ($box === VOID)
      $box = {};
    $box.w17_1 = this$0;
    super($box);
  }
  x17() {
    var _iterator__ex2g4s = this.w17_1.e15_1.x();
    while (_iterator__ex2g4s.y()) {
      var listener = _iterator__ex2g4s.z();
      listener.y17();
    }
  }
}
class GWTTimer extends AbstractCPTimer {
  constructor(name, delay, postponing) {
    super();
    this.g18_1 = name;
    this.h18_1 = delay;
    this.i18_1 = postponing;
    var tmp = this;
    tmp.j18_1 = new GWTTimer$1(this);
  }
  g15() {
    if (this.i18_1 || !this.j18_1.b18()) {
      this.j18_1.d18(this.h18_1);
    }
  }
}
class Companion_29 {
  constructor() {
    Companion_instance_29 = this;
    this.k18_1 = new FormatFactory();
  }
}
class FormatFactory$createDecimalFormat$1 {
  l18(value) {
    return toString_0(value);
  }
  m18(value, htmlSupported) {
    if (!htmlSupported) {
      return this.l18(value);
    } else {
      return toString_0(value);
    }
  }
  wl(value, htmlSupported) {
    return this.m18((value == null ? true : !(value == null)) ? value : THROW_CCE(), htmlSupported);
  }
  xl() {
    var reason = 'Not yet implemented';
    throw NotImplementedError.bk('An operation is not implemented: ' + reason);
  }
}
class FormatFactory {
  constructor() {
    Companion_getInstance_29();
  }
  n18() {
    return new FormatFactory$createDecimalFormat$1();
  }
  o18(pattern) {
    // Inline function 'kotlin.TODO' call
    var reason = 'Not yet implemented';
    throw NotImplementedError.bk('An operation is not implemented: ' + reason);
  }
  p18(pattern) {
    // Inline function 'kotlin.TODO' call
    var reason = 'Not yet implemented';
    throw NotImplementedError.bk('An operation is not implemented: ' + reason);
  }
}
class BigDecimals {
  constructor() {
    BigDecimals_instance = this;
    this.np_1 = Companion_getInstance_20().ZERO;
    this.op_1 = Companion_getInstance_20().ONE;
    this.pp_1 = Companion_getInstance_20().TWO;
    this.qp_1 = Companion_getInstance_20().TEN;
    this.rp_1 = Companion_getInstance_20().ONE_TENTH;
    this.sp_1 = Companion_getInstance_20().ONE_HALF;
    this.tp_1 = Companion_getInstance_20().PI;
    this.up_1 = Companion_getInstance_20().E;
  }
}
class BigIntegers {
  constructor() {
    BigIntegers_instance = this;
    this.oq_1 = Companion_getInstance_21().ZERO;
    this.pq_1 = Companion_getInstance_21().ONE;
    this.qq_1 = Companion_getInstance_21().TWO;
    this.rq_1 = Companion_getInstance_21().TEN;
    this.sq_1 = Companion_getInstance_21().NEGATIVE_ONE;
  }
}
class Timing {
  constructor() {
    this.q18_1 = 0.0;
    this.r18_1 = 0.0;
    this.s18_1 = new Long(0, 0);
    this.t18_1 = new Long(0, 0);
    this.u18_1 = 0;
  }
  v18() {
    return this.s18_1;
  }
  w18() {
    var tmp0 = this.t18_1;
    // Inline function 'kotlin.Long.div' call
    var other = this.u18_1;
    return tmp0.k3(toLong(other));
  }
  x18() {
    if (this.v18().m1(new Long(0, 0)) > 0) {
      return (new Long(1000, 0)).k3(this.v18()).l1();
    } else {
      return 1000;
    }
  }
  y18() {
    this.q18_1 = Date.now();
  }
  z18() {
    this.r18_1 = Date.now();
    this.s18_1 = numberToLong(this.r18_1 - this.q18_1);
    this.t18_1 = this.t18_1.h3(this.s18_1);
    this.u18_1 = this.u18_1 + 1 | 0;
  }
  toString() {
    return 'Timing(lastDuration=' + this.v18().toString() + ', fps=' + this.x18() + ', averageDuration=' + this.w18().toString() + ')';
  }
}
class atomicfu$TraceBase {
  atomicfu$Trace$append$1(event) {
  }
  atomicfu$Trace$append$2(event1, event2) {
  }
  atomicfu$Trace$append$3(event1, event2, event3) {
  }
  atomicfu$Trace$append$4(event1, event2, event3, event4) {
  }
}
class None extends atomicfu$TraceBase {
  constructor() {
    None_instance = null;
    super();
    None_instance = this;
  }
}
class AtomicRef {
  constructor(value) {
    this.kotlinx$atomicfu$value = value;
  }
  a19(_set____db54di) {
    this.kotlinx$atomicfu$value = _set____db54di;
  }
  b19() {
    return this.kotlinx$atomicfu$value;
  }
  atomicfu$compareAndSet(expect, update) {
    if (!(this.kotlinx$atomicfu$value === expect))
      return false;
    this.kotlinx$atomicfu$value = update;
    return true;
  }
  atomicfu$getAndSet(value) {
    var oldValue = this.kotlinx$atomicfu$value;
    this.kotlinx$atomicfu$value = value;
    return oldValue;
  }
  toString() {
    return toString_0(this.kotlinx$atomicfu$value);
  }
}
class AtomicBoolean {
  constructor(value) {
    this.kotlinx$atomicfu$value = value;
  }
  c19(_set____db54di) {
    this.kotlinx$atomicfu$value = _set____db54di;
  }
  b19() {
    return this.kotlinx$atomicfu$value;
  }
  atomicfu$compareAndSet(expect, update) {
    if (!(this.kotlinx$atomicfu$value === expect))
      return false;
    this.kotlinx$atomicfu$value = update;
    return true;
  }
  atomicfu$getAndSet(value) {
    var oldValue = this.kotlinx$atomicfu$value;
    this.kotlinx$atomicfu$value = value;
    return oldValue;
  }
  toString() {
    return this.kotlinx$atomicfu$value.toString();
  }
}
class AtomicInt {
  constructor(value) {
    this.kotlinx$atomicfu$value = value;
  }
  d19(_set____db54di) {
    this.kotlinx$atomicfu$value = _set____db54di;
  }
  b19() {
    return this.kotlinx$atomicfu$value;
  }
  atomicfu$compareAndSet(expect, update) {
    if (!(this.kotlinx$atomicfu$value === expect))
      return false;
    this.kotlinx$atomicfu$value = update;
    return true;
  }
  atomicfu$getAndSet(value) {
    var oldValue = this.kotlinx$atomicfu$value;
    this.kotlinx$atomicfu$value = value;
    return oldValue;
  }
  atomicfu$getAndIncrement() {
    var _unary__edvuaz = this.kotlinx$atomicfu$value;
    this.kotlinx$atomicfu$value = _unary__edvuaz + 1 | 0;
    return _unary__edvuaz;
  }
  atomicfu$getAndDecrement() {
    var _unary__edvuaz = this.kotlinx$atomicfu$value;
    this.kotlinx$atomicfu$value = _unary__edvuaz - 1 | 0;
    return _unary__edvuaz;
  }
  atomicfu$getAndAdd(delta) {
    var oldValue = this.kotlinx$atomicfu$value;
    this.kotlinx$atomicfu$value = this.kotlinx$atomicfu$value + delta | 0;
    return oldValue;
  }
  atomicfu$addAndGet(delta) {
    this.kotlinx$atomicfu$value = this.kotlinx$atomicfu$value + delta | 0;
    return this.kotlinx$atomicfu$value;
  }
  atomicfu$incrementAndGet() {
    this.kotlinx$atomicfu$value = this.kotlinx$atomicfu$value + 1 | 0;
    return this.kotlinx$atomicfu$value;
  }
  atomicfu$decrementAndGet() {
    this.kotlinx$atomicfu$value = this.kotlinx$atomicfu$value - 1 | 0;
    return this.kotlinx$atomicfu$value;
  }
  toString() {
    return this.kotlinx$atomicfu$value.toString();
  }
}
class SchedulerTask {}
class DispatchedTask extends SchedulerTask {
  constructor(resumeMode) {
    super();
    this.t19_1 = resumeMode;
  }
  r1a(takenState, cause) {
  }
  b1b(state) {
    return (state == null ? true : !(state == null)) ? state : THROW_CCE();
  }
  l1b(state) {
    var tmp0_safe_receiver = state instanceof CompletedExceptionally ? state : null;
    return tmp0_safe_receiver == null ? null : tmp0_safe_receiver.i1a_1;
  }
  x17() {
    // Inline function 'kotlinx.coroutines.assert' call
    try {
      var tmp = this.m1a();
      var delegate = tmp instanceof DispatchedContinuation ? tmp : THROW_CCE();
      var continuation = delegate.o19_1;
      // Inline function 'kotlinx.coroutines.withContinuationContext' call
      delegate.q19_1;
      // Inline function 'kotlinx.coroutines.DispatchedTask.run.<anonymous>' call
      var context = continuation.dc();
      var state = this.q1a();
      var exception = this.l1b(state);
      var job = exception == null && get_isCancellableMode(this.t19_1) ? context.ec(Key_instance_2) : null;
      if (!(job == null) && !job.a13()) {
        var cause = job.y1a();
        this.r1a(state, cause);
        // Inline function 'kotlinx.coroutines.resumeWithStackTrace' call
        // Inline function 'kotlin.Companion.failure' call
        var exception_0 = recoverStackTrace(cause, continuation);
        var tmp$ret$0 = _Result___init__impl__xyqfz8(createFailure(exception_0));
        continuation.d1b(tmp$ret$0);
      } else {
        if (!(exception == null)) {
          // Inline function 'kotlin.coroutines.resumeWithException' call
          // Inline function 'kotlin.Companion.failure' call
          var tmp$ret$1 = _Result___init__impl__xyqfz8(createFailure(exception));
          continuation.d1b(tmp$ret$1);
        } else {
          // Inline function 'kotlin.coroutines.resume' call
          // Inline function 'kotlin.Companion.success' call
          var value = this.b1b(state);
          var tmp$ret$3 = _Result___init__impl__xyqfz8(value);
          continuation.d1b(tmp$ret$3);
        }
      }
    } catch ($p) {
      if ($p instanceof DispatchException) {
        var e = $p;
        handleCoroutineException(this.m1a().dc(), e.m1c_1);
      } else {
        if ($p instanceof Error) {
          var e_0 = $p;
          this.n1b(e_0);
        } else {
          throw $p;
        }
      }
    }
  }
  n1b(exception) {
    var reason = CoroutinesInternalError.g1d('Fatal exception in coroutines machinery for ' + toString_1(this) + '. ' + "Please read KDoc to 'handleFatalException' method and report this incident to maintainers", exception);
    handleCoroutineException(this.m1a().dc(), reason);
  }
}
class CancellableContinuationImpl extends DispatchedTask {
  constructor(delegate, resumeMode) {
    super(resumeMode);
    this.f19_1 = delegate;
    // Inline function 'kotlinx.coroutines.assert' call
    this.g19_1 = this.f19_1.dc();
    var tmp = this;
    // Inline function 'kotlinx.coroutines.decisionAndIndex' call
    var tmp$ret$0 = (0 << 29) + 536870911 | 0;
    tmp.h19_1 = atomic$int$1(tmp$ret$0);
    this.i19_1 = atomic$ref$1(Active_instance);
    this.j19_1 = atomic$ref$1(null);
  }
  m1a() {
    return this.f19_1;
  }
  dc() {
    return this.g19_1;
  }
  l19() {
    return this.i19_1.kotlinx$atomicfu$value;
  }
  n1a() {
    var tmp = this.l19();
    return !(!(tmp == null) ? isInterface(tmp, NotCompleted) : false);
  }
  o1a() {
    var tmp0_elvis_lhs = installParentHandle(this);
    var tmp;
    if (tmp0_elvis_lhs == null) {
      return Unit_instance;
    } else {
      tmp = tmp0_elvis_lhs;
    }
    var handle = tmp;
    if (this.n1a()) {
      handle.p1a();
      this.j19_1.kotlinx$atomicfu$value = NonDisposableHandle_instance;
    }
  }
  q1a() {
    return this.l19();
  }
  r1a(takenState, cause) {
    var this_0 = this.i19_1;
    while (true) {
      // Inline function 'kotlinx.coroutines.CancellableContinuationImpl.cancelCompletedResult.<anonymous>' call
      var state = this_0.kotlinx$atomicfu$value;
      if (!(state == null) ? isInterface(state, NotCompleted) : false) {
        // Inline function 'kotlin.error' call
        var message = 'Not completed';
        throw IllegalStateException.n4(toString_1(message));
      } else {
        if (state instanceof CompletedExceptionally)
          return Unit_instance;
        else {
          if (state instanceof CompletedContinuation) {
            // Inline function 'kotlin.check' call
            if (!!state.g1a()) {
              // Inline function 'kotlinx.coroutines.CancellableContinuationImpl.cancelCompletedResult.<anonymous>.<anonymous>' call
              var message_0 = 'Must be called at most once';
              throw IllegalStateException.n4(toString_1(message_0));
            }
            var update = state.h1a(VOID, VOID, VOID, VOID, cause);
            if (this.i19_1.atomicfu$compareAndSet(state, update)) {
              state.s1a(this, cause);
              return Unit_instance;
            }
          } else {
            if (this.i19_1.atomicfu$compareAndSet(state, new CompletedContinuation(state, VOID, VOID, VOID, cause))) {
              return Unit_instance;
            }
          }
        }
      }
    }
    return Unit_instance;
  }
  t1a(cause) {
    // Inline function 'kotlinx.atomicfu.loop' call
    var this_0 = this.i19_1;
    while (true) {
      var tmp1 = this_0.kotlinx$atomicfu$value;
      $l$block: {
        // Inline function 'kotlinx.coroutines.CancellableContinuationImpl.cancel.<anonymous>' call
        if (!(!(tmp1 == null) ? isInterface(tmp1, NotCompleted) : false))
          return false;
        var tmp;
        if (isInterface(tmp1, CancelHandler)) {
          tmp = true;
        } else {
          tmp = tmp1 instanceof Segment;
        }
        var update = new CancelledContinuation(this, cause, tmp);
        if (!this.i19_1.atomicfu$compareAndSet(tmp1, update)) {
          break $l$block;
        }
        if (isInterface(tmp1, CancelHandler)) {
          this.f1a(tmp1, cause);
        } else {
          if (tmp1 instanceof Segment) {
            callSegmentOnCancellation(this, tmp1, cause);
          }
        }
        detachChildIfNonReusable(this);
        dispatchResume(this, this.t19_1);
        return true;
      }
    }
  }
  u1a(cause) {
    if (cancelLater(this, cause))
      return Unit_instance;
    this.t1a(cause);
    detachChildIfNonReusable(this);
  }
  f1a(handler, cause) {
    var tmp;
    try {
      handler.v1a(cause);
      tmp = Unit_instance;
    } catch ($p) {
      var tmp_0;
      if ($p instanceof Error) {
        var ex = $p;
        handleCoroutineException(this.dc(), CompletionHandlerException.z19('Exception in invokeOnCancellation handler for ' + this.toString(), ex));
        tmp_0 = Unit_instance;
      } else {
        throw $p;
      }
      tmp = tmp_0;
    }
    return tmp;
  }
  w1a(onCancellation, cause, value) {
    try {
      onCancellation(cause, value, this.dc());
    } catch ($p) {
      if ($p instanceof Error) {
        var ex = $p;
        handleCoroutineException(this.dc(), CompletionHandlerException.z19('Exception in resume onCancellation handler for ' + this.toString(), ex));
      } else {
        throw $p;
      }
    }
  }
  x1a(parent) {
    return parent.y1a();
  }
  z1a() {
    var isReusable_0 = isReusable(this);
    if (trySuspend(this)) {
      if (_get_parentHandle__f8dcex(this) == null) {
        installParentHandle(this);
      }
      if (isReusable_0) {
        this.a1b();
      }
      return get_COROUTINE_SUSPENDED();
    }
    if (isReusable_0) {
      this.a1b();
    }
    var state = this.l19();
    if (state instanceof CompletedExceptionally)
      throw recoverStackTrace(state.i1a_1, this);
    if (get_isCancellableMode(this.t19_1)) {
      var job = this.dc().ec(Key_instance_2);
      if (!(job == null) && !job.a13()) {
        var cause = job.y1a();
        this.r1a(state, cause);
        throw recoverStackTrace(cause, this);
      }
    }
    return this.b1b(state);
  }
  a1b() {
    var tmp = this.f19_1;
    var tmp0_safe_receiver = tmp instanceof DispatchedContinuation ? tmp : null;
    var tmp1_elvis_lhs = tmp0_safe_receiver == null ? null : tmp0_safe_receiver.c1b(this);
    var tmp_0;
    if (tmp1_elvis_lhs == null) {
      return Unit_instance;
    } else {
      tmp_0 = tmp1_elvis_lhs;
    }
    var cancellationCause = tmp_0;
    this.l1a();
    this.t1a(cancellationCause);
  }
  d1b(result) {
    return this.e1b(toState(result, this), this.t19_1);
  }
  f1b(handler) {
    return invokeOnCancellation(this, new UserSupplied(handler));
  }
  k19(handler) {
    return invokeOnCancellationImpl(this, handler);
  }
  g1b(proposedUpdate, resumeMode, onCancellation) {
    // Inline function 'kotlinx.atomicfu.loop' call
    var this_0 = this.i19_1;
    while (true) {
      var tmp1 = this_0.kotlinx$atomicfu$value;
      $l$block: {
        // Inline function 'kotlinx.coroutines.CancellableContinuationImpl.resumeImpl.<anonymous>' call
        if (!(tmp1 == null) ? isInterface(tmp1, NotCompleted) : false) {
          var update = resumedState(this, tmp1, proposedUpdate, resumeMode, onCancellation, null);
          if (!this.i19_1.atomicfu$compareAndSet(tmp1, update)) {
            break $l$block;
          }
          detachChildIfNonReusable(this);
          dispatchResume(this, resumeMode);
          return Unit_instance;
        } else {
          if (tmp1 instanceof CancelledContinuation) {
            if (tmp1.k1b()) {
              if (onCancellation == null)
                null;
              else {
                // Inline function 'kotlin.let' call
                // Inline function 'kotlinx.coroutines.CancellableContinuationImpl.resumeImpl.<anonymous>.<anonymous>' call
                this.w1a(onCancellation, tmp1.i1a_1, proposedUpdate);
              }
              return Unit_instance;
            }
          }
        }
        alreadyResumedError(this, proposedUpdate);
      }
    }
  }
  e1b(proposedUpdate, resumeMode, onCancellation, $super) {
    onCancellation = onCancellation === VOID ? null : onCancellation;
    var tmp;
    if ($super === VOID) {
      this.g1b(proposedUpdate, resumeMode, onCancellation);
      tmp = Unit_instance;
    } else {
      tmp = $super.g1b.call(this, proposedUpdate, resumeMode, onCancellation);
    }
    return tmp;
  }
  l1a() {
    var tmp0_elvis_lhs = _get_parentHandle__f8dcex(this);
    var tmp;
    if (tmp0_elvis_lhs == null) {
      return Unit_instance;
    } else {
      tmp = tmp0_elvis_lhs;
    }
    var handle = tmp;
    handle.p1a();
    this.j19_1.kotlinx$atomicfu$value = NonDisposableHandle_instance;
  }
  b1b(state) {
    var tmp;
    if (state instanceof CompletedContinuation) {
      var tmp_0 = state.a1a_1;
      tmp = (tmp_0 == null ? true : !(tmp_0 == null)) ? tmp_0 : THROW_CCE();
    } else {
      tmp = (state == null ? true : !(state == null)) ? state : THROW_CCE();
    }
    return tmp;
  }
  l1b(state) {
    var tmp0_safe_receiver = super.l1b(state);
    var tmp;
    if (tmp0_safe_receiver == null) {
      tmp = null;
    } else {
      // Inline function 'kotlin.let' call
      // Inline function 'kotlinx.coroutines.CancellableContinuationImpl.getExceptionalResult.<anonymous>' call
      tmp = recoverStackTrace(tmp0_safe_receiver, this.f19_1);
    }
    return tmp;
  }
  toString() {
    return this.m1b() + '(' + toDebugString(this.f19_1) + '){' + _get_stateDebugRepresentation__bf18u4(this) + '}@' + get_hexAddress(this);
  }
  m1b() {
    return 'CancellableContinuation';
  }
}
class NotCompleted {}
class CancelHandler {}
class UserSupplied {
  constructor(handler) {
    this.o1b_1 = handler;
  }
  v1a(cause) {
    this.o1b_1(cause);
  }
  toString() {
    return 'CancelHandler.UserSupplied[' + get_classSimpleName(this.o1b_1) + '@' + get_hexAddress(this) + ']';
  }
}
class Active {
  toString() {
    return 'Active';
  }
}
class CompletedContinuation {
  constructor(result, cancelHandler, onCancellation, idempotentResume, cancelCause) {
    cancelHandler = cancelHandler === VOID ? null : cancelHandler;
    onCancellation = onCancellation === VOID ? null : onCancellation;
    idempotentResume = idempotentResume === VOID ? null : idempotentResume;
    cancelCause = cancelCause === VOID ? null : cancelCause;
    this.a1a_1 = result;
    this.b1a_1 = cancelHandler;
    this.c1a_1 = onCancellation;
    this.d1a_1 = idempotentResume;
    this.e1a_1 = cancelCause;
  }
  g1a() {
    return !(this.e1a_1 == null);
  }
  s1a(cont, cause) {
    var tmp0_safe_receiver = this.b1a_1;
    if (tmp0_safe_receiver == null)
      null;
    else {
      // Inline function 'kotlin.let' call
      // Inline function 'kotlinx.coroutines.CompletedContinuation.invokeHandlers.<anonymous>' call
      cont.f1a(tmp0_safe_receiver, cause);
    }
    var tmp1_safe_receiver = this.c1a_1;
    if (tmp1_safe_receiver == null)
      null;
    else {
      // Inline function 'kotlin.let' call
      // Inline function 'kotlinx.coroutines.CompletedContinuation.invokeHandlers.<anonymous>' call
      cont.w1a(tmp1_safe_receiver, cause, this.a1a_1);
    }
  }
  p1b(result, cancelHandler, onCancellation, idempotentResume, cancelCause) {
    return new CompletedContinuation(result, cancelHandler, onCancellation, idempotentResume, cancelCause);
  }
  h1a(result, cancelHandler, onCancellation, idempotentResume, cancelCause, $super) {
    result = result === VOID ? this.a1a_1 : result;
    cancelHandler = cancelHandler === VOID ? this.b1a_1 : cancelHandler;
    onCancellation = onCancellation === VOID ? this.c1a_1 : onCancellation;
    idempotentResume = idempotentResume === VOID ? this.d1a_1 : idempotentResume;
    cancelCause = cancelCause === VOID ? this.e1a_1 : cancelCause;
    return $super === VOID ? this.p1b(result, cancelHandler, onCancellation, idempotentResume, cancelCause) : $super.p1b.call(this, result, cancelHandler, onCancellation, idempotentResume, cancelCause);
  }
  toString() {
    return 'CompletedContinuation(result=' + toString_0(this.a1a_1) + ', cancelHandler=' + toString_0(this.b1a_1) + ', onCancellation=' + toString_0(this.c1a_1) + ', idempotentResume=' + toString_0(this.d1a_1) + ', cancelCause=' + toString_0(this.e1a_1) + ')';
  }
  hashCode() {
    var result = this.a1a_1 == null ? 0 : hashCode(this.a1a_1);
    result = imul_0(result, 31) + (this.b1a_1 == null ? 0 : hashCode(this.b1a_1)) | 0;
    result = imul_0(result, 31) + (this.c1a_1 == null ? 0 : hashCode(this.c1a_1)) | 0;
    result = imul_0(result, 31) + (this.d1a_1 == null ? 0 : hashCode(this.d1a_1)) | 0;
    result = imul_0(result, 31) + (this.e1a_1 == null ? 0 : hashCode(this.e1a_1)) | 0;
    return result;
  }
  equals(other) {
    if (this === other)
      return true;
    if (!(other instanceof CompletedContinuation))
      return false;
    var tmp0_other_with_cast = other instanceof CompletedContinuation ? other : THROW_CCE();
    if (!equals(this.a1a_1, tmp0_other_with_cast.a1a_1))
      return false;
    if (!equals(this.b1a_1, tmp0_other_with_cast.b1a_1))
      return false;
    if (!equals(this.c1a_1, tmp0_other_with_cast.c1a_1))
      return false;
    if (!equals(this.d1a_1, tmp0_other_with_cast.d1a_1))
      return false;
    if (!equals(this.e1a_1, tmp0_other_with_cast.e1a_1))
      return false;
    return true;
  }
}
class LockFreeLinkedListNode {
  constructor() {
    this.c1c_1 = this;
    this.d1c_1 = this;
    this.e1c_1 = false;
  }
  f1c(node, permissionsBitmask) {
    var prev = this.d1c_1;
    var tmp;
    if (prev instanceof ListClosed) {
      tmp = ((prev.g1e_1 & permissionsBitmask) === 0 && prev.f1c(node, permissionsBitmask));
    } else {
      node.c1c_1 = this;
      node.d1c_1 = prev;
      prev.c1c_1 = node;
      this.d1c_1 = node;
      tmp = true;
    }
    return tmp;
  }
  g1c() {
    if (this.e1c_1)
      return false;
    var prev = this.d1c_1;
    var next = this.c1c_1;
    prev.c1c_1 = next;
    next.d1c_1 = prev;
    this.e1c_1 = true;
    return true;
  }
  h1c(node) {
    if (!(this.c1c_1 === this))
      return false;
    this.f1c(node, -2147483648);
    return true;
  }
}
class Incomplete {}
class JobNode extends LockFreeLinkedListNode {
  a1c() {
    var tmp = this.z1b_1;
    if (!(tmp == null))
      return tmp;
    else {
      throwUninitializedPropertyAccessException('job');
    }
  }
  b1c() {
    return null;
  }
  p1a() {
    return this.a1c().p1d(this);
  }
  toString() {
    return get_classSimpleName(this) + '@' + get_hexAddress(this) + '[job@' + get_hexAddress(this.a1c()) + ']';
  }
}
class ChildContinuation extends JobNode {
  constructor(child) {
    super();
    this.u1b_1 = child;
  }
  v1b() {
    return true;
  }
  v1a(cause) {
    this.u1b_1.u1a(this.u1b_1.x1a(this.a1c()));
  }
}
class CompletedExceptionally {
  constructor(cause, handled) {
    handled = handled === VOID ? false : handled;
    this.i1a_1 = cause;
    this.j1a_1 = atomic$boolean$1(handled);
  }
  k1a() {
    return this.j1a_1.atomicfu$compareAndSet(false, true);
  }
  toString() {
    return get_classSimpleName(this) + '[' + this.i1a_1.toString() + ']';
  }
}
class CancelledContinuation extends CompletedExceptionally {
  constructor(continuation, cause, handled) {
    super(cause == null ? CancellationException.mc('Continuation ' + toString_1(continuation) + ' was cancelled normally') : cause, handled);
    this.j1b_1 = atomic$boolean$1(false);
  }
  k1b() {
    return this.j1b_1.atomicfu$compareAndSet(false, true);
  }
}
class Key_0 extends AbstractCoroutineContextKey {
  constructor() {
    Key_instance_0 = null;
    var tmp = Key_instance;
    super(tmp, CoroutineDispatcher$Key$_init_$lambda_akl8b5);
    Key_instance_0 = this;
  }
}
class CoroutineDispatcher extends AbstractCoroutineContextElement {
  constructor() {
    Key_getInstance_0();
    super(Key_instance);
  }
  j1c(context) {
    return true;
  }
  fc(continuation) {
    return new DispatchedContinuation(this, continuation);
  }
  toString() {
    return get_classSimpleName(this) + '@' + get_hexAddress(this);
  }
}
class Key_1 {}
class EventLoop extends CoroutineDispatcher {
  constructor() {
    super();
    this.q1c_1 = new Long(0, 0);
    this.r1c_1 = false;
    this.s1c_1 = null;
  }
  t1c() {
    var tmp0_elvis_lhs = this.s1c_1;
    var tmp;
    if (tmp0_elvis_lhs == null) {
      return false;
    } else {
      tmp = tmp0_elvis_lhs;
    }
    var queue = tmp;
    var tmp1_elvis_lhs = queue.jg();
    var tmp_0;
    if (tmp1_elvis_lhs == null) {
      return false;
    } else {
      tmp_0 = tmp1_elvis_lhs;
    }
    var task = tmp_0;
    task.x17();
    return true;
  }
  u1c(task) {
    var tmp0_elvis_lhs = this.s1c_1;
    var tmp;
    if (tmp0_elvis_lhs == null) {
      // Inline function 'kotlin.also' call
      var this_0 = ArrayDeque.fg();
      // Inline function 'kotlinx.coroutines.EventLoop.dispatchUnconfined.<anonymous>' call
      this.s1c_1 = this_0;
      tmp = this_0;
    } else {
      tmp = tmp0_elvis_lhs;
    }
    var queue = tmp;
    queue.hg(task);
  }
  v1c() {
    return this.q1c_1.m1(delta(this, true)) >= 0;
  }
  w1c() {
    var tmp0_safe_receiver = this.s1c_1;
    var tmp1_elvis_lhs = tmp0_safe_receiver == null ? null : tmp0_safe_receiver.c1();
    return tmp1_elvis_lhs == null ? true : tmp1_elvis_lhs;
  }
  x1c(unconfined) {
    this.q1c_1 = this.q1c_1.h3(delta(this, unconfined));
    if (!unconfined)
      this.r1c_1 = true;
  }
  y1c(unconfined) {
    this.q1c_1 = this.q1c_1.i3(delta(this, unconfined));
    if (this.q1c_1.m1(new Long(0, 0)) > 0)
      return Unit_instance;
    // Inline function 'kotlinx.coroutines.assert' call
    if (this.r1c_1) {
      this.z1c();
    }
  }
  z1c() {
  }
}
class ThreadLocalEventLoop {
  constructor() {
    ThreadLocalEventLoop_instance = this;
    this.a1d_1 = commonThreadLocal(new Symbol_0('ThreadLocalEventLoop'));
  }
  b1d() {
    var tmp0_elvis_lhs = this.a1d_1.xk();
    var tmp;
    if (tmp0_elvis_lhs == null) {
      // Inline function 'kotlin.also' call
      var this_0 = createEventLoop();
      // Inline function 'kotlinx.coroutines.ThreadLocalEventLoop.<get-eventLoop>.<anonymous>' call
      ThreadLocalEventLoop_getInstance().a1d_1.d1d(this_0);
      tmp = this_0;
    } else {
      tmp = tmp0_elvis_lhs;
    }
    return tmp;
  }
}
class CompletionHandlerException extends RuntimeException {
  static z19(message, cause) {
    var $this = this.rc(message, cause);
    captureStack($this, $this.y19_1);
    return $this;
  }
}
class CoroutinesInternalError extends Error_0 {
  static g1d(message, cause) {
    var $this = this.wc(message, cause);
    captureStack($this, $this.f1d_1);
    return $this;
  }
}
class Key_2 {}
class NonDisposableHandle {
  p1a() {
  }
  toString() {
    return 'NonDisposableHandle';
  }
}
class Empty {
  constructor(isActive) {
    this.k1d_1 = isActive;
  }
  b1c() {
    return null;
  }
  toString() {
    return 'Empty{' + (this.k1d_1 ? 'Active' : 'New') + '}';
  }
}
class LockFreeLinkedListHead extends LockFreeLinkedListNode {}
class NodeList extends LockFreeLinkedListHead {
  b1c() {
    return this;
  }
  o1d(state) {
    // Inline function 'kotlin.text.buildString' call
    // Inline function 'kotlin.apply' call
    var this_0 = StringBuilder.u();
    // Inline function 'kotlinx.coroutines.NodeList.getString.<anonymous>' call
    this_0.lb('List{');
    this_0.lb(state);
    this_0.lb('}[');
    var first = true;
    // Inline function 'kotlinx.coroutines.internal.LockFreeLinkedListHead.forEach' call
    var cur = this.c1c_1;
    while (!equals(cur, this)) {
      // Inline function 'kotlinx.coroutines.NodeList.getString.<anonymous>.<anonymous>' call
      var node = cur;
      if (node instanceof JobNode) {
        if (first) {
          first = false;
        } else
          this_0.lb(', ');
        this_0.kb(node);
      }
      cur = cur.c1c_1;
    }
    this_0.lb(']');
    return this_0.toString();
  }
  toString() {
    return get_DEBUG() ? this.o1d('Active') : super.toString();
  }
}
class SynchronizedObject {}
class Finishing extends SynchronizedObject {
  r1d() {
    return this.q1d_1.kotlinx$atomicfu$value;
  }
}
class JobSupport {
  l19() {
    return this.i1d_1.kotlinx$atomicfu$value;
  }
  j1d(invokeImmediately, node) {
    node.z1b_1 = this;
    var tmp$ret$0;
    $l$block_1: {
      // Inline function 'kotlinx.coroutines.JobSupport.tryPutNodeIntoList' call
      // Inline function 'kotlinx.coroutines.JobSupport.loopOnState' call
      while (true) {
        // Inline function 'kotlinx.coroutines.JobSupport.tryPutNodeIntoList.<anonymous>' call
        var state = this.l19();
        if (state instanceof Empty) {
          if (state.k1d_1) {
            if (this.i1d_1.atomicfu$compareAndSet(state, node)) {
              tmp$ret$0 = true;
              break $l$block_1;
            }
          } else {
            promoteEmptyToNodeList(this, state);
          }
        } else {
          if (!(state == null) ? isInterface(state, Incomplete) : false) {
            var list = state.b1c();
            if (list == null) {
              promoteSingleToNodeList(this, state instanceof JobNode ? state : THROW_CCE());
            } else {
              // Inline function 'kotlinx.coroutines.JobSupport.invokeOnCompletionInternal.<anonymous>' call
              var tmp;
              if (node.v1b()) {
                var tmp0_safe_receiver = state instanceof Finishing ? state : null;
                var rootCause = tmp0_safe_receiver == null ? null : tmp0_safe_receiver.r1d();
                var tmp_0;
                if (rootCause == null) {
                  tmp_0 = list.f1c(node, 5);
                } else {
                  if (invokeImmediately) {
                    node.v1a(rootCause);
                  }
                  return NonDisposableHandle_instance;
                }
                tmp = tmp_0;
              } else {
                tmp = list.f1c(node, 1);
              }
              if (tmp) {
                tmp$ret$0 = true;
                break $l$block_1;
              }
            }
          } else {
            tmp$ret$0 = false;
            break $l$block_1;
          }
        }
      }
    }
    var added = tmp$ret$0;
    if (added)
      return node;
    else if (invokeImmediately) {
      var tmp_1 = this.l19();
      var tmp0_safe_receiver_0 = tmp_1 instanceof CompletedExceptionally ? tmp_1 : null;
      node.v1a(tmp0_safe_receiver_0 == null ? null : tmp0_safe_receiver_0.i1a_1);
    }
    return NonDisposableHandle_instance;
  }
  p1d(node) {
    // Inline function 'kotlinx.coroutines.JobSupport.loopOnState' call
    while (true) {
      // Inline function 'kotlinx.coroutines.JobSupport.removeNode.<anonymous>' call
      var state = this.l19();
      if (state instanceof JobNode) {
        if (!(state === node))
          return Unit_instance;
        if (this.i1d_1.atomicfu$compareAndSet(state, get_EMPTY_ACTIVE()))
          return Unit_instance;
      } else {
        if (!(state == null) ? isInterface(state, Incomplete) : false) {
          if (!(state.b1c() == null)) {
            node.g1c();
          }
          return Unit_instance;
        } else {
          return Unit_instance;
        }
      }
    }
  }
}
class InactiveNodeList {
  constructor(list) {
    this.s1d_1 = list;
  }
  b1c() {
    return this.s1d_1;
  }
  toString() {
    return get_DEBUG() ? this.s1d_1.o1d('New') : anyToString(this);
  }
}
class ConcurrentLinkedListNode {}
class Segment extends ConcurrentLinkedListNode {}
class ExceptionSuccessfullyProcessed extends Exception {}
class DispatchedContinuation extends DispatchedTask {
  constructor(dispatcher, continuation) {
    super(-1);
    this.n19_1 = dispatcher;
    this.o19_1 = continuation;
    this.p19_1 = get_UNDEFINED();
    this.q19_1 = threadContextElements(this.dc());
    this.r19_1 = atomic$ref$1(null);
  }
  s19() {
    return !(this.r19_1.kotlinx$atomicfu$value == null);
  }
  c1b(continuation) {
    // Inline function 'kotlinx.atomicfu.loop' call
    var this_0 = this.r19_1;
    while (true) {
      // Inline function 'kotlinx.coroutines.internal.DispatchedContinuation.tryReleaseClaimedContinuation.<anonymous>' call
      var state = this_0.kotlinx$atomicfu$value;
      if (state === get_REUSABLE_CLAIMED()) {
        if (this.r19_1.atomicfu$compareAndSet(get_REUSABLE_CLAIMED(), continuation))
          return null;
      } else {
        if (state instanceof Error) {
          // Inline function 'kotlin.require' call
          // Inline function 'kotlin.require' call
          if (!this.r19_1.atomicfu$compareAndSet(state, null)) {
            // Inline function 'kotlin.require.<anonymous>' call
            var message = 'Failed requirement.';
            throw IllegalArgumentException.h(toString_1(message));
          }
          return state;
        } else {
          // Inline function 'kotlin.error' call
          var message_0 = 'Inconsistent state ' + toString_0(state);
          throw IllegalStateException.n4(toString_1(message_0));
        }
      }
    }
  }
  u19(cause) {
    // Inline function 'kotlinx.atomicfu.loop' call
    var this_0 = this.r19_1;
    while (true) {
      // Inline function 'kotlinx.coroutines.internal.DispatchedContinuation.postponeCancellation.<anonymous>' call
      var state = this_0.kotlinx$atomicfu$value;
      if (equals(state, get_REUSABLE_CLAIMED())) {
        if (this.r19_1.atomicfu$compareAndSet(get_REUSABLE_CLAIMED(), cause))
          return true;
      } else {
        if (state instanceof Error)
          return true;
        else {
          if (this.r19_1.atomicfu$compareAndSet(state, null))
            return false;
        }
      }
    }
  }
  q1a() {
    var state = this.p19_1;
    // Inline function 'kotlinx.coroutines.assert' call
    this.p19_1 = get_UNDEFINED();
    return state;
  }
  m1a() {
    return this;
  }
  d1b(result) {
    var state = toState_0(result);
    if (safeIsDispatchNeeded(this.n19_1, this.dc())) {
      this.p19_1 = state;
      this.t19_1 = 0;
      safeDispatch(this.n19_1, this.dc(), this);
    } else {
      $l$block: {
        // Inline function 'kotlinx.coroutines.internal.executeUnconfined' call
        // Inline function 'kotlinx.coroutines.assert' call
        var eventLoop = ThreadLocalEventLoop_getInstance().b1d();
        if (false && eventLoop.w1c()) {
          break $l$block;
        }
        var tmp;
        if (eventLoop.v1c()) {
          this.p19_1 = state;
          this.t19_1 = 0;
          eventLoop.u1c(this);
          tmp = true;
        } else {
          // Inline function 'kotlinx.coroutines.runUnconfinedEventLoop' call
          eventLoop.x1c(true);
          try {
            // Inline function 'kotlinx.coroutines.internal.DispatchedContinuation.resumeWith.<anonymous>' call
            this.dc();
            // Inline function 'kotlinx.coroutines.withCoroutineContext' call
            this.q19_1;
            // Inline function 'kotlinx.coroutines.internal.DispatchedContinuation.resumeWith.<anonymous>.<anonymous>' call
            this.o19_1.d1b(result);
            $l$loop: while (eventLoop.t1c()) {
            }
          } catch ($p) {
            if ($p instanceof Error) {
              var e = $p;
              this.n1b(e);
            } else {
              throw $p;
            }
          }
          finally {
            eventLoop.y1c(true);
          }
          tmp = false;
        }
      }
    }
  }
  toString() {
    return 'DispatchedContinuation[' + this.n19_1.toString() + ', ' + toDebugString(this.o19_1) + ']';
  }
  dc() {
    return this.o19_1.dc();
  }
}
class DispatchException extends Exception {
  static x1d(cause, dispatcher, context) {
    var $this = this.oc('Coroutine dispatcher ' + dispatcher.toString() + ' threw an exception, context = ' + toString_1(context), cause);
    captureStack($this, $this.n1c_1);
    $this.m1c_1 = cause;
    return $this;
  }
  w1() {
    return this.m1c_1;
  }
  get cause() {
    return this.w1();
  }
}
class Symbol_0 {
  constructor(symbol) {
    this.y1d_1 = symbol;
  }
  toString() {
    return '<' + this.y1d_1 + '>';
  }
}
class UnconfinedEventLoop extends EventLoop {
  k1c(context, block) {
    unsupported();
  }
}
class DiagnosticCoroutineContextException extends RuntimeException {
  static w1d(context) {
    var $this = this.ja(toString_1(context));
    captureStack($this, $this.v1d_1);
    return $this;
  }
}
class ListClosed extends LockFreeLinkedListNode {}
class CommonThreadLocal {
  constructor() {
    this.c1d_1 = null;
  }
  xk() {
    var tmp = this.c1d_1;
    return (tmp == null ? true : !(tmp == null)) ? tmp : THROW_CCE();
  }
  d1d(value) {
    this.c1d_1 = value;
  }
}
class EventInstance {}
class ReactHTML {}
class IColor {}
function toHTMLColor() {
  var alpha;
  var red = toString_6(this.h1e(), 16);
  var blu = toString_6(this.j1e(), 16);
  var gre = toString_6(this.i1e(), 16);
  var tmp = this.k1e();
  // Inline function 'kotlin.UInt.toUByte' call
  var this_0 = _UInt___init__impl__l7qpdl(255);
  // Inline function 'kotlin.toUByte' call
  var this_1 = _UInt___get_data__impl__f0vqqw(this_0);
  if (tmp === _UByte___init__impl__g9hnc4(toByte(this_1))) {
    alpha = '';
  } else {
    alpha = toString_6(this.k1e(), 16);
    alpha = alpha.length === 1 ? '0' + alpha : alpha;
  }
  red = red.length === 1 ? '0' + red : red;
  blu = blu.length === 1 ? '0' + blu : blu;
  gre = gre.length === 1 ? '0' + gre : gre;
  return '#' + alpha + red + gre + blu;
}
function toJavaScriptColor() {
  var tmp;
  var tmp_0 = this.k1e();
  // Inline function 'kotlin.UInt.toUByte' call
  var this_0 = _UInt___init__impl__l7qpdl(255);
  // Inline function 'kotlin.toUByte' call
  var this_1 = _UInt___get_data__impl__f0vqqw(this_0);
  if (tmp_0 === _UByte___init__impl__g9hnc4(toByte(this_1))) {
    tmp = this.l1e();
  } else {
    var tmp_1 = 'rgba(' + UByte__toString_impl_v72jg(this.h1e()) + ',' + UByte__toString_impl_v72jg(this.i1e()) + ',' + UByte__toString_impl_v72jg(this.j1e()) + ',';
    // Inline function 'kotlin.UByte.toFloat' call
    // Inline function 'kotlin.UByte.toInt' call
    var this_2 = this.k1e();
    // Inline function 'kotlin.uintToFloat' call
    var value = _UByte___get_data__impl__jof9qr(this_2) & 255;
    tmp = tmp_1 + (uintToDouble(value) / 255.0).toString() + ')';
  }
  return tmp;
}
class PropertyType extends Enum {}
class WeakColorMapListener {
  constructor(listener) {
    this.n1e_1 = new WeakReference(listener);
  }
  o1e(event) {
    var l = this.hl();
    if (!(l == null)) {
      l.o1e(event);
    } else {
      event.t1e().removeColorMapListener(this);
    }
  }
  hl() {
    return this.n1e_1.xk();
  }
}
class Companion_30 {
  constructor() {
    this.u1e_1 = 'inverval';
    this.v1e_1 = 'palette';
    this.w1e_1 = 'matching';
    this.x1e_1 = 'assignments';
    this.y1e_1 = 'missingValuesColor';
    this.z1e_1 = 'underflowColor';
    this.a1f_1 = 'overflowColor';
    this.b1f_1 = 'inverted';
    this.c1f_1 = 'numberOfSteps';
    this.d1f_1 = 'brightness';
    this.e1f_1 = 'saturation';
    this.f1f_1 = 'alpha';
  }
}
class AbstractColorMap {
  static h1f() {
    var $this = createThis(this);
    $this.g1f_1 = CollectionFactory_instance.ll();
    return $this;
  }
  i1f(listener) {
    this.g1f_1.o(listener);
  }
  addColorMapListener(listener) {
    return this.i1f(listener);
  }
  j1f(listener) {
    this.g1f_1.o(new WeakColorMapListener(listener));
  }
  addWeakColorMapListener(listener) {
    return this.j1f(listener);
  }
  k1f(listener) {
    if (listener instanceof WeakColorMapListener) {
      var removed = this.g1f_1.w2(listener);
    } else {
      var toRemove = null;
      var _iterator__ex2g4s = this.g1f_1.x();
      while (_iterator__ex2g4s.y()) {
        var ColormapListener = _iterator__ex2g4s.z();
        var comparable;
        var tmp;
        if (ColormapListener instanceof WeakColorMapListener) {
          tmp = ColormapListener.hl();
        } else {
          tmp = ColormapListener;
        }
        comparable = tmp;
        if (equals(listener, comparable)) {
          toRemove = ColormapListener;
        }
      }
      if (!(toRemove == null)) {
        var removed_0 = this.g1f_1.w2(toRemove);
      }
    }
  }
  removeColorMapListener(listener) {
    return this.k1f(listener);
  }
  l1f(event) {
    var _iterator__ex2g4s = this.g1f_1.x();
    while (_iterator__ex2g4s.y()) {
      var listener = _iterator__ex2g4s.z();
      listener.o1e(event);
    }
  }
}
class Assignments extends Enum {}
class ColorMapEvent {
  constructor(colorMap, propertyName, oldValue, newValue) {
    this.p1e_1 = colorMap;
    this.q1e_1 = propertyName;
    this.s1e_1 = oldValue;
    this.r1e_1 = newValue;
  }
  t1e() {
    return this.p1e_1;
  }
}
class ColorMapFactory {
  constructor(paletteFactory) {
    this.y1f_1 = Companion_getInstance_54().a1g_1;
    this.z1f_1 = paletteFactory;
  }
  b1g(min, max) {
    return this.c1g(min, max, this.z1f_1.createDefaultSequentialPalette());
  }
  d1g(min, max) {
    return this.c1g(min, max, this.z1f_1.createDefaultDivergingPalette());
  }
  e1g(values) {
    return this.f1g(values, true, this.z1f_1.createDefaultQualititativePalette());
  }
  c1g(min, max, palette) {
    return SimpleColorMap.intervalConstructor(PropertyClosedInterval.ko(min, max - min), palette);
  }
  f1g(values, cyclic, palette) {
    return SimpleColorMap.values(values, cyclic, palette);
  }
  g1g(mininum, maximum) {
    var tmp;
    if (!(mininum == null) && !(maximum == null)) {
      var tmp_0;
      if (numberToDouble(mininum) < 0 && numberToDouble(maximum) > 0) {
        var diffMin = 0 - numberToDouble(mininum);
        var diffMax = numberToDouble(maximum);
        // Inline function 'kotlin.math.max' call
        var maxDiff = Math.max(diffMin, diffMax);
        tmp_0 = this.d1g(0 - maxDiff, maxDiff);
      } else {
        tmp_0 = this.b1g(numberToDouble(mininum), numberToDouble(maximum));
      }
      tmp = tmp_0;
    } else {
      tmp = this.b1g(0.0, 0.0);
    }
    return tmp;
  }
  h1g(mininum, maximum) {
    var tmp;
    if (!(mininum == null) && !(maximum == null)) {
      var tmp_0;
      if (numberToDouble(mininum) < 0 && numberToDouble(maximum) > 0) {
        var diffMin = 0 - numberToDouble(mininum);
        var diffMax = numberToDouble(maximum);
        // Inline function 'kotlin.math.max' call
        var maxDiff = Math.max(diffMin, diffMax);
        var min = 0 - maxDiff;
        var minF = (min - numberToDouble(mininum)) / (numberToDouble(maximum) - numberToDouble(mininum));
        var maxF = (maxDiff - numberToDouble(mininum)) / (numberToDouble(maximum) - numberToDouble(mininum));
        var meanF = (maxF + minF) / 2.0;
        tmp_0 = this.c1g(numberToDouble(mininum), numberToDouble(maximum), CustomPalette.w1g([new Entry_0(minF, colorOf_1(255, 0, 0)), new Entry_0(meanF, this.y1f_1.n1g()), new Entry_0(maxF, colorOf_1(0, 128, 0))]));
      } else {
        tmp_0 = this.c1g(numberToDouble(mininum), numberToDouble(maximum), CustomPalette.w1g([new Entry_0(0.0, colorOf_1(255, 0, 0)), new Entry_0(0.5, this.y1f_1.n1g()), new Entry_0(1.0, colorOf_1(0, 128, 0))]));
      }
      tmp = tmp_0;
    } else {
      tmp = this.c1g(0.0, 0.0, CustomPalette.w1g([new Entry_0(0.0, this.y1f_1.n1g())]));
    }
    return tmp;
  }
}
class Matching extends Enum {}
class SetStoreMutableProperty$1 {
  constructor($store) {
    this.x1g_1 = $store;
  }
  a10(event) {
    if (!event.newValue) {
      this.x1g_1.vo(null);
    }
  }
  qo(event) {
    return this.a10(event);
  }
}
class SetStoreMutableProperty$2 {
  constructor(this$0) {
    this.y1g_1 = this$0;
  }
  z1g(event) {
    this.y1g_1.vx(new PropertyEvent(null, this.y1g_1.r2()));
  }
  qo(event) {
    return this.z1g(event);
  }
}
class SetStoreMutableProperty$3 {
  constructor(this$0) {
    this.g1h_1 = this$0;
  }
  h1h(event) {
    this.g1h_1.vx(new PropertyEvent(event.oldValue, this.g1h_1.r2()));
  }
  qo(event) {
    return this.h1h(event);
  }
}
class SetStoreMutableProperty extends AbstractMutableProperty {
  constructor(set, store, palette, fraction) {
    super();
    this.c1h_1 = set;
    this.d1h_1 = store;
    this.e1h_1 = palette;
    this.f1h_1 = fraction;
    this.c1h_1.uo(new SetStoreMutableProperty$1(store));
    palette.uo(new SetStoreMutableProperty$2(this));
    store.uo(new SetStoreMutableProperty$3(this));
  }
  i1h(value) {
    if (!(value == null)) {
      this.c1h_1.vo(true);
    }
    this.d1h_1.vo(value);
  }
  vo(_set____db54di) {
    return this.i1h((_set____db54di == null ? true : _set____db54di instanceof CPColor) ? _set____db54di : THROW_CCE());
  }
  r2() {
    var tmp;
    if (!(this.d1h_1.r2() == null)) {
      tmp = this.d1h_1.r2();
    } else {
      tmp = !(this.e1h_1.r2() == null) ? ensureNotNull(this.e1h_1.r2()).getColor(this.f1h_1) : null;
    }
    return tmp;
  }
}
class SimpleColorMap$intervalListener$1 {
  constructor(this$0) {
    this.j1h_1 = this$0;
  }
  fn(event) {
    this.j1h_1.l1f(new ColorMapEvent(this.j1h_1, 'inverval', null, null));
  }
}
class SimpleColorMap$paletteListener$1 {
  constructor(this$0) {
    this.k1h_1 = this$0;
  }
  l1h(event) {
    this.k1h_1.l1f(new ColorMapEvent(this.k1h_1, 'palette', null, null));
  }
}
class SimpleColorMap$1 {
  constructor(this$0) {
    this.m1h_1 = this$0;
  }
  z1g(event) {
    if (!(event.oldValue == null)) {
      ensureNotNull(event.oldValue).removePaletteListener(this.m1h_1.p1i_1);
    }
    if (!(event.newValue == null)) {
      ensureNotNull(event.newValue).addPaletteListener(this.m1h_1.p1i_1);
    }
    this.m1h_1.l1f(new ColorMapEvent(this.m1h_1, 'palette', event.oldValue, event.newValue));
  }
  qo(event) {
    return this.z1g(event);
  }
}
class SimpleColorMap$2 {
  constructor(this$0) {
    this.q1i_1 = this$0;
  }
  a10(event) {
    this.q1i_1.l1f(new ColorMapEvent(this.q1i_1, 'inverted', event.oldValue, event.newValue));
  }
  qo(event) {
    return this.a10(event);
  }
}
class SimpleColorMap$3 {
  constructor(this$0) {
    this.r1i_1 = this$0;
  }
  s1i(event) {
    this.r1i_1.l1f(new ColorMapEvent(this.r1i_1, 'brightness', event.oldValue, event.newValue));
  }
  qo(event) {
    return this.s1i(event);
  }
}
class SimpleColorMap$4 {
  constructor(this$0) {
    this.t1i_1 = this$0;
  }
  s1i(event) {
    this.t1i_1.l1f(new ColorMapEvent(this.t1i_1, 'saturation', event.oldValue, event.newValue));
  }
  qo(event) {
    return this.s1i(event);
  }
}
class SimpleColorMap$5 {
  constructor(this$0) {
    this.u1i_1 = this$0;
  }
  h1h(event) {
    this.u1i_1.l1f(new ColorMapEvent(this.u1i_1, 'overflowColor', event.oldValue, event.newValue));
  }
  qo(event) {
    return this.h1h(event);
  }
}
class SimpleColorMap$6 {
  constructor(this$0) {
    this.v1i_1 = this$0;
  }
  h1h(event) {
    this.v1i_1.l1f(new ColorMapEvent(this.v1i_1, 'underflowColor', event.oldValue, event.newValue));
  }
  qo(event) {
    return this.h1h(event);
  }
}
class SimpleColorMap$7 {
  constructor(this$0) {
    this.w1i_1 = this$0;
  }
  h1h(event) {
    this.w1i_1.l1f(new ColorMapEvent(this.w1i_1, 'missingValuesColor', event.oldValue, event.newValue));
  }
  qo(event) {
    return this.h1h(event);
  }
}
class SimpleColorMap$8 {
  constructor(this$0) {
    this.x1i_1 = this$0;
  }
  a10(event) {
    this.x1i_1.l1f(new ColorMapEvent(this.x1i_1, 'numberOfSteps', event.oldValue, event.newValue));
  }
  qo(event) {
    return this.a10(event);
  }
}
class SimpleColorMap$9 {
  constructor(this$0) {
    this.y1i_1 = this$0;
  }
  s1i(event) {
    this.y1i_1.l1f(new ColorMapEvent(this.y1i_1, 'numberOfSteps', event.oldValue, event.newValue));
  }
  qo(event) {
    return this.s1i(event);
  }
}
class SimpleColorMap extends AbstractColorMap {
  static z1i() {
    var $this = this.h1f();
    $this.o1h_1 = new EnumProperties(values_0());
    $this.p1h_1 = null;
    $this.q1h_1 = $this.o1h_1.vy(PropertyType_Palette_getInstance(), null);
    $this.r1h_1 = PropertyDelegates_instance.j10($this.q1h_1);
    $this.t1h_1 = Matching_EXACT_getInstance();
    $this.u1h_1 = Assignments_STATIC_getInstance();
    $this.v1h_1 = $this.o1h_1.vy(PropertyType_MissingValuesColor_getInstance(), null);
    $this.w1h_1 = PropertyDelegates_instance.j10($this.v1h_1);
    $this.x1h_1 = new SimpleProperty(false);
    $this.y1h_1 = new SimpleProperty(null);
    $this.z1h_1 = $this.o1h_1.wy(PropertyType_UnderflowColor_getInstance(), new SetStoreMutableProperty($this.x1h_1, $this.y1h_1, $this.q1h_1, 0.0));
    $this.a1i_1 = new SimpleProperty(false);
    $this.b1i_1 = new SimpleProperty(null);
    $this.c1i_1 = $this.o1h_1.wy(PropertyType_OverflowColor_getInstance(), new SetStoreMutableProperty($this.a1i_1, $this.b1i_1, $this.q1h_1, 1.0));
    $this.d1i_1 = $this.o1h_1.vy(PropertyType_Inverted_getInstance(), false);
    $this.e1i_1 = PropertyDelegates_instance.j10($this.d1i_1);
    $this.f1i_1 = new SimpleProperty(false);
    $this.g1i_1 = $this.o1h_1.vy(PropertyType_NumberOfSteps_getInstance(), 3);
    $this.h1i_1 = PropertyDelegates_instance.j10($this.g1i_1);
    $this.i1i_1 = $this.o1h_1.vy(PropertyType_Brightness_getInstance(), 0);
    $this.j1i_1 = PropertyDelegates_instance.j10($this.i1i_1);
    $this.k1i_1 = $this.o1h_1.vy(PropertyType_Saturation_getInstance(), 0);
    $this.l1i_1 = PropertyDelegates_instance.j10($this.k1i_1);
    $this.m1i_1 = 1.0;
    $this.n1i_1 = Companion_getInstance_54().a1g_1;
    var tmp = $this;
    tmp.o1i_1 = new SimpleColorMap$intervalListener$1($this);
    var tmp_0 = $this;
    tmp_0.p1i_1 = new SimpleColorMap$paletteListener$1($this);
    $this.o1h_1.vy(PropertyType_Inverval_getInstance(), null);
    $this.o1h_1.vy(PropertyType_Matching_getInstance(), Matching_EXACT_getInstance());
    $this.o1h_1.vy(PropertyType_Assignments_getInstance(), Assignments_STATIC_getInstance());
    var tmp_1 = $this.q1h_1;
    tmp_1.uo(new SimpleColorMap$1($this));
    var tmp_2 = $this.d1i_1;
    tmp_2.uo(new SimpleColorMap$2($this));
    var tmp_3 = $this.i1i_1;
    tmp_3.uo(new SimpleColorMap$3($this));
    var tmp_4 = $this.k1i_1;
    tmp_4.uo(new SimpleColorMap$4($this));
    $this.c1i_1.uo(new SimpleColorMap$5($this));
    $this.z1h_1.uo(new SimpleColorMap$6($this));
    $this.v1h_1.uo(new SimpleColorMap$7($this));
    var tmp_5 = $this.f1i_1;
    tmp_5.uo(new SimpleColorMap$8($this));
    var tmp_6 = $this.g1i_1;
    tmp_6.uo(new SimpleColorMap$9($this));
    $this.v1h_1.vo($this.n1i_1.a1j());
    $this.s1h_1 = HashMap.d8();
    return $this;
  }
  b1j(interval) {
    if (!(this.p1h_1 === interval)) {
      var old = this.p1h_1;
      if (!(this.p1h_1 == null)) {
        ensureNotNull(this.p1h_1).removeIntervalListener(this.o1i_1);
      }
      this.p1h_1 = interval;
      if (!(this.p1h_1 == null)) {
        ensureNotNull(this.p1h_1).addIntervalListener(this.o1i_1);
      }
      this.l1f(new ColorMapEvent(this, 'inverval', old, interval));
    }
  }
  q1f() {
    return this.p1h_1;
  }
  c1j(_set____db54di) {
    this.q1h_1 = _set____db54di;
  }
  d1j() {
    return this.q1h_1;
  }
  e1j(_set____db54di) {
    return this.r1h_1.vh(this, palette$factory(), _set____db54di);
  }
  r1f() {
    return this.r1h_1.th(this, palette$factory_0());
  }
  f1j() {
    return this.v1h_1;
  }
  g1j(_set____db54di) {
    return this.w1h_1.vh(this, nullColor$factory(), _set____db54di);
  }
  s1f() {
    return this.w1h_1.th(this, nullColor$factory_0());
  }
  h1j(_set____db54di) {
    this.x1h_1 = _set____db54di;
  }
  i1j() {
    return this.x1h_1;
  }
  j1j(_set____db54di) {
    this.y1h_1 = _set____db54di;
  }
  k1j() {
    return this.y1h_1;
  }
  l1j() {
    return this.z1h_1;
  }
  m1j(_set____db54di) {
    this.a1i_1 = _set____db54di;
  }
  n1j() {
    return this.a1i_1;
  }
  o1j(_set____db54di) {
    this.b1i_1 = _set____db54di;
  }
  p1j() {
    return this.b1i_1;
  }
  q1j() {
    return this.c1i_1;
  }
  r1j(_set____db54di) {
    this.d1i_1 = _set____db54di;
  }
  s1j() {
    return this.d1i_1;
  }
  t1j(_set____db54di) {
    return this.e1i_1.vh(this, isInverted$factory(), _set____db54di);
  }
  an() {
    return this.e1i_1.th(this, isInverted$factory_0());
  }
  u1j(_set____db54di) {
    this.f1i_1 = _set____db54di;
  }
  v1j() {
    return this.f1i_1;
  }
  w1j(_set____db54di) {
    this.g1i_1 = _set____db54di;
  }
  x1j() {
    return this.g1i_1;
  }
  y1j(_set____db54di) {
    return this.h1i_1.vh(this, colorCount$factory(), _set____db54di);
  }
  x1f() {
    return this.h1i_1.th(this, colorCount$factory_0());
  }
  z1j(_set____db54di) {
    this.i1i_1 = _set____db54di;
  }
  a1k() {
    return this.i1i_1;
  }
  b1k(_set____db54di) {
    return this.j1i_1.vh(this, brightness$factory(), _set____db54di);
  }
  n1f() {
    return this.j1i_1.th(this, brightness$factory_0());
  }
  c1k(_set____db54di) {
    this.k1i_1 = _set____db54di;
  }
  d1k() {
    return this.k1i_1;
  }
  e1k(_set____db54di) {
    return this.l1i_1.vh(this, saturation$factory(), _set____db54di);
  }
  o1f() {
    return this.l1i_1.th(this, saturation$factory_0());
  }
  f1k(alpha) {
    if (!(this.m1i_1 === alpha)) {
      var old = this.m1i_1;
      this.m1i_1 = alpha;
      this.l1f(new ColorMapEvent(this, 'alpha', old, alpha));
    }
  }
  p1f() {
    return this.m1i_1;
  }
  static intervalConstructor(interval, palette) {
    var $this = this.z1i();
    $this.b1j(interval);
    $this.e1j(palette);
    return $this;
  }
  static values(values, cyclic, palette) {
    var $this = this.z1i();
    $this.e1j(palette);
    if (values == null)
      null;
    else {
      // Inline function 'kotlin.let' call
      // Inline function 'org.mkui.colormap.SimpleColorMap.<init>.<anonymous>' call
      $this.g1k(values, cyclic);
    }
    return $this;
  }
  h1k(value) {
    var color;
    if (!(value == null)) {
      if (value instanceof CPColor) {
        return value;
      } else {
        var tmp;
        if (!(value == null) ? isComparable(value) : false) {
          tmp = this.s1h_1.s2(value);
        } else {
          tmp = false;
        }
        if (tmp) {
          color = this.s1h_1.u2(value);
        } else {
          var tmp_0;
          if (isNumber(value)) {
            tmp_0 = !(this.p1h_1 == null);
          } else {
            tmp_0 = false;
          }
          if (tmp_0) {
            var v = numberToDouble(value);
            var fraction;
            var tmp_1;
            if (!ensureNotNull(this.p1h_1).isDegenerate) {
              tmp_1 = (v - ensureNotNull(this.p1h_1).start) / ensureNotNull(this.p1h_1).extent;
            } else {
              tmp_1 = 0.5;
            }
            fraction = tmp_1;
            if (this.an()) {
              fraction = 1.0 - fraction;
            }
            if (fraction < this.j1k()) {
              return this.u1f();
            } else if (fraction > this.i1k()) {
              return this.t1f();
            } else {
              var colorCount = this.f1i_1.r2() ? this.x1f() : 0;
              if (colorCount > 0) {
                var tmp_2;
                if (colorCount > 1) {
                  tmp_2 = numberToInt(fraction * colorCount) / (colorCount - 1 | 0);
                } else {
                  tmp_2 = 0.5;
                }
                fraction = tmp_2;
              }
              color = ensureNotNull(this.q1h_1.r2()).getColor(fraction);
            }
          } else {
            if (!(value == null) ? isArray(value) : false) {
              var str = arrayToString_0(this, value);
              var tmp_3;
              if (this.s1h_1.s2(str)) {
                tmp_3 = this.s1h_1.u2(str);
              } else {
                tmp_3 = this.s1f();
              }
              color = tmp_3;
            } else {
              var tmp_4;
              if (this.u1h_1 === Assignments_DYNAMIC_getInstance()) {
                var c = ensureNotNull(this.q1h_1.r2()).getColorAt(this.s1h_1.a1() % ensureNotNull(this.q1h_1.r2()).colorCount | 0);
                this.s1h_1.i7(value, c);
                tmp_4 = c;
              } else {
                tmp_4 = this.s1f();
              }
              color = tmp_4;
            }
          }
        }
      }
    } else {
      color = this.s1f();
    }
    if (!(color == null) && (!(this.i1i_1.r2() === 0) || !(this.k1i_1.r2() === 0))) {
      color = brightenAndSaturate(color, this.i1i_1.r2() / 300.0, this.k1i_1.r2() / 300.0);
    }
    if (!(color == null) && !(this.m1i_1 === 1.0)) {
      color = alpha(color, this.m1i_1);
    }
    return color;
  }
  getColor(value) {
    return this.h1k(value);
  }
  j1k() {
    var tmp = this.q1h_1.r2();
    if (tmp instanceof InterpolatedPalette) {
      var tmp_0 = this.q1h_1.r2();
      var tmp_1 = (tmp_0 instanceof InterpolatedPalette ? tmp_0 : THROW_CCE()).getEntries();
      var entries = tmp_1 instanceof SortedSet ? tmp_1 : THROW_CCE();
      if (!entries.c1()) {
        return first_0(entries).fraction;
      }
    } else {
      var tmp_2 = this.q1h_1.r2();
      if (tmp_2 instanceof CustomPalette) {
        var tmp_3 = this.r1f();
        var tmp_4 = (tmp_3 instanceof CustomPalette ? tmp_3 : THROW_CCE()).k1k();
        var entries_0 = tmp_4 instanceof SortedSet ? tmp_4 : THROW_CCE();
        if (!entries_0.c1()) {
          return first_0(entries_0).l1k_1;
        }
      }
    }
    return 0.0;
  }
  i1k() {
    var tmp = this.q1h_1.r2();
    if (tmp instanceof InterpolatedPalette) {
      var tmp_0 = this.q1h_1.r2();
      var tmp_1 = (tmp_0 instanceof InterpolatedPalette ? tmp_0 : THROW_CCE()).getEntries();
      var entries = tmp_1 instanceof SortedSet ? tmp_1 : THROW_CCE();
      if (!entries.c1()) {
        return last_0(entries).fraction;
      }
    } else {
      var tmp_2 = this.q1h_1.r2();
      if (tmp_2 instanceof CustomPalette) {
        var tmp_3 = this.r1f();
        var tmp_4 = (tmp_3 instanceof CustomPalette ? tmp_3 : THROW_CCE()).k1k();
        var entries_0 = tmp_4 instanceof SortedSet ? tmp_4 : THROW_CCE();
        if (!entries_0.c1()) {
          return last_0(entries_0).l1k_1;
        }
      }
    }
    return 1.0;
  }
  o1k(matching) {
    if (!(this.t1h_1 === matching)) {
      var old = this.t1h_1;
      this.t1h_1 = ensureNotNull(matching);
      this.l1f(new ColorMapEvent(this, 'matching', old, matching));
    }
  }
  setMatching(matching) {
    return this.o1k(matching);
  }
  p1k(assignments) {
    if (!(this.u1h_1 === assignments)) {
      var old = this.u1h_1;
      this.u1h_1 = ensureNotNull(assignments);
      this.l1f(new ColorMapEvent(this, 'assignments', old, assignments));
    }
  }
  setAssignments(assignments) {
    return this.p1k(assignments);
  }
  u1f() {
    return ensureNotNull(this.z1h_1.r2());
  }
  q1k(underColor) {
    if (!equals(this.u1f(), underColor) && (this.u1f() == null || !equals(this.u1f(), underColor))) {
      this.z1h_1.vo(ensureNotNull(underColor));
    }
  }
  setUnderColor(underColor) {
    return this.q1k(underColor);
  }
  t1f() {
    return ensureNotNull(this.b1i_1.r2());
  }
  r1k(overColor) {
    if (!equals(this.t1f(), overColor) && (this.t1f() == null || !equals(this.t1f(), overColor))) {
      this.b1i_1.vo(overColor);
    }
  }
  setOverColor(overColor) {
    return this.r1k(overColor);
  }
  v1f() {
    return this.a1i_1.r2();
  }
  w1f() {
    return this.x1h_1.r2();
  }
  g1k(values, cyclic) {
    this.s1h_1.o5();
    var i = 0;
    var _iterator__ex2g4s = values.x();
    while (_iterator__ex2g4s.y()) {
      var value = _iterator__ex2g4s.z();
      var color;
      var tmp;
      if (!cyclic) {
        tmp = ensureNotNull(this.q1h_1.r2()).getColor(i / values.a1());
      } else {
        tmp = ensureNotNull(this.q1h_1.r2()).getColorAt(i % ensureNotNull(this.q1h_1.r2()).colorCount | 0);
      }
      color = tmp;
      var v;
      var tmp_0;
      if (!(value == null) ? isArray(value) : false) {
        tmp_0 = arrayToString_0(this, value);
      } else {
        tmp_0 = value;
      }
      v = tmp_0;
      this.s1h_1.i7(v, ensureNotNull(color));
      i = i + 1 | 0;
    }
    this.l1f(new ColorMapEvent(this, 'assignments', null, null));
  }
  assignColorsSet(values, normalized) {
    return this.g1k(values, normalized);
  }
  s1k(values) {
    this.s1h_1.o5();
    var i = 0;
    var inductionVariable = 0;
    var last = values.length;
    while (inductionVariable < last) {
      var value = values[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      if (!this.s1h_1.s2(value)) {
        this.s1h_1.i7(value, ensureNotNull(this.q1h_1.r2()).getColorAt(i % ensureNotNull(this.q1h_1.r2()).colorCount | 0));
        i = i + 1 | 0;
      }
    }
    this.l1f(new ColorMapEvent(this, 'assignments', null, null));
  }
  assignColors() {
    var values = [].slice.call(arguments);
    return this.s1k(values);
  }
  t1k(values) {
    this.s1h_1.o5();
    var i = 0;
    var _iterator__ex2g4s = values.x();
    while (_iterator__ex2g4s.y()) {
      var value = _iterator__ex2g4s.z();
      if (!this.s1h_1.s2(value)) {
        this.s1h_1.i7(value, ensureNotNull(this.q1h_1.r2()).getColorAt(i % ensureNotNull(this.q1h_1.r2()).colorCount | 0));
        i = i + 1 | 0;
      }
    }
    this.l1f(new ColorMapEvent(this, 'assignments', null, null));
  }
  assignColorsIterable(values) {
    return this.t1k(values);
  }
  u1k(value, color) {
    this.s1h_1.i7(value, ensureNotNull(color));
    this.l1f(new ColorMapEvent(this, 'assignments', null, null));
  }
  setColor(value, color) {
    return this.u1k(value, color);
  }
  v1k() {
    this.s1h_1.o5();
    this.l1f(new ColorMapEvent(this, 'assignments', null, null));
  }
  clearAssignedColor() {
    return this.v1k();
  }
  m1f() {
    return this.s1h_1.g7();
  }
  w1k() {
    var set = SortedSet.uk(new UniversalComparator());
    set.x2(this.s1h_1.g7());
    this.g1k(set, true);
  }
  resetAssignedValues() {
    return this.w1k();
  }
  x1k(property, value) {
    switch (property) {
      case 'inverval':
        this.b1j((!(value == null) ? !(value == null) : false) ? value : THROW_CCE());
        break;
      case 'palette':
        this.e1j((!(value == null) ? isInterface(value, MutablePalette) : false) ? value : THROW_CCE());
        break;
      case 'matching':
        this.o1k(value instanceof Matching ? value : THROW_CCE());
        break;
      case 'assignments':
        this.p1k(value instanceof Assignments ? value : THROW_CCE());
        break;
      case 'missingValuesColor':
        this.g1j(value instanceof CPColor ? value : THROW_CCE());
        break;
      case 'underflowColor':
        this.q1k(value instanceof CPColor ? value : THROW_CCE());
        break;
      case 'overflowColor':
        this.r1k(value instanceof CPColor ? value : THROW_CCE());
        break;
      case 'inverted':
        this.t1j((!(value == null) ? typeof value === 'boolean' : false) ? value : THROW_CCE());
        break;
      case 'numberOfSteps':
        this.y1j((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'brightness':
        this.b1k((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'saturation':
        this.e1k((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'alpha':
        this.f1k((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      default:
        println('Unknonw property ' + property);
        break;
    }
  }
  setProperty(property, value) {
    return this.x1k(property, value);
  }
  toString() {
    return 'SimpleColorMap{interval=' + this.p1h_1 + ', palette=' + this.r1f() + ', nullColor=' + this.s1f() + ', underColor=' + this.z1h_1 + toString(_Char___init__impl__6a9atx(125));
  }
  get interval() {
    return this.q1f();
  }
  set interval(value) {
    this.b1j(value);
  }
  get paletteProperty() {
    return this.d1j();
  }
  set paletteProperty(value) {
    this.c1j(value);
  }
  get palette() {
    return this.r1f();
  }
  set palette(value) {
    this.e1j(value);
  }
  get nullColorProperty() {
    return this.f1j();
  }
  get nullColor() {
    return this.s1f();
  }
  set nullColor(value) {
    this.g1j(value);
  }
  get underColorSetProperty() {
    return this.i1j();
  }
  set underColorSetProperty(value) {
    this.h1j(value);
  }
  get underColorStoreProperty() {
    return this.k1j();
  }
  set underColorStoreProperty(value) {
    this.j1j(value);
  }
  get underColorProperty() {
    return this.l1j();
  }
  get overColorSetProperty() {
    return this.n1j();
  }
  set overColorSetProperty(value) {
    this.m1j(value);
  }
  get overColorStoreProperty() {
    return this.p1j();
  }
  set overColorStoreProperty(value) {
    this.o1j(value);
  }
  get overColorProperty() {
    return this.q1j();
  }
  get isInvertedProperty() {
    return this.s1j();
  }
  set isInvertedProperty(value) {
    this.r1j(value);
  }
  get isInverted() {
    return this.an();
  }
  set isInverted(value) {
    this.t1j(value);
  }
  get colorCountSetProperty() {
    return this.v1j();
  }
  set colorCountSetProperty(value) {
    this.u1j(value);
  }
  get colorCountProperty() {
    return this.x1j();
  }
  set colorCountProperty(value) {
    this.w1j(value);
  }
  get colorCount() {
    return this.x1f();
  }
  set colorCount(value) {
    this.y1j(value);
  }
  get brightnessProperty() {
    return this.a1k();
  }
  set brightnessProperty(value) {
    this.z1j(value);
  }
  get brightness() {
    return this.n1f();
  }
  set brightness(value) {
    this.b1k(value);
  }
  get saturationProperty() {
    return this.d1k();
  }
  set saturationProperty(value) {
    this.c1k(value);
  }
  get saturation() {
    return this.o1f();
  }
  set saturation(value) {
    this.e1k(value);
  }
  get alpha() {
    return this.p1f();
  }
  set alpha(value) {
    this.f1k(value);
  }
  get underflowColor() {
    return this.u1f();
  }
  get overflowColor() {
    return this.t1f();
  }
  get isOverflowColorSet() {
    return this.v1f();
  }
  get isUnderflowColorSet() {
    return this.w1f();
  }
  get assignedValues() {
    return this.m1f();
  }
}
class MutableColorMapOverrideProperty extends OverrideProperty {
  f10() {
    var overrideProperty = new MutableColorMapProperty(this.d10().r2());
    return this.g10(overrideProperty);
  }
}
class MutableColorMapProperty$colorMapListener$1 {
  constructor(this$0, $colorMap) {
    this.e1l_1 = this$0;
    this.f1l_1 = $colorMap;
  }
  o1e(event) {
    this.e1l_1.vx(new PropertyEvent(null, this.f1l_1));
  }
}
class MutableColorMapProperty extends AbstractMutableProperty {
  constructor(colorMap) {
    super();
    this.i1l_1 = null;
    var tmp = this;
    tmp.j1l_1 = new MutableColorMapProperty$colorMapListener$1(this, colorMap);
    this.k1l(colorMap);
  }
  k1l(value) {
    if (!(this.i1l_1 == null)) {
      ensureNotNull(this.i1l_1).removeColorMapListener(this.j1l_1);
    }
    var old = this.i1l_1;
    this.i1l_1 = value;
    if (!(this.i1l_1 == null)) {
      ensureNotNull(this.i1l_1).addColorMapListener(this.j1l_1);
    }
    this.vx(new PropertyEvent(old, this.i1l_1));
  }
  vo(_set____db54di) {
    return this.k1l((_set____db54di == null ? true : !(_set____db54di == null)) ? _set____db54di : THROW_CCE());
  }
  r2() {
    return this.i1l_1;
  }
}
class InteractiveComponentListeners {
  constructor() {
    this.l1l_1 = ArrayList.e1();
    this.m1l_1 = ArrayList.e1();
    this.n1l_1 = ArrayList.e1();
    this.o1l_1 = ArrayList.e1();
    this.p1l_1 = ArrayList.e1();
  }
}
class Posture extends Enum {}
class Weight extends Enum {}
class Companion_31 {
  constructor() {
    this.q1l_1 = 1;
    this.r1l_1 = 2;
    this.s1l_1 = 4;
    this.t1l_1 = 8;
  }
}
class Shape {}
function get_bounds() {
  var b = this.y1l();
  var width = b.cm();
  var height = b.dm();
  if (width < 0 || height < 0) {
    return Rectangle.empty();
  }
  var x = b.w1l();
  var y = b.x1l();
  // Inline function 'kotlin.math.floor' call
  var x1 = Math.floor(x);
  // Inline function 'kotlin.math.floor' call
  var y1 = Math.floor(y);
  // Inline function 'kotlin.math.ceil' call
  var x_0 = x + width;
  var x2 = Math.ceil(x_0);
  // Inline function 'kotlin.math.ceil' call
  var x_1 = y + height;
  var y2 = Math.ceil(x_1);
  return Rectangle.from(numberToInt(x1), numberToInt(y1), numberToInt(x2 - x1), numberToInt(y2 - y1));
}
function getPathIterator$default(at, $super) {
  at = at === VOID ? null : at;
  return $super === VOID ? this.e1m(at) : $super.e1m.call(this, at);
}
class Rectangle2D {}
class AbstractRectangle2D {
  static u1l() {
    return createThis(this);
  }
  v1l() {
    var width = this.cm();
    var height = this.dm();
    if (width < 0 || height < 0) {
      return Rectangle.empty();
    }
    var x = this.w1l();
    var y = this.x1l();
    // Inline function 'kotlin.math.floor' call
    var x1 = Math.floor(x);
    // Inline function 'kotlin.math.floor' call
    var y1 = Math.floor(y);
    // Inline function 'kotlin.math.ceil' call
    var x_0 = x + width;
    var x2 = Math.ceil(x_0);
    // Inline function 'kotlin.math.ceil' call
    var x_1 = y + height;
    var y2 = Math.ceil(x_1);
    return Rectangle.from(numberToInt(x1), numberToInt(y1), numberToInt(x2 - x1), numberToInt(y2 - y1));
  }
  y1l() {
    return this;
  }
  z1l(point) {
    var x = point.w1l();
    var y = point.x1l();
    var x0 = this.w1l();
    var y0 = this.x1l();
    return x >= x0 && y >= y0 && x < x0 + this.cm() && y < y0 + this.dm();
  }
  a1m() {
    return this.w1l() + this.cm() / 2.0;
  }
  b1m(rect) {
    var x = rect.w1l();
    var y = rect.x1l();
    var w = rect.cm();
    var h = rect.dm();
    if (w <= 0 || h <= 0) {
      return false;
    }
    var x0 = this.w1l();
    var y0 = this.x1l();
    return x + w > x0 && y + h > y0 && x < x0 + this.cm() && y < y0 + this.dm();
  }
  c1m() {
    return this.x1l() + this.dm() / 2.0;
  }
  d1m() {
    return this.e1m(null);
  }
  f1m() {
    return this.w1l();
  }
  e1m(at) {
    return new RectIterator(this, at);
  }
  h1m() {
    return this.x1l();
  }
  i1m() {
    return this.w1l() + this.cm();
  }
  j1m() {
    return this.x1l() + this.dm();
  }
  k1m(r) {
    var tmp0 = this.f1m();
    // Inline function 'kotlin.math.max' call
    var b = r.f1m();
    var x1 = Math.max(tmp0, b);
    var tmp2 = this.h1m();
    // Inline function 'kotlin.math.max' call
    var b_0 = r.h1m();
    var y1 = Math.max(tmp2, b_0);
    var tmp4 = this.i1m();
    // Inline function 'kotlin.math.min' call
    var b_1 = r.i1m();
    var x2 = Math.min(tmp4, b_1);
    var tmp6 = this.j1m();
    // Inline function 'kotlin.math.min' call
    var b_2 = r.j1m();
    var y2 = Math.min(tmp6, b_2);
    return Double_3.p1m(x1, y1, x2 - x1, y2 - y1);
  }
  q1m(x1, y1, x2, y2) {
    var x1_0 = x1;
    var y1_0 = y1;
    var out2;
    // Inline function 'kotlin.also' call
    var this_0 = this.r1m(x2, y2);
    // Inline function 'org.mkui.geom.AbstractRectangle2D.intersectsLine.<anonymous>' call
    out2 = this_0;
    if (this_0 === 0) {
      return true;
    }
    var out1;
    $l$loop: while (true) {
      // Inline function 'kotlin.also' call
      var this_1 = this.r1m(x1_0, y1_0);
      // Inline function 'org.mkui.geom.AbstractRectangle2D.intersectsLine.<anonymous>' call
      out1 = this_1;
      if (!!(this_1 === 0)) {
        break $l$loop;
      }
      if (!((out1 & out2) === 0)) {
        return false;
      }
      if (!((out1 & 5) === 0)) {
        var x = this.w1l();
        if (!((out1 & 4) === 0)) {
          x = x + this.cm();
        }
        y1_0 = y1_0 + (x - x1_0) * (y2 - y1_0) / (x2 - x1_0);
        x1_0 = x;
      } else {
        var y = this.x1l();
        if (!((out1 & 8) === 0)) {
          y = y + this.dm();
        }
        x1_0 = x1_0 + (y - y1_0) * (x2 - x1_0) / (y2 - y1_0);
        y1_0 = y;
      }
    }
    return true;
  }
  r1m(x, y) {
    var out = 0;
    if (this.cm() <= 0) {
      out = out | 5;
    } else if (x < this.w1l()) {
      out = out | 1;
    } else if (x > this.w1l() + this.cm()) {
      out = out | 4;
    }
    if (this.dm() <= 0) {
      out = out | 10;
    } else if (y < this.x1l()) {
      out = out | 2;
    } else if (y > this.x1l() + this.dm()) {
      out = out | 8;
    }
    return out;
  }
}
class Companion_32 {
  constructor() {
    Companion_instance_32 = this;
    this.e1n_1 = 0;
    this.f1n_1 = 1;
    this.g1n_1 = 2;
    this.h1n_1 = 4;
    this.i1n_1 = 6;
    this.j1n_1 = 64;
    this.k1n_1 = 8;
    this.l1n_1 = 16;
    this.m1n_1 = 24;
    this.n1n_1 = 32;
    this.o1n_1 = 0;
    this.p1n_1 = 1;
    this.q1n_1 = 2;
    this.r1n_1 = 4;
    this.s1n_1 = -1;
    this.t1n_1 = 3;
    this.u1n_1 = 0;
    this.v1n_1 = 8;
    this.w1n_1 = 16;
    this.x1n_1 = 32;
    var tmp = this;
    // Inline function 'kotlin.intArrayOf' call
    tmp.y1n_1 = new Int32Array([4, 5, 4, 5, 2, 3, 6, 7]);
  }
}
class AffineTransform {
  static z1n() {
    Companion_getInstance_32();
    var $this = createThis(this);
    init_org_mkui_geom_AffineTransform($this);
    $this.z1m_1 = 1.0;
    $this.w1m_1 = $this.z1m_1;
    return $this;
  }
  static a1o(Tx) {
    Companion_getInstance_32();
    var $this = createThis(this);
    init_org_mkui_geom_AffineTransform($this);
    $this.w1m_1 = Tx.w1m_1;
    $this.x1m_1 = Tx.x1m_1;
    $this.y1m_1 = Tx.y1m_1;
    $this.z1m_1 = Tx.z1m_1;
    $this.a1n_1 = Tx.a1n_1;
    $this.b1n_1 = Tx.b1n_1;
    $this.c1n_1 = Tx.c1n_1;
    $this.d1n_1 = Tx.d1n_1;
    return $this;
  }
  b1o() {
    if (this.y1m_1 === 0.0 && this.x1m_1 === 0.0) {
      if (this.w1m_1 === 1.0 && this.z1m_1 === 1.0) {
        if (this.a1n_1 === 0.0 && this.b1n_1 === 0.0) {
          this.c1n_1 = 0;
          this.d1n_1 = 0;
        } else {
          this.c1n_1 = 1;
          this.d1n_1 = 1;
        }
      } else {
        if (this.a1n_1 === 0.0 && this.b1n_1 === 0.0) {
          this.c1n_1 = 2;
          this.d1n_1 = -1;
        } else {
          this.c1n_1 = 3;
          this.d1n_1 = -1;
        }
      }
    } else {
      if (this.w1m_1 === 0.0 && this.z1m_1 === 0.0) {
        if (this.a1n_1 === 0.0 && this.b1n_1 === 0.0) {
          this.c1n_1 = 4;
          this.d1n_1 = -1;
        } else {
          this.c1n_1 = 5;
          this.d1n_1 = -1;
        }
      } else {
        if (this.a1n_1 === 0.0 && this.b1n_1 === 0.0) {
          this.c1n_1 = 6;
          this.d1n_1 = -1;
        } else {
          this.c1n_1 = 7;
          this.d1n_1 = -1;
        }
      }
    }
  }
  static c1o(m00, m10, m01, m11, m02, m12) {
    Companion_getInstance_32();
    var $this = createThis(this);
    init_org_mkui_geom_AffineTransform($this);
    $this.w1m_1 = m00;
    $this.x1m_1 = m10;
    $this.y1m_1 = m01;
    $this.z1m_1 = m11;
    $this.a1n_1 = m02;
    $this.b1n_1 = m12;
    $this.b1o();
    return $this;
  }
  d1o(sx, sy) {
    this.w1m_1 = sx;
    this.x1m_1 = 0.0;
    this.y1m_1 = 0.0;
    this.z1m_1 = sy;
    this.a1n_1 = 0.0;
    this.b1n_1 = 0.0;
    if (!(sx === 1.0) || !(sy === 1.0)) {
      this.c1n_1 = 2;
      this.d1n_1 = -1;
    } else {
      this.c1n_1 = 0;
      this.d1n_1 = 0;
    }
  }
  e1o(tx, ty) {
    switch (this.c1n_1) {
      case 7:
        this.a1n_1 = tx * this.w1m_1 + ty * this.y1m_1 + this.a1n_1;
        this.b1n_1 = tx * this.x1m_1 + ty * this.z1m_1 + this.b1n_1;
        if (this.a1n_1 === 0.0 && this.b1n_1 === 0.0) {
          this.c1n_1 = 6;
          if (!(this.d1n_1 === -1)) {
            this.d1n_1 = this.d1n_1 - 1 | 0;
          }
        }

        return Unit_instance;
      case 6:
        this.a1n_1 = tx * this.w1m_1 + ty * this.y1m_1;
        this.b1n_1 = tx * this.x1m_1 + ty * this.z1m_1;
        if (!(this.a1n_1 === 0.0) || !(this.b1n_1 === 0.0)) {
          this.c1n_1 = 7;
          this.d1n_1 = this.d1n_1 | 1;
        }

        return Unit_instance;
      case 5:
        this.a1n_1 = ty * this.y1m_1 + this.a1n_1;
        this.b1n_1 = tx * this.x1m_1 + this.b1n_1;
        if (this.a1n_1 === 0.0 && this.b1n_1 === 0.0) {
          this.c1n_1 = 4;
          if (!(this.d1n_1 === -1)) {
            this.d1n_1 = this.d1n_1 - 1 | 0;
          }
        }

        return Unit_instance;
      case 4:
        this.a1n_1 = ty * this.y1m_1;
        this.b1n_1 = tx * this.x1m_1;
        if (!(this.a1n_1 === 0.0) || !(this.b1n_1 === 0.0)) {
          this.c1n_1 = 5;
          this.d1n_1 = this.d1n_1 | 1;
        }

        return Unit_instance;
      case 3:
        this.a1n_1 = tx * this.w1m_1 + this.a1n_1;
        this.b1n_1 = ty * this.z1m_1 + this.b1n_1;
        if (this.a1n_1 === 0.0 && this.b1n_1 === 0.0) {
          this.c1n_1 = 2;
          if (!(this.d1n_1 === -1)) {
            this.d1n_1 = this.d1n_1 - 1 | 0;
          }
        }

        return Unit_instance;
      case 2:
        this.a1n_1 = tx * this.w1m_1;
        this.b1n_1 = ty * this.z1m_1;
        if (!(this.a1n_1 === 0.0) || !(this.b1n_1 === 0.0)) {
          this.c1n_1 = 3;
          this.d1n_1 = this.d1n_1 | 1;
        }

        return Unit_instance;
      case 1:
        this.a1n_1 = tx + this.a1n_1;
        this.b1n_1 = ty + this.b1n_1;
        if (this.a1n_1 === 0.0 && this.b1n_1 === 0.0) {
          this.c1n_1 = 0;
          this.d1n_1 = 0;
        }

        return Unit_instance;
      case 0:
        this.a1n_1 = tx;
        this.b1n_1 = ty;
        if (!(tx === 0.0) || !(ty === 0.0)) {
          this.c1n_1 = 1;
          this.d1n_1 = 1;
        }

        return Unit_instance;
      default:
        stateError(this);
        return Unit_instance;
    }
  }
  f1o(theta) {
    // Inline function 'kotlin.math.sin' call
    var sin = Math.sin(theta);
    if (sin === 1.0) {
      rotate90(this);
    } else if (sin === -1.0) {
      rotate270(this);
    } else {
      // Inline function 'kotlin.math.cos' call
      var cos = Math.cos(theta);
      if (cos === -1.0) {
        rotate180(this);
      } else if (!(cos === 1.0)) {
        var M0 = this.w1m_1;
        var M1 = this.y1m_1;
        this.w1m_1 = cos * M0 + sin * M1;
        this.y1m_1 = -sin * M0 + cos * M1;
        M0 = this.x1m_1;
        M1 = this.z1m_1;
        this.x1m_1 = cos * M0 + sin * M1;
        this.z1m_1 = -sin * M0 + cos * M1;
        this.b1o();
      }
    }
  }
  g1o() {
    this.z1m_1 = 1.0;
    this.w1m_1 = this.z1m_1;
    this.b1n_1 = 0.0;
    this.a1n_1 = this.b1n_1;
    this.y1m_1 = this.a1n_1;
    this.x1m_1 = this.y1m_1;
    this.c1n_1 = 0;
    this.d1n_1 = 0;
  }
  h1o(Tx) {
    var M0;
    var T01;
    var T10;
    var mystate = this.c1n_1;
    var txstate = Tx.c1n_1;
    switch (txstate << 3 | mystate) {
      case 0:
      case 1:
      case 2:
      case 3:
      case 4:
      case 5:
      case 6:
      case 7:
        return Unit_instance;
      case 56:
        this.y1m_1 = Tx.y1m_1;
        this.x1m_1 = Tx.x1m_1;
        this.w1m_1 = Tx.w1m_1;
        this.z1m_1 = Tx.z1m_1;
        this.a1n_1 = Tx.a1n_1;
        this.b1n_1 = Tx.b1n_1;
        this.c1n_1 = txstate;
        this.d1n_1 = Tx.d1n_1;
        return Unit_instance;
      case 24:
        this.w1m_1 = Tx.w1m_1;
        this.z1m_1 = Tx.z1m_1;
        this.a1n_1 = Tx.a1n_1;
        this.b1n_1 = Tx.b1n_1;
        this.c1n_1 = txstate;
        this.d1n_1 = Tx.d1n_1;
        return Unit_instance;
      case 8:
        this.a1n_1 = Tx.a1n_1;
        this.b1n_1 = Tx.b1n_1;
        this.c1n_1 = txstate;
        this.d1n_1 = Tx.d1n_1;
        return Unit_instance;
      case 48:
        this.y1m_1 = Tx.y1m_1;
        this.x1m_1 = Tx.x1m_1;
        this.w1m_1 = Tx.w1m_1;
        this.z1m_1 = Tx.z1m_1;
        this.c1n_1 = txstate;
        this.d1n_1 = Tx.d1n_1;
        return Unit_instance;
      case 16:
        this.w1m_1 = Tx.w1m_1;
        this.z1m_1 = Tx.z1m_1;
        this.c1n_1 = txstate;
        this.d1n_1 = Tx.d1n_1;
        return Unit_instance;
      case 40:
        this.a1n_1 = Tx.a1n_1;
        this.b1n_1 = Tx.b1n_1;
        this.y1m_1 = Tx.y1m_1;
        this.x1m_1 = Tx.x1m_1;
        // Inline function 'kotlin.run' call

        // Inline function 'org.mkui.geom.AffineTransform.concatenate.<anonymous>' call

        this.z1m_1 = 0.0;
        this.w1m_1 = this.z1m_1;
        this.c1n_1 = txstate;
        this.d1n_1 = Tx.d1n_1;
        return Unit_instance;
      case 32:
        this.y1m_1 = Tx.y1m_1;
        this.x1m_1 = Tx.x1m_1;
        // Inline function 'kotlin.run' call

        // Inline function 'org.mkui.geom.AffineTransform.concatenate.<anonymous>' call

        this.z1m_1 = 0.0;
        this.w1m_1 = this.z1m_1;
        this.c1n_1 = txstate;
        this.d1n_1 = Tx.d1n_1;
        return Unit_instance;
      case 15:
      case 14:
      case 13:
      case 12:
      case 11:
      case 10:
      case 9:
        this.e1o(Tx.a1n_1, Tx.b1n_1);
        return Unit_instance;
      case 23:
      case 22:
      case 21:
      case 20:
      case 19:
      case 18:
      case 17:
        this.i1o(Tx.w1m_1, Tx.z1m_1);
        return Unit_instance;
      case 39:
      case 38:
        T01 = Tx.y1m_1;
        T10 = Tx.x1m_1;
        M0 = this.w1m_1;
        this.w1m_1 = this.y1m_1 * T10;
        this.y1m_1 = M0 * T01;
        M0 = this.x1m_1;
        this.x1m_1 = this.z1m_1 * T10;
        this.z1m_1 = M0 * T01;
        this.d1n_1 = -1;
        return Unit_instance;
      case 37:
      case 36:
        this.w1m_1 = this.y1m_1 * Tx.x1m_1;
        this.y1m_1 = 0.0;
        this.z1m_1 = this.x1m_1 * Tx.y1m_1;
        this.x1m_1 = 0.0;
        this.c1n_1 = mystate ^ 6;
        this.d1n_1 = -1;
        return Unit_instance;
      case 35:
      case 34:
        this.y1m_1 = this.w1m_1 * Tx.y1m_1;
        this.w1m_1 = 0.0;
        this.x1m_1 = this.z1m_1 * Tx.x1m_1;
        this.z1m_1 = 0.0;
        this.c1n_1 = mystate ^ 6;
        this.d1n_1 = -1;
        return Unit_instance;
      case 33:
        this.w1m_1 = 0.0;
        this.y1m_1 = Tx.y1m_1;
        this.x1m_1 = Tx.x1m_1;
        this.z1m_1 = 0.0;
        this.c1n_1 = 5;
        this.d1n_1 = -1;
        return Unit_instance;
    }
    var T00 = Tx.w1m_1;
    T01 = Tx.y1m_1;
    var T02 = Tx.a1n_1;
    T10 = Tx.x1m_1;
    var T11 = Tx.z1m_1;
    var T12 = Tx.b1n_1;
    var M1;
    switch (mystate) {
      case 6:
        this.c1n_1 = mystate | txstate;
        M0 = this.w1m_1;
        M1 = this.y1m_1;
        this.w1m_1 = T00 * M0 + T10 * M1;
        this.y1m_1 = T01 * M0 + T11 * M1;
        this.a1n_1 = this.a1n_1 + (T02 * M0 + T12 * M1);
        M0 = this.x1m_1;
        M1 = this.z1m_1;
        this.x1m_1 = T00 * M0 + T10 * M1;
        this.z1m_1 = T01 * M0 + T11 * M1;
        this.b1n_1 = this.b1n_1 + (T02 * M0 + T12 * M1);
        this.d1n_1 = -1;
        return Unit_instance;
      case 7:
        M0 = this.w1m_1;
        M1 = this.y1m_1;
        this.w1m_1 = T00 * M0 + T10 * M1;
        this.y1m_1 = T01 * M0 + T11 * M1;
        this.a1n_1 = this.a1n_1 + (T02 * M0 + T12 * M1);
        M0 = this.x1m_1;
        M1 = this.z1m_1;
        this.x1m_1 = T00 * M0 + T10 * M1;
        this.z1m_1 = T01 * M0 + T11 * M1;
        this.b1n_1 = this.b1n_1 + (T02 * M0 + T12 * M1);
        this.d1n_1 = -1;
        return Unit_instance;
      case 5:
      case 4:
        M0 = this.y1m_1;
        this.w1m_1 = T10 * M0;
        this.y1m_1 = T11 * M0;
        this.a1n_1 = this.a1n_1 + T12 * M0;
        M0 = this.x1m_1;
        this.x1m_1 = T00 * M0;
        this.z1m_1 = T01 * M0;
        this.b1n_1 = this.b1n_1 + T02 * M0;
        break;
      case 3:
      case 2:
        M0 = this.w1m_1;
        this.w1m_1 = T00 * M0;
        this.y1m_1 = T01 * M0;
        this.a1n_1 = this.a1n_1 + T02 * M0;
        M0 = this.z1m_1;
        this.x1m_1 = T10 * M0;
        this.z1m_1 = T11 * M0;
        this.b1n_1 = this.b1n_1 + T12 * M0;
        break;
      case 1:
        this.w1m_1 = T00;
        this.y1m_1 = T01;
        this.a1n_1 = this.a1n_1 + T02;
        this.x1m_1 = T10;
        this.z1m_1 = T11;
        this.b1n_1 = this.b1n_1 + T12;
        this.c1n_1 = txstate | 1;
        this.d1n_1 = -1;
        return Unit_instance;
      default:
        stateError(this);
        this.c1n_1 = mystate | txstate;
        M0 = this.w1m_1;
        M1 = this.y1m_1;
        this.w1m_1 = T00 * M0 + T10 * M1;
        this.y1m_1 = T01 * M0 + T11 * M1;
        this.a1n_1 = this.a1n_1 + (T02 * M0 + T12 * M1);
        M0 = this.x1m_1;
        M1 = this.z1m_1;
        this.x1m_1 = T00 * M0 + T10 * M1;
        this.z1m_1 = T01 * M0 + T11 * M1;
        this.b1n_1 = this.b1n_1 + (T02 * M0 + T12 * M1);
        this.d1n_1 = -1;
        return Unit_instance;
    }
    this.b1o();
  }
  i1o(sx, sy) {
    var state = this.c1n_1;
    switch (state) {
      case 7:
      case 6:
        this.w1m_1 = this.w1m_1 * sx;
        this.z1m_1 = this.z1m_1 * sy;
        this.y1m_1 = this.y1m_1 * sy;
        this.x1m_1 = this.x1m_1 * sx;
        if (this.y1m_1 === 0.0 && this.x1m_1 === 0.0) {
          state = state & 1;
          if (this.w1m_1 === 1.0 && this.z1m_1 === 1.0) {
            this.d1n_1 = state === 0 ? 0 : 1;
          } else {
            state = state | 2;
            this.d1n_1 = -1;
          }
          this.c1n_1 = state;
        }

        return Unit_instance;
      case 5:
      case 4:
        this.y1m_1 = this.y1m_1 * sy;
        this.x1m_1 = this.x1m_1 * sx;
        if (this.y1m_1 === 0.0 && this.x1m_1 === 0.0) {
          state = state & 1;
          if (this.w1m_1 === 1.0 && this.z1m_1 === 1.0) {
            this.d1n_1 = state === 0 ? 0 : 1;
          } else {
            state = state | 2;
            this.d1n_1 = -1;
          }
          this.c1n_1 = state;
        }

        return Unit_instance;
      case 3:
      case 2:
        this.w1m_1 = this.w1m_1 * sx;
        this.z1m_1 = this.z1m_1 * sy;
        if (this.w1m_1 === 1.0 && this.z1m_1 === 1.0) {
          var tmp = this;
          // Inline function 'kotlin.let' call
          // Inline function 'org.mkui.geom.AffineTransform.scale.<anonymous>' call
          state = state & 1;
          tmp.c1n_1 = state;
          this.d1n_1 = state === 0 ? 0 : 1;
        } else {
          this.d1n_1 = -1;
        }

        return Unit_instance;
      case 1:
      case 0:
        this.w1m_1 = sx;
        this.z1m_1 = sy;
        if (!(sx === 1.0) || !(sy === 1.0)) {
          this.c1n_1 = state | 2;
          this.d1n_1 = -1;
        }

        return Unit_instance;
      default:
        stateError(this);
        this.w1m_1 = this.w1m_1 * sx;
        this.z1m_1 = this.z1m_1 * sy;
        this.y1m_1 = this.y1m_1 * sy;
        this.x1m_1 = this.x1m_1 * sx;
        if (this.y1m_1 === 0.0 && this.x1m_1 === 0.0) {
          state = state & 1;
          if (this.w1m_1 === 1.0 && this.z1m_1 === 1.0) {
            this.d1n_1 = state === 0 ? 0 : 1;
          } else {
            state = state | 2;
            this.d1n_1 = -1;
          }
          this.c1n_1 = state;
        }

        return Unit_instance;
    }
  }
  j1o(ptSrc, ptDst) {
    var ptDst_0 = ptDst;
    if (ptDst_0 == null) {
      var tmp;
      if (ptSrc instanceof Double_2) {
        tmp = Double_2.p1o();
      } else {
        tmp = Float.m1o();
      }
      ptDst_0 = tmp;
    }
    var x = ptSrc.w1l();
    var y = ptSrc.x1l();
    var tmp_0;
    switch (this.c1n_1) {
      case 7:
        ptDst_0.q1o(x * this.w1m_1 + y * this.y1m_1 + this.a1n_1, x * this.x1m_1 + y * this.z1m_1 + this.b1n_1);
        tmp_0 = ptDst_0;
        break;
      case 6:
        ptDst_0.q1o(x * this.w1m_1 + y * this.y1m_1, x * this.x1m_1 + y * this.z1m_1);
        tmp_0 = ptDst_0;
        break;
      case 5:
        ptDst_0.q1o(y * this.y1m_1 + this.a1n_1, x * this.x1m_1 + this.b1n_1);
        tmp_0 = ptDst_0;
        break;
      case 4:
        ptDst_0.q1o(y * this.y1m_1, x * this.x1m_1);
        tmp_0 = ptDst_0;
        break;
      case 3:
        ptDst_0.q1o(x * this.w1m_1 + this.a1n_1, y * this.z1m_1 + this.b1n_1);
        tmp_0 = ptDst_0;
        break;
      case 2:
        ptDst_0.q1o(x * this.w1m_1, y * this.z1m_1);
        tmp_0 = ptDst_0;
        break;
      case 1:
        ptDst_0.q1o(x + this.a1n_1, y + this.b1n_1);
        tmp_0 = ptDst_0;
        break;
      case 0:
        ptDst_0.q1o(x, y);
        tmp_0 = ptDst_0;
        break;
      default:
        stateError(this);
        tmp_0 = null;
        break;
    }
    return tmp_0;
  }
  r1o(srcPts, srcOff, dstPts, dstOff, numPts) {
    var srcOff_0 = srcOff;
    var dstOff_0 = dstOff;
    var numPts_0 = numPts;
    if (equals(dstPts, srcPts) && dstOff_0 > srcOff_0 && dstOff_0 < (srcOff_0 + imul_0(numPts_0, 2) | 0)) {
      arraycopy_0(srcPts, srcOff_0, dstPts, dstOff_0, imul_0(numPts_0, 2));
      srcOff_0 = dstOff_0;
    }
    var M12;
    var M11;
    var M10;
    var M02;
    var M01;
    var M00;
    switch (this.c1n_1) {
      case 7:
        M00 = this.w1m_1;
        M01 = this.y1m_1;
        M02 = this.a1n_1;
        M10 = this.x1m_1;
        M11 = this.z1m_1;
        M12 = this.b1n_1;
        $l$loop: while (true) {
          numPts_0 = numPts_0 - 1 | 0;
          if (!(numPts_0 >= 0)) {
            break $l$loop;
          }
          var _unary__edvuaz = srcOff_0;
          srcOff_0 = _unary__edvuaz + 1 | 0;
          var x = srcPts[_unary__edvuaz];
          var _unary__edvuaz_0 = srcOff_0;
          srcOff_0 = _unary__edvuaz_0 + 1 | 0;
          var y = srcPts[_unary__edvuaz_0];
          var _unary__edvuaz_1 = dstOff_0;
          dstOff_0 = _unary__edvuaz_1 + 1 | 0;
          dstPts[_unary__edvuaz_1] = M00 * x + M01 * y + M02;
          var _unary__edvuaz_2 = dstOff_0;
          dstOff_0 = _unary__edvuaz_2 + 1 | 0;
          dstPts[_unary__edvuaz_2] = M10 * x + M11 * y + M12;
        }

        return Unit_instance;
      case 6:
        M00 = this.w1m_1;
        M01 = this.y1m_1;
        M10 = this.x1m_1;
        M11 = this.z1m_1;
        $l$loop_0: while (true) {
          numPts_0 = numPts_0 - 1 | 0;
          if (!(numPts_0 >= 0)) {
            break $l$loop_0;
          }
          var _unary__edvuaz_3 = srcOff_0;
          srcOff_0 = _unary__edvuaz_3 + 1 | 0;
          var x_0 = srcPts[_unary__edvuaz_3];
          var _unary__edvuaz_4 = srcOff_0;
          srcOff_0 = _unary__edvuaz_4 + 1 | 0;
          var y_0 = srcPts[_unary__edvuaz_4];
          var _unary__edvuaz_5 = dstOff_0;
          dstOff_0 = _unary__edvuaz_5 + 1 | 0;
          dstPts[_unary__edvuaz_5] = M00 * x_0 + M01 * y_0;
          var _unary__edvuaz_6 = dstOff_0;
          dstOff_0 = _unary__edvuaz_6 + 1 | 0;
          dstPts[_unary__edvuaz_6] = M10 * x_0 + M11 * y_0;
        }

        return Unit_instance;
      case 5:
        M01 = this.y1m_1;
        M02 = this.a1n_1;
        M10 = this.x1m_1;
        M12 = this.b1n_1;
        $l$loop_1: while (true) {
          numPts_0 = numPts_0 - 1 | 0;
          if (!(numPts_0 >= 0)) {
            break $l$loop_1;
          }
          var _unary__edvuaz_7 = srcOff_0;
          srcOff_0 = _unary__edvuaz_7 + 1 | 0;
          var x_1 = srcPts[_unary__edvuaz_7];
          var _unary__edvuaz_8 = dstOff_0;
          dstOff_0 = _unary__edvuaz_8 + 1 | 0;
          var _unary__edvuaz_9 = srcOff_0;
          srcOff_0 = _unary__edvuaz_9 + 1 | 0;
          dstPts[_unary__edvuaz_8] = M01 * srcPts[_unary__edvuaz_9] + M02;
          var _unary__edvuaz_10 = dstOff_0;
          dstOff_0 = _unary__edvuaz_10 + 1 | 0;
          dstPts[_unary__edvuaz_10] = M10 * x_1 + M12;
        }

        return Unit_instance;
      case 4:
        M01 = this.y1m_1;
        M10 = this.x1m_1;
        $l$loop_2: while (true) {
          numPts_0 = numPts_0 - 1 | 0;
          if (!(numPts_0 >= 0)) {
            break $l$loop_2;
          }
          var _unary__edvuaz_11 = srcOff_0;
          srcOff_0 = _unary__edvuaz_11 + 1 | 0;
          var x_2 = srcPts[_unary__edvuaz_11];
          var _unary__edvuaz_12 = dstOff_0;
          dstOff_0 = _unary__edvuaz_12 + 1 | 0;
          var _unary__edvuaz_13 = srcOff_0;
          srcOff_0 = _unary__edvuaz_13 + 1 | 0;
          dstPts[_unary__edvuaz_12] = M01 * srcPts[_unary__edvuaz_13];
          var _unary__edvuaz_14 = dstOff_0;
          dstOff_0 = _unary__edvuaz_14 + 1 | 0;
          dstPts[_unary__edvuaz_14] = M10 * x_2;
        }

        return Unit_instance;
      case 3:
        M00 = this.w1m_1;
        M02 = this.a1n_1;
        M11 = this.z1m_1;
        M12 = this.b1n_1;
        $l$loop_3: while (true) {
          numPts_0 = numPts_0 - 1 | 0;
          if (!(numPts_0 >= 0)) {
            break $l$loop_3;
          }
          var _unary__edvuaz_15 = dstOff_0;
          dstOff_0 = _unary__edvuaz_15 + 1 | 0;
          var _unary__edvuaz_16 = srcOff_0;
          srcOff_0 = _unary__edvuaz_16 + 1 | 0;
          dstPts[_unary__edvuaz_15] = M00 * srcPts[_unary__edvuaz_16] + M02;
          var _unary__edvuaz_17 = dstOff_0;
          dstOff_0 = _unary__edvuaz_17 + 1 | 0;
          var _unary__edvuaz_18 = srcOff_0;
          srcOff_0 = _unary__edvuaz_18 + 1 | 0;
          dstPts[_unary__edvuaz_17] = M11 * srcPts[_unary__edvuaz_18] + M12;
        }

        return Unit_instance;
      case 2:
        M00 = this.w1m_1;
        M11 = this.z1m_1;
        $l$loop_4: while (true) {
          numPts_0 = numPts_0 - 1 | 0;
          if (!(numPts_0 >= 0)) {
            break $l$loop_4;
          }
          var _unary__edvuaz_19 = dstOff_0;
          dstOff_0 = _unary__edvuaz_19 + 1 | 0;
          var _unary__edvuaz_20 = srcOff_0;
          srcOff_0 = _unary__edvuaz_20 + 1 | 0;
          dstPts[_unary__edvuaz_19] = M00 * srcPts[_unary__edvuaz_20];
          var _unary__edvuaz_21 = dstOff_0;
          dstOff_0 = _unary__edvuaz_21 + 1 | 0;
          var _unary__edvuaz_22 = srcOff_0;
          srcOff_0 = _unary__edvuaz_22 + 1 | 0;
          dstPts[_unary__edvuaz_21] = M11 * srcPts[_unary__edvuaz_22];
        }

        return Unit_instance;
      case 1:
        M02 = this.a1n_1;
        M12 = this.b1n_1;
        $l$loop_5: while (true) {
          numPts_0 = numPts_0 - 1 | 0;
          if (!(numPts_0 >= 0)) {
            break $l$loop_5;
          }
          var _unary__edvuaz_23 = dstOff_0;
          dstOff_0 = _unary__edvuaz_23 + 1 | 0;
          var _unary__edvuaz_24 = srcOff_0;
          srcOff_0 = _unary__edvuaz_24 + 1 | 0;
          dstPts[_unary__edvuaz_23] = srcPts[_unary__edvuaz_24] + M02;
          var _unary__edvuaz_25 = dstOff_0;
          dstOff_0 = _unary__edvuaz_25 + 1 | 0;
          var _unary__edvuaz_26 = srcOff_0;
          srcOff_0 = _unary__edvuaz_26 + 1 | 0;
          dstPts[_unary__edvuaz_25] = srcPts[_unary__edvuaz_26] + M12;
        }

        return Unit_instance;
      case 0:
        if (!equals(srcPts, dstPts) || !(srcOff_0 === dstOff_0)) {
          arraycopy_0(srcPts, srcOff_0, dstPts, dstOff_0, imul_0(numPts_0, 2));
        }

        return Unit_instance;
      default:
        stateError(this);
        return Unit_instance;
    }
  }
  s1o(pSrc) {
    var tmp;
    if (pSrc == null) {
      tmp = null;
    } else {
      tmp = Double_1.y1o(pSrc, this);
    }
    return tmp;
  }
  hashCode() {
    var bits = toRawBits(this.w1m_1);
    // Inline function 'kotlin.Long.times' call
    bits = bits.j3(toLong(31)).h3(toRawBits(this.y1m_1));
    // Inline function 'kotlin.Long.times' call
    bits = bits.j3(toLong(31)).h3(toRawBits(this.a1n_1));
    // Inline function 'kotlin.Long.times' call
    bits = bits.j3(toLong(31)).h3(toRawBits(this.x1m_1));
    // Inline function 'kotlin.Long.times' call
    bits = bits.j3(toLong(31)).h3(toRawBits(this.z1m_1));
    // Inline function 'kotlin.Long.times' call
    bits = bits.j3(toLong(31)).h3(toRawBits(this.b1n_1));
    return bits.l1() ^ bits.r3(32).l1();
  }
  equals(obj) {
    if (!(obj instanceof AffineTransform)) {
      return false;
    }
    return this.w1m_1 === obj.w1m_1 && this.y1m_1 === obj.y1m_1 && this.a1n_1 === obj.a1n_1 && this.x1m_1 === obj.x1m_1 && this.z1m_1 === obj.z1m_1 && this.b1n_1 === obj.b1n_1;
  }
  toString() {
    return 'AffineTransform[[' + _matround(Companion_getInstance_32(), this.w1m_1) + ', ' + _matround(Companion_getInstance_32(), this.y1m_1) + ', ' + _matround(Companion_getInstance_32(), this.a1n_1) + '], [' + _matround(Companion_getInstance_32(), this.x1m_1) + ', ' + _matround(Companion_getInstance_32(), this.z1m_1) + ', ' + _matround(Companion_getInstance_32(), this.b1n_1) + ']]';
  }
}
class Companion_33 {
  z1o(angle) {
    var angle_0 = angle;
    if (angle_0 > 180.0) {
      if (angle_0 <= 180.0 + 360.0) {
        angle_0 = angle_0 - 360.0;
      } else {
        angle_0 = this.a1p(angle_0, 360.0);
        if (angle_0 === -180.0) {
          angle_0 = 180.0;
        }
      }
    } else if (angle_0 <= -180.0) {
      if (angle_0 > -180.0 - 360.0) {
        angle_0 = angle_0 + 360.0;
      } else {
        angle_0 = this.a1p(angle_0, 360.0);
        if (angle_0 === -180.0) {
          angle_0 = 180.0;
        }
      }
    }
    return angle_0;
  }
  a1p(f1, f2) {
    // Inline function 'kotlin.math.abs' call
    var x = f1 % f2;
    var r = Math.abs(x);
    var tmp;
    var tmp_0;
    if (isNaN_0(r) || r === f2) {
      tmp_0 = true;
    } else {
      // Inline function 'kotlin.math.abs' call
      tmp_0 = r <= Math.abs(f2) / 2.0;
    }
    if (tmp_0) {
      tmp = r;
    } else {
      // Inline function 'kotlin.math.sign' call
      tmp = sign(f1) * (r - f2);
    }
    return tmp;
  }
}
class Arc2D {}
class Double {
  w1l() {
    return this.b1p_1;
  }
  x1l() {
    return this.c1p_1;
  }
  cm() {
    return this.d1p_1;
  }
  dm() {
    return this.e1p_1;
  }
  i1p() {
    return this.h1p_1;
  }
  static j1p(bounds, start, extent, type) {
    var $this = createThis(this);
    init_org_mkui_geom_Arc2D_Double($this);
    $this.b1p_1 = bounds.w1l();
    $this.c1p_1 = bounds.x1l();
    $this.d1p_1 = bounds.cm();
    $this.e1p_1 = bounds.dm();
    $this.f1p_1 = start;
    $this.g1p_1 = extent;
    $this.h1p_1 = type;
    return $this;
  }
  y1l() {
    return this.k1p();
  }
  k1p() {
    if (this.l1p()) {
      return Double_3.p1m(this.b1p_1, this.c1p_1, this.d1p_1, this.e1p_1);
    }
    var x1;
    var y1;
    var x2;
    var y2;
    if (this.h1p_1 === 2) {
      y2 = 0.0;
      x2 = y2;
      y1 = x2;
      x1 = y1;
    } else {
      y1 = 1.0;
      x1 = y1;
      y2 = -1.0;
      x2 = y2;
    }
    var angle = 0.0;
    var inductionVariable = 0;
    if (inductionVariable <= 5)
      $l$loop: do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        if (i < 4) {
          angle = angle + 90.0;
          if (!this.o1p(angle)) {
            continue $l$loop;
          }
        } else if (i === 4) {
          angle = this.n1p();
        } else {
          angle = angle + this.m1p();
        }
        var rads = convertDegreesToRadians(-angle);
        // Inline function 'kotlin.math.cos' call
        var xe = Math.cos(rads);
        // Inline function 'kotlin.math.min' call
        var a = x1;
        x1 = Math.min(a, xe);
        // Inline function 'kotlin.math.sin' call
        var ye = Math.sin(rads);
        // Inline function 'kotlin.math.min' call
        var a_0 = y1;
        y1 = Math.min(a_0, ye);
        // Inline function 'kotlin.math.max' call
        var a_1 = x2;
        x2 = Math.max(a_1, xe);
        // Inline function 'kotlin.math.max' call
        var a_2 = y2;
        y2 = Math.max(a_2, ye);
      }
       while (inductionVariable <= 5);
    var w = this.d1p_1;
    var h = this.e1p_1;
    x2 = (x2 - x1) * 0.5 * w;
    y2 = (y2 - y1) * 0.5 * h;
    x1 = this.b1p_1 + (x1 * 0.5 + 0.5) * w;
    y1 = this.c1p_1 + (y1 * 0.5 + 0.5) * h;
    return Double_3.p1m(x1, y1, x2, y2);
  }
  l1p() {
    return this.d1p_1 <= 0.0 || this.e1p_1 <= 0.0;
  }
  z1l(p) {
    var x = p.w1l();
    var y = p.x1l();
    var ellw = this.d1p_1;
    if (ellw <= 0.0) {
      return false;
    }
    var normx = (x - x) / ellw - 0.5;
    var ellh = this.e1p_1;
    if (ellh <= 0.0) {
      return false;
    }
    var normy = (y - y) / ellh - 0.5;
    var distSq = normx * normx + normy * normy;
    if (distSq >= 0.25) {
      return false;
    }
    // Inline function 'kotlin.math.abs' call
    var x_0 = this.m1p();
    var angExt = Math.abs(x_0);
    if (angExt >= 360.0) {
      return true;
    }
    // Inline function 'kotlin.math.atan2' call
    var tmp$ret$1 = Math.atan2(normy, normx);
    var inarc = this.o1p(-convertRadiansToDegrees(tmp$ret$1));
    if (this.h1p_1 === 2) {
      return inarc;
    }
    if (inarc) {
      if (angExt >= 180.0) {
        return true;
      }
    } else {
      if (angExt <= 180.0) {
        return false;
      }
    }
    var angle = convertDegreesToRadians(-this.n1p());
    // Inline function 'kotlin.math.cos' call
    var x_1 = angle;
    var x1 = Math.cos(x_1);
    // Inline function 'kotlin.math.sin' call
    var x_2 = angle;
    var y1 = Math.sin(x_2);
    angle = angle + convertDegreesToRadians(-this.m1p());
    // Inline function 'kotlin.math.cos' call
    var x_3 = angle;
    var x2 = Math.cos(x_3);
    // Inline function 'kotlin.math.sin' call
    var x_4 = angle;
    var y2 = Math.sin(x_4);
    var inside = imul_0(Companion_instance_41.p1p(x1, y1, x2, y2, 2 * normx, 2 * normy), Companion_instance_41.p1p(x1, y1, x2, y2, 0.0, 0.0)) >= 0;
    return !(inarc === inside);
  }
  b1m(r) {
    var x = r.w1l();
    var y = r.x1l();
    var w = r.cm();
    var h = r.dm();
    var aw = this.d1p_1;
    var ah = this.e1p_1;
    if (w <= 0 || h <= 0 || aw <= 0 || ah <= 0) {
      return false;
    }
    var ext = this.m1p();
    if (ext === 0.0) {
      return false;
    }
    var ax = x;
    var ay = y;
    var axw = ax + aw;
    var ayh = ay + ah;
    var xw = x + w;
    var yh = y + h;
    if (x >= axw || y >= ayh || xw <= ax || yh <= ay) {
      return false;
    }
    var axc = this.a1m();
    var ayc = this.c1m();
    var sp = this.q1p();
    var ep = this.r1p();
    var sx = sp.w1l();
    var sy = sp.x1l();
    var ex = ep.w1l();
    var ey = ep.x1l();
    if (ayc >= y && ayc <= yh) {
      if (sx < xw && ex < xw && axc < xw && axw > x && this.o1p(0.0) || (sx > x && ex > x && axc > x && ax < xw && this.o1p(180.0))) {
        return true;
      }
    }
    if (axc >= x && axc <= xw) {
      if (sy > y && ey > y && ayc > y && ay < yh && this.o1p(90.0) || (sy < yh && ey < yh && ayc < yh && ayh > y && this.o1p(270.0))) {
        return true;
      }
    }
    var rect = Double_3.p1m(x, y, w, h);
    var tmp;
    if (this.h1p_1 === 2) {
      tmp = true;
    } else {
      // Inline function 'kotlin.math.abs' call
      tmp = Math.abs(ext) > 180;
    }
    if (tmp) {
      if (rect.q1m(axc, ayc, sx, sy) || rect.q1m(axc, ayc, ex, ey)) {
        return true;
      }
    } else {
      if (rect.q1m(sx, sy, ex, ey)) {
        return true;
      }
    }
    return this.z1l(Double_2.s1p(x, y)) || this.z1l(Double_2.s1p(x + w, y)) || this.z1l(Double_2.s1p(x, y + h)) || this.z1l(Double_2.s1p(x + w, y + h));
  }
  d1m() {
    return this.e1m(null);
  }
  e1m(at) {
    return new ArcIterator(this, at);
  }
  a1m() {
    return this.b1p_1 + this.d1p_1 / 2.0;
  }
  c1m() {
    return this.c1p_1 + this.e1p_1 / 2.0;
  }
  n1p() {
    return this.f1p_1;
  }
  m1p() {
    return this.g1p_1;
  }
  q1p() {
    return this.t1p();
  }
  t1p() {
    var angle = convertDegreesToRadians(-this.n1p());
    // Inline function 'kotlin.math.cos' call
    var tmp$ret$0 = Math.cos(angle);
    var x = this.b1p_1 + (tmp$ret$0 * 0.5 + 0.5) * this.d1p_1;
    // Inline function 'kotlin.math.sin' call
    var tmp$ret$1 = Math.sin(angle);
    var y = this.c1p_1 + (tmp$ret$1 * 0.5 + 0.5) * this.e1p_1;
    return Double_2.s1p(x, y);
  }
  r1p() {
    return this.u1p();
  }
  u1p() {
    var angle = convertDegreesToRadians(-this.n1p() - this.m1p());
    // Inline function 'kotlin.math.cos' call
    var tmp$ret$0 = Math.cos(angle);
    var x = this.b1p_1 + (tmp$ret$0 * 0.5 + 0.5) * this.d1p_1;
    // Inline function 'kotlin.math.sin' call
    var tmp$ret$1 = Math.sin(angle);
    var y = this.c1p_1 + (tmp$ret$1 * 0.5 + 0.5) * this.e1p_1;
    return Double_2.s1p(x, y);
  }
  o1p(angle) {
    var angle_0 = angle;
    var angExt = this.m1p();
    var backwards = angExt < 0.0;
    if (backwards) {
      angExt = -angExt;
    }
    if (angExt >= 360.0) {
      return true;
    }
    angle_0 = Companion_instance_33.z1o(angle_0) - Companion_instance_33.z1o(this.n1p());
    if (backwards) {
      angle_0 = -angle_0;
    }
    if (angle_0 < 0.0) {
      angle_0 = angle_0 + 360.0;
    }
    return angle_0 >= 0.0 && angle_0 < angExt;
  }
}
class Companion_34 {}
class ArcIterator {
  constructor(a, at) {
    this.b1q_1 = 0.0;
    this.c1q_1 = 0.0;
    this.d1q_1 = 0;
    this.e1q_1 = 0;
    this.f1q_1 = 0;
    this.x1p_1 = a.cm() / 2;
    this.y1p_1 = a.dm() / 2;
    this.v1p_1 = a.w1l() + this.x1p_1;
    this.w1p_1 = a.x1l() + this.y1p_1;
    this.z1p_1 = -convertDegreesToRadians(a.n1p());
    this.a1q_1 = at;
    var ext = -a.m1p();
    if (ext >= 360.0 || ext <= -360) {
      this.e1q_1 = 4;
      this.b1q_1 = 3.141592653589793 / 2;
      this.c1q_1 = 0.5522847498307933;
      if (ext < 0) {
        this.b1q_1 = -this.b1q_1;
        this.c1q_1 = -this.c1q_1;
      }
    } else {
      var tmp = this;
      // Inline function 'kotlin.math.abs' call
      // Inline function 'kotlin.math.ceil' call
      var x = Math.abs(ext) / 90.0;
      var tmp$ret$1 = Math.ceil(x);
      tmp.e1q_1 = numberToInt(tmp$ret$1);
      this.b1q_1 = convertDegreesToRadians(ext / this.e1q_1);
      this.c1q_1 = btan(Companion_instance_34, this.b1q_1);
      if (this.c1q_1 === 0.0) {
        this.e1q_1 = 0;
      }
    }
    switch (a.i1p()) {
      case 0:
        this.f1q_1 = 0;
        break;
      case 1:
        this.f1q_1 = 1;
        break;
      case 2:
        this.f1q_1 = 2;
        break;
    }
    if (this.x1p_1 < 0 || this.y1p_1 < 0) {
      this.f1q_1 = -1;
      this.e1q_1 = this.f1q_1;
    }
  }
  g1q() {
    return 1;
  }
  b17() {
    return this.d1q_1 > (this.e1q_1 + this.f1q_1 | 0);
  }
  h1q() {
    this.d1q_1 = this.d1q_1 + 1 | 0;
  }
  i1q(coords) {
    if (this.b17()) {
      throw NoSuchElementException.s('arc iterator out of bounds');
    }
    var angle = this.z1p_1;
    if (this.d1q_1 === 0) {
      // Inline function 'kotlin.math.cos' call
      var x = angle;
      var tmp$ret$0 = Math.cos(x);
      coords[0] = this.v1p_1 + tmp$ret$0 * this.x1p_1;
      // Inline function 'kotlin.math.sin' call
      var x_0 = angle;
      var tmp$ret$1 = Math.sin(x_0);
      coords[1] = this.w1p_1 + tmp$ret$1 * this.y1p_1;
      var tmp0_safe_receiver = this.a1q_1;
      if (tmp0_safe_receiver == null)
        null;
      else {
        tmp0_safe_receiver.r1o(coords, 0, coords, 0, 1);
      }
      return 0;
    }
    if (this.d1q_1 > this.e1q_1) {
      if (this.d1q_1 === (this.e1q_1 + this.f1q_1 | 0)) {
        return 4;
      }
      coords[0] = this.v1p_1;
      coords[1] = this.w1p_1;
      var tmp1_safe_receiver = this.a1q_1;
      if (tmp1_safe_receiver == null)
        null;
      else {
        tmp1_safe_receiver.r1o(coords, 0, coords, 0, 1);
      }
      return 1;
    }
    angle = angle + this.b1q_1 * (this.d1q_1 - 1 | 0);
    // Inline function 'kotlin.math.cos' call
    var x_1 = angle;
    var relx = Math.cos(x_1);
    // Inline function 'kotlin.math.sin' call
    var x_2 = angle;
    var rely = Math.sin(x_2);
    coords[0] = this.v1p_1 + (relx - this.c1q_1 * rely) * this.x1p_1;
    coords[1] = this.w1p_1 + (rely + this.c1q_1 * relx) * this.y1p_1;
    angle = angle + this.b1q_1;
    // Inline function 'kotlin.math.cos' call
    var x_3 = angle;
    relx = Math.cos(x_3);
    // Inline function 'kotlin.math.sin' call
    var x_4 = angle;
    rely = Math.sin(x_4);
    coords[2] = this.v1p_1 + (relx + this.c1q_1 * rely) * this.x1p_1;
    coords[3] = this.w1p_1 + (rely - this.c1q_1 * relx) * this.y1p_1;
    coords[4] = this.v1p_1 + relx * this.x1p_1;
    coords[5] = this.w1p_1 + rely * this.y1p_1;
    var tmp2_safe_receiver = this.a1q_1;
    if (tmp2_safe_receiver == null)
      null;
    else {
      tmp2_safe_receiver.r1o(coords, 0, coords, 0, 3);
    }
    return 3;
  }
}
class AreaIterator {
  constructor(curves, at) {
    this.b1r_1 = 0;
    this.c1r_1 = null;
    this.d1r_1 = null;
    this.a1r_1 = curves;
    this.z1q_1 = at;
    if (curves.a1() >= 1) {
      var tmp = this;
      var tmp_0 = curves.b1(0);
      tmp.d1r_1 = tmp_0 instanceof Curve ? tmp_0 : THROW_CCE();
    }
  }
  g1q() {
    return 1;
  }
  b17() {
    return this.c1r_1 == null && this.d1r_1 == null;
  }
  h1q() {
    if (!(this.c1r_1 == null)) {
      this.c1r_1 = null;
    } else {
      this.c1r_1 = this.d1r_1;
      this.b1r_1 = this.b1r_1 + 1 | 0;
      if (this.b1r_1 < this.a1r_1.a1()) {
        this.d1r_1 = this.a1r_1.b1(this.b1r_1);
        if (!(ensureNotNull(this.d1r_1).e1r() === 0) && ensureNotNull(this.c1r_1).f1r() === ensureNotNull(this.d1r_1).w1q() && ensureNotNull(this.c1r_1).g1r() === ensureNotNull(this.d1r_1).x1q()) {
          this.c1r_1 = null;
        }
      } else {
        this.d1r_1 = null;
      }
    }
  }
  i1q(coords) {
    var segtype;
    var numpoints;
    if (!(this.c1r_1 == null)) {
      if (this.d1r_1 == null || ensureNotNull(this.d1r_1).e1r() === 0) {
        return 4;
      }
      coords[0] = ensureNotNull(this.d1r_1).w1q();
      coords[1] = ensureNotNull(this.d1r_1).x1q();
      segtype = 1;
      numpoints = 1;
    } else if (this.d1r_1 == null) {
      throw NoSuchElementException.s('area iterator out of bounds');
    } else {
      segtype = ensureNotNull(this.d1r_1).h1r(coords);
      numpoints = ensureNotNull(this.d1r_1).e1r();
      if (numpoints === 0) {
        numpoints = 1;
      }
    }
    if (!(this.z1q_1 == null)) {
      this.z1q_1.r1o(coords, 0, coords, 0, numpoints);
    }
    return segtype;
  }
}
class Companion_35 {
  constructor() {
    Companion_instance_35 = this;
    this.r1q_1 = ArrayList.e1();
  }
}
class Area {
  static i1r() {
    Companion_getInstance_35();
    var $this = createThis(this);
    init_corg_mkui_geom_Area($this);
    $this.t1q_1 = Companion_getInstance_35().r1q_1;
    return $this;
  }
  static j1r(s) {
    Companion_getInstance_35();
    var $this = createThis(this);
    init_corg_mkui_geom_Area($this);
    var tmp = $this;
    var tmp_0;
    if (s instanceof Area) {
      tmp_0 = (s instanceof Area ? s : THROW_CCE()).t1q_1;
    } else {
      tmp_0 = pathToCurves(Companion_getInstance_35(), s.g1m());
    }
    tmp.t1q_1 = tmp_0;
    return $this;
  }
  k1r(rhs) {
    this.t1q_1 = (new IntOp()).s1q(ensureNotNull(this.t1q_1), ensureNotNull(rhs.t1q_1));
    invalidateBounds(this);
  }
  y1l() {
    return getCachedBounds(this).y1l();
  }
  z1l(p) {
    return this.v1m(p.w1l(), p.x1l());
  }
  v1m(x, y) {
    if (!getCachedBounds(this).v1m(x, y)) {
      return false;
    }
    var crossings = 0;
    var _iterator__ex2g4s = ensureNotNull(this.t1q_1).x();
    while (_iterator__ex2g4s.y()) {
      var c = _iterator__ex2g4s.z();
      crossings = crossings + c.l1r(x, y) | 0;
    }
    return (crossings & 1) === 1;
  }
  b1m(r) {
    return this.u1m(r.w1l(), r.x1l(), r.cm(), r.dm());
  }
  u1m(x, y, w, h) {
    if (w < 0 || h < 0) {
      return false;
    }
    if (!getCachedBounds(this).u1m(x, y, w, h)) {
      return false;
    }
    var c = Companion_instance_37.n1r(ensureNotNull(this.t1q_1), x, y, x + w, y + h);
    return c == null || !c.l1p();
  }
  d1m() {
    return new AreaIterator(ensureNotNull(this.t1q_1), null);
  }
  e1m(at) {
    return new AreaIterator(ensureNotNull(this.t1q_1), at);
  }
  equals(other) {
    if (other === this) {
      return true;
    }
    if (other == null) {
      return false;
    }
    if (other instanceof Area) {
      var c = (new XorOp()).s1q(ensureNotNull(this.t1q_1), ensureNotNull(other.t1q_1));
      return c.c1();
    } else {
      return false;
    }
  }
}
class sam$kotlin_Comparator$0_0 {
  constructor(function_0) {
    this.v1r_1 = function_0;
  }
  jf(a, b) {
    return this.v1r_1(a, b);
  }
  compare(a, b) {
    return this.jf(a, b);
  }
  b4() {
    return this.v1r_1;
  }
  equals(other) {
    var tmp;
    if (!(other == null) ? isInterface(other, Comparator) : false) {
      var tmp_0;
      if (!(other == null) ? isInterface(other, FunctionAdapter) : false) {
        tmp_0 = equals(this.b4(), other.b4());
      } else {
        tmp_0 = false;
      }
      tmp = tmp_0;
    } else {
      tmp = false;
    }
    return tmp;
  }
  hashCode() {
    return hashCode(this.b4());
  }
}
class AreaOp {
  constructor() {
    Companion_getInstance_36();
  }
  s1q(left, right) {
    var edges = ArrayList.e1();
    addEdges(Companion_getInstance_36(), edges, left, 0);
    addEdges(Companion_getInstance_36(), edges, right, 1);
    var curves = pruneEdges(this, edges);
    if (false) {
      println('result: ');
      var numcurves = curves.a1();
      // Inline function 'kotlin.collections.toTypedArray' call
      var curvelist = copyToArray(curves);
      var inductionVariable = 0;
      if (inductionVariable < numcurves)
        do {
          var i = inductionVariable;
          inductionVariable = inductionVariable + 1 | 0;
          println('curvelist[' + i + '] = ' + curvelist[i].toString());
        }
         while (inductionVariable < numcurves);
    }
    return curves;
  }
}
class CAGOp extends AreaOp {
  constructor() {
    super();
    this.h1t_1 = false;
    this.i1t_1 = false;
    this.j1t_1 = false;
  }
  t1s() {
    this.h1t_1 = false;
    this.i1t_1 = false;
    this.j1t_1 = false;
  }
  u1s(e) {
    if (e.x1r_1 === 0) {
      this.h1t_1 = !this.h1t_1;
    } else {
      this.i1t_1 = !this.i1t_1;
    }
    var newClass = this.k1t(this.h1t_1, this.i1t_1);
    if (this.j1t_1 === newClass) {
      return 0;
    }
    this.j1t_1 = newClass;
    return newClass ? 1 : -1;
  }
  v1s() {
    return this.j1t_1 ? 1 : -1;
  }
}
class IntOp extends CAGOp {
  k1t(inLeft, inRight) {
    return inLeft && inRight;
  }
}
class XorOp extends CAGOp {
  k1t(inLeft, inRight) {
    return !(inLeft === inRight);
  }
}
class NZWindOp extends AreaOp {
  constructor() {
    super();
    this.r1t_1 = 0;
  }
  t1s() {
    this.r1t_1 = 0;
  }
  u1s(e) {
    var newCount = this.r1t_1;
    var type = newCount === 0 ? 1 : 0;
    newCount = newCount + e.w1r_1.v1q_1 | 0;
    this.r1t_1 = newCount;
    return newCount === 0 ? -1 : type;
  }
  v1s() {
    return this.r1t_1 === 0 ? -1 : 1;
  }
}
class EOWindOp extends AreaOp {
  constructor() {
    super();
    this.s1t_1 = false;
  }
  t1s() {
    this.s1t_1 = false;
  }
  u1s(e) {
    var newInside = !this.s1t_1;
    this.s1t_1 = newInside;
    return newInside ? 1 : -1;
  }
  v1s() {
    return this.s1t_1 ? 1 : -1;
  }
}
class Companion_36 {
  constructor() {
    Companion_instance_36 = this;
    this.g1s_1 = 0;
    this.h1s_1 = 1;
    this.i1s_1 = 0;
    this.j1s_1 = 1;
    this.k1s_1 = -1;
    this.l1s_1 = 1;
    this.m1s_1 = -1;
    var tmp = this;
    var tmp_0 = AreaOp$Companion$YXTopComparator$lambda;
    tmp.n1s_1 = new sam$kotlin_Comparator$0_0(tmp_0);
    var tmp_1 = this;
    // Inline function 'kotlin.arrayOfNulls' call
    tmp_1.o1s_1 = fillArrayVal(Array(2), null);
    var tmp_2 = this;
    // Inline function 'kotlin.arrayOfNulls' call
    tmp_2.p1s_1 = fillArrayVal(Array(2), null);
  }
  r1s(subcurves, chains) {
    var numchains = chains.a1();
    if (numchains === 0) {
      return Unit_instance;
    }
    if (!((numchains & 1) === 0)) {
      throw UnsupportedOperationException.t9('Odd number of chains!');
    }
    // Inline function 'kotlin.collections.toTypedArray' call
    var endlist = copyToArray(chains);
    var i = 1;
    while (i < numchains) {
      var open = endlist[i - 1 | 0];
      var close = endlist[i];
      var subcurve = ensureNotNull(open).x1t(close);
      if (!(subcurve == null)) {
        subcurves.o(subcurve);
      }
      i = i + 2 | 0;
    }
    chains.o5();
  }
  e1t(subcurves, chains, links) {
    var numlinks = links.a1();
    var linklist;
    var tmp;
    if (numlinks === 0) {
      tmp = this.o1s_1;
    } else {
      if (!((numlinks & 1) === 0)) {
        throw UnsupportedOperationException.t9('Odd number of new curves!');
      }
      // Inline function 'kotlin.collections.toTypedArray' call
      var tmp$ret$0 = copyToArray(links);
      tmp = copyOf_0(tmp$ret$0, numlinks + 2 | 0);
    }
    linklist = tmp;
    var numchains = chains.a1();
    var endlist;
    var tmp_0;
    if (numchains === 0) {
      tmp_0 = this.p1s_1;
    } else {
      if (!((numchains & 1) === 0)) {
        throw UnsupportedOperationException.t9('Odd number of chains!');
      }
      // Inline function 'kotlin.collections.toTypedArray' call
      var tmp$ret$1 = copyToArray(chains);
      tmp_0 = copyOf_0(tmp$ret$1, numchains + 2 | 0);
    }
    endlist = tmp_0;
    chains.o5();
    var chain = endlist[0];
    var nextchain = endlist[1];
    var link = linklist[0];
    var nextlink = linklist[1];
    var curlink = 0;
    var curchain = 0;
    while (!(chain == null) || !(link == null)) {
      var connectchains = link == null;
      var connectlinks = chain == null;
      if (!connectchains && !connectlinks) {
        connectchains = ((curchain & 1) === 0 && ensureNotNull(chain).w1l() === ensureNotNull(nextchain).w1l());
        connectlinks = ((curlink & 1) === 0 && ensureNotNull(link).w1l() === ensureNotNull(nextlink).w1l());
        if (!connectchains && !connectlinks) {
          var cx = ensureNotNull(chain).w1l();
          var lx = ensureNotNull(link).w1l();
          connectchains = (!(nextchain == null) && cx < lx && this.y1t(nextchain.w1l(), lx, curchain));
          connectlinks = (!(nextlink == null) && lx < cx && this.y1t(nextlink.w1l(), cx, curlink));
        }
      }
      if (connectchains) {
        var subcurve = ensureNotNull(chain).x1t(nextchain);
        if (!(subcurve == null)) {
          subcurves.o(subcurve);
        }
        curchain = curchain + 2 | 0;
        chain = endlist[curchain];
        nextchain = endlist[curchain + 1 | 0];
      }
      if (connectlinks) {
        var openend = new ChainEnd(ensureNotNull(link), null);
        var closeend = new ChainEnd(ensureNotNull(nextlink), openend);
        openend.z1t(closeend);
        chains.o(openend);
        chains.o(closeend);
        curlink = curlink + 2 | 0;
        link = linklist[curlink];
        nextlink = linklist[curlink + 1 | 0];
      }
      if (!connectchains && !connectlinks) {
        ensureNotNull(chain).a1u(ensureNotNull(link));
        chains.o(chain);
        curchain = curchain + 1 | 0;
        chain = nextchain;
        nextchain = endlist[curchain + 1 | 0];
        curlink = curlink + 1 | 0;
        link = nextlink;
        nextlink = linklist[curlink + 1 | 0];
      }
    }
    if (!((chains.a1() & 1) === 0)) {
      println('Odd number of chains!');
    }
  }
  y1t(v1, v2, phase) {
    return (phase & 1) === 0 ? v1 <= v2 : v1 < v2;
  }
}
class ChainEnd {
  constructor(first, partner) {
    this.t1t_1 = first;
    this.u1t_1 = first;
    this.v1t_1 = partner;
    this.w1t_1 = first.z1s_1;
  }
  z1t(partner) {
    this.v1t_1 = partner;
  }
  x1t(that) {
    if (this.w1t_1 === 0 || ensureNotNull(that).w1t_1 === 0) {
      throw UnsupportedOperationException.t9('ChainEnd linked more than once!');
    }
    if (this.w1t_1 === that.w1t_1) {
      throw UnsupportedOperationException.t9('Linking chains of the same type!');
    }
    var enter;
    var exit;
    if (this.w1t_1 === 1) {
      enter = this;
      exit = that;
    } else {
      enter = that;
      exit = this;
    }
    this.w1t_1 = 0;
    that.w1t_1 = 0;
    enter.u1t_1.c1t_1 = exit.t1t_1;
    enter.u1t_1 = exit.u1t_1;
    if (equals(this.v1t_1, that)) {
      return enter.t1t_1;
    }
    var otherenter = exit.v1t_1;
    var otherexit = enter.v1t_1;
    ensureNotNull(otherenter).v1t_1 = otherexit;
    ensureNotNull(otherexit).v1t_1 = otherenter;
    if (enter.t1t_1.a1t_1 < otherenter.t1t_1.a1t_1) {
      enter.u1t_1.c1t_1 = otherenter.t1t_1;
      otherenter.t1t_1 = enter.t1t_1;
    } else {
      otherexit.u1t_1.c1t_1 = enter.t1t_1;
      otherexit.u1t_1 = enter.u1t_1;
    }
    return null;
  }
  a1u(newlink) {
    if (this.w1t_1 === 1) {
      this.u1t_1.c1t_1 = newlink;
      this.u1t_1 = newlink;
    } else {
      newlink.c1t_1 = this.t1t_1;
      this.t1t_1 = newlink;
    }
  }
  w1l() {
    var tmp;
    if (this.w1t_1 === 1) {
      tmp = this.u1t_1.b1u();
    } else {
      tmp = this.t1t_1.b1u();
    }
    return tmp;
  }
}
class Crossings {
  constructor(xLo, yLo, xHi, yHi) {
    this.o1r_1 = xLo;
    this.p1r_1 = yLo;
    this.q1r_1 = xHi;
    this.r1r_1 = yHi;
    this.s1r_1 = ArrayList.e1();
    this.t1r_1 = 0;
    this.u1r_1 = new Float64Array(10);
  }
  k1u() {
    println('Crossings [');
    println('  bounds = [' + this.p1r_1 + ', ' + this.r1r_1 + toString(_Char___init__impl__6a9atx(93)));
    var i = 0;
    while (i < this.t1r_1) {
      println('  [' + this.u1r_1[i] + ', ' + this.u1r_1[i + 1 | 0] + toString(_Char___init__impl__6a9atx(93)));
      i = i + 2 | 0;
    }
    println(']');
  }
  l1p() {
    return this.t1r_1 === 0;
  }
}
class EvenOdd extends Crossings {
  j1u(ystart, yend, direction) {
    var ystart_0 = ystart;
    var yend_0 = yend;
    if (ystart_0 >= yend_0) {
      return Unit_instance;
    }
    var from = 0;
    while (from < this.t1r_1 && ystart_0 > this.u1r_1[from + 1 | 0]) {
      from = from + 2 | 0;
    }
    var to = from;
    $l$loop_0: while (from < this.t1r_1) {
      var tmp = this.u1r_1;
      var _unary__edvuaz = from;
      from = _unary__edvuaz + 1 | 0;
      var yrlo = tmp[_unary__edvuaz];
      var tmp_0 = this.u1r_1;
      var _unary__edvuaz_0 = from;
      from = _unary__edvuaz_0 + 1 | 0;
      var yrhi = tmp_0[_unary__edvuaz_0];
      if (yend_0 < yrlo) {
        var tmp_1 = this.u1r_1;
        var _unary__edvuaz_1 = to;
        to = _unary__edvuaz_1 + 1 | 0;
        tmp_1[_unary__edvuaz_1] = ystart_0;
        var tmp_2 = this.u1r_1;
        var _unary__edvuaz_2 = to;
        to = _unary__edvuaz_2 + 1 | 0;
        tmp_2[_unary__edvuaz_2] = yend_0;
        ystart_0 = yrlo;
        yend_0 = yrhi;
        continue $l$loop_0;
      }
      var yll;
      var ylh;
      if (ystart_0 < yrlo) {
        yll = ystart_0;
        ylh = yrlo;
      } else {
        yll = yrlo;
        ylh = ystart_0;
      }
      var yhh;
      var yhl;
      if (yend_0 < yrhi) {
        yhl = yend_0;
        yhh = yrhi;
      } else {
        yhl = yrhi;
        yhh = yend_0;
      }
      if (ylh === yhl) {
        ystart_0 = yll;
        yend_0 = yhh;
      } else {
        if (ylh > yhl) {
          ystart_0 = yhl;
          yhl = ylh;
          ylh = ystart_0;
        }
        if (!(yll === ylh)) {
          var tmp_3 = this.u1r_1;
          var _unary__edvuaz_3 = to;
          to = _unary__edvuaz_3 + 1 | 0;
          tmp_3[_unary__edvuaz_3] = yll;
          var tmp_4 = this.u1r_1;
          var _unary__edvuaz_4 = to;
          to = _unary__edvuaz_4 + 1 | 0;
          tmp_4[_unary__edvuaz_4] = ylh;
        }
        ystart_0 = yhl;
        yend_0 = yhh;
      }
      if (ystart_0 >= yend_0) {
        break $l$loop_0;
      }
    }
    if (to < from && from < this.t1r_1) {
      arraycopy_0(this.u1r_1, from, this.u1r_1, to, this.t1r_1 - from | 0);
    }
    to = to + (this.t1r_1 - from | 0) | 0;
    if (ystart_0 < yend_0) {
      if (to >= this.u1r_1.length) {
        var newranges = new Float64Array(to + 10 | 0);
        arraycopy_0(this.u1r_1, 0, newranges, 0, to);
        this.u1r_1 = newranges;
      }
      var tmp_5 = this.u1r_1;
      var _unary__edvuaz_5 = to;
      to = _unary__edvuaz_5 + 1 | 0;
      tmp_5[_unary__edvuaz_5] = ystart_0;
      var tmp_6 = this.u1r_1;
      var _unary__edvuaz_6 = to;
      to = _unary__edvuaz_6 + 1 | 0;
      tmp_6[_unary__edvuaz_6] = yend_0;
    }
    this.t1r_1 = to;
  }
}
class Companion_37 {
  constructor() {
    this.m1r_1 = false;
  }
  n1r(curves, xlo, ylo, xhi, yhi) {
    var cross = new EvenOdd(xlo, ylo, xhi, yhi);
    var _iterator__ex2g4s = curves.x();
    while (_iterator__ex2g4s.y()) {
      var c = _iterator__ex2g4s.z();
      if (ensureNotNull(c).l1u(cross)) {
        return null;
      }
    }
    if (false) {
      cross.k1u();
    }
    return cross;
  }
}
class Companion_38 {
  constructor() {
    this.j1q_1 = 1;
    this.k1q_1 = -1;
    this.l1q_1 = -2147483648;
    this.m1q_1 = 0.001;
  }
  o1q(curves, x, y) {
    curves.o(new Order0(x, y));
  }
  n1q(curves, x0, y0, x1, y1) {
    if (y0 < y1) {
      curves.o(new Order1(x0, y0, x1, y1, 1));
    } else if (y0 > y1) {
      curves.o(new Order1(x1, y1, x0, y0, -1));
    }
  }
  p1q(curves, x0, y0, coords) {
    var y1 = coords[3];
    if (y0 > y1) {
      Companion_instance_42.m1u(curves, coords, coords[2], y1, coords[0], coords[1], x0, y0, -1);
    } else if (y0 === y1 && y0 === coords[1]) {
      return Unit_instance;
    } else {
      Companion_instance_42.m1u(curves, coords, x0, y0, coords[0], coords[1], coords[2], y1, 1);
    }
  }
  q1q(curves, x0, y0, coords) {
    var y1 = coords[5];
    if (y0 > y1) {
      Companion_instance_43.n1u(curves, coords, coords[4], y1, coords[2], coords[3], coords[0], coords[1], x0, y0, -1);
    } else if (y0 === y1 && y0 === coords[1] && y0 === coords[3]) {
      return Unit_instance;
    } else {
      Companion_instance_43.n1u(curves, coords, x0, y0, coords[0], coords[1], coords[2], coords[3], coords[4], y1, 1);
    }
  }
  o1u(px, py, x0, y0, x1, y1) {
    if (py < y0 && py < y1)
      return 0;
    if (py >= y0 && py >= y1)
      return 0;
    if (px >= x0 && px >= x1)
      return 0;
    if (px < x0 && px < x1)
      return y0 < y1 ? 1 : -1;
    var xintercept = x0 + (py - y0) * (x1 - x0) / (y1 - y0);
    if (px >= xintercept)
      return 0;
    return y0 < y1 ? 1 : -1;
  }
  p1u(px, py, x0, y0, xc, yc, x1, y1, level) {
    var xc_0 = xc;
    var yc_0 = yc;
    if (py < y0 && py < yc_0 && py < y1)
      return 0;
    if (py >= y0 && py >= yc_0 && py >= y1)
      return 0;
    if (px >= x0 && px >= xc_0 && px >= x1)
      return 0;
    if (px < x0 && px < xc_0 && px < x1) {
      if (py >= y0) {
        if (py < y1)
          return 1;
      } else {
        if (py >= y1)
          return -1;
      }
      return 0;
    }
    if (level > 52)
      return this.o1u(px, py, x0, y0, x1, y1);
    var x0c = (x0 + xc_0) / 2;
    var y0c = (y0 + yc_0) / 2;
    var xc1 = (xc_0 + x1) / 2;
    var yc1 = (yc_0 + y1) / 2;
    xc_0 = (x0c + xc1) / 2;
    yc_0 = (y0c + yc1) / 2;
    var tmp;
    if (isNaN_3(xc_0) || isNaN_3(yc_0)) {
      tmp = 0;
    } else {
      tmp = this.p1u(px, py, x0, y0, x0c, y0c, xc_0, yc_0, level + 1 | 0) + this.p1u(px, py, xc_0, yc_0, xc1, yc1, x1, y1, level + 1 | 0) | 0;
    }
    return tmp;
  }
  q1u(px, py, x0, y0, xc0, yc0, xc1, yc1, x1, y1, level) {
    var xc0_0 = xc0;
    var yc0_0 = yc0;
    var xc1_0 = xc1;
    var yc1_0 = yc1;
    if (py < y0 && py < yc0_0 && py < yc1_0 && py < y1)
      return 0;
    if (py >= y0 && py >= yc0_0 && py >= yc1_0 && py >= y1)
      return 0;
    if (px >= x0 && px >= xc0_0 && px >= xc1_0 && px >= x1)
      return 0;
    if (px < x0 && px < xc0_0 && px < xc1_0 && px < x1) {
      if (py >= y0) {
        if (py < y1)
          return 1;
      } else {
        if (py >= y1)
          return -1;
      }
      return 0;
    }
    if (level > 52)
      return this.o1u(px, py, x0, y0, x1, y1);
    var xmid = (xc0_0 + xc1_0) / 2;
    var ymid = (yc0_0 + yc1_0) / 2;
    xc0_0 = (x0 + xc0_0) / 2;
    yc0_0 = (y0 + yc0_0) / 2;
    xc1_0 = (xc1_0 + x1) / 2;
    yc1_0 = (yc1_0 + y1) / 2;
    var xc0m = (xc0_0 + xmid) / 2;
    var yc0m = (yc0_0 + ymid) / 2;
    var xmc1 = (xmid + xc1_0) / 2;
    var ymc1 = (ymid + yc1_0) / 2;
    xmid = (xc0m + xmc1) / 2;
    ymid = (yc0m + ymc1) / 2;
    var tmp;
    if (isNaN_3(xmid) || isNaN_3(ymid)) {
      tmp = 0;
    } else {
      tmp = this.q1u(px, py, x0, y0, xc0_0, yc0_0, xc0m, yc0m, xmid, ymid, level + 1 | 0) + this.q1u(px, py, xmid, ymid, xmc1, ymc1, xc1_0, yc1_0, x1, y1, level + 1 | 0) | 0;
    }
    return tmp;
  }
  r1u(crossings, rxmin, rymin, rxmax, rymax, x0, y0, x1, y1) {
    var crossings_0 = crossings;
    if (y0 >= rymax && y1 >= rymax)
      return crossings_0;
    if (y0 <= rymin && y1 <= rymin)
      return crossings_0;
    if (x0 <= rxmin && x1 <= rxmin)
      return crossings_0;
    if (x0 >= rxmax && x1 >= rxmax) {
      if (y0 < y1) {
        if (y0 <= rymin) {
          crossings_0 = crossings_0 + 1 | 0;
        }
        if (y1 >= rymax) {
          crossings_0 = crossings_0 + 1 | 0;
        }
      } else if (y1 < y0) {
        if (y1 <= rymin) {
          crossings_0 = crossings_0 - 1 | 0;
        }
        if (y0 >= rymax) {
          crossings_0 = crossings_0 - 1 | 0;
        }
      }
      return crossings_0;
    }
    if (x0 > rxmin && x0 < rxmax && y0 > rymin && y0 < rymax || (x1 > rxmin && x1 < rxmax && y1 > rymin && y1 < rymax)) {
      return -2147483648;
    }
    var xi0 = x0;
    if (y0 < rymin) {
      xi0 = xi0 + (rymin - y0) * (x1 - x0) / (y1 - y0);
    } else if (y0 > rymax) {
      xi0 = xi0 + (rymax - y0) * (x1 - x0) / (y1 - y0);
    }
    var xi1 = x1;
    if (y1 < rymin) {
      xi1 = xi1 + (rymin - y1) * (x0 - x1) / (y0 - y1);
    } else if (y1 > rymax) {
      xi1 = xi1 + (rymax - y1) * (x0 - x1) / (y0 - y1);
    }
    if (xi0 <= rxmin && xi1 <= rxmin)
      return crossings_0;
    if (xi0 >= rxmax && xi1 >= rxmax) {
      if (y0 < y1) {
        if (y0 <= rymin) {
          crossings_0 = crossings_0 + 1 | 0;
        }
        if (y1 >= rymax) {
          crossings_0 = crossings_0 + 1 | 0;
        }
      } else if (y1 < y0) {
        if (y1 <= rymin) {
          crossings_0 = crossings_0 - 1 | 0;
        }
        if (y0 >= rymax) {
          crossings_0 = crossings_0 - 1 | 0;
        }
      }
      return crossings_0;
    }
    return -2147483648;
  }
  s1u(crossings, rxmin, rymin, rxmax, rymax, x0, y0, xc, yc, x1, y1, level) {
    var crossings_0 = crossings;
    var xc_0 = xc;
    var yc_0 = yc;
    if (y0 >= rymax && yc_0 >= rymax && y1 >= rymax)
      return crossings_0;
    if (y0 <= rymin && yc_0 <= rymin && y1 <= rymin)
      return crossings_0;
    if (x0 <= rxmin && xc_0 <= rxmin && x1 <= rxmin)
      return crossings_0;
    if (x0 >= rxmax && xc_0 >= rxmax && x1 >= rxmax) {
      if (y0 < y1) {
        if (y0 <= rymin && y1 > rymin) {
          crossings_0 = crossings_0 + 1 | 0;
        }
        if (y0 < rymax && y1 >= rymax) {
          crossings_0 = crossings_0 + 1 | 0;
        }
      } else if (y1 < y0) {
        if (y1 <= rymin && y0 > rymin) {
          crossings_0 = crossings_0 - 1 | 0;
        }
        if (y1 < rymax && y0 >= rymax) {
          crossings_0 = crossings_0 - 1 | 0;
        }
      }
      return crossings_0;
    }
    if (x0 < rxmax && x0 > rxmin && y0 < rymax && y0 > rymin || (x1 < rxmax && x1 > rxmin && y1 < rymax && y1 > rymin)) {
      return -2147483648;
    }
    if (level > 52) {
      return this.r1u(crossings_0, rxmin, rymin, rxmax, rymax, x0, y0, x1, y1);
    }
    var x0c = (x0 + xc_0) / 2;
    var y0c = (y0 + yc_0) / 2;
    var xc1 = (xc_0 + x1) / 2;
    var yc1 = (yc_0 + y1) / 2;
    xc_0 = (x0c + xc1) / 2;
    yc_0 = (y0c + yc1) / 2;
    if (isNaN_3(xc_0) || isNaN_3(yc_0)) {
      return 0;
    }
    crossings_0 = this.s1u(crossings_0, rxmin, rymin, rxmax, rymax, x0, y0, x0c, y0c, xc_0, yc_0, level + 1 | 0);
    if (!(crossings_0 === -2147483648)) {
      crossings_0 = this.s1u(crossings_0, rxmin, rymin, rxmax, rymax, xc_0, yc_0, xc1, yc1, x1, y1, level + 1 | 0);
    }
    return crossings_0;
  }
  t1u(crossings, rxmin, rymin, rxmax, rymax, x0, y0, xc0, yc0, xc1, yc1, x1, y1, level) {
    var crossings_0 = crossings;
    var xc0_0 = xc0;
    var yc0_0 = yc0;
    var xc1_0 = xc1;
    var yc1_0 = yc1;
    if (y0 >= rymax && yc0_0 >= rymax && yc1_0 >= rymax && y1 >= rymax) {
      return crossings_0;
    }
    if (y0 <= rymin && yc0_0 <= rymin && yc1_0 <= rymin && y1 <= rymin) {
      return crossings_0;
    }
    if (x0 <= rxmin && xc0_0 <= rxmin && xc1_0 <= rxmin && x1 <= rxmin) {
      return crossings_0;
    }
    if (x0 >= rxmax && xc0_0 >= rxmax && xc1_0 >= rxmax && x1 >= rxmax) {
      if (y0 < y1) {
        if (y0 <= rymin && y1 > rymin) {
          crossings_0 = crossings_0 + 1 | 0;
        }
        if (y0 < rymax && y1 >= rymax) {
          crossings_0 = crossings_0 + 1 | 0;
        }
      } else if (y1 < y0) {
        if (y1 <= rymin && y0 > rymin) {
          crossings_0 = crossings_0 - 1 | 0;
        }
        if (y1 < rymax && y0 >= rymax) {
          crossings_0 = crossings_0 - 1 | 0;
        }
      }
      return crossings_0;
    }
    if (x0 > rxmin && x0 < rxmax && y0 > rymin && y0 < rymax || (x1 > rxmin && x1 < rxmax && y1 > rymin && y1 < rymax)) {
      return -2147483648;
    }
    if (level > 52) {
      return this.r1u(crossings_0, rxmin, rymin, rxmax, rymax, x0, y0, x1, y1);
    }
    var xmid = (xc0_0 + xc1_0) / 2;
    var ymid = (yc0_0 + yc1_0) / 2;
    xc0_0 = (x0 + xc0_0) / 2;
    yc0_0 = (y0 + yc0_0) / 2;
    xc1_0 = (xc1_0 + x1) / 2;
    yc1_0 = (yc1_0 + y1) / 2;
    var xc0m = (xc0_0 + xmid) / 2;
    var yc0m = (yc0_0 + ymid) / 2;
    var xmc1 = (xmid + xc1_0) / 2;
    var ymc1 = (ymid + yc1_0) / 2;
    xmid = (xc0m + xmc1) / 2;
    ymid = (yc0m + ymc1) / 2;
    if (isNaN_3(xmid) || isNaN_3(ymid)) {
      return 0;
    }
    crossings_0 = this.t1u(crossings_0, rxmin, rymin, rxmax, rymax, x0, y0, xc0_0, yc0_0, xc0m, yc0m, xmid, ymid, level + 1 | 0);
    if (!(crossings_0 === -2147483648)) {
      crossings_0 = this.t1u(crossings_0, rxmin, rymin, rxmax, rymax, xmid, ymid, xmc1, ymc1, xc1_0, yc1_0, x1, y1, level + 1 | 0);
    }
    return crossings_0;
  }
  u1u(x1, x2) {
    if (x1 < x2) {
      return -1;
    }
    var tmp;
    if (x1 > x2) {
      tmp = 1;
    } else {
      tmp = 0;
    }
    return tmp;
  }
  v1u(y1, y2) {
    return abs(doubleToLongBits(y1).i3(doubleToLongBits(y2)));
  }
  w1u(v) {
    return v;
  }
}
class Curve {
  constructor(direction) {
    this.v1q_1 = direction;
  }
  x1u(direction) {
    return this.v1q_1 === direction ? this : ensureNotNull(this.y1u());
  }
  toString() {
    return 'Curve[' + this.e1r() + ', ' + ('(' + Companion_instance_38.w1u(this.w1q()) + ', ' + Companion_instance_38.w1u(this.x1q()) + '), ') + this.z1u() + ('(' + Companion_instance_38.w1u(this.f1r()) + ', ' + Companion_instance_38.w1u(this.g1r()) + '), ') + (this.v1q_1 === 1 ? 'D' : 'U') + toString(_Char___init__impl__6a9atx(93));
  }
  z1u() {
    return '';
  }
  l1r(x, y) {
    if (y >= this.e1s() && y < this.q1s()) {
      if (x < this.b1v() && (x < this.c1v() || x < this.d1v(y))) {
        return 1;
      }
    }
    return 0;
  }
  l1u(c) {
    var xhi = c.q1r_1;
    if (this.c1v() >= xhi) {
      return false;
    }
    var xlo = c.o1r_1;
    var ylo = c.p1r_1;
    var yhi = c.r1r_1;
    var y0 = this.e1s();
    var y1 = this.q1s();
    var tstart;
    var ystart;
    if (y0 < ylo) {
      if (y1 <= ylo) {
        return false;
      }
      ystart = ylo;
      tstart = this.e1v(ylo);
    } else {
      if (y0 >= yhi) {
        return false;
      }
      ystart = y0;
      tstart = 0.0;
    }
    var yend;
    var tend;
    if (y1 > yhi) {
      yend = yhi;
      tend = this.e1v(yhi);
    } else {
      yend = y1;
      tend = 1.0;
    }
    var hitLo = false;
    var hitHi = false;
    $l$loop: while (true) {
      var x = this.f1v(tstart);
      if (x < xhi) {
        if (hitHi || x > xlo) {
          return true;
        }
        hitLo = true;
      } else {
        if (hitLo) {
          return true;
        }
        hitHi = true;
      }
      if (tstart >= tend) {
        break $l$loop;
      }
      tstart = this.g1v(tstart, tend);
    }
    if (hitLo) {
      c.j1u(ystart, yend, this.v1q_1);
    }
    return false;
  }
  i1v(that, yrange) {
    var y0 = yrange[0];
    var y1 = yrange[1];
    var tmp0 = y1;
    // Inline function 'kotlin.math.min' call
    var b = this.q1s();
    var tmp2 = Math.min(tmp0, b);
    // Inline function 'kotlin.math.min' call
    var b_0 = that.q1s();
    y1 = Math.min(tmp2, b_0);
    if (y1 <= yrange[0]) {
      println('this == ' + this.toString());
      println('that == ' + that.toString());
      println('target range = ' + yrange[0] + '=>' + yrange[1]);
      throw Error_0.vc('backstepping from ' + yrange[0] + ' to ' + y1);
    }
    yrange[1] = y1;
    if (this.b1v() <= that.c1v()) {
      var tmp;
      if (this.c1v() === that.b1v()) {
        tmp = 0;
      } else {
        tmp = -1;
      }
      return tmp;
    }
    if (this.c1v() >= that.b1v()) {
      return 1;
    }
    var s0 = this.e1v(y0);
    var ys0 = this.a1v(s0);
    if (ys0 < y0) {
      s0 = this.j1v(s0, ys0, y0);
      ys0 = this.a1v(s0);
    }
    var s1 = this.e1v(y1);
    if (this.a1v(s1) < y0) {
      s1 = this.j1v(s1, this.a1v(s1), y0);
    }
    var t0 = that.e1v(y0);
    var yt0 = that.a1v(t0);
    if (yt0 < y0) {
      t0 = that.j1v(t0, yt0, y0);
      yt0 = that.a1v(t0);
    }
    var t1 = that.e1v(y1);
    if (that.a1v(t1) < y0) {
      t1 = that.j1v(t1, that.a1v(t1), y0);
    }
    var xs0 = this.f1v(s0);
    var xt0 = that.f1v(t0);
    // Inline function 'kotlin.math.abs' call
    var tmp6 = Math.abs(y0);
    // Inline function 'kotlin.math.abs' call
    var x = y1;
    // Inline function 'kotlin.math.max' call
    var b_1 = Math.abs(x);
    var scale = Math.max(tmp6, b_1);
    // Inline function 'kotlin.math.max' call
    var a = scale * 1.0E-14;
    var ymin = Math.max(a, 1.0E-300);
    if (fairlyClose(Companion_instance_38, xs0, xt0)) {
      var bump = ymin;
      var tmp10 = ymin * 1.0E13;
      // Inline function 'kotlin.math.min' call
      var b_2 = (y1 - y0) * 0.1;
      var maxbump = Math.min(tmp10, b_2);
      var y = y0 + bump;
      $l$loop_0: while (y <= y1) {
        if (fairlyClose(Companion_instance_38, this.d1v(y), that.d1v(y))) {
          // Inline function 'kotlin.let' call
          // Inline function 'org.mkui.geom.Curve.compareTo.<anonymous>' call
          bump = bump * 2;
          if (bump > maxbump) {
            bump = maxbump;
          }
        } else {
          y = y - bump;
          $l$loop: while (true) {
            bump = bump / 2.0;
            var newy = y + bump;
            if (newy <= y) {
              break $l$loop;
            }
            if (fairlyClose(Companion_instance_38, this.d1v(newy), that.d1v(newy))) {
              y = newy;
            }
          }
          break $l$loop_0;
        }
        y = y + bump;
      }
      if (y > y0) {
        if (y < y1) {
          yrange[1] = y;
        }
        return 0;
      }
    }
    if (ymin <= 0) {
      println('ymin = ' + ymin);
    }
    $l$loop_3: while (s0 < s1 && t0 < t1) {
      var sh = this.g1v(s0, s1);
      var xsh = this.f1v(sh);
      var ysh = this.a1v(sh);
      var th = that.g1v(t0, t1);
      var xth = that.f1v(th);
      var yth = that.a1v(th);
      try {
        if (this.k1v(that, yrange, ymin, 0, 0, s0, xs0, ys0, sh, xsh, ysh, t0, xt0, yt0, th, xth, yth)) {
          break $l$loop_3;
        }
      } catch ($p) {
        if ($p instanceof Error) {
          var t = $p;
          println('Error: ' + t.toString());
          println('y range was ' + yrange[0] + '=>' + yrange[1]);
          println('s y range is ' + ys0 + '=>' + ysh);
          println('t y range is ' + yt0 + '=>' + yth);
          println('ymin is ' + ymin);
          return 0;
        } else {
          throw $p;
        }
      }
      if (ysh < yth) {
        if (ysh > yrange[0]) {
          if (ysh < yrange[1]) {
            yrange[1] = ysh;
          }
          break $l$loop_3;
        }
        s0 = sh;
        xs0 = xsh;
        ys0 = ysh;
      } else {
        if (yth > yrange[0]) {
          if (yth < yrange[1]) {
            yrange[1] = yth;
          }
          break $l$loop_3;
        }
        t0 = th;
        xt0 = xth;
        yt0 = yth;
      }
    }
    var ymid = (yrange[0] + yrange[1]) / 2;
    return Companion_instance_38.u1u(this.d1v(ymid), that.d1v(ymid));
  }
  k1v(that, yrange, ymin, slevel, tlevel, s0, xs0, ys0, s1, xs1, ys1, t0, xt0, yt0, t1, xt1, yt1) {
    if (ys0 > yt1 || yt0 > ys1) {
      return false;
    }
    var tmp;
    // Inline function 'kotlin.math.min' call
    var tmp_0 = Math.min(xs0, xs1);
    // Inline function 'kotlin.math.max' call
    if (tmp_0 > Math.max(xt0, xt1)) {
      tmp = true;
    } else {
      // Inline function 'kotlin.math.max' call
      var tmp_1 = Math.max(xs0, xs1);
      // Inline function 'kotlin.math.min' call
      tmp = tmp_1 < Math.min(xt0, xt1);
    }
    if (tmp) {
      return false;
    }
    if (s1 - s0 > 0.001) {
      var s = (s0 + s1) / 2;
      var xs = this.f1v(s);
      var ys = this.a1v(s);
      if (s === s0 || s === s1) {
        println('s0 = ' + s0);
        println('s1 = ' + s1);
        throw Error_0.vc('no s progress!');
      }
      if (t1 - t0 > 0.001) {
        var t = (t0 + t1) / 2;
        var xt = that.f1v(t);
        var yt = that.a1v(t);
        if (t === t0 || t === t1) {
          println('t0 = ' + t0);
          println('t1 = ' + t1);
          throw Error_0.vc('no t progress!');
        }
        if (ys >= yt0 && yt >= ys0) {
          if (this.k1v(that, yrange, ymin, slevel + 1 | 0, tlevel + 1 | 0, s0, xs0, ys0, s, xs, ys, t0, xt0, yt0, t, xt, yt)) {
            return true;
          }
        }
        if (ys >= yt) {
          if (this.k1v(that, yrange, ymin, slevel + 1 | 0, tlevel + 1 | 0, s0, xs0, ys0, s, xs, ys, t, xt, yt, t1, xt1, yt1)) {
            return true;
          }
        }
        if (yt >= ys) {
          if (this.k1v(that, yrange, ymin, slevel + 1 | 0, tlevel + 1 | 0, s, xs, ys, s1, xs1, ys1, t0, xt0, yt0, t, xt, yt)) {
            return true;
          }
        }
        if (ys1 >= yt && yt1 >= ys) {
          return this.k1v(that, yrange, ymin, slevel + 1 | 0, tlevel + 1 | 0, s, xs, ys, s1, xs1, ys1, t, xt, yt, t1, xt1, yt1);
        }
      } else {
        if (ys >= yt0) {
          if (this.k1v(that, yrange, ymin, slevel + 1 | 0, tlevel, s0, xs0, ys0, s, xs, ys, t0, xt0, yt0, t1, xt1, yt1)) {
            return true;
          }
        }
        if (yt1 >= ys) {
          return this.k1v(that, yrange, ymin, slevel + 1 | 0, tlevel, s, xs, ys, s1, xs1, ys1, t0, xt0, yt0, t1, xt1, yt1);
        }
      }
    } else if (t1 - t0 > 0.001) {
      var t_0 = (t0 + t1) / 2;
      var xt_0 = that.f1v(t_0);
      var yt_0 = that.a1v(t_0);
      if (t_0 === t0 || t_0 === t1) {
        println('t0 = ' + t0);
        println('t1 = ' + t1);
        throw Error_0.vc('no t progress!');
      }
      if (yt_0 >= ys0) {
        if (this.k1v(that, yrange, ymin, slevel, tlevel + 1 | 0, s0, xs0, ys0, s1, xs1, ys1, t0, xt0, yt0, t_0, xt_0, yt_0)) {
          return true;
        }
      }
      if (ys1 >= yt_0) {
        return this.k1v(that, yrange, ymin, slevel, tlevel + 1 | 0, s0, xs0, ys0, s1, xs1, ys1, t_0, xt_0, yt_0, t1, xt1, yt1);
      }
    } else {
      var xlk = xs1 - xs0;
      var ylk = ys1 - ys0;
      var xnm = xt1 - xt0;
      var ynm = yt1 - yt0;
      var det = xnm * ylk - ynm * xlk;
      if (!(det === 0.0)) {
        var detinv = 1 / det;
        var ymk = yt0 - ys0;
        var xmk = xt0 - xs0;
        var s_0 = (xnm * ymk - ynm * xmk) * detinv;
        var t_1 = (xlk * ymk - ylk * xmk) * detinv;
        if (s_0 >= 0 && s_0 <= 1 && t_1 >= 0 && t_1 <= 1) {
          s_0 = s0 + s_0 * (s1 - s0);
          t_1 = t0 + t_1 * (t1 - t0);
          if (s_0 < 0 || s_0 > 1 || t_1 < 0 || t_1 > 1) {
            println('Uh oh!');
          }
          var y = (this.a1v(s_0) + that.a1v(t_1)) / 2;
          if (y <= yrange[1] && y > yrange[0]) {
            yrange[1] = y;
            return true;
          }
        }
      }
    }
    return false;
  }
  j1v(t0, yt0, y0) {
    var t0_0 = t0;
    var t1 = 1.0;
    while (true) {
      var th = (t0_0 + t1) / 2;
      if (th === t0_0 || th === t1) {
        return t1;
      }
      var y = this.a1v(th);
      if (y < y0) {
        t0_0 = th;
      } else if (y > y0) {
        t1 = th;
      } else {
        return t1;
      }
    }
  }
}
class CurveLink {
  constructor(curve, ystart, yend, etag) {
    this.c1t_1 = null;
    this.y1s_1 = curve;
    this.a1t_1 = ystart;
    this.b1t_1 = yend;
    this.z1s_1 = etag;
    if (this.a1t_1 < curve.e1s() || this.b1t_1 > curve.q1s()) {
      throw UnsupportedOperationException.t9('bad curvelink [' + this.a1t_1 + '=>' + this.b1t_1 + '] for ' + curve.toString());
    }
  }
  g1t(link) {
    return this.l1v(link.y1s_1, link.a1t_1, link.b1t_1, link.z1s_1);
  }
  l1v(curve, ystart, yend, etag) {
    if (!(this.y1s_1 === curve) || !(this.z1s_1 === etag) || this.b1t_1 < ystart || this.a1t_1 > yend) {
      return false;
    }
    if (ystart < curve.e1s() || yend > curve.q1s()) {
      throw UnsupportedOperationException.t9('bad curvelink [' + ystart + '=>' + yend + '] for ' + curve.toString());
    }
    var tmp = this;
    // Inline function 'kotlin.math.min' call
    var a = this.a1t_1;
    tmp.a1t_1 = Math.min(a, ystart);
    var tmp_0 = this;
    // Inline function 'kotlin.math.max' call
    var a_0 = this.b1t_1;
    tmp_0.b1t_1 = Math.max(a_0, yend);
    return true;
  }
  d1t() {
    var tmp;
    if (this.a1t_1 === this.y1s_1.e1s() && this.b1t_1 === this.y1s_1.q1s()) {
      tmp = this.y1s_1.x1u(this.z1s_1);
    } else {
      tmp = this.y1s_1.h1v(this.a1t_1, this.b1t_1, this.z1s_1);
    }
    return tmp;
  }
  f1t() {
    return new Order0(this.f1s(), this.a1t_1);
  }
  f1s() {
    return this.y1s_1.d1v(this.a1t_1);
  }
  b1u() {
    return this.y1s_1.d1v(this.b1t_1);
  }
  w1l() {
    return this.y1s_1.d1v(this.a1t_1);
  }
}
class Companion_39 {
  constructor() {
    this.m1v_1 = 4;
    this.n1v_1 = 10;
  }
}
class Edge {
  constructor(c, ctag, etag) {
    etag = etag === VOID ? 0 : etag;
    this.z1r_1 = 0.0;
    this.a1s_1 = 0;
    this.b1s_1 = null;
    this.c1s_1 = 0;
    this.d1s_1 = 0.0;
    this.w1r_1 = c;
    this.x1r_1 = ctag;
    this.y1r_1 = etag;
  }
  s1s(other, yrange) {
    if (equals(other, this.b1s_1) && yrange[0] < this.d1s_1) {
      if (yrange[1] > this.d1s_1) {
        yrange[1] = this.d1s_1;
      }
      return this.c1s_1;
    }
    if (equals(this, other.b1s_1) && yrange[0] < other.d1s_1) {
      if (yrange[1] > other.d1s_1) {
        yrange[1] = other.d1s_1;
      }
      return 0 - other.c1s_1 | 0;
    }
    var ret = this.w1r_1.i1v(other.w1r_1, yrange);
    this.b1s_1 = other;
    this.d1s_1 = yrange[1];
    this.c1s_1 = ret;
    return ret;
  }
  x1s(yend, etag) {
    this.z1r_1 = yend;
    this.y1r_1 = etag;
  }
  w1s(y, etag) {
    return this.y1r_1 === etag && this.z1r_1 >= y;
  }
  toString() {
    return 'Edge[' + this.w1r_1 + ', ' + (this.x1r_1 === 0 ? 'L' : 'R') + ', ' + (this.y1r_1 === 1 ? 'I' : this.y1r_1 === -1 ? 'O' : 'N') + toString(_Char___init__impl__6a9atx(93));
  }
}
class Ellipse2D {}
class Double_0 {
  constructor(x, y, width, height) {
    this.o1v_1 = x;
    this.p1v_1 = y;
    this.q1v_1 = width;
    this.r1v_1 = height;
  }
  w1l() {
    return this.o1v_1;
  }
  x1l() {
    return this.p1v_1;
  }
  cm() {
    return this.q1v_1;
  }
  dm() {
    return this.r1v_1;
  }
  y1l() {
    return Double_3.p1m(this.o1v_1, this.p1v_1, this.q1v_1, this.r1v_1);
  }
  z1l(point) {
    var x = point.w1l();
    var y = point.x1l();
    var x0 = x;
    var y0 = y;
    return x >= x0 && y >= y0 && x < x0 + this.q1v_1 && y < y0 + this.r1v_1;
  }
  b1m(rect) {
    var x = rect.w1l();
    var y = rect.x1l();
    var w = rect.cm();
    var h = rect.dm();
    if (w <= 0.0 || h <= 0.0) {
      return false;
    }
    var ellw = this.q1v_1;
    if (ellw <= 0.0) {
      return false;
    }
    var normx0 = (x - x) / ellw - 0.5;
    var ellh = this.r1v_1;
    if (ellh <= 0.0) {
      return false;
    }
    var normy0 = (y - y) / ellh - 0.5;
    var nearx;
    var normx1 = normx0 + w / ellw;
    var tmp;
    if (normx0 > 0.0) {
      tmp = normx0;
    } else if (normx1 < 0.0) {
      tmp = normx1;
    } else {
      tmp = 0.0;
    }
    nearx = tmp;
    var neary;
    var normy1 = normy0 + h / ellh;
    var tmp_0;
    if (normy0 > 0.0) {
      tmp_0 = normy0;
    } else if (normy1 < 0.0) {
      tmp_0 = normy1;
    } else {
      tmp_0 = 0.0;
    }
    neary = tmp_0;
    return nearx * nearx + neary * neary < 0.25;
  }
  a1m() {
    return this.o1v_1 + this.q1v_1 / 2.0;
  }
  c1m() {
    return this.p1v_1 + this.r1v_1 / 2.0;
  }
  d1m() {
    return this.e1m(null);
  }
  e1m(at) {
    return new EllipseIterator(this, at);
  }
  toString() {
    return 'Ellipse2D.Double{x=' + this.o1v_1 + ', y=' + this.p1v_1 + ', width=' + this.q1v_1 + ', height=' + this.r1v_1 + toString(_Char___init__impl__6a9atx(125));
  }
}
class Companion_40 {
  constructor() {
    Companion_instance_40 = this;
    this.s1v_1 = 0.5522847498307933;
    this.t1v_1 = 0.7761423749153966;
    this.u1v_1 = 0.22385762508460333;
    var tmp = this;
    // Inline function 'kotlin.doubleArrayOf' call
    var tmp_0 = new Float64Array([1.0, 0.7761423749153966, 0.7761423749153966, 1.0, 0.5, 1.0]);
    // Inline function 'kotlin.doubleArrayOf' call
    var tmp_1 = new Float64Array([0.22385762508460333, 1.0, 0.0, 0.7761423749153966, 0.0, 0.5]);
    // Inline function 'kotlin.doubleArrayOf' call
    var tmp_2 = new Float64Array([0.0, 0.22385762508460333, 0.22385762508460333, 0.0, 0.5, 0.0]);
    // Inline function 'kotlin.doubleArrayOf' call
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp.v1v_1 = [tmp_0, tmp_1, tmp_2, new Float64Array([0.7761423749153966, 0.0, 1.0, 0.22385762508460333, 1.0, 0.5])];
  }
}
class EllipseIterator {
  constructor(e, at) {
    Companion_getInstance_40();
    this.b1w_1 = 0;
    this.w1v_1 = e.w1l();
    this.x1v_1 = e.x1l();
    this.y1v_1 = e.cm();
    this.z1v_1 = e.dm();
    this.a1w_1 = at;
    if (this.y1v_1 < 0 || this.z1v_1 < 0) {
      this.b1w_1 = 6;
    }
  }
  g1q() {
    return 1;
  }
  b17() {
    return this.b1w_1 > 5;
  }
  h1q() {
    this.b1w_1 = this.b1w_1 + 1 | 0;
  }
  i1q(coords) {
    if (this.b17()) {
      throw NoSuchElementException.s('ellipse iterator out of bounds');
    }
    if (this.b1w_1 === 5) {
      return 4;
    }
    if (this.b1w_1 === 0) {
      var ctrls = Companion_getInstance_40().v1v_1[3];
      coords[0] = this.w1v_1 + ctrls[4] * this.y1v_1;
      coords[1] = this.x1v_1 + ctrls[5] * this.z1v_1;
      var tmp0_safe_receiver = this.a1w_1;
      if (tmp0_safe_receiver == null)
        null;
      else {
        tmp0_safe_receiver.r1o(coords, 0, coords, 0, 1);
      }
      return 0;
    }
    var ctrls_0 = Companion_getInstance_40().v1v_1[this.b1w_1 - 1 | 0];
    coords[0] = this.w1v_1 + ctrls_0[0] * this.y1v_1;
    coords[1] = this.x1v_1 + ctrls_0[1] * this.z1v_1;
    coords[2] = this.w1v_1 + ctrls_0[2] * this.y1v_1;
    coords[3] = this.x1v_1 + ctrls_0[3] * this.z1v_1;
    coords[4] = this.w1v_1 + ctrls_0[4] * this.y1v_1;
    coords[5] = this.x1v_1 + ctrls_0[5] * this.z1v_1;
    var tmp1_safe_receiver = this.a1w_1;
    if (tmp1_safe_receiver == null)
      null;
    else {
      tmp1_safe_receiver.r1o(coords, 0, coords, 0, 3);
    }
    return 3;
  }
}
class Companion_41 {
  p1p(x1, y1, x2, y2, px, py) {
    var x2_0 = x2;
    var y2_0 = y2;
    var px_0 = px;
    var py_0 = py;
    x2_0 = x2_0 - x1;
    y2_0 = y2_0 - y1;
    px_0 = px_0 - x1;
    py_0 = py_0 - y1;
    var ccw = px_0 * y2_0 - py_0 * x2_0;
    if (ccw === 0.0) {
      ccw = px_0 * x2_0 + py_0 * y2_0;
      if (ccw > 0.0) {
        px_0 = px_0 - x2_0;
        py_0 = py_0 - y2_0;
        ccw = px_0 * x2_0 + py_0 * y2_0;
        if (ccw < 0.0) {
          ccw = 0.0;
        }
      }
    }
    return ccw < 0.0 ? -1 : ccw > 0.0 ? 1 : 0;
  }
}
class Order0 extends Curve {
  constructor(x, y) {
    super(1);
    this.d1w_1 = x;
    this.e1w_1 = y;
  }
  e1r() {
    return 0;
  }
  w1q() {
    return this.d1w_1;
  }
  x1q() {
    return this.e1w_1;
  }
  f1r() {
    return this.d1w_1;
  }
  g1r() {
    return this.e1w_1;
  }
  f1s() {
    return this.d1w_1;
  }
  e1s() {
    return this.e1w_1;
  }
  q1s() {
    return this.e1w_1;
  }
  c1v() {
    return this.d1w_1;
  }
  b1v() {
    return this.d1w_1;
  }
  y1u() {
    return this;
  }
  a1v(t) {
    return this.e1w_1;
  }
  l1r(x, y) {
    return 0;
  }
  d1v(y) {
    return y;
  }
  l1u(c) {
    return this.d1w_1 > c.o1r_1 && this.d1w_1 < c.q1r_1 && this.e1w_1 > c.p1r_1 && this.e1w_1 < c.r1r_1;
  }
  e1v(y) {
    return 0.0;
  }
  f1v(t) {
    return this.d1w_1;
  }
  y1q(r) {
    return r.t1m(this.d1w_1, this.e1w_1);
  }
  g1v(t0, t1) {
    return t1;
  }
  h1v(ystart, yend, dir) {
    return this;
  }
  h1r(coords) {
    coords[0] = this.d1w_1;
    coords[1] = this.e1w_1;
    return 0;
  }
}
class Order1 extends Curve {
  constructor(xTop, yTop, xBot, yBot, direction) {
    super(direction);
    this.g1w_1 = xTop;
    this.h1w_1 = yTop;
    this.i1w_1 = xBot;
    this.j1w_1 = yBot;
    this.k1w_1 = 0.0;
    this.l1w_1 = 0.0;
    if (this.g1w_1 < this.i1w_1) {
      this.k1w_1 = this.g1w_1;
      this.l1w_1 = this.i1w_1;
    } else {
      this.k1w_1 = this.i1w_1;
      this.l1w_1 = this.g1w_1;
    }
  }
  f1s() {
    return this.g1w_1;
  }
  e1s() {
    return this.h1w_1;
  }
  q1s() {
    return this.j1w_1;
  }
  c1v() {
    return this.k1w_1;
  }
  b1v() {
    return this.l1w_1;
  }
  y1u() {
    return new Order1(this.g1w_1, this.h1w_1, this.i1w_1, this.j1w_1, -this.v1q_1 | 0);
  }
  e1r() {
    return 1;
  }
  w1q() {
    return this.v1q_1 === 1 ? this.g1w_1 : this.i1w_1;
  }
  x1q() {
    return this.v1q_1 === 1 ? this.h1w_1 : this.j1w_1;
  }
  f1r() {
    return this.v1q_1 === -1 ? this.g1w_1 : this.i1w_1;
  }
  g1r() {
    return this.v1q_1 === -1 ? this.h1w_1 : this.j1w_1;
  }
  a1v(t) {
    return this.h1w_1 + t * (this.j1w_1 - this.h1w_1);
  }
  d1v(y) {
    if (this.g1w_1 === this.i1w_1 || y <= this.h1w_1) {
      return this.g1w_1;
    }
    var tmp;
    if (y >= this.j1w_1) {
      tmp = this.i1w_1;
    } else {
      tmp = this.g1w_1 + (y - this.h1w_1) * (this.i1w_1 - this.g1w_1) / (this.j1w_1 - this.h1w_1);
    }
    return tmp;
  }
  l1u(c) {
    var xlo = c.o1r_1;
    var ylo = c.p1r_1;
    var xhi = c.q1r_1;
    var yhi = c.r1r_1;
    if (this.k1w_1 >= xhi) {
      return false;
    }
    var xstart;
    var ystart;
    if (this.h1w_1 < ylo) {
      if (this.j1w_1 <= ylo) {
        return false;
      }
      ystart = ylo;
      xstart = this.d1v(ylo);
    } else {
      if (this.h1w_1 >= yhi) {
        return false;
      }
      ystart = this.h1w_1;
      xstart = this.g1w_1;
    }
    var yend;
    var xend;
    if (this.j1w_1 > yhi) {
      yend = yhi;
      xend = this.d1v(yhi);
    } else {
      yend = this.j1w_1;
      xend = this.i1w_1;
    }
    if (xstart >= xhi && xend >= xhi) {
      return false;
    }
    if (xstart > xlo || xend > xlo) {
      return true;
    }
    c.j1u(ystart, yend, this.v1q_1);
    return false;
  }
  e1v(y) {
    if (y <= this.h1w_1) {
      return 0.0;
    }
    var tmp;
    if (y >= this.j1w_1) {
      tmp = 1.0;
    } else {
      tmp = (y - this.h1w_1) / (this.j1w_1 - this.h1w_1);
    }
    return tmp;
  }
  f1v(t) {
    return this.g1w_1 + t * (this.i1w_1 - this.g1w_1);
  }
  y1q(r) {
    var r_0 = r;
    r_0 = r_0.t1m(this.g1w_1, this.h1w_1);
    return r_0.t1m(this.i1w_1, this.j1w_1);
  }
  g1v(t0, t1) {
    return t1;
  }
  h1v(ystart, yend, dir) {
    if (ystart === this.h1w_1 && yend === this.j1w_1) {
      return this.x1u(dir);
    }
    if (this.g1w_1 === this.i1w_1) {
      return new Order1(this.g1w_1, ystart, this.i1w_1, yend, dir);
    }
    var num = this.g1w_1 - this.i1w_1;
    var denom = this.h1w_1 - this.j1w_1;
    var xstart = this.g1w_1 + (ystart - this.h1w_1) * num / denom;
    var xend = this.g1w_1 + (yend - this.h1w_1) * num / denom;
    return new Order1(xstart, ystart, xend, yend, dir);
  }
  i1v(other, yrange) {
    if (!(other instanceof Order1)) {
      return super.i1v(other, yrange);
    }
    if (yrange[1] <= yrange[0]) {
      throw UnsupportedOperationException.t9('yrange already screwed up...');
    }
    var tmp0 = yrange[1];
    // Inline function 'kotlin.math.min' call
    var b = this.j1w_1;
    var tmp2 = Math.min(tmp0, b);
    // Inline function 'kotlin.math.min' call
    var b_0 = other.j1w_1;
    yrange[1] = Math.min(tmp2, b_0);
    if (yrange[1] <= yrange[0]) {
      throw UnsupportedOperationException.t9('backstepping from ' + yrange[0] + ' to ' + yrange[1]);
    }
    if (this.l1w_1 <= other.k1w_1) {
      return this.k1w_1 === other.l1w_1 ? 0 : -1;
    }
    if (this.k1w_1 >= other.l1w_1) {
      return 1;
    }
    var dxa = this.i1w_1 - this.g1w_1;
    var dya = this.j1w_1 - this.h1w_1;
    var dxb = other.i1w_1 - other.g1w_1;
    var dyb = other.j1w_1 - other.h1w_1;
    var denom = dxb * dya - dxa * dyb;
    var y;
    if (!(denom === 0.0)) {
      var num = (this.g1w_1 - other.g1w_1) * dya * dyb - this.h1w_1 * dxa * dyb + other.h1w_1 * dxb * dya;
      y = num / denom;
      if (y <= yrange[0]) {
        var tmp4 = this.j1w_1;
        // Inline function 'kotlin.math.min' call
        var b_1 = other.j1w_1;
        y = Math.min(tmp4, b_1);
      } else {
        if (y < yrange[1]) {
          yrange[1] = y;
        }
        var tmp6 = this.h1w_1;
        // Inline function 'kotlin.math.max' call
        var b_2 = other.h1w_1;
        y = Math.max(tmp6, b_2);
      }
    } else {
      var tmp8 = this.h1w_1;
      // Inline function 'kotlin.math.max' call
      var b_3 = other.h1w_1;
      y = Math.max(tmp8, b_3);
    }
    return Companion_instance_38.u1u(this.d1v(y), other.d1v(y));
  }
  h1r(coords) {
    if (this.v1q_1 === 1) {
      coords[0] = this.i1w_1;
      coords[1] = this.j1w_1;
    } else {
      coords[0] = this.g1w_1;
      coords[1] = this.h1w_1;
    }
    return 1;
  }
}
class Companion_42 {
  m1u(curves, tmp, x0, y0, cx0, cy0, x1, y1, direction) {
    var numparams = this.m1w(y0, cy0, y1, tmp);
    if (numparams === 0) {
      this.n1w(curves, x0, y0, cx0, cy0, x1, y1, direction);
      return Unit_instance;
    }
    var t = tmp[0];
    tmp[0] = x0;
    tmp[1] = y0;
    tmp[2] = cx0;
    tmp[3] = cy0;
    tmp[4] = x1;
    tmp[5] = y1;
    this.o1w(tmp, 0, t);
    var i0 = direction === 1 ? 0 : 4;
    this.n1w(curves, tmp[i0], tmp[i0 + 1 | 0], tmp[i0 + 2 | 0], tmp[i0 + 3 | 0], tmp[i0 + 4 | 0], tmp[i0 + 5 | 0], direction);
    var i1 = 4 - i0 | 0;
    this.n1w(curves, tmp[i1], tmp[i1 + 1 | 0], tmp[i1 + 2 | 0], tmp[i1 + 3 | 0], tmp[i1 + 4 | 0], tmp[i1 + 5 | 0], direction);
  }
  n1w(curves, x0, y0, cx0, cy0, x1, y1, direction) {
    if (y0 > y1) {
      curves.o(new Order2(x1, y1, cx0, cy0, x0, y0, -direction | 0));
    } else if (y1 > y0) {
      curves.o(new Order2(x0, y0, cx0, cy0, x1, y1, direction));
    }
  }
  m1w(c0, cp, c1, ret) {
    var c0_0 = c0;
    var c1_0 = c1;
    if (c0_0 <= cp && cp <= c1_0) {
      return 0;
    }
    c0_0 = c0_0 - cp;
    c1_0 = c1_0 - cp;
    var denom = c0_0 + c1_0;
    if (denom === 0.0) {
      return 0;
    }
    var t = c0_0 / denom;
    if (t <= 0 || t >= 1) {
      return 0;
    }
    ret[0] = t;
    return 1;
  }
  o1w(coords, pos, t) {
    var x1;
    x1 = coords[pos + 4 | 0];
    coords[pos + 8 | 0] = x1;
    var y1;
    y1 = coords[pos + 5 | 0];
    coords[pos + 9 | 0] = y1;
    var cx = coords[pos + 2 | 0];
    var cy = coords[pos + 3 | 0];
    x1 = cx + (x1 - cx) * t;
    y1 = cy + (y1 - cy) * t;
    var x0 = coords[pos + 0 | 0];
    var y0 = coords[pos + 1 | 0];
    x0 = x0 + (cx - x0) * t;
    y0 = y0 + (cy - y0) * t;
    cx = x0 + (x1 - x0) * t;
    cy = y0 + (y1 - y0) * t;
    coords[pos + 2 | 0] = x0;
    coords[pos + 3 | 0] = y0;
    coords[pos + 4 | 0] = cx;
    coords[pos + 5 | 0] = cy;
    coords[pos + 6 | 0] = x1;
    coords[pos + 7 | 0] = y1;
  }
  p1w(y, ycoeff0, ycoeff1, ycoeff2) {
    var ycoeff0_0 = ycoeff0;
    ycoeff0_0 = ycoeff0_0 - y;
    if (ycoeff2 === 0.0) {
      var root = -ycoeff0_0 / ycoeff1;
      if (root >= 0 && root <= 1) {
        return root;
      }
    } else {
      var d = ycoeff1 * ycoeff1 - 4.0 * ycoeff2 * ycoeff0_0;
      if (d >= 0.0) {
        // Inline function 'kotlin.math.sqrt' call
        var x = d;
        d = Math.sqrt(x);
        if (ycoeff1 < 0.0) {
          d = -d;
        }
        var q = (ycoeff1 + d) / -2.0;
        var root_0 = q / ycoeff2;
        if (root_0 >= 0 && root_0 <= 1) {
          return root_0;
        }
        if (!(q === 0.0)) {
          root_0 = ycoeff0_0 / q;
          if (root_0 >= 0 && root_0 <= 1) {
            return root_0;
          }
        }
      }
    }
    var y0 = ycoeff0_0;
    var y1 = ycoeff0_0 + ycoeff1 + ycoeff2;
    return 0 < (y0 + y1) / 2 ? 0.0 : 1.0;
  }
}
class Order2 extends Curve {
  constructor(x0, y0, cx0, cy0, x1, y1, direction) {
    super(direction);
    var cy0_0 = cy0;
    if (cy0_0 < y0) {
      cy0_0 = y0;
    } else if (cy0_0 > y1) {
      cy0_0 = y1;
    }
    this.r1w_1 = x0;
    this.s1w_1 = y0;
    this.t1w_1 = cx0;
    this.u1w_1 = cy0_0;
    this.v1w_1 = x1;
    this.w1w_1 = y1;
    var tmp = this;
    // Inline function 'kotlin.math.min' call
    // Inline function 'kotlin.math.min' call
    var a = Math.min(x0, x1);
    tmp.x1w_1 = Math.min(a, cx0);
    var tmp_0 = this;
    // Inline function 'kotlin.math.max' call
    // Inline function 'kotlin.math.max' call
    var a_0 = Math.max(x0, x1);
    tmp_0.y1w_1 = Math.max(a_0, cx0);
    this.z1w_1 = x0;
    this.a1x_1 = cx0 + cx0 - x0 - x0;
    this.b1x_1 = x0 - cx0 - cx0 + x1;
    this.c1x_1 = y0;
    this.d1x_1 = cy0_0 + cy0_0 - y0 - y0;
    this.e1x_1 = y0 - cy0_0 - cy0_0 + y1;
  }
  f1s() {
    return this.r1w_1;
  }
  e1s() {
    return this.s1w_1;
  }
  q1s() {
    return this.w1w_1;
  }
  c1v() {
    return this.x1w_1;
  }
  b1v() {
    return this.y1w_1;
  }
  y1u() {
    return new Order2(this.r1w_1, this.s1w_1, this.t1w_1, this.u1w_1, this.v1w_1, this.w1w_1, -this.v1q_1 | 0);
  }
  z1u() {
    return '(' + Companion_instance_38.w1u(this.t1w_1).toString() + ', ' + Companion_instance_38.w1u(this.u1w_1).toString() + '), ';
  }
  e1r() {
    return 2;
  }
  w1q() {
    return this.v1q_1 === 1 ? this.r1w_1 : this.v1w_1;
  }
  x1q() {
    return this.v1q_1 === 1 ? this.s1w_1 : this.w1w_1;
  }
  f1r() {
    return this.v1q_1 === -1 ? this.r1w_1 : this.v1w_1;
  }
  g1r() {
    return this.v1q_1 === -1 ? this.s1w_1 : this.w1w_1;
  }
  a1v(t) {
    return (this.e1x_1 * t + this.d1x_1) * t + this.c1x_1;
  }
  d1v(y) {
    if (y <= this.s1w_1) {
      return this.r1w_1;
    }
    var tmp;
    if (y >= this.w1w_1) {
      tmp = this.v1w_1;
    } else {
      tmp = this.f1v(this.e1v(y));
    }
    return tmp;
  }
  e1v(y) {
    if (y <= this.s1w_1) {
      return 0.0;
    }
    var tmp;
    if (y >= this.w1w_1) {
      tmp = 1.0;
    } else {
      tmp = Companion_instance_42.p1w(y, this.c1x_1, this.d1x_1, this.e1x_1);
    }
    return tmp;
  }
  y1q(r) {
    var r_0 = r;
    r_0 = r_0.t1m(this.r1w_1, this.s1w_1);
    var t = -this.a1x_1 / (2 * this.b1x_1);
    if (t > 0 && t < 1) {
      r_0 = r_0.t1m(this.f1v(t), this.a1v(t));
    }
    return r_0.t1m(this.v1w_1, this.w1w_1);
  }
  f1v(t) {
    return (this.b1x_1 * t + this.a1x_1) * t + this.z1w_1;
  }
  g1v(t0, t1) {
    var t = -this.a1x_1 / (2 * this.b1x_1);
    var tmp;
    if (t > t0 && t < t1) {
      tmp = t;
    } else {
      tmp = t1;
    }
    return tmp;
  }
  h1v(ystart, yend, dir) {
    var t0;
    var tmp;
    if (ystart <= this.s1w_1) {
      if (yend >= this.w1w_1) {
        return this.x1u(dir);
      }
      tmp = 0.0;
    } else {
      tmp = Companion_instance_42.p1w(ystart, this.c1x_1, this.d1x_1, this.e1x_1);
    }
    t0 = tmp;
    var t1;
    var tmp_0;
    if (yend >= this.w1w_1) {
      tmp_0 = 1.0;
    } else {
      tmp_0 = Companion_instance_42.p1w(yend, this.c1x_1, this.d1x_1, this.e1x_1);
    }
    t1 = tmp_0;
    var eqn = new Float64Array(10);
    eqn[0] = this.r1w_1;
    eqn[1] = this.s1w_1;
    eqn[2] = this.t1w_1;
    eqn[3] = this.u1w_1;
    eqn[4] = this.v1w_1;
    eqn[5] = this.w1w_1;
    if (t1 < 1) {
      Companion_instance_42.o1w(eqn, 0, t1);
    }
    var i;
    var tmp_1;
    if (t0 <= 0) {
      tmp_1 = 0;
    } else {
      Companion_instance_42.o1w(eqn, 0, t0 / t1);
      tmp_1 = 4;
    }
    i = tmp_1;
    return new Order2(eqn[i + 0 | 0], ystart, eqn[i + 2 | 0], eqn[i + 3 | 0], eqn[i + 4 | 0], yend, dir);
  }
  h1r(coords) {
    coords[0] = this.t1w_1;
    coords[1] = this.u1w_1;
    if (this.v1q_1 === 1) {
      coords[2] = this.v1w_1;
      coords[3] = this.w1w_1;
    } else {
      coords[2] = this.r1w_1;
      coords[3] = this.s1w_1;
    }
    return 2;
  }
}
class Companion_43 {
  n1u(curves, tmp, x0, y0, cx0, cy0, cx1, cy1, x1, y1, direction) {
    var numparams = this.f1x(y0, cy0, cy1, y1, tmp);
    if (numparams === 0) {
      this.g1x(curves, x0, y0, cx0, cy0, cx1, cy1, x1, y1, direction);
      return Unit_instance;
    }
    tmp[3] = x0;
    tmp[4] = y0;
    tmp[5] = cx0;
    tmp[6] = cy0;
    tmp[7] = cx1;
    tmp[8] = cy1;
    tmp[9] = x1;
    tmp[10] = y1;
    var t = tmp[0];
    if (numparams > 1 && t > tmp[1]) {
      tmp[0] = tmp[1];
      tmp[1] = t;
      t = tmp[0];
    }
    this.o1w(tmp, 3, t);
    if (numparams > 1) {
      t = (tmp[1] - t) / (1 - t);
      this.o1w(tmp, 9, t);
    }
    var index = 3;
    if (direction === -1) {
      index = index + imul_0(numparams, 6) | 0;
    }
    while (numparams >= 0) {
      this.g1x(curves, tmp[index + 0 | 0], tmp[index + 1 | 0], tmp[index + 2 | 0], tmp[index + 3 | 0], tmp[index + 4 | 0], tmp[index + 5 | 0], tmp[index + 6 | 0], tmp[index + 7 | 0], direction);
      numparams = numparams - 1 | 0;
      if (direction === 1) {
        index = index + 6 | 0;
      } else {
        index = index - 6 | 0;
      }
    }
  }
  g1x(curves, x0, y0, cx0, cy0, cx1, cy1, x1, y1, direction) {
    if (y0 > y1) {
      curves.o(new Order3(x1, y1, cx1, cy1, cx0, cy0, x0, y0, -direction | 0));
    } else if (y1 > y0) {
      curves.o(new Order3(x0, y0, cx0, cy0, cx1, cy1, x1, y1, direction));
    }
  }
  f1x(c0, cp0, cp1, c1, ret) {
    var cp0_0 = cp0;
    var cp1_0 = cp1;
    var c1_0 = c1;
    if (c0 <= cp0_0 && cp0_0 <= cp1_0 && cp1_0 <= c1_0) {
      return 0;
    }
    c1_0 = c1_0 - cp1_0;
    cp1_0 = cp1_0 - cp0_0;
    cp0_0 = cp0_0 - c0;
    ret[0] = cp0_0;
    ret[1] = (cp1_0 - cp0_0) * 2;
    ret[2] = c1_0 - cp1_0 - cp1_0 + cp0_0;
    var numroots = Companion_instance_46.m1x(ret, ret);
    var j = 0;
    var inductionVariable = 0;
    if (inductionVariable < numroots)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var t = ret[i];
        if (t > 0 && t < 1) {
          if (j < i) {
            ret[j] = t;
          }
          j = j + 1 | 0;
        }
      }
       while (inductionVariable < numroots);
    return j;
  }
  o1w(coords, pos, t) {
    var x1;
    x1 = coords[pos + 6 | 0];
    coords[pos + 12 | 0] = x1;
    var y1;
    y1 = coords[pos + 7 | 0];
    coords[pos + 13 | 0] = y1;
    var cx1 = coords[pos + 4 | 0];
    var cy1 = coords[pos + 5 | 0];
    x1 = cx1 + (x1 - cx1) * t;
    y1 = cy1 + (y1 - cy1) * t;
    var x0 = coords[pos + 0 | 0];
    var y0 = coords[pos + 1 | 0];
    var cx0 = coords[pos + 2 | 0];
    var cy0 = coords[pos + 3 | 0];
    x0 = x0 + (cx0 - x0) * t;
    y0 = y0 + (cy0 - y0) * t;
    cx0 = cx0 + (cx1 - cx0) * t;
    cy0 = cy0 + (cy1 - cy0) * t;
    cx1 = cx0 + (x1 - cx0) * t;
    cy1 = cy0 + (y1 - cy0) * t;
    cx0 = x0 + (cx0 - x0) * t;
    cy0 = y0 + (cy0 - y0) * t;
    coords[pos + 2 | 0] = x0;
    coords[pos + 3 | 0] = y0;
    coords[pos + 4 | 0] = cx0;
    coords[pos + 5 | 0] = cy0;
    coords[pos + 6 | 0] = cx0 + (cx1 - cx0) * t;
    coords[pos + 7 | 0] = cy0 + (cy1 - cy0) * t;
    coords[pos + 8 | 0] = cx1;
    coords[pos + 9 | 0] = cy1;
    coords[pos + 10 | 0] = x1;
    coords[pos + 11 | 0] = y1;
  }
}
class Order3 extends Curve {
  constructor(x0, y0, cx0, cy0, cx1, cy1, x1, y1, direction) {
    super(direction);
    this.g1y_1 = 0.0;
    this.i1y_1 = 0.0;
    this.k1y_1 = 0.0;
    var cy0_0 = cy0;
    var cy1_0 = cy1;
    if (cy0_0 < y0)
      cy0_0 = y0;
    if (cy1_0 > y1)
      cy1_0 = y1;
    this.o1x_1 = x0;
    this.p1x_1 = y0;
    this.q1x_1 = cx0;
    this.r1x_1 = cy0_0;
    this.s1x_1 = cx1;
    this.t1x_1 = cy1_0;
    this.u1x_1 = x1;
    this.v1x_1 = y1;
    var tmp = this;
    // Inline function 'kotlin.math.min' call
    var tmp4 = Math.min(x0, x1);
    // Inline function 'kotlin.math.min' call
    // Inline function 'kotlin.math.min' call
    var b = Math.min(cx0, cx1);
    tmp.w1x_1 = Math.min(tmp4, b);
    var tmp_0 = this;
    // Inline function 'kotlin.math.max' call
    var tmp10 = Math.max(x0, x1);
    // Inline function 'kotlin.math.max' call
    // Inline function 'kotlin.math.max' call
    var b_0 = Math.max(cx0, cx1);
    tmp_0.x1x_1 = Math.max(tmp10, b_0);
    this.y1x_1 = x0;
    this.z1x_1 = (cx0 - x0) * 3.0;
    this.a1y_1 = (cx1 - cx0 - cx0 + x0) * 3.0;
    this.b1y_1 = x1 - (cx1 - cx0) * 3.0 - x0;
    this.c1y_1 = y0;
    this.d1y_1 = (cy0_0 - y0) * 3.0;
    this.e1y_1 = (cy1_0 - cy0_0 - cy0_0 + y0) * 3.0;
    this.f1y_1 = y1 - (cy1_0 - cy0_0) * 3.0 - y0;
    this.l1y_1 = y0;
    this.j1y_1 = this.l1y_1;
    this.h1y_1 = this.j1y_1;
  }
  f1s() {
    return this.o1x_1;
  }
  e1s() {
    return this.p1x_1;
  }
  q1s() {
    return this.v1x_1;
  }
  c1v() {
    return this.w1x_1;
  }
  b1v() {
    return this.x1x_1;
  }
  y1u() {
    return new Order3(this.o1x_1, this.p1x_1, this.q1x_1, this.r1x_1, this.s1x_1, this.t1x_1, this.u1x_1, this.v1x_1, -this.v1q_1 | 0);
  }
  z1u() {
    return '(' + Companion_instance_38.w1u(this.m1y()).toString() + ', ' + Companion_instance_38.w1u(this.n1y()).toString() + '), ' + ('(' + Companion_instance_38.w1u(this.o1y()).toString() + ', ' + Companion_instance_38.w1u(this.p1y()).toString() + '), ');
  }
  e1r() {
    return 3;
  }
  w1q() {
    return this.v1q_1 === 1 ? this.o1x_1 : this.u1x_1;
  }
  x1q() {
    return this.v1q_1 === 1 ? this.p1x_1 : this.v1x_1;
  }
  f1r() {
    return this.v1q_1 === 1 ? this.p1x_1 : this.v1x_1;
  }
  g1r() {
    return this.v1q_1 === -1 ? this.p1x_1 : this.v1x_1;
  }
  a1v(t) {
    return ((this.f1y_1 * t + this.e1y_1) * t + this.d1y_1) * t + this.c1y_1;
  }
  q1y(t, deriv) {
    switch (deriv) {
      case 0:
        return ((this.f1y_1 * t + this.e1y_1) * t + this.d1y_1) * t + this.c1y_1;
      case 1:
        return (3 * this.f1y_1 * t + 2 * this.e1y_1) * t + this.d1y_1;
      case 2:
        return 6 * this.f1y_1 * t + 2 * this.e1y_1;
      case 3:
        return 6 * this.f1y_1;
      default:
        return 0.0;
    }
  }
  d1v(y) {
    if (y <= this.p1x_1) {
      return this.o1x_1;
    }
    var tmp;
    if (y >= this.v1x_1) {
      tmp = this.u1x_1;
    } else {
      tmp = this.f1v(this.e1v(y));
    }
    return tmp;
  }
  e1v(y) {
    if (y <= this.p1x_1)
      return 0.0;
    if (y >= this.v1x_1)
      return 1.0;
    if (y === this.h1y_1)
      return this.g1y_1;
    if (y === this.j1y_1)
      return this.i1y_1;
    if (y === this.l1y_1)
      return this.k1y_1;
    if (this.f1y_1 === 0.0) {
      return Companion_instance_42.p1w(y, this.c1y_1, this.d1y_1, this.e1y_1);
    }
    var a = this.e1y_1 / this.f1y_1;
    var b = this.d1y_1 / this.f1y_1;
    var c = (this.c1y_1 - y) / this.f1y_1;
    var roots = 0;
    var Q = (a * a - 3.0 * b) / 9.0;
    var R = (2.0 * a * a * a - 9.0 * a * b + 27.0 * c) / 54.0;
    var R2 = R * R;
    var Q3 = Q * Q * Q;
    var a_3 = a / 3.0;
    var t;
    if (R2 < Q3) {
      var tmp = R;
      // Inline function 'kotlin.math.sqrt' call
      // Inline function 'kotlin.math.acos' call
      var x = tmp / Math.sqrt(Q3);
      var theta = Math.acos(x);
      var tmp_0 = -2.0;
      // Inline function 'kotlin.math.sqrt' call
      var x_0 = Q;
      Q = tmp_0 * Math.sqrt(x_0);
      var tmp_1 = Q;
      // Inline function 'kotlin.math.cos' call
      var x_1 = theta / 3.0;
      var tmp$ret$3 = Math.cos(x_1);
      t = this.r1y(a, b, c, y, tmp_1 * tmp$ret$3 - a_3);
      if (t < 0) {
        var tmp_2 = Q;
        // Inline function 'kotlin.math.cos' call
        var x_2 = (theta + 3.141592653589793 * 2.0) / 3.0;
        var tmp$ret$4 = Math.cos(x_2);
        t = this.r1y(a, b, c, y, tmp_2 * tmp$ret$4 - a_3);
      }
      if (t < 0) {
        var tmp_3 = Q;
        // Inline function 'kotlin.math.cos' call
        var x_3 = (theta - 3.141592653589793 * 2.0) / 3.0;
        var tmp$ret$5 = Math.cos(x_3);
        t = this.r1y(a, b, c, y, tmp_3 * tmp$ret$5 - a_3);
      }
    } else {
      var neg = R < 0.0;
      if (neg) {
        R = -R;
      }
      // Inline function 'kotlin.math.sqrt' call
      var x_4 = R2 - Q3;
      var S = Math.sqrt(x_4);
      var tmp7 = R + S;
      // Inline function 'kotlin.math.pow' call
      var x_5 = 1.0 / 3.0;
      var A = Math.pow(tmp7, x_5);
      if (!neg) {
        A = -A;
      }
      var B = A === 0.0 ? 0.0 : Q / A;
      t = this.r1y(a, b, c, y, A + B - a_3);
    }
    if (t < 0) {
      var t0 = 0.0;
      var t1 = 1.0;
      $l$loop_0: while (true) {
        t = (t0 + t1) / 2;
        if (t === t0 || t === t1) {
          break $l$loop_0;
        }
        var yt = this.a1v(t);
        if (yt < y) {
          t0 = t;
        } else if (yt > y) {
          t1 = t;
        } else {
          break $l$loop_0;
        }
      }
    }
    if (t >= 0) {
      this.k1y_1 = this.i1y_1;
      this.l1y_1 = this.j1y_1;
      this.i1y_1 = this.g1y_1;
      this.j1y_1 = this.h1y_1;
      this.g1y_1 = t;
      this.h1y_1 = y;
    }
    return t;
  }
  r1y(a, b, c, target, t) {
    var t_0 = t;
    if (t_0 < -0.1 || t_0 > 1.1) {
      return -1;
    }
    var y = this.a1v(t_0);
    var t0;
    var t1;
    if (y < target) {
      t0 = t_0;
      t1 = 1.0;
    } else {
      t0 = 0.0;
      t1 = t_0;
    }
    var origt = t_0;
    var origy = y;
    var useslope = true;
    $l$loop_2: while (!(y === target)) {
      if (!useslope) {
        var t2 = (t0 + t1) / 2;
        if (t2 === t0 || t2 === t1) {
          break $l$loop_2;
        }
        t_0 = t2;
      } else {
        var slope = this.q1y(t_0, 1);
        if (slope === 0.0) {
          useslope = false;
          continue $l$loop_2;
        }
        var t2_0 = t_0 + (target - y) / slope;
        if (t2_0 === t_0 || t2_0 <= t0 || t2_0 >= t1) {
          useslope = false;
          continue $l$loop_2;
        }
        t_0 = t2_0;
      }
      y = this.a1v(t_0);
      if (y < target) {
        t0 = t_0;
      } else if (y > target) {
        t1 = t_0;
      } else {
        break $l$loop_2;
      }
    }
    if (false && t_0 >= 0 && t_0 <= 1) {
      y = this.a1v(t_0);
      var tdiff = Companion_instance_38.v1u(t_0, origt);
      var ydiff = Companion_instance_38.v1u(y, origy);
      var yerr = Companion_instance_38.v1u(y, target);
      var verbose = false;
    }
    return t_0 > 1 ? -1.0 : t_0;
  }
  f1v(t) {
    return ((this.b1y_1 * t + this.a1y_1) * t + this.z1x_1) * t + this.y1x_1;
  }
  g1v(t0, t1) {
    var t1_0 = t1;
    // Inline function 'kotlin.doubleArrayOf' call
    var eqn = new Float64Array([this.z1x_1, 2 * this.a1y_1, 3 * this.b1y_1]);
    var numroots = Companion_instance_46.m1x(eqn, eqn);
    var inductionVariable = 0;
    if (inductionVariable < numroots)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        if (eqn[i] > t0 && eqn[i] < t1_0) {
          t1_0 = eqn[i];
        }
      }
       while (inductionVariable < numroots);
    return t1_0;
  }
  h1v(ystart, yend, dir) {
    if (ystart <= this.p1x_1 && yend >= this.v1x_1) {
      return this.x1u(dir);
    }
    var t0 = this.e1v(ystart);
    var t1 = this.e1v(yend);
    var eqn = new Float64Array(14);
    eqn[0] = this.o1x_1;
    eqn[1] = this.p1x_1;
    eqn[2] = this.q1x_1;
    eqn[3] = this.r1x_1;
    eqn[4] = this.s1x_1;
    eqn[5] = this.t1x_1;
    eqn[6] = this.u1x_1;
    eqn[7] = this.v1x_1;
    if (t0 > t1) {
      var t = t0;
      t0 = t1;
      t1 = t;
    }
    if (t1 < 1) {
      Companion_instance_43.o1w(eqn, 0, t1);
    }
    var i;
    var tmp;
    if (t0 <= 0) {
      tmp = 0;
    } else {
      Companion_instance_43.o1w(eqn, 0, t0 / t1);
      tmp = 6;
    }
    i = tmp;
    return new Order3(eqn[i + 0 | 0], ystart, eqn[i + 2 | 0], eqn[i + 3 | 0], eqn[i + 4 | 0], eqn[i + 5 | 0], eqn[i + 6 | 0], yend, dir);
  }
  h1r(coords) {
    if (this.v1q_1 === 1) {
      coords[0] = this.q1x_1;
      coords[1] = this.r1x_1;
      coords[2] = this.s1x_1;
      coords[3] = this.t1x_1;
      coords[4] = this.u1x_1;
      coords[5] = this.v1x_1;
    } else {
      coords[0] = this.s1x_1;
      coords[1] = this.t1x_1;
      coords[2] = this.q1x_1;
      coords[3] = this.r1x_1;
      coords[4] = this.o1x_1;
      coords[5] = this.p1x_1;
    }
    return 3;
  }
  y1q(r) {
    var r_0 = r;
    r_0 = r_0.t1m(this.o1x_1, this.p1x_1);
    // Inline function 'kotlin.doubleArrayOf' call
    var eqn = new Float64Array([this.z1x_1, 2 * this.a1y_1, 3 * this.b1y_1]);
    var numroots = Companion_instance_46.m1x(eqn, eqn);
    var inductionVariable = 0;
    if (inductionVariable < numroots)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var t = eqn[i];
        if (t > 0 && t < 1) {
          r_0 = r_0.t1m(this.f1v(t), this.a1v(t));
        }
      }
       while (inductionVariable < numroots);
    return r_0.t1m(this.u1x_1, this.v1x_1);
  }
  m1y() {
    return this.v1q_1 === 1 ? this.q1x_1 : this.s1x_1;
  }
  n1y() {
    return this.v1q_1 === 1 ? this.r1x_1 : this.t1x_1;
  }
  o1y() {
    return this.v1q_1 === -1 ? this.q1x_1 : this.s1x_1;
  }
  p1y() {
    return this.v1q_1 === -1 ? this.r1x_1 : this.t1x_1;
  }
}
class Iterator {
  constructor(path) {
    Companion_getInstance_44();
    this.a1z_1 = path;
    this.b1z_1 = 0;
    this.c1z_1 = 0;
  }
  g1q() {
    return this.a1z_1.z1y_1;
  }
  b17() {
    return this.b1z_1 >= this.a1z_1.x1y_1;
  }
  h1q() {
    var tmp = this.a1z_1.w1y_1;
    var _unary__edvuaz = this.b1z_1;
    this.b1z_1 = _unary__edvuaz + 1 | 0;
    var type = tmp[_unary__edvuaz];
    this.c1z_1 = this.c1z_1 + Companion_getInstance_44().d1z_1[type] | 0;
  }
}
class CopyIterator extends Iterator {
  constructor(p2dd) {
    super(p2dd);
    this.v1y_1 = p2dd.x1o_1;
  }
  i1q(coords) {
    var type = this.a1z_1.w1y_1[this.b1z_1];
    var numCoords = Companion_getInstance_44().d1z_1[type];
    if (numCoords > 0) {
      var inductionVariable = 0;
      if (inductionVariable < numCoords)
        do {
          var i = inductionVariable;
          inductionVariable = inductionVariable + 1 | 0;
          coords[i] = this.v1y_1[this.c1z_1 + i | 0];
        }
         while (inductionVariable < numCoords);
    }
    return type;
  }
}
class TxIterator extends Iterator {
  constructor(p2dd, at) {
    super(p2dd);
    this.h1z_1 = p2dd.x1o_1;
    this.i1z_1 = at;
  }
  i1q(coords) {
    var type = this.a1z_1.w1y_1[this.b1z_1];
    var numCoords = Companion_getInstance_44().d1z_1[type];
    if (numCoords > 0) {
      this.i1z_1.r1o(this.h1z_1, this.c1z_1, coords, 0, numCoords / 2 | 0);
    }
    return type;
  }
}
class Companion_44 {
  constructor() {
    Companion_instance_44 = this;
    var tmp = this;
    // Inline function 'kotlin.intArrayOf' call
    tmp.d1z_1 = new Int32Array([2, 2, 4, 6, 0]);
  }
}
class Path2D {
  static l1z() {
    var $this = createThis(this);
    init_org_mkui_geom_Path2D($this);
    $this.w1y_1 = new Int8Array(0);
    return $this;
  }
  static k1z(rule, initialTypes) {
    var $this = createThis(this);
    init_org_mkui_geom_Path2D($this);
    $this.z1y_1 = rule;
    $this.w1y_1 = new Int8Array(initialTypes);
    return $this;
  }
  g20() {
    if (this.x1y_1 === 0 || !(this.w1y_1[this.x1y_1 - 1 | 0] === 4)) {
      this.z1z(true, 0);
      var tmp = this.w1y_1;
      var _unary__edvuaz = this.x1y_1;
      this.x1y_1 = _unary__edvuaz + 1 | 0;
      tmp[_unary__edvuaz] = 4;
    }
  }
  z1l(p) {
    return this.v1m(p.w1l(), p.x1l());
  }
  v1m(x, y) {
    var tmp;
    if (x * 0.0 + y * 0.0 === 0.0) {
      if (this.x1y_1 < 2) {
        return false;
      }
      var mask = this.z1y_1 === 1 ? -1 : 1;
      tmp = !((this.a20(x, y) & mask) === 0);
    } else {
      tmp = false;
    }
    return tmp;
  }
  b1m(r) {
    return this.u1m(r.w1l(), r.x1l(), r.cm(), r.dm());
  }
  u1m(x, y, w, h) {
    if (isNaN_0(x + w) || isNaN_0(y + h)) {
      return false;
    }
    if (w <= 0 || h <= 0) {
      return false;
    }
    var mask = this.z1y_1 === 1 ? -1 : 2;
    var crossings = this.b20(x, y, x + w, y + h);
    return crossings === -2147483648 || !((crossings & mask) === 0);
  }
}
class Double_1 extends Path2D {
  static j1z(rule, initialCapacity) {
    rule = rule === VOID ? 1 : rule;
    initialCapacity = initialCapacity === VOID ? 20 : initialCapacity;
    var $this = this.k1z(rule, initialCapacity);
    init_org_mkui_geom_Path2D_Double($this);
    $this.x1o_1 = new Float64Array(imul_0(initialCapacity, 2));
    return $this;
  }
  static y1o(s, at) {
    var $this = this.l1z();
    init_org_mkui_geom_Path2D_Double($this);
    if (s instanceof Path2D) {
      $this.z1y_1 = s.z1y_1;
      $this.x1y_1 = s.x1y_1;
      $this.w1y_1 = Companion_instance_45.w1z(s.w1y_1, s.x1y_1);
      $this.y1y_1 = s.y1y_1;
      $this.x1o_1 = s.x1z(at);
    } else {
      var pi = s.e1m(at);
      $this.z1y_1 = pi.g1q();
      $this.w1y_1 = new Int8Array(20);
      $this.x1o_1 = new Float64Array(40);
      $this.m1z(pi, false);
    }
    return $this;
  }
  x1z(at) {
    var ret;
    if (at == null) {
      ret = Companion_instance_45.y1z(this.x1o_1, this.y1y_1);
    } else {
      ret = new Float64Array(this.y1y_1);
      at.r1o(this.x1o_1, 0, ret, 0, this.y1y_1 / 2 | 0);
    }
    return ret;
  }
  z1z(needMove, newCoords) {
    // Inline function 'kotlin.check' call
    if (!!(needMove && this.x1y_1 === 0)) {
      // Inline function 'org.mkui.geom.Double.needRoom.<anonymous>' call
      var message = 'missing initial moveto in path definition';
      throw IllegalStateException.n4(toString_1(message));
    }
    var size = this.w1y_1.length;
    if (this.x1y_1 >= size) {
      var grow = size;
      if (grow > 500) {
        grow = 500;
      }
      this.w1y_1 = Companion_instance_45.w1z(this.w1y_1, size + grow | 0);
    }
    size = this.x1o_1.length;
    if ((this.y1y_1 + newCoords | 0) > size) {
      var grow_0 = size;
      if (grow_0 > 1000) {
        grow_0 = 1000;
      }
      if (grow_0 < newCoords) {
        grow_0 = newCoords;
      }
      this.x1o_1 = Companion_instance_45.y1z(this.x1o_1, size + grow_0 | 0);
    }
  }
  a20(px, py) {
    if (this.x1y_1 === 0) {
      return 0;
    }
    var movx;
    var coords = this.x1o_1;
    movx = coords[0];
    var curx = movx;
    var movy;
    movy = coords[1];
    var cury = movy;
    var crossings = 0;
    var ci = 2;
    var inductionVariable = 1;
    var last = this.x1y_1;
    if (inductionVariable < last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var endy;
        var endx;
        var tmp0_subject = this.w1y_1[i];
        if (tmp0_subject === 0) {
          if (!(cury === movy)) {
            crossings = crossings + Companion_instance_38.o1u(px, py, curx, cury, movx, movy) | 0;
          }
          // Inline function 'kotlin.run' call
          // Inline function 'org.mkui.geom.Double.pointCrossings.<anonymous>' call
          var _unary__edvuaz = ci;
          ci = _unary__edvuaz + 1 | 0;
          curx = coords[_unary__edvuaz];
          movx = curx;
          // Inline function 'kotlin.run' call
          // Inline function 'org.mkui.geom.Double.pointCrossings.<anonymous>' call
          var _unary__edvuaz_0 = ci;
          ci = _unary__edvuaz_0 + 1 | 0;
          cury = coords[_unary__edvuaz_0];
          movy = cury;
        } else if (tmp0_subject === 1) {
          var tmp = crossings;
          var tmp_0 = Companion_instance_38;
          var tmp_1 = curx;
          var tmp_2 = cury;
          var _unary__edvuaz_1 = ci;
          ci = _unary__edvuaz_1 + 1 | 0;
          // Inline function 'kotlin.also' call
          var this_0 = coords[_unary__edvuaz_1];
          // Inline function 'org.mkui.geom.Double.pointCrossings.<anonymous>' call
          endx = this_0;
          var tmp_3 = this_0;
          var _unary__edvuaz_2 = ci;
          ci = _unary__edvuaz_2 + 1 | 0;
          // Inline function 'kotlin.also' call
          var this_1 = coords[_unary__edvuaz_2];
          // Inline function 'org.mkui.geom.Double.pointCrossings.<anonymous>' call
          endy = this_1;
          crossings = tmp + tmp_0.o1u(px, py, tmp_1, tmp_2, tmp_3, this_1) | 0;
          curx = endx;
          cury = endy;
        } else if (tmp0_subject === 2) {
          var tmp_4 = crossings;
          var tmp_5 = Companion_instance_38;
          var tmp_6 = curx;
          var tmp_7 = cury;
          var _unary__edvuaz_3 = ci;
          ci = _unary__edvuaz_3 + 1 | 0;
          var tmp_8 = coords[_unary__edvuaz_3];
          var _unary__edvuaz_4 = ci;
          ci = _unary__edvuaz_4 + 1 | 0;
          var tmp_9 = coords[_unary__edvuaz_4];
          var _unary__edvuaz_5 = ci;
          ci = _unary__edvuaz_5 + 1 | 0;
          // Inline function 'kotlin.also' call
          var this_2 = coords[_unary__edvuaz_5];
          // Inline function 'org.mkui.geom.Double.pointCrossings.<anonymous>' call
          endx = this_2;
          var tmp_10 = this_2;
          var _unary__edvuaz_6 = ci;
          ci = _unary__edvuaz_6 + 1 | 0;
          // Inline function 'kotlin.also' call
          var this_3 = coords[_unary__edvuaz_6];
          // Inline function 'org.mkui.geom.Double.pointCrossings.<anonymous>' call
          endy = this_3;
          crossings = tmp_4 + tmp_5.p1u(px, py, tmp_6, tmp_7, tmp_8, tmp_9, tmp_10, this_3, 0) | 0;
          curx = endx;
          cury = endy;
        } else if (tmp0_subject === 3) {
          var tmp_11 = crossings;
          var tmp_12 = Companion_instance_38;
          var tmp_13 = curx;
          var tmp_14 = cury;
          var _unary__edvuaz_7 = ci;
          ci = _unary__edvuaz_7 + 1 | 0;
          var tmp_15 = coords[_unary__edvuaz_7];
          var _unary__edvuaz_8 = ci;
          ci = _unary__edvuaz_8 + 1 | 0;
          var tmp_16 = coords[_unary__edvuaz_8];
          var _unary__edvuaz_9 = ci;
          ci = _unary__edvuaz_9 + 1 | 0;
          var tmp_17 = coords[_unary__edvuaz_9];
          var _unary__edvuaz_10 = ci;
          ci = _unary__edvuaz_10 + 1 | 0;
          var tmp_18 = coords[_unary__edvuaz_10];
          var _unary__edvuaz_11 = ci;
          ci = _unary__edvuaz_11 + 1 | 0;
          // Inline function 'kotlin.also' call
          var this_4 = coords[_unary__edvuaz_11];
          // Inline function 'org.mkui.geom.Double.pointCrossings.<anonymous>' call
          endx = this_4;
          var tmp_19 = this_4;
          var _unary__edvuaz_12 = ci;
          ci = _unary__edvuaz_12 + 1 | 0;
          // Inline function 'kotlin.also' call
          var this_5 = coords[_unary__edvuaz_12];
          // Inline function 'org.mkui.geom.Double.pointCrossings.<anonymous>' call
          endy = this_5;
          crossings = tmp_11 + tmp_12.q1u(px, py, tmp_13, tmp_14, tmp_15, tmp_16, tmp_17, tmp_18, tmp_19, this_5, 0) | 0;
          curx = endx;
          cury = endy;
        } else if (tmp0_subject === 4) {
          if (!(cury === movy)) {
            crossings = crossings + Companion_instance_38.o1u(px, py, curx, cury, movx, movy) | 0;
          }
          curx = movx;
          cury = movy;
        }
      }
       while (inductionVariable < last);
    if (!(cury === movy)) {
      crossings = crossings + Companion_instance_38.o1u(px, py, curx, cury, movx, movy) | 0;
    }
    return crossings;
  }
  b20(rxmin, rymin, rxmax, rymax) {
    if (this.x1y_1 === 0) {
      return 0;
    }
    var coords = this.x1o_1;
    var movx;
    movx = coords[0];
    var curx = movx;
    var movy;
    movy = coords[1];
    var cury = movy;
    var crossings = 0;
    var ci = 2;
    var i = 1;
    while (!(crossings === -2147483648) && i < this.x1y_1) {
      var endy;
      var endx;
      var tmp0_subject = this.w1y_1[i];
      if (tmp0_subject === 0) {
        if (!(curx === movx) || !(cury === movy)) {
          crossings = Companion_instance_38.r1u(crossings, rxmin, rymin, rxmax, rymax, curx, cury, movx, movy);
        }
        // Inline function 'kotlin.run' call
        // Inline function 'org.mkui.geom.Double.rectCrossings.<anonymous>' call
        var _unary__edvuaz = ci;
        ci = _unary__edvuaz + 1 | 0;
        curx = coords[_unary__edvuaz];
        movx = curx;
        // Inline function 'kotlin.run' call
        // Inline function 'org.mkui.geom.Double.rectCrossings.<anonymous>' call
        var _unary__edvuaz_0 = ci;
        ci = _unary__edvuaz_0 + 1 | 0;
        cury = coords[_unary__edvuaz_0];
        movy = cury;
      } else if (tmp0_subject === 1) {
        var _unary__edvuaz_1 = ci;
        ci = _unary__edvuaz_1 + 1 | 0;
        endx = coords[_unary__edvuaz_1];
        var _unary__edvuaz_2 = ci;
        ci = _unary__edvuaz_2 + 1 | 0;
        endy = coords[_unary__edvuaz_2];
        crossings = Companion_instance_38.r1u(crossings, rxmin, rymin, rxmax, rymax, curx, cury, endx, endy);
        curx = endx;
        cury = endy;
      } else if (tmp0_subject === 2) {
        var tmp = Companion_instance_38;
        var tmp_0 = crossings;
        var tmp_1 = curx;
        var tmp_2 = cury;
        var _unary__edvuaz_3 = ci;
        ci = _unary__edvuaz_3 + 1 | 0;
        var tmp_3 = coords[_unary__edvuaz_3];
        var _unary__edvuaz_4 = ci;
        ci = _unary__edvuaz_4 + 1 | 0;
        var tmp_4 = coords[_unary__edvuaz_4];
        var _unary__edvuaz_5 = ci;
        ci = _unary__edvuaz_5 + 1 | 0;
        // Inline function 'kotlin.also' call
        var this_0 = coords[_unary__edvuaz_5];
        // Inline function 'org.mkui.geom.Double.rectCrossings.<anonymous>' call
        endx = this_0;
        var tmp_5 = this_0;
        var _unary__edvuaz_6 = ci;
        ci = _unary__edvuaz_6 + 1 | 0;
        // Inline function 'kotlin.also' call
        var this_1 = coords[_unary__edvuaz_6];
        // Inline function 'org.mkui.geom.Double.rectCrossings.<anonymous>' call
        endy = this_1;
        crossings = tmp.s1u(tmp_0, rxmin, rymin, rxmax, rymax, tmp_1, tmp_2, tmp_3, tmp_4, tmp_5, this_1, 0);
        curx = endx;
        cury = endy;
      } else if (tmp0_subject === 3) {
        var tmp_6 = Companion_instance_38;
        var tmp_7 = crossings;
        var tmp_8 = curx;
        var tmp_9 = cury;
        var _unary__edvuaz_7 = ci;
        ci = _unary__edvuaz_7 + 1 | 0;
        var tmp_10 = coords[_unary__edvuaz_7];
        var _unary__edvuaz_8 = ci;
        ci = _unary__edvuaz_8 + 1 | 0;
        var tmp_11 = coords[_unary__edvuaz_8];
        var _unary__edvuaz_9 = ci;
        ci = _unary__edvuaz_9 + 1 | 0;
        var tmp_12 = coords[_unary__edvuaz_9];
        var _unary__edvuaz_10 = ci;
        ci = _unary__edvuaz_10 + 1 | 0;
        var tmp_13 = coords[_unary__edvuaz_10];
        var _unary__edvuaz_11 = ci;
        ci = _unary__edvuaz_11 + 1 | 0;
        // Inline function 'kotlin.also' call
        var this_2 = coords[_unary__edvuaz_11];
        // Inline function 'org.mkui.geom.Double.rectCrossings.<anonymous>' call
        endx = this_2;
        var tmp_14 = this_2;
        var _unary__edvuaz_12 = ci;
        ci = _unary__edvuaz_12 + 1 | 0;
        // Inline function 'kotlin.also' call
        var this_3 = coords[_unary__edvuaz_12];
        // Inline function 'org.mkui.geom.Double.rectCrossings.<anonymous>' call
        endy = this_3;
        crossings = tmp_6.t1u(tmp_7, rxmin, rymin, rxmax, rymax, tmp_8, tmp_9, tmp_10, tmp_11, tmp_12, tmp_13, tmp_14, this_3, 0);
        curx = endx;
        cury = endy;
      } else if (tmp0_subject === 4) {
        if (!(curx === movx) || !(cury === movy)) {
          crossings = Companion_instance_38.r1u(crossings, rxmin, rymin, rxmax, rymax, curx, cury, movx, movy);
        }
        curx = movx;
        cury = movy;
      }
      i = i + 1 | 0;
    }
    if (!(crossings === -2147483648) && (!(curx === movx) || !(cury === movy))) {
      crossings = Companion_instance_38.r1u(crossings, rxmin, rymin, rxmax, rymax, curx, cury, movx, movy);
    }
    return crossings;
  }
  c20(x, y) {
    if (this.x1y_1 > 0 && this.w1y_1[this.x1y_1 - 1 | 0] === 0) {
      this.x1o_1[this.y1y_1 - 2 | 0] = x;
      this.x1o_1[this.y1y_1 - 1 | 0] = y;
    } else {
      this.z1z(false, 2);
      var tmp = this.w1y_1;
      var _unary__edvuaz = this.x1y_1;
      this.x1y_1 = _unary__edvuaz + 1 | 0;
      tmp[_unary__edvuaz] = 0;
      var tmp_0 = this.x1o_1;
      var _unary__edvuaz_0 = this.y1y_1;
      this.y1y_1 = _unary__edvuaz_0 + 1 | 0;
      tmp_0[_unary__edvuaz_0] = x;
      var tmp_1 = this.x1o_1;
      var _unary__edvuaz_1 = this.y1y_1;
      this.y1y_1 = _unary__edvuaz_1 + 1 | 0;
      tmp_1[_unary__edvuaz_1] = y;
    }
  }
  d20(x, y) {
    this.z1z(true, 2);
    var tmp = this.w1y_1;
    var _unary__edvuaz = this.x1y_1;
    this.x1y_1 = _unary__edvuaz + 1 | 0;
    tmp[_unary__edvuaz] = 1;
    var tmp_0 = this.x1o_1;
    var _unary__edvuaz_0 = this.y1y_1;
    this.y1y_1 = _unary__edvuaz_0 + 1 | 0;
    tmp_0[_unary__edvuaz_0] = x;
    var tmp_1 = this.x1o_1;
    var _unary__edvuaz_1 = this.y1y_1;
    this.y1y_1 = _unary__edvuaz_1 + 1 | 0;
    tmp_1[_unary__edvuaz_1] = y;
  }
  e20(x1, y1, x2, y2) {
    this.z1z(true, 4);
    var tmp = this.w1y_1;
    var _unary__edvuaz = this.x1y_1;
    this.x1y_1 = _unary__edvuaz + 1 | 0;
    tmp[_unary__edvuaz] = 2;
    var tmp_0 = this.x1o_1;
    var _unary__edvuaz_0 = this.y1y_1;
    this.y1y_1 = _unary__edvuaz_0 + 1 | 0;
    tmp_0[_unary__edvuaz_0] = x1;
    var tmp_1 = this.x1o_1;
    var _unary__edvuaz_1 = this.y1y_1;
    this.y1y_1 = _unary__edvuaz_1 + 1 | 0;
    tmp_1[_unary__edvuaz_1] = y1;
    var tmp_2 = this.x1o_1;
    var _unary__edvuaz_2 = this.y1y_1;
    this.y1y_1 = _unary__edvuaz_2 + 1 | 0;
    tmp_2[_unary__edvuaz_2] = x2;
    var tmp_3 = this.x1o_1;
    var _unary__edvuaz_3 = this.y1y_1;
    this.y1y_1 = _unary__edvuaz_3 + 1 | 0;
    tmp_3[_unary__edvuaz_3] = y2;
  }
  f20(x1, y1, x2, y2, x3, y3) {
    this.z1z(true, 6);
    var tmp = this.w1y_1;
    var _unary__edvuaz = this.x1y_1;
    this.x1y_1 = _unary__edvuaz + 1 | 0;
    tmp[_unary__edvuaz] = 3;
    var tmp_0 = this.x1o_1;
    var _unary__edvuaz_0 = this.y1y_1;
    this.y1y_1 = _unary__edvuaz_0 + 1 | 0;
    tmp_0[_unary__edvuaz_0] = x1;
    var tmp_1 = this.x1o_1;
    var _unary__edvuaz_1 = this.y1y_1;
    this.y1y_1 = _unary__edvuaz_1 + 1 | 0;
    tmp_1[_unary__edvuaz_1] = y1;
    var tmp_2 = this.x1o_1;
    var _unary__edvuaz_2 = this.y1y_1;
    this.y1y_1 = _unary__edvuaz_2 + 1 | 0;
    tmp_2[_unary__edvuaz_2] = x2;
    var tmp_3 = this.x1o_1;
    var _unary__edvuaz_3 = this.y1y_1;
    this.y1y_1 = _unary__edvuaz_3 + 1 | 0;
    tmp_3[_unary__edvuaz_3] = y2;
    var tmp_4 = this.x1o_1;
    var _unary__edvuaz_4 = this.y1y_1;
    this.y1y_1 = _unary__edvuaz_4 + 1 | 0;
    tmp_4[_unary__edvuaz_4] = x3;
    var tmp_5 = this.x1o_1;
    var _unary__edvuaz_5 = this.y1y_1;
    this.y1y_1 = _unary__edvuaz_5 + 1 | 0;
    tmp_5[_unary__edvuaz_5] = y3;
  }
  m1z(pi, connect) {
    var connect_0 = connect;
    var coords = new Float64Array(6);
    while (!pi.b17()) {
      var tmp0_subject = toByte(pi.i1q(coords));
      if (tmp0_subject === 0) {
        if (!connect_0 || this.x1y_1 < 1 || this.y1y_1 < 1) {
          this.c20(coords[0], coords[1]);
        } else if (this.w1y_1[this.x1y_1 - 1 | 0] === 4 || this.x1o_1[this.y1y_1 - 2 | 0] !== coords[0] || this.x1o_1[this.y1y_1 - 1 | 0] !== coords[1]) {
          this.d20(coords[0], coords[1]);
        }
      } else if (tmp0_subject === 1) {
        this.d20(coords[0], coords[1]);
      } else if (tmp0_subject === 2) {
        this.e20(coords[0], coords[1], coords[2], coords[3]);
      } else if (tmp0_subject === 3) {
        this.f20(coords[0], coords[1], coords[2], coords[3], coords[4], coords[5]);
      } else if (tmp0_subject === 4) {
        this.g20();
      }
      pi.h1q();
      connect_0 = false;
    }
  }
  y1l() {
    return this.k1p();
  }
  k1p() {
    var x1;
    var y1;
    var x2;
    var y2;
    var i = this.y1y_1;
    if (i > 0) {
      var tmp = this.x1o_1;
      i = i - 1 | 0;
      y2 = tmp[i];
      y1 = y2;
      var tmp_0 = this.x1o_1;
      i = i - 1 | 0;
      x2 = tmp_0[i];
      x1 = x2;
      while (i > 0) {
        var tmp_1 = this.x1o_1;
        i = i - 1 | 0;
        var y = tmp_1[i];
        var tmp_2 = this.x1o_1;
        i = i - 1 | 0;
        var x = tmp_2[i];
        if (x < x1)
          x1 = x;
        if (y < y1)
          y1 = y;
        if (x > x2)
          x2 = x;
        if (y > y2)
          y2 = y;
      }
    } else {
      y2 = 0.0;
      x2 = y2;
      y1 = x2;
      x1 = y1;
    }
    return Double_3.p1m(x1, y1, x2 - x1, y2 - y1);
  }
  d1m() {
    return this.e1m(null);
  }
  e1m(at) {
    var tmp;
    if (at == null) {
      tmp = new CopyIterator(this);
    } else {
      tmp = new TxIterator(this, at);
    }
    return tmp;
  }
}
class Companion_45 {
  constructor() {
    this.n1z_1 = 0;
    this.o1z_1 = 1;
    this.p1z_1 = 20;
    this.q1z_1 = 500;
    this.r1z_1 = 0;
    this.s1z_1 = 1;
    this.t1z_1 = 2;
    this.u1z_1 = 3;
    this.v1z_1 = 4;
  }
  w1z(original, newLength) {
    var copy = new Int8Array(newLength);
    // Inline function 'kotlin.math.min' call
    var a = original.length;
    var tmp$ret$0 = Math.min(a, newLength);
    arraycopy_1(original, 0, copy, 0, tmp$ret$0);
    return copy;
  }
  y1z(original, newLength) {
    var copy = new Float64Array(newLength);
    // Inline function 'kotlin.math.min' call
    var a = original.length;
    var tmp$ret$0 = Math.min(a, newLength);
    arraycopy_0(original, 0, copy, 0, tmp$ret$0);
    return copy;
  }
}
class Point {
  constructor(ix, iy) {
    this.h20_1 = ix;
    this.i20_1 = iy;
  }
  toString() {
    return 'Point.Integer{x=' + this.w1l() + ', y=' + this.x1l() + toString(_Char___init__impl__6a9atx(125));
  }
  w1l() {
    return this.h20_1;
  }
  x1l() {
    return this.i20_1;
  }
  q1o(x, y) {
    var tmp = this;
    // Inline function 'kotlin.math.floor' call
    var x_0 = x + 0.5;
    var tmp$ret$0 = Math.floor(x_0);
    tmp.h20_1 = numberToInt(tmp$ret$0);
    var tmp_0 = this;
    // Inline function 'kotlin.math.floor' call
    var x_1 = y + 0.5;
    var tmp$ret$1 = Math.floor(x_1);
    tmp_0.i20_1 = numberToInt(tmp$ret$1);
  }
  j20(pt) {
    var px = pt.w1l() - this.w1l();
    var py = pt.x1l() - this.x1l();
    // Inline function 'kotlin.math.sqrt' call
    var x = px * px + py * py;
    return Math.sqrt(x);
  }
}
class Double_2 {
  w1l() {
    return this.n1o_1;
  }
  x1l() {
    return this.o1o_1;
  }
  static p1o() {
    var $this = createThis(this);
    init_org_mkui_geom_Point2D_Double($this);
    return $this;
  }
  static s1p(x, y) {
    var $this = createThis(this);
    init_org_mkui_geom_Point2D_Double($this);
    $this.n1o_1 = x;
    $this.o1o_1 = y;
    return $this;
  }
  toString() {
    return 'Point.Double{x=' + this.n1o_1 + ', y=' + this.o1o_1 + toString(_Char___init__impl__6a9atx(125));
  }
  q1o(x, y) {
    this.n1o_1 = x;
    this.o1o_1 = y;
  }
  j20(pt) {
    var px = pt.w1l() - this.n1o_1;
    var py = pt.x1l() - this.o1o_1;
    // Inline function 'kotlin.math.sqrt' call
    var x = px * px + py * py;
    return Math.sqrt(x);
  }
}
class Float {
  static m1o() {
    var $this = createThis(this);
    init_org_mkui_geom_Point2D_Float($this);
    return $this;
  }
  w1l() {
    return this.k1o_1;
  }
  x1l() {
    return this.l1o_1;
  }
  toString() {
    return 'Point.Float{x=' + this.k1o_1 + ', y=' + this.l1o_1 + toString(_Char___init__impl__6a9atx(125));
  }
  q1o(x, y) {
    this.k1o_1 = x;
    this.l1o_1 = y;
  }
  j20(pt) {
    var px = pt.w1l() - this.w1l();
    var py = pt.x1l() - this.x1l();
    // Inline function 'kotlin.math.sqrt' call
    var x = px * px + py * py;
    return Math.sqrt(x);
  }
}
class Companion_46 {
  constructor() {
    this.h1x_1 = -2;
    this.i1x_1 = -1;
    this.j1x_1 = 0;
    this.k1x_1 = 1;
    this.l1x_1 = 2;
  }
  m1x(eqn, res) {
    var a = eqn[2];
    var b = eqn[1];
    var c = eqn[0];
    var roots = 0;
    if (a === 0.0) {
      if (b === 0.0) {
        return -1;
      }
      var _unary__edvuaz = roots;
      roots = _unary__edvuaz + 1 | 0;
      res[_unary__edvuaz] = -c / b;
    } else {
      var d = b * b - 4.0 * a * c;
      if (d < 0.0) {
        return 0;
      }
      // Inline function 'kotlin.math.sqrt' call
      var x = d;
      d = Math.sqrt(x);
      if (b < 0.0) {
        d = -d;
      }
      var q = (b + d) / -2.0;
      var _unary__edvuaz_0 = roots;
      roots = _unary__edvuaz_0 + 1 | 0;
      res[_unary__edvuaz_0] = q / a;
      if (!(q === 0.0)) {
        var _unary__edvuaz_1 = roots;
        roots = _unary__edvuaz_1 + 1 | 0;
        res[_unary__edvuaz_1] = c / q;
      }
    }
    return roots;
  }
}
class RectIterator {
  constructor(r, at) {
    this.p20_1 = 0;
    this.k20_1 = r.w1l();
    this.l20_1 = r.x1l();
    this.m20_1 = r.cm();
    this.n20_1 = r.dm();
    this.o20_1 = at;
    if (this.m20_1 < 0 || this.n20_1 < 0) {
      this.p20_1 = 6;
    }
  }
  g1q() {
    return 1;
  }
  b17() {
    return this.p20_1 > 5;
  }
  h1q() {
    this.p20_1 = this.p20_1 + 1 | 0;
  }
  i1q(coords) {
    if (this.b17()) {
      throw NoSuchElementException.s('rect iterator out of bounds');
    }
    if (this.p20_1 === 5) {
      return 4;
    }
    coords[0] = this.k20_1;
    coords[1] = this.l20_1;
    if (this.p20_1 === 1 || this.p20_1 === 2) {
      coords[0] = coords[0] + this.m20_1;
    }
    if (this.p20_1 === 2 || this.p20_1 === 3) {
      coords[1] = coords[1] + this.n20_1;
    }
    var tmp0_safe_receiver = this.o20_1;
    if (tmp0_safe_receiver == null)
      null;
    else {
      tmp0_safe_receiver.r1o(coords, 0, coords, 0, 1);
    }
    return this.p20_1 === 0 ? 0 : 1;
  }
}
class Rectangle extends AbstractRectangle2D {
  static empty() {
    var $this = this.u1l();
    init_org_mkui_geom_Rectangle($this);
    return $this;
  }
  static fromRectangle(rectangle) {
    var $this = this.u1l();
    init_org_mkui_geom_Rectangle($this);
    $this.q20_1 = rectangle.q20_1;
    $this.r20_1 = rectangle.r20_1;
    $this.s20_1 = rectangle.s20_1;
    $this.t20_1 = rectangle.t20_1;
    return $this;
  }
  static from(x, y, width, height) {
    var $this = this.u1l();
    init_org_mkui_geom_Rectangle($this);
    $this.q20_1 = x;
    $this.r20_1 = y;
    $this.s20_1 = width;
    $this.t20_1 = height;
    return $this;
  }
  t1m(x, y) {
    // Inline function 'kotlin.math.min' call
    var a = this.f1m();
    var x1 = Math.min(a, x);
    // Inline function 'kotlin.math.max' call
    var a_0 = this.i1m();
    var x2 = Math.max(a_0, x);
    // Inline function 'kotlin.math.min' call
    var a_1 = this.h1m();
    var y1 = Math.min(a_1, y);
    // Inline function 'kotlin.math.max' call
    var a_2 = this.j1m();
    var y2 = Math.max(a_2, y);
    return Double_3.p1m(x1, y1, x2 - x1, y2 - y1);
  }
  u20(r) {
    var tx1 = this.q20_1;
    var ty1 = this.r20_1;
    var rx1 = r.q20_1;
    var ry1 = r.r20_1;
    var tx2 = tx1;
    tx2 = tx2 + this.s20_1 | 0;
    var ty2 = ty1;
    ty2 = ty2 + this.t20_1 | 0;
    var rx2 = rx1;
    rx2 = rx2 + r.s20_1 | 0;
    var ry2 = ry1;
    ry2 = ry2 + r.t20_1 | 0;
    if (tx1 < rx1)
      tx1 = rx1;
    if (ty1 < ry1)
      ty1 = ry1;
    if (tx2 > rx2)
      tx2 = rx2;
    if (ty2 > ry2)
      ty2 = ry2;
    tx2 = tx2 - tx1 | 0;
    ty2 = ty2 - ty1 | 0;
    if (tx2 < -2147483648)
      tx2 = -2147483648;
    if (ty2 < -2147483648)
      ty2 = -2147483648;
    return Rectangle.from(tx1, ty1, tx2, ty2);
  }
  toString() {
    return 'Rectangle{x=' + this.w1l() + ', y=' + this.x1l() + ', width=' + this.cm() + ', height=' + this.dm() + toString(_Char___init__impl__6a9atx(125));
  }
  w1l() {
    return this.q20_1;
  }
  x1l() {
    return this.r20_1;
  }
  cm() {
    return this.s20_1;
  }
  dm() {
    return this.t20_1;
  }
  z1l(point) {
    return point.x1l() >= this.x1l() && point.x1l() <= this.x1l() + this.dm() && point.w1l() >= this.w1l() && point.w1l() <= this.w1l() + this.cm();
  }
  s1m() {
    if (_get_isNormalized__vs9aom(this))
      return this;
    var normalizedX = this.q20_1;
    var normalizedY = this.r20_1;
    var normalizedWidth = this.s20_1;
    var normalizedHeight = this.t20_1;
    if (normalizedWidth < 0) {
      normalizedWidth = -normalizedWidth | 0;
      normalizedX = normalizedX - normalizedWidth | 0;
    }
    if (normalizedHeight < 0) {
      normalizedHeight = -normalizedHeight | 0;
      normalizedY = normalizedY - this.t20_1 | 0;
    }
    return Rectangle.from(normalizedX, normalizedY, normalizedWidth, normalizedHeight);
  }
  u1m(x, y, w, h) {
    return this.b1m(Double_3.p1m(x, y, w, h));
  }
  v1m(x, y) {
    return this.z1l(Double_2.s1p(x, y));
  }
}
class Companion_47 {
  v20(x1, y1, x2, y2) {
    var x1_0 = x1;
    var y1_0 = y1;
    var x2_0 = x2;
    var y2_0 = y2;
    if (x2_0 < x1_0) {
      var t = x1_0;
      x1_0 = x2_0;
      x2_0 = t;
    }
    if (y2_0 < y1_0) {
      var t_0 = y1_0;
      y1_0 = y2_0;
      y2_0 = t_0;
    }
    return Double_3.p1m(x1_0, y1_0, x2_0 - x1_0, y2_0 - y1_0);
  }
}
class Double_3 extends AbstractRectangle2D {
  static p1m(x, y, width, height) {
    var $this = this.u1l();
    $this.l1m_1 = x;
    $this.m1m_1 = y;
    $this.n1m_1 = width;
    $this.o1m_1 = height;
    return $this;
  }
  w1l() {
    return this.l1m_1;
  }
  x1l() {
    return this.m1m_1;
  }
  cm() {
    return this.n1m_1;
  }
  dm() {
    return this.o1m_1;
  }
  t1m(x, y) {
    // Inline function 'kotlin.math.min' call
    var a = this.f1m();
    var x1 = Math.min(a, x);
    // Inline function 'kotlin.math.max' call
    var a_0 = this.i1m();
    var x2 = Math.max(a_0, x);
    // Inline function 'kotlin.math.min' call
    var a_1 = this.h1m();
    var y1 = Math.min(a_1, y);
    // Inline function 'kotlin.math.max' call
    var a_2 = this.j1m();
    var y2 = Math.max(a_2, y);
    return Double_3.p1m(x1, y1, x2 - x1, y2 - y1);
  }
  toString() {
    return 'Rectangle2D.Double{x=' + this.w1l() + ', y=' + this.x1l() + ', width=' + this.cm() + ', height=' + this.dm() + toString(_Char___init__impl__6a9atx(125));
  }
  s1m() {
    if (_get_isNormalized__vs9aom_0(this))
      return this;
    var normalizedX = this.w1l();
    var normalizedWidth = this.cm();
    if (normalizedWidth < 0) {
      normalizedWidth = -normalizedWidth;
      normalizedX = normalizedX - normalizedWidth;
    }
    var normalizedHeight = this.dm();
    var normalizedY = this.x1l();
    if (normalizedHeight < 0) {
      normalizedHeight = -normalizedHeight;
      normalizedY = normalizedY - normalizedHeight;
    }
    return Double_3.p1m(normalizedX, normalizedY, normalizedWidth, normalizedHeight);
  }
  u1m(x, y, w, h) {
    return this.b1m(Double_3.p1m(x, y, w, h));
  }
  v1m(x, y) {
    return this.z1l(Double_2.s1p(x, y));
  }
}
class Companion_48 {
  constructor() {
    Companion_instance_48 = this;
    this.w20_1 = 0.7853981633974483;
    var tmp = this;
    // Inline function 'kotlin.math.cos' call
    var x = 0.7853981633974483;
    tmp.x20_1 = 1.0 - Math.cos(x);
    var tmp_0 = this;
    // Inline function 'kotlin.math.tan' call
    var x_0 = 0.7853981633974483;
    tmp_0.y20_1 = Math.tan(x_0);
    var tmp_1 = this;
    // Inline function 'kotlin.math.sqrt' call
    var x_1 = 1.0 + this.y20_1 * this.y20_1;
    tmp_1.z20_1 = Math.sqrt(x_1) - 1 + this.x20_1;
    this.a21_1 = 4.0 / 3.0 * this.x20_1 * this.y20_1 / this.z20_1;
    this.b21_1 = (1.0 - this.a21_1) / 2.0;
    var tmp_2 = this;
    // Inline function 'kotlin.doubleArrayOf' call
    var tmp_3 = new Float64Array([0.0, 0.0, 0.0, 0.5]);
    // Inline function 'kotlin.doubleArrayOf' call
    var tmp_4 = new Float64Array([0.0, 0.0, 1.0, -0.5]);
    // Inline function 'kotlin.doubleArrayOf' call
    var tmp_5 = new Float64Array([0.0, 0.0, 1.0, -this.b21_1, 0.0, this.b21_1, 1.0, 0.0, 0.0, 0.5, 1.0, 0.0]);
    // Inline function 'kotlin.doubleArrayOf' call
    var tmp_6 = new Float64Array([1.0, -0.5, 1.0, 0.0]);
    // Inline function 'kotlin.doubleArrayOf' call
    var tmp_7 = new Float64Array([1.0, -this.b21_1, 1.0, 0.0, 1.0, 0.0, 1.0, -this.b21_1, 1.0, 0.0, 1.0, -0.5]);
    // Inline function 'kotlin.doubleArrayOf' call
    var tmp_8 = new Float64Array([1.0, 0.0, 0.0, 0.5]);
    // Inline function 'kotlin.doubleArrayOf' call
    var tmp_9 = new Float64Array([1.0, 0.0, 0.0, this.b21_1, 1.0, -this.b21_1, 0.0, 0.0, 1.0, -0.5, 0.0, 0.0]);
    // Inline function 'kotlin.doubleArrayOf' call
    var tmp_10 = new Float64Array([0.0, 0.5, 0.0, 0.0]);
    // Inline function 'kotlin.doubleArrayOf' call
    var tmp_11 = new Float64Array([0.0, this.b21_1, 0.0, 0.0, 0.0, 0.0, 0.0, this.b21_1, 0.0, 0.0, 0.0, 0.5]);
    // Inline function 'kotlin.doubleArrayOf' call
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp_2.c21_1 = [tmp_3, tmp_4, tmp_5, tmp_6, tmp_7, tmp_8, tmp_9, tmp_10, tmp_11, new Float64Array([])];
    var tmp_12 = this;
    // Inline function 'kotlin.intArrayOf' call
    tmp_12.d21_1 = new Int32Array([0, 1, 3, 1, 3, 1, 3, 1, 3, 4]);
  }
}
class RoundRectIterator {
  constructor(rr, at) {
    Companion_getInstance_48();
    this.l21_1 = 0;
    this.e21_1 = rr.w1l();
    this.f21_1 = rr.x1l();
    this.g21_1 = rr.cm();
    this.h21_1 = rr.dm();
    var tmp = this;
    var tmp1 = this.g21_1;
    // Inline function 'kotlin.math.abs' call
    var x = rr.m21();
    // Inline function 'kotlin.math.min' call
    var b = Math.abs(x);
    tmp.i21_1 = Math.min(tmp1, b);
    var tmp_0 = this;
    var tmp4 = this.h21_1;
    // Inline function 'kotlin.math.abs' call
    var x_0 = rr.n21();
    // Inline function 'kotlin.math.min' call
    var b_0 = Math.abs(x_0);
    tmp_0.j21_1 = Math.min(tmp4, b_0);
    this.k21_1 = at;
    if (this.i21_1 < 0 || this.j21_1 < 0) {
      this.l21_1 = Companion_getInstance_48().c21_1.length;
    }
  }
  g1q() {
    return 1;
  }
  b17() {
    return this.l21_1 >= Companion_getInstance_48().c21_1.length;
  }
  h1q() {
    this.l21_1 = this.l21_1 + 1 | 0;
  }
  i1q(coords) {
    if (this.b17()) {
      throw NoSuchElementException.s('roundrect iterator out of bounds');
    }
    var ctrls = Companion_getInstance_48().c21_1[this.l21_1];
    var nc = 0;
    var i = 0;
    while (i < ctrls.length) {
      var _unary__edvuaz = nc;
      nc = _unary__edvuaz + 1 | 0;
      coords[_unary__edvuaz] = this.e21_1 + ctrls[i + 0 | 0] * this.g21_1 + ctrls[i + 1 | 0] * this.i21_1;
      var _unary__edvuaz_0 = nc;
      nc = _unary__edvuaz_0 + 1 | 0;
      coords[_unary__edvuaz_0] = this.f21_1 + ctrls[i + 2 | 0] * this.h21_1 + ctrls[i + 3 | 0] * this.j21_1;
      i = i + 4 | 0;
    }
    var tmp0_safe_receiver = this.k21_1;
    if (tmp0_safe_receiver == null)
      null;
    else {
      tmp0_safe_receiver.r1o(coords, 0, coords, 0, nc / 2 | 0);
    }
    return Companion_getInstance_48().d21_1[this.l21_1];
  }
}
class RoundRectangle2D extends AbstractRectangle2D {
  static v21() {
    return this.u1l();
  }
  u1m(x, y, w, h) {
    var x_0 = x;
    var y_0 = y;
    if (this.l1p() || w <= 0 || h <= 0) {
      return false;
    }
    var rrx0 = x_0;
    var rry0 = y_0;
    var rrx1 = rrx0 + this.cm();
    var rry1 = rry0 + this.dm();
    if (x_0 + w <= rrx0 || x_0 >= rrx1 || y_0 + h <= rry0 || y_0 >= rry1) {
      return false;
    }
    var tmp1 = this.cm();
    // Inline function 'kotlin.math.abs' call
    var x_1 = this.m21();
    // Inline function 'kotlin.math.min' call
    var b = Math.abs(x_1);
    var aw = Math.min(tmp1, b) / 2.0;
    var tmp4 = this.dm();
    // Inline function 'kotlin.math.abs' call
    var x_2 = this.n21();
    // Inline function 'kotlin.math.min' call
    var b_0 = Math.abs(x_2);
    var ah = Math.min(tmp4, b_0) / 2.0;
    var x0class = classify(this, x_0, rrx0, rrx1, aw);
    var x1class = classify(this, x_0 + w, rrx0, rrx1, aw);
    var y0class = classify(this, y_0, rry0, rry1, ah);
    var y1class = classify(this, y_0 + h, rry0, rry1, ah);
    if (x0class === 2 || x1class === 2 || y0class === 2 || y1class === 2) {
      return true;
    }
    if (x0class < 2 && x1class > 2 || (y0class < 2 && y1class > 2)) {
      return true;
    }
    x_0 = x1class === 1 ? x_0 + w - (rrx0 + aw) : x_0 - (rrx1 - aw);
    y_0 = y1class === 1 ? y_0 + h - (rry0 + ah) : y_0 - (rry1 - ah);
    x_0 = x_0 / aw;
    y_0 = y_0 / ah;
    return x_0 * x_0 + y_0 * y_0 <= 1.0;
  }
  v1m(x, y) {
    var x_0 = x;
    var y_0 = y;
    if (this.l1p()) {
      return false;
    }
    var rrx0 = x_0;
    var rry0 = y_0;
    var rrx1 = rrx0 + this.cm();
    var rry1 = rry0 + this.dm();
    if (x_0 < rrx0 || y_0 < rry0 || x_0 >= rrx1 || y_0 >= rry1) {
      return false;
    }
    var tmp1 = this.cm();
    // Inline function 'kotlin.math.absoluteValue' call
    var this_0 = this.m21();
    // Inline function 'kotlin.math.min' call
    var b = Math.abs(this_0);
    var aw = Math.min(tmp1, b) / 2.0;
    var tmp4 = this.dm();
    // Inline function 'kotlin.math.absoluteValue' call
    var this_1 = this.n21();
    // Inline function 'kotlin.math.min' call
    var b_0 = Math.abs(this_1);
    var ah = Math.min(tmp4, b_0) / 2.0;
    var tmp;
    var tmp_0 = x_0;
    // Inline function 'kotlin.let' call
    // Inline function 'org.mkui.geom.RoundRectangle2D.contains.<anonymous>' call
    rrx0 = rrx0 + aw;
    if (tmp_0 >= rrx0) {
      var tmp_1 = x_0;
      // Inline function 'kotlin.also' call
      // Inline function 'org.mkui.geom.RoundRectangle2D.contains.<anonymous>' call
      rrx0 = aw;
      tmp = tmp_1 < rrx1 - aw;
    } else {
      tmp = false;
    }
    if (tmp) {
      return true;
    }
    var tmp_2;
    var tmp_3 = y_0;
    // Inline function 'kotlin.let' call
    // Inline function 'org.mkui.geom.RoundRectangle2D.contains.<anonymous>' call
    rry0 = rry0 + ah;
    if (tmp_3 >= rry0) {
      var tmp_4 = y_0;
      // Inline function 'kotlin.also' call
      // Inline function 'org.mkui.geom.RoundRectangle2D.contains.<anonymous>' call
      rry0 = ah;
      tmp_2 = tmp_4 < rry1 - ah;
    } else {
      tmp_2 = false;
    }
    if (tmp_2) {
      return true;
    }
    x_0 = (x_0 - rrx0) / aw;
    y_0 = (y_0 - rry0) / ah;
    return x_0 * x_0 + y_0 * y_0 <= 1.0;
  }
  e1m(at) {
    return new RoundRectIterator(this, at);
  }
  hashCode() {
    var bits = toRawBits(this.w1l());
    var tmp = bits;
    // Inline function 'kotlin.Long.times' call
    var tmp$ret$0 = toRawBits(this.x1l()).j3(toLong(37));
    bits = tmp.h3(tmp$ret$0);
    var tmp_0 = bits;
    // Inline function 'kotlin.Long.times' call
    var tmp$ret$1 = toRawBits(this.cm()).j3(toLong(43));
    bits = tmp_0.h3(tmp$ret$1);
    var tmp_1 = bits;
    // Inline function 'kotlin.Long.times' call
    var tmp$ret$2 = toRawBits(this.dm()).j3(toLong(47));
    bits = tmp_1.h3(tmp$ret$2);
    var tmp_2 = bits;
    // Inline function 'kotlin.Long.times' call
    var tmp$ret$3 = toRawBits(this.m21()).j3(toLong(53));
    bits = tmp_2.h3(tmp$ret$3);
    var tmp_3 = bits;
    // Inline function 'kotlin.Long.times' call
    var tmp$ret$4 = toRawBits(this.n21()).j3(toLong(59));
    bits = tmp_3.h3(tmp$ret$4);
    return bits.l1() ^ bits.r3(32).l1();
  }
  equals(obj) {
    if (obj === this) {
      return true;
    }
    if (obj instanceof RoundRectangle2D) {
      return this.w1l() === obj.w1l() && this.x1l() === obj.x1l() && this.cm() === obj.cm() && this.dm() === obj.dm() && this.m21() === obj.m21() && this.n21() === obj.n21();
    }
    return false;
  }
}
class Double_4 extends RoundRectangle2D {
  w1l() {
    return this.o21_1;
  }
  x1l() {
    return this.p21_1;
  }
  cm() {
    return this.q21_1;
  }
  dm() {
    return this.r21_1;
  }
  m21() {
    return this.s21_1;
  }
  n21() {
    return this.t21_1;
  }
  static u21() {
    var $this = this.v21();
    init_org_mkui_geom_RoundRectangle2D_Double($this);
    return $this;
  }
  static w21(x, y, w, h, arcw, arch) {
    var $this = this.v21();
    init_org_mkui_geom_RoundRectangle2D_Double($this);
    $this.x21(x, y, w, h, arcw, arch);
    return $this;
  }
  t1m(x, y) {
    // Inline function 'kotlin.math.min' call
    var a = this.f1m();
    var x1 = Math.min(a, x);
    // Inline function 'kotlin.math.max' call
    var a_0 = this.i1m();
    var x2 = Math.max(a_0, x);
    // Inline function 'kotlin.math.min' call
    var a_1 = this.h1m();
    var y1 = Math.min(a_1, y);
    // Inline function 'kotlin.math.max' call
    var a_2 = this.j1m();
    var y2 = Math.max(a_2, y);
    return Double_4.w21(x1, y1, x2 - x1, y2 - y1, this.s21_1, this.t21_1);
  }
  s1m() {
    if (_get_isNormalized__vs9aom_1(this))
      return this;
    var normalizedX = this.o21_1;
    var normalizedY = this.p21_1;
    var normalizedWidth = this.q21_1;
    var normalizedHeight = this.r21_1;
    if (normalizedWidth < 0) {
      normalizedWidth = -normalizedWidth;
      normalizedX = normalizedX - normalizedWidth;
    }
    if (normalizedHeight < 0) {
      normalizedHeight = -normalizedHeight;
      normalizedY = normalizedY - normalizedHeight;
    }
    return Double_4.w21(normalizedX, normalizedY, normalizedWidth, normalizedHeight, this.s21_1, this.t21_1);
  }
  x21(x, y, w, h, arcw, arch) {
    this.o21_1 = x;
    this.p21_1 = y;
    this.q21_1 = w;
    this.r21_1 = h;
    this.s21_1 = arcw;
    this.t21_1 = arch;
  }
  l1p() {
    return this.q21_1 <= 0.0 || this.r21_1 <= 0.0;
  }
}
class ScreenTransformHelper {
  y21(xModel, yModel) {
    var tmp;
    if (yModel.u15()) {
      var xs = xModel.m15() / xModel.t15();
      var ys = yModel.m15() / yModel.t15();
      var at = AffineTransform.z1n();
      at.d1o(xs, ys);
      at.e1o(-xModel.s15(), -yModel.s15());
      tmp = at;
    } else {
      var xs_0 = xModel.m15() / xModel.t15();
      var ys_0 = yModel.m15() / yModel.t15();
      var tx = -xModel.s15() * xs_0;
      var ty = yModel.s15() * ys_0 + yModel.m15();
      tmp = AffineTransform.c1o(xs_0, 0.0, 0.0, -ys_0, tx, ty);
    }
    return tmp;
  }
}
class TextShape {
  c22() {
    return true;
  }
  y1l() {
    return this.a22_1.y1l();
  }
  d22(at) {
    throw NotImplementedError.bk();
  }
}
class Companion_49 {}
class AbstractIGraphics {
  constructor() {
    this.e22_1 = null;
    this.f22_1 = null;
  }
}
class Insets {
  constructor(top, left, bottom, right) {
    this.j22_1 = 0;
    this.k22_1 = 0;
    this.l22_1 = 0;
    this.m22_1 = 0;
    this.j22_1 = top;
    this.k22_1 = left;
    this.l22_1 = bottom;
    this.m22_1 = right;
  }
}
class Companion_50 {
  constructor() {
    Companion_instance_50 = this;
    this.n22_1 = 0.5;
    this.o22_1 = listOf_0([Off_getInstance(), Brightness_getInstance(), BlackWhite_getInstance(), Complement_getInstance()]);
  }
}
class ContrastEnhancement {
  constructor() {
    Companion_getInstance_50();
  }
}
class Off extends ContrastEnhancement {
  constructor() {
    Off_instance = null;
    super();
    Off_instance = this;
  }
  p22(foreground, background) {
    return foreground;
  }
}
class Brightness extends ContrastEnhancement {
  constructor() {
    Brightness_instance = null;
    super();
    Brightness_instance = this;
  }
  p22(foreground, background) {
    var foreground_0 = foreground;
    var diff_0 = diff(foreground_0, background);
    var tmp;
    if (diff_0 <= 0.5) {
      var foregroundBrightness = brightness(foreground_0);
      var tmp_0 = foreground_0;
      // Inline function 'kotlin.math.min' call
      var b = foregroundBrightness + (0.5 - diff_0);
      var tmp$ret$0 = Math.min(1.0, b);
      var brighterForeground = replaceBrightness(tmp_0, tmp$ret$0);
      var tmp_1 = foreground_0;
      // Inline function 'kotlin.math.max' call
      var b_0 = foregroundBrightness - (0.5 - diff_0);
      var tmp$ret$1 = Math.max(0.0, b_0);
      var darkerForeground = replaceBrightness(tmp_1, tmp$ret$1);
      var backgroundLuminance = luminance(background);
      // Inline function 'kotlin.math.abs' call
      var x = luminance(brighterForeground) - backgroundLuminance;
      var brighterDiff = Math.abs(x);
      // Inline function 'kotlin.math.abs' call
      var x_0 = luminance(darkerForeground) - backgroundLuminance;
      var darkerDiff = Math.abs(x_0);
      var tmp_2;
      if (brighterDiff > darkerDiff) {
        tmp_2 = brighterForeground;
      } else {
        tmp_2 = darkerForeground;
      }
      foreground_0 = tmp_2;
      tmp = foreground_0;
    } else {
      tmp = foreground_0;
    }
    return tmp;
  }
}
class BlackWhite extends ContrastEnhancement {
  constructor() {
    BlackWhite_instance = null;
    super();
    BlackWhite_instance = this;
  }
  p22(foreground, background) {
    var diff_0 = diff(foreground, background);
    var tmp;
    if (diff_0 <= 0.5) {
      var backgroundLuminance = lum(background);
      tmp = backgroundLuminance >= 186 ? get_Black() : get_White();
    } else {
      tmp = foreground;
    }
    return tmp;
  }
  toString() {
    return 'Black&White';
  }
}
class Complement extends ContrastEnhancement {
  constructor() {
    Complement_instance = null;
    super();
    Complement_instance = this;
  }
  p22(foreground, background) {
    var foreground_0 = foreground;
    var diff_0 = diff(foreground_0, background);
    var tmp;
    if (diff_0 <= 0.5) {
      var alpha = getUAlpha(foreground_0);
      var red = getURed(foreground_0);
      var blue = getUBlue(foreground_0);
      var green = getUBlue(foreground_0);
      // Inline function 'kotlin.UByte.inv' call
      var this_0 = red;
      // Inline function 'kotlin.experimental.inv' call
      var this_1 = _UByte___get_data__impl__jof9qr(this_0);
      var tmp$ret$0 = toByte(~this_1);
      red = _UByte___init__impl__g9hnc4(tmp$ret$0);
      // Inline function 'kotlin.UByte.inv' call
      var this_2 = blue;
      // Inline function 'kotlin.experimental.inv' call
      var this_3 = _UByte___get_data__impl__jof9qr(this_2);
      var tmp$ret$2 = toByte(~this_3);
      blue = _UByte___init__impl__g9hnc4(tmp$ret$2);
      // Inline function 'kotlin.UByte.inv' call
      var this_4 = green;
      // Inline function 'kotlin.experimental.inv' call
      var this_5 = _UByte___get_data__impl__jof9qr(this_4);
      var tmp$ret$4 = toByte(~this_5);
      green = _UByte___init__impl__g9hnc4(tmp$ret$4);
      var complement = colorOf_0(red, green, blue, alpha);
      var backgroundLuminance = luminance(background);
      // Inline function 'kotlin.math.abs' call
      var x = luminance(foreground_0) - backgroundLuminance;
      var brighterDiff = Math.abs(x);
      // Inline function 'kotlin.math.abs' call
      var x_0 = luminance(complement) - backgroundLuminance;
      var darkerDiff = Math.abs(x_0);
      var tmp_0;
      if (brighterDiff > darkerDiff) {
        tmp_0 = foreground_0;
      } else {
        tmp_0 = complement;
      }
      foreground_0 = tmp_0;
      tmp = foreground_0;
    } else {
      tmp = foreground_0;
    }
    return tmp;
  }
}
class Effect {}
class Plain extends Effect {
  constructor() {
    Plain_instance = null;
    super();
    Plain_instance = this;
  }
}
class Shadow extends Effect {
  constructor() {
    Shadow_instance = null;
    super();
    Shadow_instance = this;
  }
}
class Glow extends Effect {
  constructor() {
    Glow_instance = null;
    super();
    Glow_instance = this;
  }
}
class Outline extends Effect {
  constructor() {
    Outline_instance = null;
    super();
    Outline_instance = this;
  }
}
class Emphasize extends Effect {
  constructor() {
    Emphasize_instance = null;
    super();
    Emphasize_instance = this;
  }
}
class Rendering extends Enum {
  get name() {
    return this.a3();
  }
  get ordinal() {
    return this.b3();
  }
}
class Companion_51 {
  constructor() {
    this.CENTER = 0;
    this.TOP = 1;
    this.LEFT = 2;
    this.BOTTOM = 3;
    this.RIGHT = 4;
    this.HORIZONTAL = 0;
    this.VERTICAL = 1;
    this.LEADING = 10;
    this.TRAILING = 11;
    this.NEXT = 12;
  }
  s22() {
    return this.CENTER;
  }
  t22() {
    return this.TOP;
  }
  u22() {
    return this.LEFT;
  }
  v22() {
    return this.BOTTOM;
  }
  w22() {
    return this.RIGHT;
  }
  x22() {
    return this.HORIZONTAL;
  }
  y22() {
    return this.VERTICAL;
  }
  z22() {
    return this.LEADING;
  }
  a23() {
    return this.TRAILING;
  }
  b23() {
    return this.NEXT;
  }
}
class EnhancedLabel {
  constructor() {
    return new.target.z23();
  }
  static z23() {
    var $this = createThis(this);
    $this.isOpaque = false;
    $this.properties = new SimpleProperties();
    $this.c23_1 = $this.properties.vy('rendering', Rendering_Clip_getInstance());
    $this.d23_1 = $this.properties.vy('justified', false);
    $this.e23_1 = $this.properties.vy('effect', Plain_getInstance());
    $this.f23_1 = $this.properties.vy('effectOpacity', 110.0 / 255.0);
    $this.g23_1 = $this.properties.vy('minimumCharactersToDisplay', null);
    $this.h23_1 = $this.properties.vy('angle', 0.0);
    $this.i23_1 = $this.properties.vy('desiredWidth', 2147483647);
    $this.j23_1 = $this.properties.vy('desiredHeight', 2147483647);
    $this.k23_1 = $this.properties.vy('text', null);
    $this.l23_1 = $this.properties.vy('html', false);
    $this.m23_1 = $this.properties.vy('font', Companion_getInstance_55().a24_1.b24());
    $this.n23_1 = $this.properties.vy('verticalAlignment', 0);
    $this.o23_1 = $this.properties.vy('horizontalAlignment', 10);
    $this.p23_1 = $this.properties.vy('width', null);
    $this.q23_1 = $this.properties.vy('height', null);
    $this.r23_1 = $this.properties.vy('insetTop', 0);
    $this.s23_1 = $this.properties.vy('insetLeft', 0);
    $this.t23_1 = $this.properties.vy('insetBottom', 0);
    $this.u23_1 = $this.properties.vy('insetRight', 0);
    $this.v23_1 = $this.properties.vy('background', null);
    $this.w23_1 = $this.properties.vy('foreground', null);
    $this.x23_1 = $this.properties.vy('enabled', true);
    $this.y23_1 = $this.properties.vy('name', null);
    $this.setVerticalAlignment(1);
    return $this;
  }
  c24(_set____db54di) {
    this.isOpaque = _set____db54di;
  }
  d24() {
    return this.isOpaque;
  }
  e24(_set____db54di) {
    this.properties = _set____db54di;
  }
  f24() {
    return this.properties;
  }
  static fromString(text) {
    var $this = this.z23();
    $this.setText(text);
    return $this;
  }
  setName(name) {
    this.y23_1.vo(name);
  }
  getName() {
    return this.y23_1.r2();
  }
  getText() {
    return this.k23_1.r2();
  }
  setText(text) {
    this.k23_1.vo(text);
  }
  g24(html) {
    this.l23_1.vo(html);
  }
  h24() {
    return this.l23_1.r2();
  }
  getFont() {
    return this.m23_1.r2();
  }
  setFont(font) {
    this.m23_1.vo(font);
  }
  getVerticalAlignment() {
    return this.n23_1.r2();
  }
  setVerticalAlignment(verticalAlignment) {
    this.n23_1.vo(verticalAlignment);
  }
  getHorizontalAlignment() {
    return this.o23_1.r2();
  }
  setHorizontalAlignment(horizontalAlignment) {
    this.o23_1.vo(horizontalAlignment);
  }
  getHeight() {
    return this.q23_1.r2();
  }
  getWidth() {
    return this.p23_1.r2();
  }
  getBackground() {
    return this.v23_1.r2();
  }
  setBackground(background) {
    this.v23_1.vo(background);
  }
  getForeground() {
    return this.w23_1.r2();
  }
  setForeground(foreground) {
    this.w23_1.vo(foreground);
  }
  isEnabled() {
    return this.x23_1.r2();
  }
  getInsetTop() {
    return this.r23_1.r2();
  }
  getInsetLeft() {
    return this.s23_1.r2();
  }
  getInsetBottom() {
    return this.t23_1.r2();
  }
  getInsetRight() {
    return this.u23_1.r2();
  }
  setInsetTop(value) {
    this.r23_1.vo(value);
  }
  setInsetLeft(value) {
    this.s23_1.vo(value);
  }
  setInsetBottom(value) {
    this.t23_1.vo(value);
  }
  setInsetRight(value) {
    this.u23_1.vo(value);
  }
  setInsets(top, left, bottom, right) {
    this.r23_1.vo(top);
    this.s23_1.vo(left);
    this.t23_1.vo(bottom);
    this.u23_1.vo(right);
  }
  getEffect() {
    return this.e23_1.r2();
  }
  setEffect(effect) {
    this.e23_1.vo(effect);
  }
  getEffectOpacity() {
    return this.f23_1.r2();
  }
  setEffectOpacity(effectOpacity) {
    this.f23_1.vo(effectOpacity);
  }
  getRendering() {
    return this.c23_1.r2();
  }
  setRendering(rendering) {
    this.c23_1.vo(rendering);
  }
  getMinimumCharactersToDisplay() {
    return this.g23_1.r2();
  }
  setMinimumCharactersToDisplay(minimumCharactersToDisplay) {
    this.g23_1.vo(minimumCharactersToDisplay);
  }
  isJustified() {
    return this.d23_1.r2();
  }
  setJustified(justified) {
    this.d23_1.vo(justified);
  }
  getAngle() {
    return this.h23_1.r2();
  }
  setAngle(angle) {
    this.h23_1.vo(angle);
  }
  getDesiredWidth() {
    return this.i23_1.r2();
  }
  setDesiredWidth(desiredSize) {
    this.i23_1.vo(desiredSize);
  }
  getDesiredHeight() {
    return this.j23_1.r2();
  }
  setDesiredHeight(desiredSize) {
    this.j23_1.vo(desiredSize);
  }
  get isHTML() {
    return this.h24();
  }
  set isHTML(value) {
    this.g24(value);
  }
}
class AbstractPalette {
  static p24() {
    var $this = createThis(this);
    $this.n24_1 = 0;
    $this.o24_1 = Cycle_NONE_getInstance();
    return $this;
  }
  y1j(_set____db54di) {
    this.n24_1 = _set____db54di;
  }
  x1f() {
    return this.n24_1;
  }
  q24() {
    return this.o24_1;
  }
  v24(fraction, colorCount, paletteSize) {
    var entry = round(fraction * (colorCount - 1 | 0));
    var f = entry / (colorCount - 1 | 0);
    var tmp2 = colorCount - 1 | 0;
    // Inline function 'kotlin.math.max' call
    var b = numberToInt(round(f * (paletteSize - 1 | 0)));
    // Inline function 'kotlin.math.min' call
    var b_0 = Math.max(0, b);
    return Math.min(tmp2, b_0);
  }
  get colorCount() {
    return this.x1f();
  }
  set colorCount(value) {
    this.y1j(value);
  }
  get cycle() {
    return this.q24();
  }
}
class MutablePalette {}
class AbstractMutablePalette extends AbstractPalette {
  static m24() {
    var $this = this.p24();
    $this.l24_1 = protoOf(AbstractPalette).q24.call($this);
    $this.k24_1 = CollectionFactory_instance.ll();
    return $this;
  }
  r24(cycle) {
    if (!equals(this.l24_1, cycle)) {
      this.l24_1 = cycle;
      this.s24(new PaletteEvent());
    }
  }
  q24() {
    return this.l24_1;
  }
  t24(listener) {
    this.k24_1.o(listener);
  }
  addPaletteListener(listener) {
    return this.t24(listener);
  }
  u24(listener) {
    var toRemove = null;
    var _iterator__ex2g4s = this.k24_1.x();
    while (_iterator__ex2g4s.y()) {
      var PaletteListener = _iterator__ex2g4s.z();
      var comparable;
      comparable = PaletteListener;
      if (equals(listener, comparable)) {
        toRemove = PaletteListener;
      }
    }
    if (!(toRemove == null)) {
      var removed = this.k24_1.w2(toRemove);
    }
  }
  removePaletteListener(listener) {
    return this.u24(listener);
  }
  s24(event) {
    var _iterator__ex2g4s = this.k24_1.x();
    while (_iterator__ex2g4s.y()) {
      var listener = _iterator__ex2g4s.z();
      listener.l1h(event);
    }
  }
  get cycle() {
    return this.q24();
  }
  set cycle(value) {
    this.r24(value);
  }
}
class Mode extends Enum {}
class Entry_0 {
  constructor(fraction, color) {
    this.l1k_1 = fraction;
    this.m1k_1 = color;
  }
  c25() {
    return this.m1k_1;
  }
  d25(o) {
    return compareTo(this.l1k_1, o.l1k_1);
  }
  d(other) {
    return this.d25(other instanceof Entry_0 ? other : THROW_CCE());
  }
  equals(other) {
    if (this === other)
      return true;
    if (other == null || !getKClassFromExpression(this).equals(getKClassFromExpression(other)))
      return false;
    if (!(other instanceof Entry_0))
      THROW_CCE();
    if (!(this.l1k_1 === other.l1k_1))
      return false;
    return true;
  }
  hashCode() {
    return getNumberHashCode(this.l1k_1);
  }
}
class sam$kotlin_Comparator$0_1 {
  constructor(function_0) {
    this.e25_1 = function_0;
  }
  jf(a, b) {
    return this.e25_1(a, b);
  }
  compare(a, b) {
    return this.jf(a, b);
  }
  b4() {
    return this.e25_1;
  }
  equals(other) {
    var tmp;
    if (!(other == null) ? isInterface(other, Comparator) : false) {
      var tmp_0;
      if (!(other == null) ? isInterface(other, FunctionAdapter) : false) {
        tmp_0 = equals(this.b4(), other.b4());
      } else {
        tmp_0 = false;
      }
      tmp = tmp_0;
    } else {
      tmp = false;
    }
    return tmp;
  }
  hashCode() {
    return hashCode(this.b4());
  }
}
class CustomPalette$1 {
  constructor(this$0) {
    this.f25_1 = this$0;
  }
  g25(event) {
    this.f25_1.s24(new PaletteEvent());
    updateFixedColorGradient(this.f25_1);
  }
  qo(event) {
    return this.g25(event);
  }
}
class DynamicPalette extends AbstractMutablePalette {
  static i25(colors) {
    var $this = this.m24();
    init_org_mkui_palette_DynamicPalette($this);
    $this.a25_1 = toMutableList(colors);
    $this.y1j($this.a25_1.a1());
    return $this;
  }
  j25(fraction) {
    var fraction_0 = fraction;
    var inverted = this.b25_1;
    var tmp0_subject = this.q24();
    switch (tmp0_subject == null ? -1 : tmp0_subject.z2_1) {
      case 2:
        inverted = (numberToInt(fraction_0) % 2 | 0) === 0;
        fraction_0 = fraction_0 - numberToInt(fraction_0);
        break;
      case 1:
        fraction_0 = fraction_0 - numberToInt(fraction_0);
        break;
      default:
        break;
    }
    var tmp;
    if (fraction_0 < this.j1k()) {
      tmp = this.j25(this.j1k());
    } else if (fraction_0 > this.i1k()) {
      tmp = this.j25(this.i1k());
    } else {
      var index = this.v24(!inverted ? fraction_0 : 1 - fraction_0, this.x1f(), this.a25_1.a1());
      tmp = this.a25_1.b1(index);
    }
    return tmp;
  }
  getColor(fraction) {
    return this.j25(fraction);
  }
  j1k() {
    return 0.0;
  }
  i1k() {
    return 1.0;
  }
  k25(index) {
    var tmp;
    if (this.x1f() === this.a25_1.a1()) {
      var tmp_0;
      if (index < 0) {
        tmp_0 = this.k25(0);
      } else if (index > (this.x1f() - 1 | 0)) {
        tmp_0 = this.k25(this.x1f() - 1 | 0);
      } else {
        tmp_0 = this.a25_1.b1(index);
      }
      tmp = tmp_0;
    } else {
      tmp = this.j25(this.x1f() / index);
    }
    return tmp;
  }
  getColorAt(fraction) {
    return this.k25(fraction);
  }
}
class CustomPalette extends DynamicPalette {
  static h25(entries) {
    var $this = this.i25([]);
    $this.u1g_1 = new SimpleProperty(Mode_Ramps_getInstance());
    $this.v1g_1 = entries;
    $this.u1g_1.uo(new CustomPalette$1($this));
    return $this;
  }
  static w1g(entries) {
    // Inline function 'kotlin.comparisons.compareBy' call
    var tmp = CustomPalette$_init_$lambda_rc1wld;
    var tmp$ret$0 = new sam$kotlin_Comparator$0_1(tmp);
    var $this = this.h25(SortedSet.uk(tmp$ret$0, asList(entries)));
    updateFixedColorGradient($this);
    return $this;
  }
  k1k() {
    return this.v1g_1;
  }
  j1k() {
    var tmp;
    if (!this.v1g_1.c1()) {
      tmp = first_0(this.v1g_1).l1k_1;
    } else {
      tmp = super.j1k();
    }
    return tmp;
  }
  i1k() {
    var tmp;
    if (!this.v1g_1.c1()) {
      tmp = last_0(this.v1g_1).l1k_1;
    } else {
      tmp = super.i1k();
    }
    return tmp;
  }
}
class Cycle extends Enum {}
class Companion_52 {}
class FixedPalette extends AbstractPalette {
  static p25(isInverted, colors) {
    var $this = this.p24();
    $this.n25_1 = isInverted;
    $this.o25_1 = colors;
    $this.y1j(!($this.o25_1 == null) ? $this.o25_1.a1() : 0);
    return $this;
  }
  t1j(_set____db54di) {
    this.n25_1 = _set____db54di;
  }
  an() {
    return this.n25_1;
  }
  q25(_set____db54di) {
    this.o25_1 = _set____db54di;
  }
  r25() {
    return this.o25_1;
  }
  static s25(colors) {
    return this.t25(false, colors.slice());
  }
  static t25(inverted, colors) {
    return this.p25(false, toCPColorList(Companion_instance_52, colors));
  }
  static u25(colors) {
    return this.p25(false, toMutableList(colors));
  }
  j25(fraction) {
    var fraction_0 = fraction;
    var inverted = this.an();
    var tmp0_subject = this.q24();
    switch (tmp0_subject == null ? -1 : tmp0_subject.z2_1) {
      case 2:
        inverted = (numberToInt(fraction_0) % 2 | 0) === 0;
        fraction_0 = fraction_0 - numberToInt(fraction_0);
        break;
      case 1:
        fraction_0 = fraction_0 - numberToInt(fraction_0);
        break;
      default:
        break;
    }
    var tmp;
    if (fraction_0 < this.j1k()) {
      tmp = this.j25(this.j1k());
    } else if (fraction_0 > this.i1k()) {
      tmp = this.j25(this.i1k());
    } else {
      var index = this.v24(!inverted ? fraction_0 : 1 - fraction_0, this.x1f(), this.o25_1.a1());
      tmp = this.o25_1.b1(index);
    }
    return tmp;
  }
  getColor(fraction) {
    return this.j25(fraction);
  }
  j1k() {
    return 0.0;
  }
  i1k() {
    return 1.0;
  }
  k25(index) {
    var tmp;
    if (this.x1f() === this.o25_1.a1()) {
      var tmp_0;
      if (index < 0) {
        tmp_0 = this.k25(0);
      } else if (index > (this.x1f() - 1 | 0)) {
        tmp_0 = this.k25(this.x1f() - 1 | 0);
      } else {
        tmp_0 = this.o25_1.b1(index);
      }
      tmp = tmp_0;
    } else {
      tmp = this.j25(this.x1f() / index);
    }
    return tmp;
  }
  getColorAt(fraction) {
    return this.k25(fraction);
  }
  t24(listener) {
  }
  addPaletteListener(listener) {
    return this.t24(listener);
  }
  u24(listener) {
  }
  removePaletteListener(listener) {
    return this.u24(listener);
  }
  r24(value) {
    throw UnsupportedOperationException.h4();
  }
  q24() {
    return super.q24();
  }
  toString() {
    return toString_1(this.j25(0.0)) + '-' + toString_1(this.j25(1.0));
  }
  get cycle() {
    return this.q24();
  }
  set cycle(value) {
    this.r24(value);
  }
}
class Mode_0 extends Enum {}
class Entry_1 {
  constructor(fraction, color) {
    this.fraction = fraction;
    this.n1k_1 = color;
  }
  a26() {
    return this.fraction;
  }
  getColor() {
    return this.n1k_1;
  }
  b26(o) {
    return compareTo(this.fraction, o.fraction);
  }
  d(other) {
    return this.b26(other instanceof Entry_1 ? other : THROW_CCE());
  }
  equals(other) {
    if (this === other)
      return true;
    if (other == null || !getKClassFromExpression(this).equals(getKClassFromExpression(other)))
      return false;
    if (!(other instanceof Entry_1))
      THROW_CCE();
    if (!(this.fraction === other.fraction))
      return false;
    return true;
  }
  hashCode() {
    return getNumberHashCode(this.fraction);
  }
}
class sam$kotlin_Comparator$0_2 {
  constructor(function_0) {
    this.c26_1 = function_0;
  }
  jf(a, b) {
    return this.c26_1(a, b);
  }
  compare(a, b) {
    return this.jf(a, b);
  }
  b4() {
    return this.c26_1;
  }
  equals(other) {
    var tmp;
    if (!(other == null) ? isInterface(other, Comparator) : false) {
      var tmp_0;
      if (!(other == null) ? isInterface(other, FunctionAdapter) : false) {
        tmp_0 = equals(this.b4(), other.b4());
      } else {
        tmp_0 = false;
      }
      tmp = tmp_0;
    } else {
      tmp = false;
    }
    return tmp;
  }
  hashCode() {
    return hashCode(this.b4());
  }
}
class sam$kotlin_Comparator$0_3 {
  constructor(function_0) {
    this.d26_1 = function_0;
  }
  jf(a, b) {
    return this.d26_1(a, b);
  }
  compare(a, b) {
    return this.jf(a, b);
  }
  b4() {
    return this.d26_1;
  }
  equals(other) {
    var tmp;
    if (!(other == null) ? isInterface(other, Comparator) : false) {
      var tmp_0;
      if (!(other == null) ? isInterface(other, FunctionAdapter) : false) {
        tmp_0 = equals(this.b4(), other.b4());
      } else {
        tmp_0 = false;
      }
      tmp = tmp_0;
    } else {
      tmp = false;
    }
    return tmp;
  }
  hashCode() {
    return hashCode(this.b4());
  }
}
class InterpolatedPalette extends FixedPalette {
  constructor(entries) {
    return new.target.e26(entries);
  }
  static e26(entries) {
    var $this = this.p25(false, emptyList());
    $this.entries = entries;
    $this.z25_1 = new SimpleProperty(Mode_Ramps_getInstance_0());
    updateFixedColorGradient_0($this);
    return $this;
  }
  f26(_set____db54di) {
    this.entries = _set____db54di;
  }
  v2() {
    return this.entries;
  }
  static paletteConstructor(p) {
    // Inline function 'kotlin.comparisons.compareBy' call
    var tmp = InterpolatedPalette$_init_$lambda_qt4r8t;
    var tmp$ret$0 = new sam$kotlin_Comparator$0_2(tmp);
    var $this = this.e26(SortedSet.uk(tmp$ret$0));
    var inductionVariable = 0;
    var last = p.colorCount;
    if (inductionVariable < last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var c = p.getColorAt(i);
        $this.entries.o(new Entry_1(i / (p.colorCount - 1 | 0), c));
      }
       while (inductionVariable < last);
    updateFixedColorGradient_0($this);
    return $this;
  }
  static entriesConstructor(e) {
    // Inline function 'kotlin.comparisons.compareBy' call
    var tmp = InterpolatedPalette$_init_$lambda_qt4r8t_0;
    var tmp$ret$0 = new sam$kotlin_Comparator$0_3(tmp);
    var $this = this.e26(SortedSet.uk(tmp$ret$0, asList(e)));
    updateFixedColorGradient_0($this);
    return $this;
  }
  getEntries() {
    return this.entries;
  }
  j1k() {
    var tmp;
    if (!this.entries.c1()) {
      tmp = first_0(this.entries).fraction;
    } else {
      tmp = super.j1k();
    }
    return tmp;
  }
  i1k() {
    var tmp;
    if (!this.entries.c1()) {
      tmp = last_0(this.entries).fraction;
    } else {
      tmp = super.i1k();
    }
    return tmp;
  }
}
class PaletteEvent {}
class Entry_2 {
  constructor(name, type, colors) {
    this.name = name;
    this.type = type;
    this.g26_1 = colors;
  }
  a3() {
    return this.name;
  }
  h26() {
    return this.type;
  }
  getPalette() {
    return this.g26_1;
  }
}
class Companion_53 {
  constructor() {
    Companion_instance_53 = this;
    this.instance = new PaletteFactory();
  }
  i26() {
    return this.instance;
  }
}
class PaletteFactory {
  constructor() {
    Companion_getInstance_53();
    this.p28_1 = ArrayList.e1();
    this.j26_1 = new Entry_2('negpos', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.entriesConstructor([new Entry_1(0.0, colorOf_1(255, 0, 0)), new Entry_1(0.498, colorOf_1(255, 230, 230)), new Entry_1(0.4981, colorOf_1(255, 255, 255)), new Entry_1(0.502, colorOf_1(255, 255, 255)), new Entry_1(0.5021, colorOf_1(230, 255, 230)), new Entry_1(1.0, colorOf_1(0, 128, 0))]));
    this.k26_1 = new Entry_2('treemapper', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.entriesConstructor([new Entry_1(0.0, colorOf_1(255, 0, 0)), new Entry_1(0.5, colorOf_1(255, 255, 255)), new Entry_1(1.0, colorOf_1(0, 128, 0))]));
    this.l26_1 = new Entry_2('composite', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.entriesConstructor([new Entry_1(0.0, colorOf_1(255, 0, 0)), new Entry_1(0.19327731092437, colorOf_1(247, 52, 0)), new Entry_1(0.428571428571429, colorOf_1(83, 10, 0)), new Entry_1(0.563025210084034, colorOf_1(19, 58, 0)), new Entry_1(1.0, colorOf_1(127, 255, 0))]));
    this.m26_1 = new Entry_2('bty', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-16316418, -15263748, -14803206, -14408456, -14145289, -13882123, -13684749, -13487374, -13355792, -13158417, -13026834, -12895252, -12763669, -12632086, -12500503, -12434713, -12303130, -12237339, -12105756, -12039965, -11908382, -11842591, -11776799, -11645216, -11579425, -11513634, -11447843, -11382051, -11250468, -11184677, -11118886, -11053094, -10987303, -10921512, -10855720, -10789929, -10724138, -10658346, -10592555, -10526763, -10460972, -10395180, -10329389, -10329390, -10263598, -10197807, -10132015, -10066224, -10000432, -9934640, -9868849, -9868849, -9803058, -9737266, -9671475, -9605683, -9539892, -9539892, -9474100, -9408309, -9342517, -9276726, -9276726, -9210934, -9145143, -9079351, -9013560, -9013560, -8947768, -8881977, -8816185, -8816185, -8750394, -8684602, -8618810, -8618811, -8553019, -8487227, -8421436, -8355644, -8355645, -8289853, -8224061, -8224062, -8158270, -8092478, -8026687, -8026687, -7960895, -7895104, -7829312, -7829312, -7763521, -7697729, -7631937, -7631938, -7566146, -7500354, -7434563, -7434563, -7368771, -7302980, -7302980, -7237188, -7171397, -7105605, -7105605, -7039814, -6974022, -6974022, -6908231, -6842439, -6776647, -6776648, -6710856, -6645064, -6645065, -6579273, -6513482, -6447690, -6447690, -6381899, -6316107, -6316107, -6250316, -6184524, -6118732, -6118733, -6052941, -5987150, -5987150, -5921358, -5855567, -5789775, -5789776, -5723984, -5658192, -5658193, -5592401, -5526610, -5460818, -5460819, -5395027, -5329235, -5329236, -5263444, -5197653, -5131861, -5131862, -5066070, -5000279, -5000279, -4934488, -4868696, -4868697, -4802905, -4737114, -4671322, -4671323, -4605531, -4539740, -4539740, -4473949, -4408157, -4342366, -4342366, -4276575, -4210783, -4210784, -4144993, -4079201, -4013410, -4013410, -3947619, -3881827, -3881828, -3816037, -3750245, -3684454, -3684455, -3618663, -3552872, -3552873, -3487081, -3421290, -3355499, -3355499, -3289708, -3223917, -3223918, -3158126, -3092335, -3026544, -3026545, -2960753, -2894962, -2894963, -2829172, -2763381, -2697590, -2697590, -2631799, -2566008, -2566009, -2500218, -2434427, -2368636, -2368637, -2302846, -2237055, -2237056, -2171265, -2105474, -2039683, -2039684, -1973893, -1908102, -1908103, -1842313, -1776522, -1710731, -1710732, -1644942, -1579151, -1513360, -1513362, -1447571, -1381781, -1381782, -1315992, -1250201, -1184411, -1184412, -1118622, -1052832, -1052834, -987044, -921253, -855463, -855466, -789676, -723886, -658096, -658099, -592310, -526520, -526523, -460735, -394946, -329158, -329162, -263375, -197588, -131803, -131812, -66035]))));
    this.n26_1 = new Entry_2('heated', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-10544128, -10347008, -10215680, -10084096, -10018304, -9886976, -9821184, -9689600, -9623808, -9492480, -9426432, -9295104, -9229312, -9097984, -8966400, -8966400, -8900608, -8769280, -8703232, -8571904, -8571904, -8506112, -8374784, -8308736, -8308736, -8177408, -8111616, -7980288, -7980288, -7848704, -7782912, -7782912, -7651584, -7651584, -7585536, -7454208, -7454208, -7388416, -7388416, -7257088, -7257088, -7191040, -7191040, -7059712, -7059712, -6993920, -6993920, -6862592, -6862592, -6731008, -6731008, -6665216, -6665216, -6665216, -6533888, -6533888, -6467840, -6467840, -6336512, -6336512, -6336512, -6270720, -6270720, -6139392, -6139392, -6073344, -6073344, -5942016, -5942016, -5876224, -5876224, -5876224, -5744896, -5744896, -5613312, -5613312, -5547520, -5547520, -5416192, -5416192, -5350144, -5350144, -5218816, -5218816, -5153024, -5153024, -5021696, -5021696, -4955648, -4824320, -4824320, -4758528, -4758528, -4626944, -4626944, -4495616, -4495616, -4429824, -4429824, -4298496, -4232448, -4232448, -4101120, -4101120, -4035328, -3904000, -3904000, -3837952, -3837952, -3706624, -3640832, -3640832, -3509248, -3509248, -3377920, -3312128, -3312128, -3180800, -3114752, -3114752, -2983424, -2917632, -2917632, -2786304, -2720256, -2720256, -2588928, -2523136, -2523136, -2391552, -2260224, -2260224, -2194432, -2063104, -2063104, -1997056, -1865728, -1865728, -1799936, -1668608, -1668608, -1602560, -1471232, -1471232, -1405440, -1273856, -1273856, -1142528, -1076736, -945408, -945408, -879360, -748032, -748032, -682240, -550656, -550656, -484864, -353536, -287744, -287744, -156160, -24832, -24832, -24576, -24320, -23808, -23808, -23552, -23296, -22784, -22784, -22528, -22272, -22272, -22016, -21504, -21248, -21248, -20992, -20736, -20224, -19968, -19712, -19200, -19200, -18944, -18688, -18432, -17657, -17398, -17138, -16622, -16363, -16103, -15587, -15068, -14808, -14293, -13773, -13258, -12739, -12479, -11704, -11444, -10669, -10149, -9374, -8855, -8339, -7820, -7045, -6010, -5490, -4715, -4196, -3936, -3161, -2386, -1866, -1607, -831, -572, -52, -49, -45, -38, -34, -31, -27, -23, -20, -16, -12, -9]))));
    this.o26_1 = new Entry_2('rainy', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-16385, -1592075, -3167765, -4743455, -6319145, -7894835, -9470525, -11046215, -12621905, -14197595, -15773285]))));
    this.p26_1 = new Entry_2('linred', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-16777216, -16777216, -16777216, -16777216, -16777216, -16777216, -16777216, -16711680, -16711680, -16711680, -16711680, -16711680, -16711680, -16711680, -16711680, -16711680, -16646144, -16646144, -16646144, -16646144, -16646144, -16646144, -16646144, -16580608, -16580608, -16580608, -16580608, -16580608, -16580608, -16580608, -16515072, -16515072, -16515072, -16515072, -16515072, -16449536, -16449536, -16449536, -16449536, -16449536, -16384000, -16384000, -16384000, -16384000, -16384000, -16318464, -16318464, -16318464, -16318464, -16318464, -16252928, -16252928, -16187392, -16187392, -16187392, -16187392, -16121856, -16121856, -16121856, -16121856, -16121856, -16056320, -16056320, -15990784, -15990784, -15990784, -15925248, -15925248, -15859712, -15859712, -15794176, -15794176, -15794176, -15728640, -15728640, -15663104, -15663104, -15597568, -15597568, -15532032, -15532032, -15532032, -15532032, -15532032, -15466496, -15466496, -15335424, -15335424, -15335424, -15269888, -15269888, -15204352, -15204352, -15073280, -15073280, -15073280, -15007744, -15007744, -14876672, -14876672, -14811136, -14811136, -14680064, -14680064, -14680064, -14680064, -14680064, -14548992, -14548992, -14483456, -14483456, -14483456, -14352384, -14352384, -14221312, -14221312, -14090240, -14090240, -14090240, -13959168, -13959168, -13828096, -13828096, -13762560, -13762560, -13762560, -13697024, -13697024, -13565952, -13565952, -13434880, -13434880, -13369344, -13369344, -13369344, -13238272, -13238272, -13107200, -13107200, -12910592, -12910592, -12910592, -12779520, -12779520, -12582912, -12582912, -12386304, -12386304, -12386304, -12255232, -12255232, -12058624, -12058624, -11862016, -11862016, -11796480, -11796480, -11796480, -11665408, -11665408, -11468800, -11468800, -11272192, -11272192, -11272192, -11075584, -11075584, -10813440, -10813440, -10616832, -10616832, -10616832, -10420224, -10420224, -10158080, -10158080, -9961472, -9961472, -9764864, -9764864, -9764864, -9699328, -9699328, -9437184, -9437184, -9175040, -9175040, -9175040, -8912896, -8912896, -8650752, -8650752, -8388608, -8388608, -8388608, -8126464, -8126464, -7864320, -7864320, -7536640, -7536640, -7274496, -7274496, -7274496, -7143424, -7143424, -6946816, -6946816, -6684672, -6684672, -6684672, -6356992, -6356992, -6029312, -6029312, -5701632, -5701632, -5701632, -5373952, -5373952, -5046272, -5046272, -4653056, -4653056, -4325376, -4325376, -4325376, -3997696, -3997696, -3997696, -3997696, -3604480, -3604480, -3604480, -3211264, -3211264, -2883584, -2883584, -2490368, -2490368, -2490368, -2097152, -2097152, -1703936, -1703936, -1245184, -1245184, -851968, -851968, -851968, -458752, -458752, -262144, -262144, -262144, -65536]))));
    this.q26_1 = new Entry_2('publimedia', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-1, -3634808, -3778215, -4182484, -6087908, -8907752, -11333360, -16777216, -16777216, -16777216, -16777216]))));
    this.r26_1 = new Entry_2('magenta', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-16777216, -14155776, -13107196, -12779511, -12582900, -12451826, -12255215, -11993068, -11927530, -11665383, -11599845, -11337698, -11206625, -11141087, -10878940, -10813402, -10682329, -10551255, -10485717, -10223570, -10092497, -10026959, -9895885, -9764812, -9699274, -9568201, -9437127, -9437127, -9371590, -9240516, -9109442, -8978369, -8912831, -8781758, -8650684, -8585146, -8454073, -8322999, -8322999, -8257462, -8126388, -7995314, -7864241, -7798703, -7667630, -7536556, -7471018, -7339945, -7208871, -7143334, -7012260, -6881186, -6881186, -6750113, -6684575, -6553502, -6422428, -6356890, -6225817, -6094743, -6029206, -5898132, -5767059, -5635985, -5570447, -5439374, -5308300, -5242763, -5111689, -4980615, -4980615, -4915078, -4784004, -4652931, -4521857, -4456319, -4325246, -4194172, -4128635, -3997561, -3866487, -3800950, -3669876, -3538803, -3407729, -3407729, -3342191, -3211118, -3080044, -3014507, -2883433, -2752359, -2686822, -2555748, -2424675, -2293601, -2228064, -2228064, -2096990, -1965916, -1900379, -1769305, -1638232, -1572694, -1441620, -1310547, -1179473, -1179473, -1113936, -982862, -851788, -786251, -655177, -523592, -457542, -457542, -457542, -325956, -325956, -194115, -194115, -62529, -62529, -62016, -62016, -62016, -61246, -60732, -60219, -60219, -59449, -58936, -58422, -57652, -57139, -56625, -55856, -55856, -55342, -54829, -54059, -53545, -53032, -52262, -51749, -51749, -51235, -50721, -49952, -49438, -48925, -48155, -48155, -47641, -47128, -46358, -45845, -45331, -44561, -44561, -44048, -43534, -42765, -42251, -41737, -40968, -40968, -40454, -39941, -39171, -38657, -38145, -38145, -37633, -36865, -36353, -35841, -35841, -35073, -34561, -34049, -34049, -33281, -32769, -32257, -32257, -31489, -30977, -30465, -30465, -29697, -29185, -28673, -28673, -27905, -27393, -26881, -26881, -26113, -25601, -25601, -25089, -24577, -24577, -23809, -23297, -23297, -22785, -22017, -21505, -21505, -20993, -20225, -20225, -19713, -19201, -19201, -18433, -17921, -17921, -17409, -16641, -16641, -16129, -15617, -14849, -14849, -14337, -13825, -13057, -13057, -12545, -12033, -11521, -11521, -10753, -10241, -9729, -9729, -8961, -8449, -7937, -7169, -6657, -6657, -6145, -5377, -4865, -4353, -3585, -3073, -3073, -2561, -1793, -1281, -1]))));
    this.s26_1 = new Entry_2('rainbow', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-16777216, -13828060, -13107154, -12845007, -12386250, -12189637, -12124099, -11861948, -11927479, -11927475, -11993007, -12124073, -12254886, -12320162, -12450975, -12646810, -12777622, -12973459, -13104015, -13299852, -13626761, -13691783, -13887620, -14083200, -14148479, -14344060, -14539642, -14865527, -15125366, -15189621, -15188339, -15187826, -15253106, -15252081, -15251570, -15251570, -15251058, -15250546, -15250546, -15249778, -15249266, -15249266, -15248755, -15247987, -15247987, -15247476, -15247476, -15181172, -15181172, -15180405, -15180405, -15180405, -15180405, -15179381, -15179381, -15112822, -15112822, -15112055, -15112055, -15112055, -15045495, -15045495, -14979192, -14979192, -14979192, -14978169, -14978169, -14911866, -14911866, -14845307, -14845307, -14845307, -14845307, -14844540, -14844540, -14778237, -14778237, -14711934, -14711934, -14711934, -14645632, -14645632, -14579329, -14579329, -14579329, -14513027, -14513027, -14446981, -14446981, -14380679, -14380679, -14380679, -14314634, -14314634, -14248332, -14248332, -14116751, -14116751, -14050705, -14050705, -13984660, -13984660, -13918614, -13918614, -13918614, -13787032, -13787032, -13720987, -13720987, -13589405, -13589405, -13457823, -13457823, -13391777, -13260195, -13260195, -13260195, -13128613, -13128613, -12997032, -12997032, -12865706, -12668588, -12537262, -12537262, -12340144, -12340144, -12208817, -12011699, -12011699, -12011699, -11814836, -11683254, -11486391, -11289272, -11026872, -10764473, -10502074, -10239674, -9977274, -9714874, -9452474, -9452474, -9190330, -8927930, -8665786, -8206777, -8009913, -7747768, -7551160, -7354551, -7354551, -7092407, -6895798, -6699190, -6502581, -6240180, -5781426, -5584817, -5388209, -5388209, -5126064, -4929455, -4733102, -4536494, -4274349, -3881131, -3684779, -3684779, -3422634, -3226281, -2833063, -2636710, -2440357, -2047394, -2047394, -1654432, -1458078, -1261980, -1131160, -1000342, -1000342, -869522, -738958, -673676, -542856, -477573, -477573, -346755, -281472, -215934, -150395, -150395, -84858, -85110, -19570, -19567, -19567, -19560, -19295, -19292, -19289, -19289, -19031, -19030, -18771, -18512, -18512, -18253, -17997, -17994, -17738, -17738, -17479, -17223, -16964, -16964, -16708, -16449, -16193, -15678, -15678, -14907, -14650, -14136, -13879, -13879, -13622, -13365, -12851, -12594, -12594, -12080, -11823, -11309, -10281, -10024, -10024, -9510, -9253, -8739, -8225, -7454, -6940, -6426, -6426, -5912, -5141, -4627, -3856, -3085, -2314, -1543, -1029, -515, -1]))));
    this.t26_1 = new Entry_2('locs', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-16777216, -16777216, -16777216, -16711680, -16646144, -16646144, -16580608, -16580608, -16515072, -16449536, -16449536, -16384000, -16318464, -16318464, -16252928, -16187392, -16187392, -16121856, -16056320, -15990784, -15925248, -15859712, -15794176, -15728640, -15663104, -15597568, -15532032, -15466496, -15400960, -15335424, -15269888, -15138816, -15073280, -15007744, -14942208, -14811136, -14745600, -14614528, -14548992, -14483456, -14352384, -14221312, -14155776, -13959168, -13828096, -13762560, -13565952, -13434880, -13303808, -13238272, -13107200, -12976128, -12845056, -12713984, -12582912, -12386304, -12255232, -12124160, -11927552, -11796480, -11534336, -11468800, -11272192, -11141120, -10944512, -10747904, -10616832, -10420224, -10223616, -10027008, -9830400, -9633792, -9437184, -9240576, -9109504, -8781824, -8519680, -8388608, -8192000, -7929856, -7929856, -7929600, -7929344, -7929088, -7928832, -7928320, -7928320, -7927808, -7927552, -7927296, -7927040, -7926528, -7926528, -7926016, -7925504, -7925504, -7924992, -7924480, -7924224, -7923968, -7923456, -7923200, -7922944, -7922432, -7921920, -7921664, -7921408, -7920896, -7920640, -7920128, -7919616, -7919104, -7918592, -7918080, -7917824, -7917312, -7916800, -7916544, -7916032, -7915520, -7915264, -7914752, -7913984, -7913728, -7913216, -7912704, -7912192, -7911424, -7911168, -7910400, -7909888, -7909376, -7908864, -7908352, -7907584, -7907328, -7906816, -7906048, -7905536, -7904768, -7904000, -7903488, -7902720, -7902464, -7901696, -7900928, -7900416, -7899648, -7898880, -7898112, -7897344, -7896832, -7895808, -7895296, -7894528, -7893760, -7892992, -7891968, -7891456, -7890176, -7889664, -7888896, -7888128, -7887360, -7886336, -7885312, -7884544, -7883776, -7882752, -7881728, -7880704, -7879936, -7878656, -7877888, -7877376, -7876096, -7875072, -7874048, -7873024, -7872000, -7870720, -7869440, -7868672, -7867392, -7866112, -7864832, -7864575, -7864571, -7864566, -7864561, -7864556, -7864553, -7864548, -7864543, -7864538, -7864533, -7864531, -7864527, -7864522, -7864517, -7864511, -7864506, -7864502, -7864496, -7864492, -7864486, -7864481, -7864478, -7864472, -7864466, -7864460, -7864456, -7864451, -7864445, -7864439, -7864432, -7864427, -7864422, -7864418, -7864411, -7864404, -7864397, -7864390, -7864385, -7864378, -7864373, -7864365, -7864360, -7864352, -7864344, -7864336, -7864328, -7864322, -7864321, -7536641, -7143425, -6684673, -6488065, -6160385, -5701633, -5439489, -5111809, -4784129, -4325377, -4128769, -3670017, -3342337, -2949121, -2621441, -2293761, -1966081, -1507329, -1245185, -983041, -458753, -1]))));
    this.u26_1 = new Entry_2('ocs', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-16777216, -16515072, -16252928, -15990784, -15728640, -15466496, -15204352, -14942208, -14680064, -14417920, -14155776, -13893632, -13631488, -13369344, -13107200, -12845056, -12582912, -12320768, -12058624, -11796480, -11534336, -11272192, -11010048, -10747904, -10485760, -10223616, -9961472, -9699328, -9437184, -9175040, -8912128, -8911616, -8910848, -8910336, -8909568, -8909056, -8908288, -8907776, -8907008, -8906496, -8905728, -8905216, -8904448, -8903936, -8903168, -8902656, -8901888, -8901376, -8900608, -8900096, -8899328, -8898816, -8898048, -8897536, -8896768, -8896256, -8895488, -8894976, -8894208, -8893696, -8892928, -8892416, -8891648, -8891136, -8890368, -8889856, -8889088, -8888576, -8887808, -8887296, -8886528, -8886016, -8885248, -8884736, -8883968, -8883456, -8882688, -8882176, -8881408, -8880893, -8880123, -8879608, -8878838, -8878323, -8877553, -8877038, -8876268, -8875753, -8809447, -8743396, -8677090, -8611039, -8544733, -8478682, -8412376, -8346325, -8280019, -8213968, -8147662, -8081611, -8080841, -8080326, -8079556, -8079041, -8078271, -8077756, -8076986, -8076471, -8075701, -8075186, -8074416, -8073901, -8073131, -8072616, -8071846, -8071331, -8070561, -8070046, -8069276, -8068761, -8067991, -8067476, -8066706, -8066191, -8065421, -8064906, -8064136, -8063621, -8062851, -8062336, -8061566, -8061051, -8061049, -8061046, -8061044, -8061041, -8061039, -8061036, -8061034, -8061031, -8061029, -8061026, -8061024, -8061021, -8061019, -8061016, -8061014, -8061011, -8061009, -8061006, -8061004, -8061001, -8060999, -8060996, -8060994, -8060991, -8060989, -8060986, -8060984, -8060981, -8060979, -8060976, -8060974, -8060971, -8060969, -8060966, -8060964, -8060961, -8060959, -8060956, -8060954, -8060951, -8060949, -8060946, -8060944, -8060941, -8060939, -8060936, -8060934, -8060931, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -8060929, -7864321, -7733249, -7536641, -7340033, -7208961, -7012353, -6881281, -6684673, -6553601, -6356993, -6225921, -6029313, -5898241, -5701633, -5570561, -5373953, -5242881, -5046273, -4915201, -4718593, -4587521, -4390913, -4259841, -4063233, -3932161, -3735553, -3604481, -3407873, -3276801, -3080193, -2949121, -2752513, -2621441, -2424833, -2293761, -2097153, -1966081, -1769473, -1638401, -1441793, -1310721, -1114113, -983041, -786433, -655361, -458753, -327681, -131073, -1, -1, -1]))));
    this.v26_1 = new Entry_2('lingrey', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-16777216, -16777216, -16777216, -16777216, -16777216, -16777216, -16777216, -16711423, -16711423, -16711423, -16711423, -16711423, -16711423, -16711423, -16711423, -16711423, -16645630, -16645630, -16645630, -16645630, -16645630, -16645630, -16645630, -16579837, -16579837, -16579837, -16579837, -16579837, -16579837, -16579837, -16514044, -16514044, -16514044, -16514044, -16514044, -16448251, -16448251, -16448251, -16448251, -16448251, -16382458, -16382458, -16382458, -16382458, -16382458, -16316665, -16316665, -16316665, -16316665, -16316665, -16250872, -16250872, -16185079, -16185079, -16185079, -16185079, -16119286, -16119286, -16119286, -16119286, -16119286, -16053493, -16053493, -15987700, -15987700, -15987700, -15921907, -15921907, -15856114, -15856114, -15790321, -15790321, -15790321, -15724528, -15724528, -15658735, -15658735, -15592942, -15592942, -15527149, -15527149, -15527149, -15527149, -15527149, -15461356, -15461356, -15329770, -15329770, -15329770, -15263977, -15263977, -15198184, -15198184, -15066598, -15066598, -15066598, -15000805, -15000805, -14869219, -14869219, -14803426, -14803426, -14671840, -14671840, -14671840, -14671840, -14671840, -14540254, -14540254, -14474461, -14474461, -14474461, -14342875, -14342875, -14211289, -14211289, -14079703, -14079703, -14079703, -13948117, -13948117, -13816531, -13816531, -13750738, -13750738, -13750738, -13684945, -13684945, -13553359, -13553359, -13421773, -13421773, -13355980, -13355980, -13355980, -13224394, -13224394, -13092808, -13092808, -12895429, -12895429, -12895429, -12763843, -12763843, -12566464, -12566464, -12369085, -12369085, -12369085, -12237499, -12237499, -12040120, -12040120, -11842741, -11842741, -11776948, -11776948, -11776948, -11645362, -11645362, -11447983, -11447983, -11250604, -11250604, -11250604, -11053225, -11053225, -10790053, -10790053, -10592674, -10592674, -10592674, -10395295, -10395295, -10132123, -10132123, -9934744, -9934744, -9737365, -9737365, -9737365, -9671572, -9671572, -9408400, -9408400, -9145228, -9145228, -9145228, -8882056, -8882056, -8618884, -8618884, -8355712, -8355712, -8355712, -8092540, -8092540, -7829368, -7829368, -7500403, -7500403, -7237231, -7237231, -7237231, -7105645, -7105645, -6908266, -6908266, -6645094, -6645094, -6645094, -6316129, -6316129, -5987164, -5987164, -5658199, -5658199, -5658199, -5329234, -5329234, -5000269, -5000269, -4605511, -4605511, -4276546, -4276546, -4276546, -3947581, -3947581, -3947581, -3947581, -3552823, -3552823, -3552823, -3158065, -3158065, -2829100, -2829100, -2434342, -2434342, -2434342, -2039584, -2039584, -1644826, -1644826, -1184275, -1184275, -789517, -789517, -789517, -394759, -394759, -197380, -197380, -197380, -1]))));
    this.w26_1 = new Entry_2('YlOrRd', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-52, -78, -4704, -75402, -78756, -85428, -160452, -242134, -1033440, -1893860, -4390874, -5177306, -8388570]))));
    this.x26_1 = new Entry_2('PRGn', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-12582837, -9033085, -8703340, -6721365, -5272125, -4020785, -1583896, -526345, -2494253, -5842016, -8405125, -10834335, -16742345, -14976969, -16759781]))));
    this.y26_1 = new Entry_2('PuOr', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-8439032, -5023738, -1679103, -2063852, -941248, -149405, -73546, -526345, -2565397, -5067822, -6713661, -8358996, -10601319, -11262072, -13828021]))));
    this.z26_1 = new Entry_2('RdGy', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-10026977, -5105621, -3538912, -2727859, -1078686, -744062, -140345, -1, -2039584, -4539718, -6710887, -7895161, -12566464, -11711155, -15066598]))));
    this.a27_1 = new Entry_2('Spectral', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-6422206, -2802097, -2680548, -758461, -225959, -151967, -73589, -65, -1641064, -5513820, -6695532, -10042715, -13925446, -13465411, -10596446]))));
    this.b27_1 = new Entry_2('Grays', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-1, -526345, -986896, -2500135, -3355444, -4342339, -6908266, -9211021, -10263709, -11382190, -14342875, -14342875, -16777216]))));
    this.c27_1 = new Entry_2('PuBuGn', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-2053, -593929, -1252624, -3091994, -4339231, -5849637, -9131569, -13201216, -14905191, -16612982, -16683943, -16686000, -16693706]))));
    this.d27_1 = new Entry_2('RdPu', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-2061, -70686, -139043, -211520, -281415, -352331, -563039, -2280297, -3859574, -5373570, -8781449, -8781449, -11992982]))));
    this.e27_1 = new Entry_2('BuPu', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-525059, -1181445, -2036492, -4205594, -4993565, -6374182, -7563578, -7574607, -7842137, -7847523, -8319108, -9567893, -11730869]))));
    this.f27_1 = new Entry_2('YlOrBr', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-27, -44, -2116, -72815, -75378, -80817, -91863, -1282028, -2531570, -3388414, -6736892, -7590652, -10083066]))));
    this.g27_1 = new Entry_2('Greens', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-525067, -1181463, -1706528, -3675712, -4528973, -6170213, -9124746, -12473507, -13524140, -14447803, -16749268, -16754126, -16759781]))));
    this.h27_1 = new Entry_2('BuGn', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-525059, -1181445, -1706503, -3347226, -5053726, -6694711, -10042716, -12472714, -13852065, -14447803, -16749268, -16754652, -16759781]))));
    this.i27_1 = new Entry_2('Accents', PaletteType_QUALITATIVE_getInstance(), FixedPalette.s25(new Int32Array([-8402561, -4280620, -147322, -103, -13079376, -1047937, -4236521, -10066330])));
    this.j27_1 = new Entry_2('GnBu', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-525072, -984600, -2034725, -3347515, -4528964, -5710411, -8663868, -11619373, -12344630, -13923138, -16226132, -16230242, -16236415]))));
    this.k27_1 = new Entry_2('PuRd', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-527111, -921866, -1580561, -2836006, -2640424, -3566393, -2136656, -1627766, -2286473, -3272106, -6815677, -7274433, -10026977]))));
    this.l27_1 = new Entry_2('Purples', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-197635, -855817, -1053195, -2434325, -3421726, -4407844, -6382904, -8356422, -9081935, -9809501, -11262065, -11922298, -12648323]))));
    this.m27_1 = new Entry_2('RdYlGn', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-5963738, -2674649, -2680548, -758461, -225959, -151967, -73589, -65, -2494581, -5842582, -7221408, -10044061, -15034815, -15034288, -16750537]))));
    this.n27_1 = new Entry_2('Paired', PaletteType_QUALITATIVE_getInstance(), FixedPalette.s25(new Int32Array([-5845277, -14714700, -5054582, -13393876, -288103, -1893860, -147601, -33024, -3493162, -9814630, -103, -5154520])));
    this.o27_1 = new Entry_2('Blues', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-525313, -1051649, -2167817, -3744785, -4335641, -6370591, -9720106, -12414266, -13532483, -14585419, -16232036, -16235116, -16240533]))));
    this.p27_1 = new Entry_2('RdBu', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-10026977, -5105621, -3538912, -2727859, -1078686, -744062, -140345, -526345, -3021328, -7158306, -9983537, -12348477, -16420432, -14588244, -16437151]))));
    this.q27_1 = new Entry_2('Oranges', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-2581, -70178, -71986, -143198, -147835, -151957, -160452, -956141, -1682163, -2537471, -5884413, -7590652, -8444156]))));
    this.r27_1 = new Entry_2('RdYlBu', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-5963738, -2674649, -2680548, -758461, -225959, -151967, -73584, -65, -2034696, -5514775, -7225381, -9130543, -13861962, -12225100, -13551979]))));
    this.s27_1 = new Entry_2('PuBu', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-2053, -921866, -1251342, -3091994, -4339231, -5849637, -9983537, -13201216, -13923138, -16420688, -16491891, -16560517, -16631720]))));
    this.t27_1 = new Entry_2('OrRd', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-2068, -69415, -71480, -142178, -144246, -148604, -225959, -1088184, -1881549, -2674657, -5046272, -6750208, -8454144]))));
    this.u27_1 = new Entry_2('Set3', PaletteType_QUALITATIVE_getInstance(), FixedPalette.s25(new Int32Array([-7482425, -77, -4277542, -294798, -8343085, -150430, -4989335, -209435, -2500135, -4423491, -3347515, -4753])));
    this.v27_1 = new Entry_2('Set2', PaletteType_QUALITATIVE_getInstance(), FixedPalette.s25(new Int32Array([-10042715, -225950, -7495477, -1602877, -5842860, -9937, -1719148, -5000269])));
    this.w27_1 = new Entry_2('Set1', PaletteType_QUALITATIVE_getInstance(), FixedPalette.s25(new Int32Array([-1828324, -13140296, -11686070, -6795613, -33024, -205, -5876184, -556609, -6710887])));
    this.x27_1 = new Entry_2('Reds', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-2576, -72231, -73518, -214111, -217455, -224654, -300470, -1098964, -2216666, -3467235, -5959915, -6750195, -10026995]))));
    this.y27_1 = new Entry_2('PiYG', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-7470766, -3859587, -3138421, -2197586, -1465399, -936230, -139025, -526345, -1641008, -4660858, -6170774, -8405951, -11686874, -11693535, -14195687]))));
    this.z27_1 = new Entry_2('Dark2', PaletteType_QUALITATIVE_getInstance(), FixedPalette.s25(new Int32Array([-14967177, -2531582, -9080653, -1627766, -10050018, -1660158, -5868003, -10066330])));
    this.a28_1 = new Entry_2('YlGn', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-27, -52, -525127, -2494301, -4004199, -5382770, -8862087, -12473507, -13524140, -14449597, -16750537, -16754126, -16759511]))));
    this.b28_1 = new Entry_2('BrBG', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-11259899, -7581430, -5873382, -4226771, -2575515, -2112899, -595773, -657931, -3675419, -8335935, -10832724, -13265009, -16677519, -16685474, -16761808]))));
    this.c28_1 = new Entry_2('YlGnBu', PaletteType_SEQUENTIAL_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.s25(new Int32Array([-39, -52, -1181519, -3675724, -6169932, -8401477, -12470615, -14839360, -13860936, -14524248, -14338924, -15979388, -16245416]))));
    this.d28_1 = new Entry_2('Pastel2', PaletteType_QUALITATIVE_getInstance(), FixedPalette.s25(new Int32Array([-4988211, -143956, -3418648, -734492, -1641015, -3410, -924980, -3355444])));
    this.e28_1 = new Entry_2('Pastel1', PaletteType_QUALITATIVE_getInstance(), FixedPalette.s25(new Int32Array([-281426, -4993565, -3347515, -2176028, -75354, -52, -1713987, -140564, -855310])));
    this.f28_1 = new Entry_2('IsoL', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.u25([colorOf_2(0.9102, 0.2236, 0.8997), colorOf_2(0.4027, 0.3711, 1.0), colorOf_2(0.0422, 0.5904, 0.5899), colorOf_2(0.0386, 0.6206, 0.0201), colorOf_2(0.5441, 0.5428, 0.011), colorOf_2(1.0, 0.2288, 0.1631)])));
    this.g28_1 = new Entry_2('CubicL', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.u25([colorOf_2(0.4706, 0.0, 0.5216), colorOf_2(0.5137, 0.0527, 0.7096), colorOf_2(0.4942, 0.2507, 0.8781), colorOf_2(0.4296, 0.3858, 0.9922), colorOf_2(0.3691, 0.5172, 0.9495), colorOf_2(0.2963, 0.6191, 0.8515), colorOf_2(0.2199, 0.7134, 0.7225), colorOf_2(0.2643, 0.7836, 0.5756), colorOf_2(0.3094, 0.8388, 0.4248), colorOf_2(0.3623, 0.8917, 0.2858), colorOf_2(0.52, 0.921, 0.3137), colorOf_2(0.68, 0.9255, 0.3386), colorOf_2(0.8, 0.9255, 0.3529), colorOf_2(0.8706, 0.8549, 0.3608), colorOf_2(0.9514, 0.7466, 0.3686), colorOf_2(0.9765, 0.5887, 0.3569)])));
    this.h28_1 = new Entry_2('Edge', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.u25([colorOf_2(0.0, 0.0, 0.0), colorOf_2(0.0, 0.0, 1.0), colorOf_2(0.0, 1.0, 1.0), colorOf_2(1.0, 1.0, 1.0), colorOf_2(1.0, 1.0, 0.0), colorOf_2(1.0, 0.0, 0.0), colorOf_2(0.0, 0.0, 0.0)])));
    this.i28_1 = new Entry_2('coolwarm', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.u25([colorOf_2(0.2298057, 0.29871798, 0.75368315), colorOf_2(0.23437709, 0.30554172, 0.75967956), colorOf_2(0.23894846, 0.3123655, 0.7656759), colorOf_2(0.24351984, 0.31918925, 0.77167225), colorOf_2(0.24809122, 0.32601303, 0.77766865), colorOf_2(0.2526626, 0.33283678, 0.783665), colorOf_2(0.25723398, 0.33966056, 0.7896614), colorOf_2(0.26180536, 0.3464843, 0.79565775), colorOf_2(0.26638147, 0.35330442, 0.8016373), colorOf_2(0.2711043, 0.36001065, 0.8070951), colorOf_2(0.2758271, 0.36671692, 0.8125529), colorOf_2(0.28054994, 0.37342316, 0.81801075), colorOf_2(0.28527278, 0.38012943, 0.82346857), colorOf_2(0.2899956, 0.38683566, 0.8289264), colorOf_2(0.29471844, 0.39354193, 0.83438414), colorOf_2(0.29944125, 0.40024817, 0.83984196), colorOf_2(0.30417427, 0.40694487, 0.8452627), colorOf_2(0.3090603, 0.41349828, 0.85012764), colorOf_2(0.31394634, 0.42005166, 0.85499257), colorOf_2(0.3188324, 0.42660505, 0.85985744), colorOf_2(0.32371843, 0.43315843, 0.8647224), colorOf_2(0.32860446, 0.43971184, 0.86958724), colorOf_2(0.3334905, 0.44626522, 0.8744522), colorOf_2(0.33837652, 0.4528186, 0.8793171), colorOf_2(0.3432775, 0.45935363, 0.8841219), colorOf_2(0.34832335, 0.46571115, 0.88834614), colorOf_2(0.35336915, 0.47206867, 0.8925704), colorOf_2(0.35841498, 0.47842616, 0.8967946), colorOf_2(0.3634608, 0.48478368, 0.90101886), colorOf_2(0.3685066, 0.4911412, 0.9052431), colorOf_2(0.37355244, 0.4974987, 0.9094674), colorOf_2(0.37859824, 0.50385624, 0.91369164), colorOf_2(0.38366207, 0.5101834, 0.91783065), colorOf_2(0.38885188, 0.5162984, 0.9213735), colorOf_2(0.3940417, 0.52241343, 0.92491627), colorOf_2(0.3992315, 0.52852845, 0.9284591), colorOf_2(0.4044213, 0.5346435, 0.9320019), colorOf_2(0.4096111, 0.5407585, 0.9355447), colorOf_2(0.4148009, 0.5468735, 0.9390875), colorOf_2(0.41999072, 0.5529885, 0.94263035), colorOf_2(0.42519897, 0.5590582, 0.94606143), colorOf_2(0.43050689, 0.56488276, 0.94888943), colorOf_2(0.4358148, 0.5707073, 0.9517174), colorOf_2(0.4411227, 0.5765319, 0.9545453), colorOf_2(0.44643065, 0.58235645, 0.9573733), colorOf_2(0.45173857, 0.58818096, 0.96020126), colorOf_2(0.45704648, 0.5940055, 0.9630292), colorOf_2(0.4623544, 0.5998301, 0.9658572), colorOf_2(0.4676781, 0.60559124, 0.9685463), colorOf_2(0.47307017, 0.6110774, 0.97063357), colorOf_2(0.47846225, 0.6165636, 0.9727209), colorOf_2(0.48385432, 0.62204987, 0.9748082), colorOf_2(0.4892464, 0.62753606, 0.9768955), colorOf_2(0.49463847, 0.63302225, 0.9789828), colorOf_2(0.5000306, 0.63850844, 0.9810701), colorOf_2(0.50542265, 0.6439947, 0.98315746), colorOf_2(0.5108243, 0.6493966, 0.98507875), colorOf_2(0.5162603, 0.6544976, 0.9864074), colorOf_2(0.52169627, 0.6595986, 0.98773605), colorOf_2(0.5271323, 0.6646996, 0.98906463), colorOf_2(0.5325682, 0.6698006, 0.9903933), colorOf_2(0.5380042, 0.6749016, 0.99172187), colorOf_2(0.5434402, 0.68000257, 0.9930505), colorOf_2(0.54887617, 0.6851036, 0.99437916), colorOf_2(0.5543119, 0.69009703, 0.9955155), colorOf_2(0.55974674, 0.6947677, 0.99607533), colorOf_2(0.56518155, 0.69943845, 0.9966351), colorOf_2(0.5706164, 0.70410913, 0.9971948), colorOf_2(0.5760513, 0.7087799, 0.9977546), colorOf_2(0.58148617, 0.7134506, 0.9983144), colorOf_2(0.586921, 0.7181213, 0.9988741), colorOf_2(0.59235585, 0.722792, 0.9994339), colorOf_2(0.5977768, 0.72732973, 0.9997767), colorOf_2(0.60316205, 0.73152745, 0.9995653), colorOf_2(0.6085474, 0.7357252, 0.9993538), colorOf_2(0.61393267, 0.739923, 0.99914235), colorOf_2(0.61931795, 0.7441207, 0.99893093), colorOf_2(0.6247032, 0.7483185, 0.99871945), colorOf_2(0.6300885, 0.7525162, 0.99850804), colorOf_2(0.63547385, 0.756714, 0.99829656), colorOf_2(0.6408278, 0.7607515, 0.99784577), colorOf_2(0.6461128, 0.7644365, 0.9968685), colorOf_2(0.6513978, 0.7681215, 0.99589115), colorOf_2(0.65668285, 0.7718065, 0.9949138), colorOf_2(0.6619679, 0.7754915, 0.99393654), colorOf_2(0.6672529, 0.7791765, 0.9929592), colorOf_2(0.672538, 0.7828615, 0.9919819), colorOf_2(0.677823, 0.7865464, 0.9910046), colorOf_2(0.6830557, 0.79004264, 0.98976845), colorOf_2(0.6881885, 0.7931784, 0.9880381), colorOf_2(0.6933213, 0.7963141, 0.9863078), colorOf_2(0.6984541, 0.79944986, 0.9845775), colorOf_2(0.7035869, 0.80258566, 0.98284715), colorOf_2(0.7087197, 0.8057214, 0.98111683), colorOf_2(0.71385247, 0.80885714, 0.9793865), colorOf_2(0.7189853, 0.8119929, 0.9776562), colorOf_2(0.72404134, 0.8149104, 0.97565097), colorOf_2(0.7289696, 0.8174641, 0.9731877), colorOf_2(0.7338978, 0.8200179, 0.97072434), colorOf_2(0.738826, 0.82257164, 0.96826106), colorOf_2(0.7437542, 0.82512534, 0.9657978), colorOf_2(0.74868244, 0.8276791, 0.96333444), colorOf_2(0.7536106, 0.83023286, 0.96087116), colorOf_2(0.75853884, 0.8327866, 0.9584079), colorOf_2(0.76336277, 0.83509225, 0.95565766), colorOf_2(0.76803434, 0.83703524, 0.95248824), colorOf_2(0.772706, 0.83897823, 0.94931877), colorOf_2(0.77737755, 0.8409212, 0.9461493), colorOf_2(0.7820491, 0.8428642, 0.9429799), colorOf_2(0.7867207, 0.8448072, 0.9398104), colorOf_2(0.79139227, 0.8467502, 0.9366409), colorOf_2(0.79606384, 0.8486932, 0.93347144), colorOf_2(0.8006008, 0.8503583, 0.9300076), colorOf_2(0.8049648, 0.85166615, 0.9261651), colorOf_2(0.8093287, 0.852974, 0.9223226), colorOf_2(0.81369257, 0.85428184, 0.9184801), colorOf_2(0.81805646, 0.8555897, 0.9146376), colorOf_2(0.8224204, 0.85689753, 0.91079515), colorOf_2(0.8267843, 0.8582054, 0.9069526), colorOf_2(0.8311482, 0.8595132, 0.90311015), colorOf_2(0.83534473, 0.860514, 0.8989704), colorOf_2(0.8393514, 0.86116683, 0.89449376), colorOf_2(0.84335816, 0.8618196, 0.8900171), colorOf_2(0.8473649, 0.8624725, 0.8855405), colorOf_2(0.85137165, 0.8631253, 0.8810638), colorOf_2(0.8553784, 0.8637781, 0.87658715), colorOf_2(0.8593851, 0.86443096, 0.87211055), colorOf_2(0.8633918, 0.8650838, 0.8676339), colorOf_2(0.86742765, 0.8643766, 0.8626025), colorOf_2(0.8714925, 0.8623094, 0.85701627), colorOf_2(0.87555736, 0.8602422, 0.85143006), colorOf_2(0.8796223, 0.8581749, 0.84584385), colorOf_2(0.88368714, 0.8561077, 0.84025764), colorOf_2(0.887752, 0.8540405, 0.8346715), colorOf_2(0.8918169, 0.8519733, 0.8290853), colorOf_2(0.8958818, 0.849906, 0.8234991), colorOf_2(0.8995432, 0.84750026, 0.8177891), colorOf_2(0.90284866, 0.84479564, 0.8119698), colorOf_2(0.90615416, 0.8420911, 0.8061506), colorOf_2(0.9094596, 0.83938646, 0.80033135), colorOf_2(0.9127651, 0.8366819, 0.7945121), colorOf_2(0.9160705, 0.8339773, 0.7886929), colorOf_2(0.919376, 0.8312727, 0.78287363), colorOf_2(0.92268145, 0.82856816, 0.77705437), colorOf_2(0.9255634, 0.8255173, 0.7711363), colorOf_2(0.928116, 0.82219714, 0.76514137), colorOf_2(0.9306686, 0.818877, 0.7591464), colorOf_2(0.93322116, 0.8155568, 0.7531514), colorOf_2(0.9357738, 0.8122367, 0.7471565), colorOf_2(0.93832636, 0.80891657, 0.7411615), colorOf_2(0.9408789, 0.8055964, 0.73516655), colorOf_2(0.94343156, 0.80227625, 0.7291716), colorOf_2(0.9455403, 0.79860574, 0.72310543), colorOf_2(0.9473454, 0.7946955, 0.71699053), colorOf_2(0.9491505, 0.79078525, 0.7108756), colorOf_2(0.9509556, 0.786875, 0.7047607), colorOf_2(0.9527607, 0.7829648, 0.6986458), colorOf_2(0.9545658, 0.7790546, 0.6925309), colorOf_2(0.95637095, 0.77514434, 0.686416), colorOf_2(0.958176, 0.7712341, 0.680301), colorOf_2(0.95951766, 0.76697284, 0.6741447), colorOf_2(0.9605812, 0.762501, 0.66796356), colorOf_2(0.9616447, 0.75802916, 0.6617824), colorOf_2(0.9627083, 0.7535573, 0.6556012), colorOf_2(0.9637718, 0.7490855, 0.64942), colorOf_2(0.96483535, 0.74461365, 0.6432389), colorOf_2(0.9658989, 0.7401418, 0.6370577), colorOf_2(0.96696246, 0.73567003, 0.63087654), colorOf_2(0.9675443, 0.73084974, 0.62468547), colorOf_2(0.9678739, 0.7258469, 0.6184892), colorOf_2(0.9682034, 0.7208441, 0.612293), colorOf_2(0.9685329, 0.7158413, 0.60609674), colorOf_2(0.9688625, 0.7108385, 0.5999005), colorOf_2(0.969192, 0.7058357, 0.5937043), colorOf_2(0.9695216, 0.70083284, 0.587508), colorOf_2(0.96985114, 0.69583005, 0.58131176), colorOf_2(0.969683, 0.6904839, 0.5751384), colorOf_2(0.9692886, 0.68498176, 0.5689753), colorOf_2(0.9688942, 0.67947954, 0.56281227), colorOf_2(0.9684997, 0.6739774, 0.55664927), colorOf_2(0.9681053, 0.6684752, 0.5504862), colorOf_2(0.9677109, 0.662973, 0.5443232), colorOf_2(0.9673165, 0.6574708, 0.53816015), colorOf_2(0.9669221, 0.65196866, 0.53199714), colorOf_2(0.9660167, 0.6461297, 0.52589035), colorOf_2(0.9649114, 0.6401591, 0.5198056), colorOf_2(0.96380603, 0.6341884, 0.51372087), colorOf_2(0.9627007, 0.62821776, 0.5076361), colorOf_2(0.9615954, 0.6222471, 0.50155133), colorOf_2(0.96049005, 0.61627644, 0.4954666), colorOf_2(0.95938474, 0.6103058, 0.48938185), colorOf_2(0.9582794, 0.60433507, 0.4832971), colorOf_2(0.95665324, 0.59803385, 0.47730228), colorOf_2(0.9548534, 0.59162235, 0.47133747), colorOf_2(0.9530536, 0.58521086, 0.46537262), colorOf_2(0.9512538, 0.57879937, 0.4594078), colorOf_2(0.949454, 0.57238793, 0.453443), colorOf_2(0.9476542, 0.56597644, 0.44747815), colorOf_2(0.94585437, 0.55956495, 0.44151333), colorOf_2(0.94405454, 0.55315346, 0.43554848), colorOf_2(0.94172794, 0.5464135, 0.42970708), colorOf_2(0.93925375, 0.5395815, 0.42390022), colorOf_2(0.9367796, 0.5327495, 0.41809335), colorOf_2(0.9343054, 0.52591753, 0.41228646), colorOf_2(0.9318313, 0.5190855, 0.4064796), colorOf_2(0.9293571, 0.5122535, 0.40067273), colorOf_2(0.926883, 0.5054215, 0.39486587), colorOf_2(0.9244088, 0.49858955, 0.389059), colorOf_2(0.9214062, 0.49142042, 0.38340843), colorOf_2(0.9182817, 0.48417348, 0.37779394), colorOf_2(0.91515714, 0.47692654, 0.37217942), colorOf_2(0.9120326, 0.4696796, 0.3665649), colorOf_2(0.908908, 0.46243262, 0.36095038), colorOf_2(0.9057835, 0.45518568, 0.3553359), colorOf_2(0.90265894, 0.44793874, 0.34972137), colorOf_2(0.8995344, 0.4406918, 0.34410685), colorOf_2(0.8958846, 0.43307456, 0.33868062), colorOf_2(0.8921375, 0.42538872, 0.33328927), colorOf_2(0.8883905, 0.4177029, 0.3278979), colorOf_2(0.88464344, 0.4100171, 0.32250655), colorOf_2(0.8808964, 0.4023313, 0.3171152), colorOf_2(0.87714934, 0.39464545, 0.31172383), colorOf_2(0.8734023, 0.38695964, 0.30633247), colorOf_2(0.86965525, 0.37927383, 0.3009411), colorOf_2(0.8653913, 0.37112767, 0.29576895), colorOf_2(0.8610536, 0.36291575, 0.29062814), colorOf_2(0.85671586, 0.35470384, 0.2854873), colorOf_2(0.85237813, 0.34649193, 0.28034648), colorOf_2(0.8480404, 0.33828005, 0.27520564), colorOf_2(0.8437027, 0.33006814, 0.2700648), colorOf_2(0.83936495, 0.32185623, 0.264924), colorOf_2(0.8350272, 0.31364432, 0.25978315), colorOf_2(0.83018655, 0.30473277, 0.25489143), colorOf_2(0.82529384, 0.29574883, 0.25002548), colorOf_2(0.8204011, 0.28676492, 0.24515952), colorOf_2(0.81550837, 0.27778098, 0.24029356), colorOf_2(0.81061566, 0.26879707, 0.23542762), colorOf_2(0.80572295, 0.25981313, 0.23056166), colorOf_2(0.80083025, 0.25082922, 0.2256957), colorOf_2(0.79593754, 0.24184528, 0.22082976), colorOf_2(0.79056156, 0.231397, 0.21624205), colorOf_2(0.7851533, 0.2208511, 0.21167287), colorOf_2(0.7797451, 0.21030518, 0.20710371), colorOf_2(0.7743369, 0.19975927, 0.20253456), colorOf_2(0.76892865, 0.18921335, 0.1979654), colorOf_2(0.7635204, 0.17866744, 0.19339623), colorOf_2(0.7581122, 0.16812153, 0.18882707), colorOf_2(0.75270396, 0.15757562, 0.18425791), colorOf_2(0.74683803, 0.14002103, 0.1799961), colorOf_2(0.7409573, 0.12224033, 0.1757442), colorOf_2(0.7350766, 0.10445963, 0.17149231), colorOf_2(0.72919595, 0.08667894, 0.1672404), colorOf_2(0.72331524, 0.068898246, 0.1629885), colorOf_2(0.7174345, 0.051117547, 0.1587366), colorOf_2(0.7115539, 0.033336855, 0.1544847), colorOf_2(0.70567316, 0.01555616, 0.1502328)])));
    this.k28_1 = new Entry_2('magma', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.u25([colorOf_2(0.001462, 4.66E-4, 0.013866), colorOf_2(0.002258, 0.001295, 0.018331), colorOf_2(0.003279, 0.002305, 0.023708), colorOf_2(0.004512, 0.00349, 0.029965), colorOf_2(0.00595, 0.004843, 0.03713), colorOf_2(0.007588, 0.006356, 0.044973), colorOf_2(0.009426, 0.008022, 0.052844), colorOf_2(0.011465, 0.009828, 0.06075), colorOf_2(0.013708, 0.011771, 0.068667), colorOf_2(0.016156, 0.01384, 0.076603), colorOf_2(0.018815, 0.016026, 0.084584), colorOf_2(0.021692, 0.01832, 0.09261), colorOf_2(0.024792, 0.020715, 0.100676), colorOf_2(0.028123, 0.023201, 0.108787), colorOf_2(0.031696, 0.025765, 0.116965), colorOf_2(0.03552, 0.028397, 0.125209), colorOf_2(0.039608, 0.03109, 0.133515), colorOf_2(0.04383, 0.03383, 0.141886), colorOf_2(0.048062, 0.036607, 0.150327), colorOf_2(0.05232, 0.039407, 0.158841), colorOf_2(0.056615, 0.04216, 0.167446), colorOf_2(0.060949, 0.044794, 0.176129), colorOf_2(0.06533, 0.047318, 0.184892), colorOf_2(0.069764, 0.049726, 0.193735), colorOf_2(0.074257, 0.052017, 0.20266), colorOf_2(0.078815, 0.054184, 0.211667), colorOf_2(0.083446, 0.056225, 0.220755), colorOf_2(0.088155, 0.058133, 0.229922), colorOf_2(0.092949, 0.059904, 0.239164), colorOf_2(0.097833, 0.061531, 0.248477), colorOf_2(0.102815, 0.06301, 0.257854), colorOf_2(0.107899, 0.064335, 0.267289), colorOf_2(0.113094, 0.065492, 0.276784), colorOf_2(0.118405, 0.066479, 0.286321), colorOf_2(0.123833, 0.067295, 0.295879), colorOf_2(0.12938, 0.067935, 0.305443), colorOf_2(0.135053, 0.068391, 0.315), colorOf_2(0.140858, 0.068654, 0.324538), colorOf_2(0.146785, 0.068738, 0.334011), colorOf_2(0.152839, 0.068637, 0.343404), colorOf_2(0.159018, 0.068354, 0.352688), colorOf_2(0.165308, 0.067911, 0.361816), colorOf_2(0.171713, 0.067305, 0.370771), colorOf_2(0.178212, 0.066576, 0.379497), colorOf_2(0.184801, 0.065732, 0.387973), colorOf_2(0.19146, 0.064818, 0.396152), colorOf_2(0.198177, 0.063862, 0.404009), colorOf_2(0.204935, 0.062907, 0.411514), colorOf_2(0.211718, 0.061992, 0.418647), colorOf_2(0.218512, 0.061158, 0.425392), colorOf_2(0.225302, 0.060445, 0.431742), colorOf_2(0.232077, 0.059889, 0.437695), colorOf_2(0.238826, 0.059517, 0.443256), colorOf_2(0.245543, 0.059352, 0.448436), colorOf_2(0.25222, 0.059415, 0.453248), colorOf_2(0.258857, 0.059706, 0.45771), colorOf_2(0.265447, 0.060237, 0.46184), colorOf_2(0.271994, 0.060994, 0.46566), colorOf_2(0.278493, 0.061978, 0.46919), colorOf_2(0.284951, 0.063168, 0.472451), colorOf_2(0.291366, 0.064553, 0.475462), colorOf_2(0.29774, 0.066117, 0.478243), colorOf_2(0.304081, 0.067835, 0.480812), colorOf_2(0.310382, 0.069702, 0.483186), colorOf_2(0.316654, 0.07169, 0.48538), colorOf_2(0.322899, 0.073782, 0.487408), colorOf_2(0.329114, 0.075972, 0.489287), colorOf_2(0.335308, 0.078236, 0.491024), colorOf_2(0.341482, 0.080564, 0.492631), colorOf_2(0.347636, 0.082946, 0.494121), colorOf_2(0.353773, 0.085373, 0.495501), colorOf_2(0.359898, 0.087831, 0.496778), colorOf_2(0.366012, 0.090314, 0.49796), colorOf_2(0.372116, 0.092816, 0.499053), colorOf_2(0.378211, 0.095332, 0.500067), colorOf_2(0.384299, 0.097855, 0.501002), colorOf_2(0.390384, 0.100379, 0.501864), colorOf_2(0.396467, 0.102902, 0.502658), colorOf_2(0.402548, 0.10542, 0.503386), colorOf_2(0.408629, 0.10793, 0.504052), colorOf_2(0.414709, 0.110431, 0.504662), colorOf_2(0.420791, 0.11292, 0.505215), colorOf_2(0.426877, 0.115395, 0.505714), colorOf_2(0.432967, 0.117855, 0.50616), colorOf_2(0.439062, 0.120298, 0.506555), colorOf_2(0.445163, 0.122724, 0.506901), colorOf_2(0.451271, 0.125132, 0.507198), colorOf_2(0.457386, 0.127522, 0.507448), colorOf_2(0.463508, 0.129893, 0.507652), colorOf_2(0.46964, 0.132245, 0.507809), colorOf_2(0.47578, 0.134577, 0.507921), colorOf_2(0.481929, 0.136891, 0.507989), colorOf_2(0.488088, 0.139186, 0.508011), colorOf_2(0.494258, 0.141462, 0.507988), colorOf_2(0.500438, 0.143719, 0.50792), colorOf_2(0.506629, 0.145958, 0.507806), colorOf_2(0.512831, 0.148179, 0.507648), colorOf_2(0.519045, 0.150383, 0.507443), colorOf_2(0.52527, 0.152569, 0.507192), colorOf_2(0.531507, 0.154739, 0.506895), colorOf_2(0.537755, 0.156894, 0.506551), colorOf_2(0.544015, 0.159033, 0.506159), colorOf_2(0.550287, 0.161158, 0.505719), colorOf_2(0.556571, 0.163269, 0.50523), colorOf_2(0.562866, 0.165368, 0.504692), colorOf_2(0.569172, 0.167454, 0.504105), colorOf_2(0.57549, 0.16953, 0.503466), colorOf_2(0.581819, 0.171596, 0.502777), colorOf_2(0.588158, 0.173652, 0.502035), colorOf_2(0.594508, 0.175701, 0.501241), colorOf_2(0.600868, 0.177743, 0.500394), colorOf_2(0.607238, 0.179779, 0.499492), colorOf_2(0.613617, 0.181811, 0.498536), colorOf_2(0.620005, 0.18384, 0.497524), colorOf_2(0.626401, 0.185867, 0.496456), colorOf_2(0.632805, 0.187893, 0.495332), colorOf_2(0.639216, 0.189921, 0.49415), colorOf_2(0.645633, 0.191952, 0.49291), colorOf_2(0.652056, 0.193986, 0.491611), colorOf_2(0.658483, 0.196027, 0.490253), colorOf_2(0.664915, 0.198075, 0.488836), colorOf_2(0.671349, 0.200133, 0.487358), colorOf_2(0.677786, 0.202203, 0.485819), colorOf_2(0.684224, 0.204286, 0.484219), colorOf_2(0.690661, 0.206384, 0.482558), colorOf_2(0.697098, 0.208501, 0.480835), colorOf_2(0.703532, 0.210638, 0.479049), colorOf_2(0.709962, 0.212797, 0.477201), colorOf_2(0.716387, 0.214982, 0.47529), colorOf_2(0.722805, 0.217194, 0.473316), colorOf_2(0.729216, 0.219437, 0.471279), colorOf_2(0.735616, 0.221713, 0.46918), colorOf_2(0.742004, 0.224025, 0.467018), colorOf_2(0.748378, 0.226377, 0.464794), colorOf_2(0.754737, 0.228772, 0.462509), colorOf_2(0.761077, 0.231214, 0.460162), colorOf_2(0.767398, 0.233705, 0.457755), colorOf_2(0.773695, 0.236249, 0.455289), colorOf_2(0.779968, 0.238851, 0.452765), colorOf_2(0.786212, 0.241514, 0.450184), colorOf_2(0.792427, 0.244242, 0.447543), colorOf_2(0.798608, 0.24704, 0.444848), colorOf_2(0.804752, 0.249911, 0.442102), colorOf_2(0.810855, 0.252861, 0.439305), colorOf_2(0.816914, 0.255895, 0.436461), colorOf_2(0.822926, 0.259016, 0.433573), colorOf_2(0.828886, 0.262229, 0.430644), colorOf_2(0.834791, 0.26554, 0.427671), colorOf_2(0.840636, 0.268953, 0.424666), colorOf_2(0.846416, 0.272473, 0.421631), colorOf_2(0.852126, 0.276106, 0.418573), colorOf_2(0.857763, 0.279857, 0.415496), colorOf_2(0.86332, 0.283729, 0.412403), colorOf_2(0.868793, 0.287728, 0.409303), colorOf_2(0.874176, 0.291859, 0.406205), colorOf_2(0.879464, 0.296125, 0.403118), colorOf_2(0.884651, 0.30053, 0.400047), colorOf_2(0.889731, 0.305079, 0.397002), colorOf_2(0.8947, 0.309773, 0.393995), colorOf_2(0.899552, 0.314616, 0.391037), colorOf_2(0.904281, 0.31961, 0.388137), colorOf_2(0.908884, 0.324755, 0.385308), colorOf_2(0.913354, 0.330052, 0.382563), colorOf_2(0.917689, 0.3355, 0.379915), colorOf_2(0.921884, 0.341098, 0.377376), colorOf_2(0.925937, 0.346844, 0.374959), colorOf_2(0.929845, 0.352734, 0.372677), colorOf_2(0.933606, 0.358764, 0.370541), colorOf_2(0.937221, 0.364929, 0.368567), colorOf_2(0.940687, 0.371224, 0.366762), colorOf_2(0.944006, 0.377643, 0.365136), colorOf_2(0.94718, 0.384178, 0.363701), colorOf_2(0.95021, 0.39082, 0.362468), colorOf_2(0.953099, 0.397563, 0.361438), colorOf_2(0.955849, 0.4044, 0.360619), colorOf_2(0.958464, 0.411324, 0.360014), colorOf_2(0.960949, 0.418323, 0.35963), colorOf_2(0.96331, 0.42539, 0.359469), colorOf_2(0.965549, 0.432519, 0.359529), colorOf_2(0.967671, 0.439703, 0.35981), colorOf_2(0.96968, 0.446936, 0.360311), colorOf_2(0.971582, 0.45421, 0.36103), colorOf_2(0.973381, 0.46152, 0.361965), colorOf_2(0.975082, 0.468861, 0.363111), colorOf_2(0.97669, 0.476226, 0.364466), colorOf_2(0.97821, 0.483612, 0.366025), colorOf_2(0.979645, 0.491014, 0.367783), colorOf_2(0.981, 0.498428, 0.369734), colorOf_2(0.982279, 0.505851, 0.371874), colorOf_2(0.983485, 0.51328, 0.374198), colorOf_2(0.984622, 0.520713, 0.376698), colorOf_2(0.985693, 0.528148, 0.379371), colorOf_2(0.9867, 0.535582, 0.38221), colorOf_2(0.987646, 0.543015, 0.38521), colorOf_2(0.988533, 0.550446, 0.388365), colorOf_2(0.989363, 0.557873, 0.391671), colorOf_2(0.990138, 0.565296, 0.395122), colorOf_2(0.990871, 0.572706, 0.398714), colorOf_2(0.991558, 0.580107, 0.402441), colorOf_2(0.992196, 0.587502, 0.406299), colorOf_2(0.992785, 0.594891, 0.410283), colorOf_2(0.993326, 0.602275, 0.41439), colorOf_2(0.993834, 0.609644, 0.418613), colorOf_2(0.994309, 0.616999, 0.42295), colorOf_2(0.994738, 0.62435, 0.427397), colorOf_2(0.995122, 0.631696, 0.431951), colorOf_2(0.99548, 0.639027, 0.436607), colorOf_2(0.99581, 0.646344, 0.441361), colorOf_2(0.996096, 0.653659, 0.446213), colorOf_2(0.996341, 0.660969, 0.45116), colorOf_2(0.99658, 0.668256, 0.456192), colorOf_2(0.996775, 0.675541, 0.461314), colorOf_2(0.996925, 0.682828, 0.466526), colorOf_2(0.997077, 0.690088, 0.471811), colorOf_2(0.997186, 0.697349, 0.477182), colorOf_2(0.997254, 0.704611, 0.482635), colorOf_2(0.997325, 0.711848, 0.488154), colorOf_2(0.997351, 0.719089, 0.493755), colorOf_2(0.997351, 0.726324, 0.499428), colorOf_2(0.997341, 0.733545, 0.505167), colorOf_2(0.997285, 0.740772, 0.510983), colorOf_2(0.997228, 0.747981, 0.516859), colorOf_2(0.997138, 0.75519, 0.522806), colorOf_2(0.997019, 0.762398, 0.528821), colorOf_2(0.996898, 0.769591, 0.534892), colorOf_2(0.996727, 0.776795, 0.541039), colorOf_2(0.996571, 0.783977, 0.547233), colorOf_2(0.996369, 0.791167, 0.553499), colorOf_2(0.996162, 0.798348, 0.55982), colorOf_2(0.995932, 0.805527, 0.566202), colorOf_2(0.99568, 0.812706, 0.572645), colorOf_2(0.995424, 0.819875, 0.57914), colorOf_2(0.995131, 0.827052, 0.585701), colorOf_2(0.994851, 0.834213, 0.592307), colorOf_2(0.994524, 0.841387, 0.598983), colorOf_2(0.994222, 0.84854, 0.605696), colorOf_2(0.993866, 0.855711, 0.612482), colorOf_2(0.993545, 0.862859, 0.619299), colorOf_2(0.99317, 0.870024, 0.626189), colorOf_2(0.992831, 0.877168, 0.633109), colorOf_2(0.99244, 0.88433, 0.640099), colorOf_2(0.992089, 0.89147, 0.647116), colorOf_2(0.991688, 0.898627, 0.654202), colorOf_2(0.991332, 0.905763, 0.661309), colorOf_2(0.99093, 0.912915, 0.668481), colorOf_2(0.99057, 0.920049, 0.675675), colorOf_2(0.990175, 0.927196, 0.682926), colorOf_2(0.989815, 0.934329, 0.690198), colorOf_2(0.989434, 0.94147, 0.697519), colorOf_2(0.989077, 0.948604, 0.704863), colorOf_2(0.988717, 0.955742, 0.712242), colorOf_2(0.988367, 0.962878, 0.719649), colorOf_2(0.988033, 0.970012, 0.727077), colorOf_2(0.987691, 0.977154, 0.734536), colorOf_2(0.987387, 0.984288, 0.742002), colorOf_2(0.987053, 0.991438, 0.749504)])));
    this.m28_1 = new Entry_2('inferno', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.u25([colorOf_2(0.001462, 4.66E-4, 0.013866), colorOf_2(0.002267, 0.00127, 0.01857), colorOf_2(0.003299, 0.002249, 0.024239), colorOf_2(0.004547, 0.003392, 0.030909), colorOf_2(0.006006, 0.004692, 0.038558), colorOf_2(0.007676, 0.006136, 0.046836), colorOf_2(0.009561, 0.007713, 0.055143), colorOf_2(0.011663, 0.009417, 0.06346), colorOf_2(0.013995, 0.011225, 0.071862), colorOf_2(0.016561, 0.013136, 0.080282), colorOf_2(0.019373, 0.015133, 0.088767), colorOf_2(0.022447, 0.017199, 0.097327), colorOf_2(0.025793, 0.019331, 0.10593), colorOf_2(0.029432, 0.021503, 0.114621), colorOf_2(0.033385, 0.023702, 0.123397), colorOf_2(0.037668, 0.025921, 0.132232), colorOf_2(0.042253, 0.028139, 0.141141), colorOf_2(0.046915, 0.030324, 0.150164), colorOf_2(0.051644, 0.032474, 0.159254), colorOf_2(0.056449, 0.034569, 0.168414), colorOf_2(0.06134, 0.03659, 0.177642), colorOf_2(0.066331, 0.038504, 0.186962), colorOf_2(0.071429, 0.040294, 0.196354), colorOf_2(0.076637, 0.041905, 0.205799), colorOf_2(0.081962, 0.043328, 0.215289), colorOf_2(0.087411, 0.044556, 0.224813), colorOf_2(0.09299, 0.045583, 0.234358), colorOf_2(0.098702, 0.046402, 0.243904), colorOf_2(0.104551, 0.047008, 0.25343), colorOf_2(0.110536, 0.047399, 0.262912), colorOf_2(0.116656, 0.047574, 0.272321), colorOf_2(0.122908, 0.047536, 0.281624), colorOf_2(0.129285, 0.047293, 0.290788), colorOf_2(0.135778, 0.046856, 0.299776), colorOf_2(0.142378, 0.046242, 0.308553), colorOf_2(0.149073, 0.045468, 0.317085), colorOf_2(0.15585, 0.044559, 0.325338), colorOf_2(0.162689, 0.043554, 0.333277), colorOf_2(0.169575, 0.042489, 0.340874), colorOf_2(0.176493, 0.041402, 0.348111), colorOf_2(0.183429, 0.040329, 0.354971), colorOf_2(0.190367, 0.039309, 0.361447), colorOf_2(0.197297, 0.0384, 0.367535), colorOf_2(0.204209, 0.037632, 0.373238), colorOf_2(0.211095, 0.03703, 0.378563), colorOf_2(0.217949, 0.036615, 0.383522), colorOf_2(0.224763, 0.036405, 0.388129), colorOf_2(0.231538, 0.036405, 0.3924), colorOf_2(0.238273, 0.036621, 0.396353), colorOf_2(0.244967, 0.037055, 0.400007), colorOf_2(0.25162, 0.037705, 0.403378), colorOf_2(0.258234, 0.038571, 0.406485), colorOf_2(0.26481, 0.039647, 0.409345), colorOf_2(0.271347, 0.040922, 0.411976), colorOf_2(0.27785, 0.042353, 0.414392), colorOf_2(0.284321, 0.043933, 0.416608), colorOf_2(0.290763, 0.045644, 0.418637), colorOf_2(0.297178, 0.04747, 0.420491), colorOf_2(0.303568, 0.049396, 0.422182), colorOf_2(0.309935, 0.051407, 0.423721), colorOf_2(0.316282, 0.05349, 0.425116), colorOf_2(0.32261, 0.055634, 0.426377), colorOf_2(0.328921, 0.057827, 0.427511), colorOf_2(0.335217, 0.06006, 0.428524), colorOf_2(0.3415, 0.062325, 0.429425), colorOf_2(0.347771, 0.064616, 0.430217), colorOf_2(0.354032, 0.066925, 0.430906), colorOf_2(0.360284, 0.069247, 0.431497), colorOf_2(0.366529, 0.071579, 0.431994), colorOf_2(0.372768, 0.073915, 0.4324), colorOf_2(0.379001, 0.076253, 0.432719), colorOf_2(0.385228, 0.078591, 0.432955), colorOf_2(0.391453, 0.080927, 0.433109), colorOf_2(0.397674, 0.083257, 0.433183), colorOf_2(0.403894, 0.08558, 0.433179), colorOf_2(0.410113, 0.087896, 0.433098), colorOf_2(0.416331, 0.090203, 0.432943), colorOf_2(0.422549, 0.092501, 0.432714), colorOf_2(0.428768, 0.09479, 0.432412), colorOf_2(0.434987, 0.097069, 0.432039), colorOf_2(0.441207, 0.099338, 0.431594), colorOf_2(0.447428, 0.101597, 0.43108), colorOf_2(0.453651, 0.103848, 0.430498), colorOf_2(0.459875, 0.106089, 0.429846), colorOf_2(0.4661, 0.108322, 0.429125), colorOf_2(0.472328, 0.110547, 0.428334), colorOf_2(0.478558, 0.112764, 0.427475), colorOf_2(0.484789, 0.114974, 0.426548), colorOf_2(0.491022, 0.117179, 0.425552), colorOf_2(0.497257, 0.119379, 0.424488), colorOf_2(0.503493, 0.121575, 0.423356), colorOf_2(0.50973, 0.123769, 0.422156), colorOf_2(0.515967, 0.12596, 0.420887), colorOf_2(0.522206, 0.12815, 0.419549), colorOf_2(0.528444, 0.130341, 0.418142), colorOf_2(0.534683, 0.132534, 0.416667), colorOf_2(0.54092, 0.134729, 0.415123), colorOf_2(0.547157, 0.136929, 0.413511), colorOf_2(0.553392, 0.139134, 0.411829), colorOf_2(0.559624, 0.141346, 0.410078), colorOf_2(0.565854, 0.143567, 0.408258), colorOf_2(0.572081, 0.145797, 0.406369), colorOf_2(0.578304, 0.148039, 0.404411), colorOf_2(0.584521, 0.150294, 0.402385), colorOf_2(0.590734, 0.152563, 0.40029), colorOf_2(0.59694, 0.154848, 0.398125), colorOf_2(0.603139, 0.157151, 0.395891), colorOf_2(0.60933, 0.159474, 0.393589), colorOf_2(0.615513, 0.161817, 0.391219), colorOf_2(0.621685, 0.164184, 0.388781), colorOf_2(0.627847, 0.166575, 0.386276), colorOf_2(0.633998, 0.168992, 0.383704), colorOf_2(0.640135, 0.171438, 0.381065), colorOf_2(0.64626, 0.173914, 0.378359), colorOf_2(0.652369, 0.176421, 0.375586), colorOf_2(0.658463, 0.178962, 0.372748), colorOf_2(0.66454, 0.181539, 0.369846), colorOf_2(0.670599, 0.184153, 0.366879), colorOf_2(0.676638, 0.186807, 0.363849), colorOf_2(0.682656, 0.189501, 0.360757), colorOf_2(0.688653, 0.192239, 0.357603), colorOf_2(0.694627, 0.195021, 0.354388), colorOf_2(0.700576, 0.197851, 0.351113), colorOf_2(0.7065, 0.200728, 0.347777), colorOf_2(0.712396, 0.203656, 0.344383), colorOf_2(0.718264, 0.206636, 0.340931), colorOf_2(0.724103, 0.20967, 0.337424), colorOf_2(0.729909, 0.212759, 0.333861), colorOf_2(0.735683, 0.215906, 0.330245), colorOf_2(0.741423, 0.219112, 0.326576), colorOf_2(0.747127, 0.222378, 0.322856), colorOf_2(0.752794, 0.225706, 0.319085), colorOf_2(0.758422, 0.229097, 0.315266), colorOf_2(0.76401, 0.232554, 0.311399), colorOf_2(0.769556, 0.236077, 0.307485), colorOf_2(0.775059, 0.239667, 0.303526), colorOf_2(0.780517, 0.243327, 0.299523), colorOf_2(0.785929, 0.247056, 0.295477), colorOf_2(0.791293, 0.250856, 0.29139), colorOf_2(0.796607, 0.254728, 0.287264), colorOf_2(0.801871, 0.258674, 0.283099), colorOf_2(0.807082, 0.262692, 0.278898), colorOf_2(0.812239, 0.266786, 0.274661), colorOf_2(0.817341, 0.270954, 0.27039), colorOf_2(0.822386, 0.275197, 0.266085), colorOf_2(0.827372, 0.279517, 0.26175), colorOf_2(0.832299, 0.283913, 0.257383), colorOf_2(0.837165, 0.288385, 0.252988), colorOf_2(0.841969, 0.292933, 0.248564), colorOf_2(0.846709, 0.297559, 0.244113), colorOf_2(0.851384, 0.30226, 0.239636), colorOf_2(0.855992, 0.307038, 0.235133), colorOf_2(0.860533, 0.311892, 0.230606), colorOf_2(0.865006, 0.316822, 0.226055), colorOf_2(0.869409, 0.321827, 0.221482), colorOf_2(0.873741, 0.326906, 0.216886), colorOf_2(0.878001, 0.33206, 0.212268), colorOf_2(0.882188, 0.337287, 0.207628), colorOf_2(0.886302, 0.342586, 0.202968), colorOf_2(0.890341, 0.347957, 0.198286), colorOf_2(0.894305, 0.353399, 0.193584), colorOf_2(0.898192, 0.358911, 0.18886), colorOf_2(0.902003, 0.364492, 0.184116), colorOf_2(0.905735, 0.37014, 0.17935), colorOf_2(0.90939, 0.375856, 0.174563), colorOf_2(0.912966, 0.381636, 0.169755), colorOf_2(0.916462, 0.387481, 0.164924), colorOf_2(0.919879, 0.393389, 0.16007), colorOf_2(0.923215, 0.399359, 0.155193), colorOf_2(0.92647, 0.405389, 0.150292), colorOf_2(0.929644, 0.411479, 0.145367), colorOf_2(0.932737, 0.417627, 0.140417), colorOf_2(0.935747, 0.423831, 0.13544), colorOf_2(0.938675, 0.430091, 0.130438), colorOf_2(0.941521, 0.436405, 0.125409), colorOf_2(0.944285, 0.442772, 0.120354), colorOf_2(0.946965, 0.449191, 0.115272), colorOf_2(0.949562, 0.45566, 0.110164), colorOf_2(0.952075, 0.462178, 0.105031), colorOf_2(0.954506, 0.468744, 0.099874), colorOf_2(0.956852, 0.475356, 0.094695), colorOf_2(0.959114, 0.482014, 0.089499), colorOf_2(0.961293, 0.488716, 0.084289), colorOf_2(0.963387, 0.495462, 0.079073), colorOf_2(0.965397, 0.502249, 0.073859), colorOf_2(0.967322, 0.509078, 0.068659), colorOf_2(0.969163, 0.515946, 0.063488), colorOf_2(0.970919, 0.522853, 0.058367), colorOf_2(0.97259, 0.529798, 0.053324), colorOf_2(0.974176, 0.53678, 0.048392), colorOf_2(0.975677, 0.543798, 0.043618), colorOf_2(0.977092, 0.55085, 0.03905), colorOf_2(0.978422, 0.557937, 0.034931), colorOf_2(0.979666, 0.565057, 0.031409), colorOf_2(0.980824, 0.572209, 0.028508), colorOf_2(0.981895, 0.579392, 0.02625), colorOf_2(0.982881, 0.586606, 0.024661), colorOf_2(0.983779, 0.593849, 0.02377), colorOf_2(0.984591, 0.601122, 0.023606), colorOf_2(0.985315, 0.608422, 0.024202), colorOf_2(0.985952, 0.61575, 0.025592), colorOf_2(0.986502, 0.623105, 0.027814), colorOf_2(0.986964, 0.630485, 0.030908), colorOf_2(0.987337, 0.63789, 0.034916), colorOf_2(0.987622, 0.64532, 0.039886), colorOf_2(0.987819, 0.652773, 0.045581), colorOf_2(0.987926, 0.66025, 0.05175), colorOf_2(0.987945, 0.667748, 0.058329), colorOf_2(0.987874, 0.675267, 0.065257), colorOf_2(0.987714, 0.682807, 0.072489), colorOf_2(0.987464, 0.690366, 0.07999), colorOf_2(0.987124, 0.697944, 0.087731), colorOf_2(0.986694, 0.70554, 0.095694), colorOf_2(0.986175, 0.713153, 0.103863), colorOf_2(0.985566, 0.720782, 0.112229), colorOf_2(0.984865, 0.728427, 0.120785), colorOf_2(0.984075, 0.736087, 0.129527), colorOf_2(0.983196, 0.743758, 0.138453), colorOf_2(0.982228, 0.751442, 0.147565), colorOf_2(0.981173, 0.759135, 0.156863), colorOf_2(0.980032, 0.766837, 0.166353), colorOf_2(0.978806, 0.774545, 0.176037), colorOf_2(0.977497, 0.782258, 0.185923), colorOf_2(0.976108, 0.789974, 0.196018), colorOf_2(0.974638, 0.797692, 0.206332), colorOf_2(0.973088, 0.805409, 0.216877), colorOf_2(0.971468, 0.813122, 0.227658), colorOf_2(0.969783, 0.820825, 0.238686), colorOf_2(0.968041, 0.828515, 0.249972), colorOf_2(0.966243, 0.836191, 0.261534), colorOf_2(0.964394, 0.843848, 0.273391), colorOf_2(0.962517, 0.851476, 0.285546), colorOf_2(0.960626, 0.859069, 0.29801), colorOf_2(0.95872, 0.866624, 0.31082), colorOf_2(0.956834, 0.874129, 0.323974), colorOf_2(0.954997, 0.881569, 0.337475), colorOf_2(0.953215, 0.888942, 0.351369), colorOf_2(0.951546, 0.896226, 0.365627), colorOf_2(0.950018, 0.903409, 0.380271), colorOf_2(0.948683, 0.910473, 0.395289), colorOf_2(0.947594, 0.917399, 0.410665), colorOf_2(0.946809, 0.924168, 0.426373), colorOf_2(0.946392, 0.930761, 0.442367), colorOf_2(0.946403, 0.937159, 0.458592), colorOf_2(0.946903, 0.943348, 0.47497), colorOf_2(0.947937, 0.949318, 0.491426), colorOf_2(0.949545, 0.955063, 0.50786), colorOf_2(0.95174, 0.960587, 0.524203), colorOf_2(0.954529, 0.965896, 0.540361), colorOf_2(0.957896, 0.971003, 0.556275), colorOf_2(0.961812, 0.975924, 0.571925), colorOf_2(0.966249, 0.980678, 0.587206), colorOf_2(0.971162, 0.985282, 0.602154), colorOf_2(0.976511, 0.989753, 0.61676), colorOf_2(0.982257, 0.994109, 0.631017), colorOf_2(0.988362, 0.998364, 0.644924)])));
    this.l28_1 = new Entry_2('plasma', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.u25([colorOf_2(0.050383, 0.029803, 0.527975), colorOf_2(0.063536, 0.028426, 0.533124), colorOf_2(0.075353, 0.027206, 0.538007), colorOf_2(0.086222, 0.026125, 0.542658), colorOf_2(0.096379, 0.025165, 0.547103), colorOf_2(0.10598, 0.024309, 0.551368), colorOf_2(0.115124, 0.023556, 0.555468), colorOf_2(0.123903, 0.022878, 0.559423), colorOf_2(0.132381, 0.022258, 0.56325), colorOf_2(0.140603, 0.021687, 0.566959), colorOf_2(0.148607, 0.021154, 0.570562), colorOf_2(0.156421, 0.020651, 0.574065), colorOf_2(0.16407, 0.020171, 0.577478), colorOf_2(0.171574, 0.019706, 0.580806), colorOf_2(0.17895, 0.019252, 0.584054), colorOf_2(0.186213, 0.018803, 0.587228), colorOf_2(0.193374, 0.018354, 0.59033), colorOf_2(0.200445, 0.017902, 0.593364), colorOf_2(0.207435, 0.017442, 0.596333), colorOf_2(0.21435, 0.016973, 0.599239), colorOf_2(0.221197, 0.016497, 0.602083), colorOf_2(0.227983, 0.016007, 0.604867), colorOf_2(0.234715, 0.015502, 0.607592), colorOf_2(0.241396, 0.014979, 0.610259), colorOf_2(0.248032, 0.014439, 0.612868), colorOf_2(0.254627, 0.013882, 0.615419), colorOf_2(0.261183, 0.013308, 0.617911), colorOf_2(0.267703, 0.012716, 0.620346), colorOf_2(0.274191, 0.012109, 0.622722), colorOf_2(0.280648, 0.011488, 0.625038), colorOf_2(0.287076, 0.010855, 0.627295), colorOf_2(0.293478, 0.010213, 0.62949), colorOf_2(0.299855, 0.009561, 0.631624), colorOf_2(0.30621, 0.008902, 0.633694), colorOf_2(0.312543, 0.008239, 0.6357), colorOf_2(0.318856, 0.007576, 0.63764), colorOf_2(0.32515, 0.006915, 0.639512), colorOf_2(0.331426, 0.006261, 0.641316), colorOf_2(0.337683, 0.005618, 0.643049), colorOf_2(0.343925, 0.004991, 0.64471), colorOf_2(0.35015, 0.004382, 0.646298), colorOf_2(0.356359, 0.003798, 0.64781), colorOf_2(0.362553, 0.003243, 0.649245), colorOf_2(0.368733, 0.002724, 0.650601), colorOf_2(0.374897, 0.002245, 0.651876), colorOf_2(0.381047, 0.001814, 0.653068), colorOf_2(0.387183, 0.001434, 0.654177), colorOf_2(0.393304, 0.001114, 0.655199), colorOf_2(0.399411, 8.59E-4, 0.656133), colorOf_2(0.405503, 6.78E-4, 0.656977), colorOf_2(0.41158, 5.77E-4, 0.65773), colorOf_2(0.417642, 5.64E-4, 0.65839), colorOf_2(0.423689, 6.46E-4, 0.658956), colorOf_2(0.429719, 8.31E-4, 0.659425), colorOf_2(0.435734, 0.001127, 0.659797), colorOf_2(0.441732, 0.00154, 0.660069), colorOf_2(0.447714, 0.00208, 0.66024), colorOf_2(0.453677, 0.002755, 0.66031), colorOf_2(0.459623, 0.003574, 0.660277), colorOf_2(0.46555, 0.004545, 0.660139), colorOf_2(0.471457, 0.005678, 0.659897), colorOf_2(0.477344, 0.00698, 0.659549), colorOf_2(0.48321, 0.00846, 0.659095), colorOf_2(0.489055, 0.010127, 0.658534), colorOf_2(0.494877, 0.01199, 0.657865), colorOf_2(0.500678, 0.014055, 0.657088), colorOf_2(0.506454, 0.016333, 0.656202), colorOf_2(0.512206, 0.018833, 0.655209), colorOf_2(0.517933, 0.021563, 0.654109), colorOf_2(0.523633, 0.024532, 0.652901), colorOf_2(0.529306, 0.027747, 0.651586), colorOf_2(0.534952, 0.031217, 0.650165), colorOf_2(0.54057, 0.03495, 0.64864), colorOf_2(0.546157, 0.038954, 0.64701), colorOf_2(0.551715, 0.043136, 0.645277), colorOf_2(0.557243, 0.047331, 0.643443), colorOf_2(0.562738, 0.051545, 0.641509), colorOf_2(0.568201, 0.055778, 0.639477), colorOf_2(0.573632, 0.060028, 0.637349), colorOf_2(0.579029, 0.064296, 0.635126), colorOf_2(0.584391, 0.068579, 0.632812), colorOf_2(0.589719, 0.072878, 0.630408), colorOf_2(0.595011, 0.07719, 0.627917), colorOf_2(0.600266, 0.081516, 0.625342), colorOf_2(0.605485, 0.085854, 0.622686), colorOf_2(0.610667, 0.090204, 0.619951), colorOf_2(0.615812, 0.094564, 0.61714), colorOf_2(0.620919, 0.098934, 0.614257), colorOf_2(0.625987, 0.103312, 0.611305), colorOf_2(0.631017, 0.107699, 0.608287), colorOf_2(0.636008, 0.112092, 0.605205), colorOf_2(0.640959, 0.116492, 0.602065), colorOf_2(0.645872, 0.120898, 0.598867), colorOf_2(0.650746, 0.125309, 0.595617), colorOf_2(0.65558, 0.129725, 0.592317), colorOf_2(0.660374, 0.134144, 0.588971), colorOf_2(0.665129, 0.138566, 0.585582), colorOf_2(0.669845, 0.142992, 0.582154), colorOf_2(0.674522, 0.147419, 0.578688), colorOf_2(0.67916, 0.151848, 0.575189), colorOf_2(0.683758, 0.156278, 0.57166), colorOf_2(0.688318, 0.160709, 0.568103), colorOf_2(0.69284, 0.165141, 0.564522), colorOf_2(0.697324, 0.169573, 0.560919), colorOf_2(0.701769, 0.174005, 0.557296), colorOf_2(0.706178, 0.178437, 0.553657), colorOf_2(0.710549, 0.182868, 0.550004), colorOf_2(0.714883, 0.187299, 0.546338), colorOf_2(0.719181, 0.191729, 0.542663), colorOf_2(0.723444, 0.196158, 0.538981), colorOf_2(0.72767, 0.200586, 0.535293), colorOf_2(0.731862, 0.205013, 0.531601), colorOf_2(0.736019, 0.209439, 0.527908), colorOf_2(0.740143, 0.213864, 0.524216), colorOf_2(0.744232, 0.218288, 0.520524), colorOf_2(0.748289, 0.222711, 0.516834), colorOf_2(0.752312, 0.227133, 0.513149), colorOf_2(0.756304, 0.231555, 0.509468), colorOf_2(0.760264, 0.235976, 0.505794), colorOf_2(0.764193, 0.240396, 0.502126), colorOf_2(0.76809, 0.244817, 0.498465), colorOf_2(0.771958, 0.249237, 0.494813), colorOf_2(0.775796, 0.253658, 0.491171), colorOf_2(0.779604, 0.258078, 0.487539), colorOf_2(0.783383, 0.2625, 0.483918), colorOf_2(0.787133, 0.266922, 0.480307), colorOf_2(0.790855, 0.271345, 0.476706), colorOf_2(0.794549, 0.27577, 0.473117), colorOf_2(0.798216, 0.280197, 0.469538), colorOf_2(0.801855, 0.284626, 0.465971), colorOf_2(0.805467, 0.289057, 0.462415), colorOf_2(0.809052, 0.293491, 0.45887), colorOf_2(0.812612, 0.297928, 0.455338), colorOf_2(0.816144, 0.302368, 0.451816), colorOf_2(0.819651, 0.306812, 0.448306), colorOf_2(0.823132, 0.311261, 0.444806), colorOf_2(0.826588, 0.315714, 0.441316), colorOf_2(0.830018, 0.320172, 0.437836), colorOf_2(0.833422, 0.324635, 0.434366), colorOf_2(0.836801, 0.329105, 0.430905), colorOf_2(0.840155, 0.33358, 0.427455), colorOf_2(0.843484, 0.338062, 0.424013), colorOf_2(0.846788, 0.342551, 0.420579), colorOf_2(0.850066, 0.347048, 0.417153), colorOf_2(0.853319, 0.351553, 0.413734), colorOf_2(0.856547, 0.356066, 0.410322), colorOf_2(0.85975, 0.360588, 0.406917), colorOf_2(0.862927, 0.365119, 0.403519), colorOf_2(0.866078, 0.36966, 0.400126), colorOf_2(0.869203, 0.374212, 0.396738), colorOf_2(0.872303, 0.378774, 0.393355), colorOf_2(0.875376, 0.383347, 0.389976), colorOf_2(0.878423, 0.387932, 0.3866), colorOf_2(0.881443, 0.392529, 0.383229), colorOf_2(0.884436, 0.397139, 0.37986), colorOf_2(0.887402, 0.401762, 0.376494), colorOf_2(0.89034, 0.406398, 0.37313), colorOf_2(0.89325, 0.411048, 0.369768), colorOf_2(0.896131, 0.415712, 0.366407), colorOf_2(0.898984, 0.420392, 0.363047), colorOf_2(0.901807, 0.425087, 0.359688), colorOf_2(0.904601, 0.429797, 0.356329), colorOf_2(0.907365, 0.434524, 0.35297), colorOf_2(0.910098, 0.439268, 0.34961), colorOf_2(0.9128, 0.444029, 0.346251), colorOf_2(0.915471, 0.448807, 0.34289), colorOf_2(0.918109, 0.453603, 0.339529), colorOf_2(0.920714, 0.458417, 0.336166), colorOf_2(0.923287, 0.463251, 0.332801), colorOf_2(0.925825, 0.468103, 0.329435), colorOf_2(0.928329, 0.472975, 0.326067), colorOf_2(0.930798, 0.477867, 0.322697), colorOf_2(0.933232, 0.48278, 0.319325), colorOf_2(0.93563, 0.487712, 0.315952), colorOf_2(0.93799, 0.492667, 0.312575), colorOf_2(0.940313, 0.497642, 0.309197), colorOf_2(0.942598, 0.502639, 0.305816), colorOf_2(0.944844, 0.507658, 0.302433), colorOf_2(0.947051, 0.512699, 0.299049), colorOf_2(0.949217, 0.517763, 0.295662), colorOf_2(0.951344, 0.52285, 0.292275), colorOf_2(0.953428, 0.52796, 0.288883), colorOf_2(0.95547, 0.533093, 0.28549), colorOf_2(0.957469, 0.53825, 0.282096), colorOf_2(0.959424, 0.543431, 0.278701), colorOf_2(0.961336, 0.548636, 0.275305), colorOf_2(0.963203, 0.553865, 0.271909), colorOf_2(0.965024, 0.559118, 0.268513), colorOf_2(0.966798, 0.564396, 0.265118), colorOf_2(0.968526, 0.5697, 0.261721), colorOf_2(0.970205, 0.575028, 0.258325), colorOf_2(0.971835, 0.580382, 0.254931), colorOf_2(0.973416, 0.585761, 0.25154), colorOf_2(0.974947, 0.591165, 0.248151), colorOf_2(0.976428, 0.596595, 0.244767), colorOf_2(0.977856, 0.602051, 0.241387), colorOf_2(0.979233, 0.607532, 0.238013), colorOf_2(0.980556, 0.613039, 0.234646), colorOf_2(0.981826, 0.618572, 0.231287), colorOf_2(0.983041, 0.624131, 0.227937), colorOf_2(0.984199, 0.629718, 0.224595), colorOf_2(0.985301, 0.63533, 0.221265), colorOf_2(0.986345, 0.640969, 0.217948), colorOf_2(0.987332, 0.646633, 0.214648), colorOf_2(0.98826, 0.652325, 0.211364), colorOf_2(0.989128, 0.658043, 0.2081), colorOf_2(0.989935, 0.663787, 0.204859), colorOf_2(0.990681, 0.669558, 0.201642), colorOf_2(0.991365, 0.675355, 0.198453), colorOf_2(0.991985, 0.681179, 0.195295), colorOf_2(0.992541, 0.68703, 0.19217), colorOf_2(0.993032, 0.692907, 0.189084), colorOf_2(0.993456, 0.69881, 0.186041), colorOf_2(0.993814, 0.704741, 0.183043), colorOf_2(0.994103, 0.710698, 0.180097), colorOf_2(0.994324, 0.716681, 0.177208), colorOf_2(0.994474, 0.722691, 0.174381), colorOf_2(0.994553, 0.728728, 0.171622), colorOf_2(0.994561, 0.734791, 0.168938), colorOf_2(0.994495, 0.74088, 0.166335), colorOf_2(0.994355, 0.746995, 0.163821), colorOf_2(0.994141, 0.753137, 0.161404), colorOf_2(0.993851, 0.759304, 0.159092), colorOf_2(0.993482, 0.765499, 0.156891), colorOf_2(0.993033, 0.77172, 0.154808), colorOf_2(0.992505, 0.777967, 0.152855), colorOf_2(0.991897, 0.784239, 0.151042), colorOf_2(0.991209, 0.790537, 0.149377), colorOf_2(0.990439, 0.796859, 0.14787), colorOf_2(0.989587, 0.803205, 0.146529), colorOf_2(0.988648, 0.809579, 0.145357), colorOf_2(0.987621, 0.815978, 0.144363), colorOf_2(0.986509, 0.822401, 0.143557), colorOf_2(0.985314, 0.828846, 0.142945), colorOf_2(0.984031, 0.835315, 0.142528), colorOf_2(0.982653, 0.841812, 0.142303), colorOf_2(0.98119, 0.848329, 0.142279), colorOf_2(0.979644, 0.854866, 0.142453), colorOf_2(0.977995, 0.861432, 0.142808), colorOf_2(0.976265, 0.868016, 0.143351), colorOf_2(0.974443, 0.874622, 0.144061), colorOf_2(0.97253, 0.88125, 0.144923), colorOf_2(0.970533, 0.887896, 0.145919), colorOf_2(0.968443, 0.894564, 0.147014), colorOf_2(0.966271, 0.901249, 0.14818), colorOf_2(0.964021, 0.90795, 0.14937), colorOf_2(0.961681, 0.914672, 0.15052), colorOf_2(0.959276, 0.921407, 0.151566), colorOf_2(0.956808, 0.928152, 0.152409), colorOf_2(0.954287, 0.934908, 0.152921), colorOf_2(0.951726, 0.941671, 0.152925), colorOf_2(0.949151, 0.948435, 0.152178), colorOf_2(0.946602, 0.95519, 0.150328), colorOf_2(0.944152, 0.961916, 0.146861), colorOf_2(0.941896, 0.96859, 0.140956), colorOf_2(0.940015, 0.975158, 0.131326)])));
    this.j28_1 = new Entry_2('viridis', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.u25([colorOf_2(0.267004, 0.004874, 0.329415), colorOf_2(0.26851, 0.009605, 0.335427), colorOf_2(0.269944, 0.014625, 0.341379), colorOf_2(0.271305, 0.019942, 0.347269), colorOf_2(0.272594, 0.025563, 0.353093), colorOf_2(0.273809, 0.031497, 0.358853), colorOf_2(0.274952, 0.037752, 0.364543), colorOf_2(0.276022, 0.044167, 0.370164), colorOf_2(0.277018, 0.050344, 0.375715), colorOf_2(0.277941, 0.056324, 0.381191), colorOf_2(0.278791, 0.062145, 0.386592), colorOf_2(0.279566, 0.067836, 0.391917), colorOf_2(0.280267, 0.073417, 0.397163), colorOf_2(0.280894, 0.078907, 0.402329), colorOf_2(0.281446, 0.08432, 0.407414), colorOf_2(0.281924, 0.089666, 0.412415), colorOf_2(0.282327, 0.094955, 0.417331), colorOf_2(0.282656, 0.100196, 0.42216), colorOf_2(0.28291, 0.105393, 0.426902), colorOf_2(0.283091, 0.110553, 0.431554), colorOf_2(0.283197, 0.11568, 0.436115), colorOf_2(0.283229, 0.120777, 0.440584), colorOf_2(0.283187, 0.125848, 0.44496), colorOf_2(0.283072, 0.130895, 0.449241), colorOf_2(0.282884, 0.13592, 0.453427), colorOf_2(0.282623, 0.140926, 0.457517), colorOf_2(0.28229, 0.145912, 0.46151), colorOf_2(0.281887, 0.150881, 0.465405), colorOf_2(0.281412, 0.155834, 0.469201), colorOf_2(0.280868, 0.160771, 0.472899), colorOf_2(0.280255, 0.165693, 0.476498), colorOf_2(0.279574, 0.170599, 0.479997), colorOf_2(0.278826, 0.17549, 0.483397), colorOf_2(0.278012, 0.180367, 0.486697), colorOf_2(0.277134, 0.185228, 0.489898), colorOf_2(0.276194, 0.190074, 0.493001), colorOf_2(0.275191, 0.194905, 0.496005), colorOf_2(0.274128, 0.199721, 0.498911), colorOf_2(0.273006, 0.20452, 0.501721), colorOf_2(0.271828, 0.209303, 0.504434), colorOf_2(0.270595, 0.214069, 0.507052), colorOf_2(0.269308, 0.218818, 0.509577), colorOf_2(0.267968, 0.223549, 0.512008), colorOf_2(0.26658, 0.228262, 0.514349), colorOf_2(0.265145, 0.232956, 0.516599), colorOf_2(0.263663, 0.237631, 0.518762), colorOf_2(0.262138, 0.242286, 0.520837), colorOf_2(0.260571, 0.246922, 0.522828), colorOf_2(0.258965, 0.251537, 0.524736), colorOf_2(0.257322, 0.25613, 0.526563), colorOf_2(0.255645, 0.260703, 0.528312), colorOf_2(0.253935, 0.265254, 0.529983), colorOf_2(0.252194, 0.269783, 0.531579), colorOf_2(0.250425, 0.27429, 0.533103), colorOf_2(0.248629, 0.278775, 0.534556), colorOf_2(0.246811, 0.283237, 0.535941), colorOf_2(0.244972, 0.287675, 0.53726), colorOf_2(0.243113, 0.292092, 0.538516), colorOf_2(0.241237, 0.296485, 0.539709), colorOf_2(0.239346, 0.300855, 0.540844), colorOf_2(0.237441, 0.305202, 0.541921), colorOf_2(0.235526, 0.309527, 0.542944), colorOf_2(0.233603, 0.313828, 0.543914), colorOf_2(0.231674, 0.318106, 0.544834), colorOf_2(0.229739, 0.322361, 0.545706), colorOf_2(0.227802, 0.326594, 0.546532), colorOf_2(0.225863, 0.330805, 0.547314), colorOf_2(0.223925, 0.334994, 0.548053), colorOf_2(0.221989, 0.339161, 0.548752), colorOf_2(0.220057, 0.343307, 0.549413), colorOf_2(0.21813, 0.347432, 0.550038), colorOf_2(0.21621, 0.351535, 0.550627), colorOf_2(0.214298, 0.355619, 0.551184), colorOf_2(0.212395, 0.359683, 0.55171), colorOf_2(0.210503, 0.363727, 0.552206), colorOf_2(0.208623, 0.367752, 0.552675), colorOf_2(0.206756, 0.371758, 0.553117), colorOf_2(0.204903, 0.375746, 0.553533), colorOf_2(0.203063, 0.379716, 0.553925), colorOf_2(0.201239, 0.38367, 0.554294), colorOf_2(0.19943, 0.387607, 0.554642), colorOf_2(0.197636, 0.391528, 0.554969), colorOf_2(0.19586, 0.395433, 0.555276), colorOf_2(0.1941, 0.399323, 0.555565), colorOf_2(0.192357, 0.403199, 0.555836), colorOf_2(0.190631, 0.407061, 0.556089), colorOf_2(0.188923, 0.41091, 0.556326), colorOf_2(0.187231, 0.414746, 0.556547), colorOf_2(0.185556, 0.41857, 0.556753), colorOf_2(0.183898, 0.422383, 0.556944), colorOf_2(0.182256, 0.426184, 0.55712), colorOf_2(0.180629, 0.429975, 0.557282), colorOf_2(0.179019, 0.433756, 0.55743), colorOf_2(0.177423, 0.437527, 0.557565), colorOf_2(0.175841, 0.44129, 0.557685), colorOf_2(0.174274, 0.445044, 0.557792), colorOf_2(0.172719, 0.448791, 0.557885), colorOf_2(0.171176, 0.45253, 0.557965), colorOf_2(0.169646, 0.456262, 0.55803), colorOf_2(0.168126, 0.459988, 0.558082), colorOf_2(0.166617, 0.463708, 0.558119), colorOf_2(0.165117, 0.467423, 0.558141), colorOf_2(0.163625, 0.471133, 0.558148), colorOf_2(0.162142, 0.474838, 0.55814), colorOf_2(0.160665, 0.47854, 0.558115), colorOf_2(0.159194, 0.482237, 0.558073), colorOf_2(0.157729, 0.485932, 0.558013), colorOf_2(0.15627, 0.489624, 0.557936), colorOf_2(0.154815, 0.493313, 0.55784), colorOf_2(0.153364, 0.497, 0.557724), colorOf_2(0.151918, 0.500685, 0.557587), colorOf_2(0.150476, 0.504369, 0.55743), colorOf_2(0.149039, 0.508051, 0.55725), colorOf_2(0.147607, 0.511733, 0.557049), colorOf_2(0.14618, 0.515413, 0.556823), colorOf_2(0.144759, 0.519093, 0.556572), colorOf_2(0.143343, 0.522773, 0.556295), colorOf_2(0.141935, 0.526453, 0.555991), colorOf_2(0.140536, 0.530132, 0.555659), colorOf_2(0.139147, 0.533812, 0.555298), colorOf_2(0.13777, 0.537492, 0.554906), colorOf_2(0.136408, 0.541173, 0.554483), colorOf_2(0.135066, 0.544853, 0.554029), colorOf_2(0.133743, 0.548535, 0.553541), colorOf_2(0.132444, 0.552216, 0.553018), colorOf_2(0.131172, 0.555899, 0.552459), colorOf_2(0.129933, 0.559582, 0.551864), colorOf_2(0.128729, 0.563265, 0.551229), colorOf_2(0.127568, 0.566949, 0.550556), colorOf_2(0.126453, 0.570633, 0.549841), colorOf_2(0.125394, 0.574318, 0.549086), colorOf_2(0.124395, 0.578002, 0.548287), colorOf_2(0.123463, 0.581687, 0.547445), colorOf_2(0.122606, 0.585371, 0.546557), colorOf_2(0.121831, 0.589055, 0.545623), colorOf_2(0.121148, 0.592739, 0.544641), colorOf_2(0.120565, 0.596422, 0.543611), colorOf_2(0.120092, 0.600104, 0.54253), colorOf_2(0.119738, 0.603785, 0.5414), colorOf_2(0.119512, 0.607464, 0.540218), colorOf_2(0.119423, 0.611141, 0.538982), colorOf_2(0.119483, 0.614817, 0.537692), colorOf_2(0.119699, 0.61849, 0.536347), colorOf_2(0.120081, 0.622161, 0.534946), colorOf_2(0.120638, 0.625828, 0.533488), colorOf_2(0.12138, 0.629492, 0.531973), colorOf_2(0.122312, 0.633153, 0.530398), colorOf_2(0.123444, 0.636809, 0.528763), colorOf_2(0.12478, 0.640461, 0.527068), colorOf_2(0.126326, 0.644107, 0.525311), colorOf_2(0.128087, 0.647749, 0.523491), colorOf_2(0.130067, 0.651384, 0.521608), colorOf_2(0.132268, 0.655014, 0.519661), colorOf_2(0.134692, 0.658636, 0.517649), colorOf_2(0.137339, 0.662252, 0.515571), colorOf_2(0.14021, 0.665859, 0.513427), colorOf_2(0.143303, 0.669459, 0.511215), colorOf_2(0.146616, 0.67305, 0.508936), colorOf_2(0.150148, 0.676631, 0.506589), colorOf_2(0.153894, 0.680203, 0.504172), colorOf_2(0.157851, 0.683765, 0.501686), colorOf_2(0.162016, 0.687316, 0.499129), colorOf_2(0.166383, 0.690856, 0.496502), colorOf_2(0.170948, 0.694384, 0.493803), colorOf_2(0.175707, 0.6979, 0.491033), colorOf_2(0.180653, 0.701402, 0.488189), colorOf_2(0.185783, 0.704891, 0.485273), colorOf_2(0.19109, 0.708366, 0.482284), colorOf_2(0.196571, 0.711827, 0.479221), colorOf_2(0.202219, 0.715272, 0.476084), colorOf_2(0.20803, 0.718701, 0.472873), colorOf_2(0.214, 0.722114, 0.469588), colorOf_2(0.220124, 0.725509, 0.466226), colorOf_2(0.226397, 0.728888, 0.462789), colorOf_2(0.232815, 0.732247, 0.459277), colorOf_2(0.239374, 0.735588, 0.455688), colorOf_2(0.24607, 0.73891, 0.452024), colorOf_2(0.252899, 0.742211, 0.448284), colorOf_2(0.259857, 0.745492, 0.444467), colorOf_2(0.266941, 0.748751, 0.440573), colorOf_2(0.274149, 0.751988, 0.436601), colorOf_2(0.281477, 0.755203, 0.432552), colorOf_2(0.288921, 0.758394, 0.428426), colorOf_2(0.296479, 0.761561, 0.424223), colorOf_2(0.304148, 0.764704, 0.419943), colorOf_2(0.311925, 0.767822, 0.415586), colorOf_2(0.319809, 0.770914, 0.411152), colorOf_2(0.327796, 0.77398, 0.40664), colorOf_2(0.335885, 0.777018, 0.402049), colorOf_2(0.344074, 0.780029, 0.397381), colorOf_2(0.35236, 0.783011, 0.392636), colorOf_2(0.360741, 0.785964, 0.387814), colorOf_2(0.369214, 0.788888, 0.382914), colorOf_2(0.377779, 0.791781, 0.377939), colorOf_2(0.386433, 0.794644, 0.372886), colorOf_2(0.395174, 0.797475, 0.367757), colorOf_2(0.404001, 0.800275, 0.362552), colorOf_2(0.412913, 0.803041, 0.357269), colorOf_2(0.421908, 0.805774, 0.35191), colorOf_2(0.430983, 0.808473, 0.346476), colorOf_2(0.440137, 0.811138, 0.340967), colorOf_2(0.449368, 0.813768, 0.335384), colorOf_2(0.458674, 0.816363, 0.329727), colorOf_2(0.468053, 0.818921, 0.323998), colorOf_2(0.477504, 0.821444, 0.318195), colorOf_2(0.487026, 0.823929, 0.312321), colorOf_2(0.496615, 0.826376, 0.306377), colorOf_2(0.506271, 0.828786, 0.300362), colorOf_2(0.515992, 0.831158, 0.294279), colorOf_2(0.525776, 0.833491, 0.288127), colorOf_2(0.535621, 0.835785, 0.281908), colorOf_2(0.545524, 0.838039, 0.275626), colorOf_2(0.555484, 0.840254, 0.269281), colorOf_2(0.565498, 0.84243, 0.262877), colorOf_2(0.575563, 0.844566, 0.256415), colorOf_2(0.585678, 0.846661, 0.249897), colorOf_2(0.595839, 0.848717, 0.243329), colorOf_2(0.606045, 0.850733, 0.236712), colorOf_2(0.616293, 0.852709, 0.230052), colorOf_2(0.626579, 0.854645, 0.223353), colorOf_2(0.636902, 0.856542, 0.21662), colorOf_2(0.647257, 0.8584, 0.209861), colorOf_2(0.657642, 0.860219, 0.203082), colorOf_2(0.668054, 0.861999, 0.196293), colorOf_2(0.678489, 0.863742, 0.189503), colorOf_2(0.688944, 0.865448, 0.182725), colorOf_2(0.699415, 0.867117, 0.175971), colorOf_2(0.709898, 0.868751, 0.169257), colorOf_2(0.720391, 0.87035, 0.162603), colorOf_2(0.730889, 0.871916, 0.156029), colorOf_2(0.741388, 0.873449, 0.149561), colorOf_2(0.751884, 0.874951, 0.143228), colorOf_2(0.762373, 0.876424, 0.137064), colorOf_2(0.772852, 0.877868, 0.131109), colorOf_2(0.783315, 0.879285, 0.125405), colorOf_2(0.79376, 0.880678, 0.120005), colorOf_2(0.804182, 0.882046, 0.114965), colorOf_2(0.814576, 0.883393, 0.110347), colorOf_2(0.82494, 0.88472, 0.106217), colorOf_2(0.83527, 0.886029, 0.102646), colorOf_2(0.845561, 0.887322, 0.099702), colorOf_2(0.85581, 0.888601, 0.097452), colorOf_2(0.866013, 0.889868, 0.095953), colorOf_2(0.876168, 0.891125, 0.09525), colorOf_2(0.886271, 0.892374, 0.095374), colorOf_2(0.89632, 0.893616, 0.096335), colorOf_2(0.906311, 0.894855, 0.098125), colorOf_2(0.916242, 0.896091, 0.100717), colorOf_2(0.926106, 0.89733, 0.104071), colorOf_2(0.935904, 0.89857, 0.108131), colorOf_2(0.945636, 0.899815, 0.112838), colorOf_2(0.9553, 0.901065, 0.118128), colorOf_2(0.964894, 0.902323, 0.123941), colorOf_2(0.974417, 0.90359, 0.130215), colorOf_2(0.983868, 0.904867, 0.136897), colorOf_2(0.993248, 0.906157, 0.143936)])));
    this.n28_1 = new Entry_2('cividis', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.u25([colorOf_2(0.0, 0.135112, 0.304751), colorOf_2(0.0, 0.138068, 0.311105), colorOf_2(0.0, 0.141013, 0.317579), colorOf_2(0.0, 0.143951, 0.323982), colorOf_2(0.0, 0.146877, 0.330479), colorOf_2(0.0, 0.149791, 0.337065), colorOf_2(0.0, 0.152673, 0.343704), colorOf_2(0.0, 0.155377, 0.3505), colorOf_2(0.0, 0.157932, 0.357521), colorOf_2(0.0, 0.160495, 0.364534), colorOf_2(0.0, 0.163058, 0.371608), colorOf_2(0.0, 0.165621, 0.378769), colorOf_2(0.0, 0.168204, 0.385902), colorOf_2(0.0, 0.1708, 0.3931), colorOf_2(0.0, 0.17342, 0.400353), colorOf_2(0.0, 0.176082, 0.407577), colorOf_2(0.0, 0.178802, 0.414764), colorOf_2(0.0, 0.18161, 0.421859), colorOf_2(0.0, 0.18455, 0.428802), colorOf_2(0.0, 0.186915, 0.435532), colorOf_2(0.0, 0.188769, 0.439563), colorOf_2(0.0, 0.19095, 0.441085), colorOf_2(0.0, 0.193366, 0.441561), colorOf_2(0.003602, 0.195911, 0.441564), colorOf_2(0.017852, 0.198528, 0.441248), colorOf_2(0.03211, 0.201199, 0.440785), colorOf_2(0.046205, 0.203903, 0.440196), colorOf_2(0.058378, 0.206629, 0.439531), colorOf_2(0.068968, 0.209372, 0.438863), colorOf_2(0.078624, 0.212122, 0.438105), colorOf_2(0.087465, 0.214879, 0.437342), colorOf_2(0.095645, 0.217643, 0.436593), colorOf_2(0.103401, 0.220406, 0.43579), colorOf_2(0.110658, 0.22317, 0.435067), colorOf_2(0.117612, 0.225935, 0.434308), colorOf_2(0.124291, 0.228697, 0.433547), colorOf_2(0.130669, 0.231458, 0.43284), colorOf_2(0.13683, 0.234216, 0.432148), colorOf_2(0.142852, 0.236972, 0.431404), colorOf_2(0.148638, 0.239724, 0.430752), colorOf_2(0.154261, 0.242475, 0.43012), colorOf_2(0.159733, 0.245221, 0.429528), colorOf_2(0.165113, 0.247965, 0.428908), colorOf_2(0.170362, 0.250707, 0.428325), colorOf_2(0.17549, 0.253444, 0.42779), colorOf_2(0.180503, 0.25618, 0.427299), colorOf_2(0.185453, 0.258914, 0.426788), colorOf_2(0.190303, 0.261644, 0.426329), colorOf_2(0.195057, 0.264372, 0.425924), colorOf_2(0.199764, 0.267099, 0.425497), colorOf_2(0.204385, 0.269823, 0.425126), colorOf_2(0.208926, 0.272546, 0.424809), colorOf_2(0.213431, 0.275266, 0.42448), colorOf_2(0.217863, 0.277985, 0.424206), colorOf_2(0.222264, 0.280702, 0.423914), colorOf_2(0.226598, 0.283419, 0.423678), colorOf_2(0.230871, 0.286134, 0.423498), colorOf_2(0.23512, 0.288848, 0.423304), colorOf_2(0.239312, 0.291562, 0.423167), colorOf_2(0.243485, 0.294274, 0.423014), colorOf_2(0.247605, 0.296986, 0.422917), colorOf_2(0.251675, 0.299698, 0.422873), colorOf_2(0.255731, 0.302409, 0.422814), colorOf_2(0.25974, 0.30512, 0.42281), colorOf_2(0.263738, 0.307831, 0.422789), colorOf_2(0.267693, 0.310542, 0.422821), colorOf_2(0.271639, 0.313253, 0.422837), colorOf_2(0.275513, 0.315965, 0.422979), colorOf_2(0.279411, 0.318677, 0.423031), colorOf_2(0.28324, 0.32139, 0.423211), colorOf_2(0.287065, 0.324103, 0.423373), colorOf_2(0.290884, 0.326816, 0.423517), colorOf_2(0.294669, 0.329531, 0.423716), colorOf_2(0.298421, 0.332247, 0.423973), colorOf_2(0.302169, 0.334963, 0.424213), colorOf_2(0.305886, 0.337681, 0.424512), colorOf_2(0.309601, 0.340399, 0.42479), colorOf_2(0.313287, 0.34312, 0.42512), colorOf_2(0.316941, 0.345842, 0.425512), colorOf_2(0.320595, 0.348565, 0.425889), colorOf_2(0.32425, 0.351289, 0.42625), colorOf_2(0.327875, 0.354016, 0.42667), colorOf_2(0.331474, 0.356744, 0.427144), colorOf_2(0.335073, 0.359474, 0.427605), colorOf_2(0.338673, 0.362206, 0.428053), colorOf_2(0.342246, 0.364939, 0.428559), colorOf_2(0.345793, 0.367676, 0.429127), colorOf_2(0.349341, 0.370414, 0.429685), colorOf_2(0.352892, 0.373153, 0.430226), colorOf_2(0.356418, 0.375896, 0.430823), colorOf_2(0.359916, 0.378641, 0.431501), colorOf_2(0.363446, 0.381388, 0.432075), colorOf_2(0.366923, 0.384139, 0.432796), colorOf_2(0.37043, 0.38689, 0.433428), colorOf_2(0.373884, 0.389646, 0.434209), colorOf_2(0.377371, 0.392404, 0.43489), colorOf_2(0.38083, 0.395164, 0.435653), colorOf_2(0.384268, 0.397928, 0.436475), colorOf_2(0.387705, 0.400694, 0.437305), colorOf_2(0.391151, 0.403464, 0.438096), colorOf_2(0.394568, 0.406236, 0.438986), colorOf_2(0.397991, 0.409011, 0.439848), colorOf_2(0.401418, 0.41179, 0.440708), colorOf_2(0.40482, 0.414572, 0.441642), colorOf_2(0.408226, 0.417357, 0.44257), colorOf_2(0.411607, 0.420145, 0.443577), colorOf_2(0.414992, 0.422937, 0.444578), colorOf_2(0.418383, 0.425733, 0.44556), colorOf_2(0.421748, 0.428531, 0.44664), colorOf_2(0.42512, 0.431334, 0.447692), colorOf_2(0.428462, 0.43414, 0.448864), colorOf_2(0.431817, 0.43695, 0.449982), colorOf_2(0.435168, 0.439763, 0.451134), colorOf_2(0.438504, 0.44258, 0.452341), colorOf_2(0.44181, 0.445402, 0.453659), colorOf_2(0.445148, 0.448226, 0.454885), colorOf_2(0.448447, 0.451053, 0.456264), colorOf_2(0.451759, 0.453887, 0.457582), colorOf_2(0.455072, 0.456718, 0.458976), colorOf_2(0.458366, 0.459552, 0.460457), colorOf_2(0.461616, 0.462405, 0.461969), colorOf_2(0.464947, 0.465241, 0.463395), colorOf_2(0.468254, 0.468083, 0.464908), colorOf_2(0.471501, 0.47096, 0.466357), colorOf_2(0.474812, 0.473832, 0.467681), colorOf_2(0.478186, 0.476699, 0.468845), colorOf_2(0.481622, 0.479573, 0.469767), colorOf_2(0.485141, 0.482451, 0.470384), colorOf_2(0.488697, 0.485318, 0.471008), colorOf_2(0.492278, 0.488198, 0.471453), colorOf_2(0.495913, 0.491076, 0.471751), colorOf_2(0.499552, 0.49396, 0.472032), colorOf_2(0.503185, 0.496851, 0.472305), colorOf_2(0.506866, 0.499743, 0.472432), colorOf_2(0.51054, 0.502643, 0.47255), colorOf_2(0.514226, 0.505546, 0.47264), colorOf_2(0.51792, 0.508454, 0.472707), colorOf_2(0.521643, 0.511367, 0.472639), colorOf_2(0.525348, 0.514285, 0.47266), colorOf_2(0.529086, 0.517207, 0.472543), colorOf_2(0.532829, 0.520135, 0.472401), colorOf_2(0.536553, 0.523067, 0.472352), colorOf_2(0.540307, 0.526005, 0.472163), colorOf_2(0.544069, 0.528948, 0.471947), colorOf_2(0.54784, 0.531895, 0.471704), colorOf_2(0.551612, 0.534849, 0.471439), colorOf_2(0.555393, 0.537807, 0.471147), colorOf_2(0.559181, 0.540771, 0.470829), colorOf_2(0.562972, 0.543741, 0.470488), colorOf_2(0.566802, 0.546715, 0.469988), colorOf_2(0.570607, 0.549695, 0.469593), colorOf_2(0.574417, 0.552682, 0.469172), colorOf_2(0.578236, 0.555673, 0.468724), colorOf_2(0.582087, 0.55867, 0.468118), colorOf_2(0.585916, 0.561674, 0.467618), colorOf_2(0.589753, 0.564682, 0.46709), colorOf_2(0.593622, 0.567697, 0.466401), colorOf_2(0.597469, 0.570718, 0.465821), colorOf_2(0.601354, 0.573743, 0.465074), colorOf_2(0.605211, 0.576777, 0.464441), colorOf_2(0.609105, 0.579816, 0.463638), colorOf_2(0.612977, 0.582861, 0.46295), colorOf_2(0.616852, 0.585913, 0.462237), colorOf_2(0.620765, 0.58897, 0.461351), colorOf_2(0.624654, 0.592034, 0.460583), colorOf_2(0.628576, 0.595104, 0.459641), colorOf_2(0.632506, 0.59818, 0.458668), colorOf_2(0.636412, 0.601264, 0.457818), colorOf_2(0.640352, 0.604354, 0.456791), colorOf_2(0.64427, 0.60745, 0.455886), colorOf_2(0.648222, 0.610553, 0.454801), colorOf_2(0.652178, 0.613664, 0.453689), colorOf_2(0.656114, 0.61678, 0.452702), colorOf_2(0.660082, 0.619904, 0.451534), colorOf_2(0.664055, 0.623034, 0.450338), colorOf_2(0.668008, 0.626171, 0.44927), colorOf_2(0.671991, 0.629316, 0.448018), colorOf_2(0.675981, 0.632468, 0.446736), colorOf_2(0.679979, 0.635626, 0.445424), colorOf_2(0.68395, 0.638793, 0.444251), colorOf_2(0.687957, 0.641966, 0.442886), colorOf_2(0.691971, 0.645145, 0.441491), colorOf_2(0.695985, 0.648334, 0.440072), colorOf_2(0.700008, 0.651529, 0.438624), colorOf_2(0.704037, 0.654731, 0.437147), colorOf_2(0.708067, 0.657942, 0.435647), colorOf_2(0.712105, 0.66116, 0.434117), colorOf_2(0.716177, 0.664384, 0.432386), colorOf_2(0.720222, 0.667618, 0.430805), colorOf_2(0.724274, 0.670859, 0.429194), colorOf_2(0.728334, 0.674107, 0.427554), colorOf_2(0.732422, 0.677364, 0.425717), colorOf_2(0.736488, 0.680629, 0.424028), colorOf_2(0.740589, 0.6839, 0.422131), colorOf_2(0.744664, 0.687181, 0.420393), colorOf_2(0.748772, 0.69047, 0.418448), colorOf_2(0.752886, 0.693766, 0.416472), colorOf_2(0.756975, 0.697071, 0.414659), colorOf_2(0.761096, 0.700384, 0.412638), colorOf_2(0.765223, 0.703705, 0.410587), colorOf_2(0.769353, 0.707035, 0.408516), colorOf_2(0.773486, 0.710373, 0.406422), colorOf_2(0.777651, 0.713719, 0.404112), colorOf_2(0.781795, 0.717074, 0.401966), colorOf_2(0.785965, 0.720438, 0.399613), colorOf_2(0.790116, 0.72381, 0.397423), colorOf_2(0.794298, 0.72719, 0.395016), colorOf_2(0.79848, 0.73058, 0.392597), colorOf_2(0.802667, 0.733978, 0.390153), colorOf_2(0.806859, 0.737385, 0.387684), colorOf_2(0.811054, 0.740801, 0.385198), colorOf_2(0.815274, 0.744226, 0.382504), colorOf_2(0.819499, 0.747659, 0.379785), colorOf_2(0.823729, 0.751101, 0.377043), colorOf_2(0.827959, 0.754553, 0.374292), colorOf_2(0.832192, 0.758014, 0.371529), colorOf_2(0.836429, 0.761483, 0.368747), colorOf_2(0.840693, 0.764962, 0.365746), colorOf_2(0.844957, 0.76845, 0.362741), colorOf_2(0.849223, 0.771947, 0.359729), colorOf_2(0.853515, 0.775454, 0.3565), colorOf_2(0.857809, 0.778969, 0.353259), colorOf_2(0.862105, 0.782494, 0.350011), colorOf_2(0.866421, 0.786028, 0.346571), colorOf_2(0.870717, 0.789572, 0.343333), colorOf_2(0.875057, 0.793125, 0.339685), colorOf_2(0.879378, 0.796687, 0.336241), colorOf_2(0.88372, 0.800258, 0.332599), colorOf_2(0.888081, 0.803839, 0.32877), colorOf_2(0.89244, 0.80743, 0.324968), colorOf_2(0.896818, 0.81103, 0.320982), colorOf_2(0.901195, 0.814639, 0.317021), colorOf_2(0.905589, 0.818257, 0.312889), colorOf_2(0.91, 0.821885, 0.308594), colorOf_2(0.914407, 0.825522, 0.304348), colorOf_2(0.918828, 0.829168, 0.29996), colorOf_2(0.923279, 0.832822, 0.295244), colorOf_2(0.927724, 0.836486, 0.290611), colorOf_2(0.93218, 0.840159, 0.28588), colorOf_2(0.93666, 0.843841, 0.280876), colorOf_2(0.941147, 0.84753, 0.275815), colorOf_2(0.945654, 0.851228, 0.270532), colorOf_2(0.950178, 0.854933, 0.265085), colorOf_2(0.954725, 0.858646, 0.259365), colorOf_2(0.959284, 0.862365, 0.253563), colorOf_2(0.963872, 0.866089, 0.247445), colorOf_2(0.968469, 0.869819, 0.24131), colorOf_2(0.973114, 0.87355, 0.234677), colorOf_2(0.97778, 0.877281, 0.227954), colorOf_2(0.982497, 0.881008, 0.220878), colorOf_2(0.987293, 0.884718, 0.213336), colorOf_2(0.992218, 0.888385, 0.205468), colorOf_2(0.994847, 0.892954, 0.203445), colorOf_2(0.995249, 0.898384, 0.207561), colorOf_2(0.995503, 0.903866, 0.21237), colorOf_2(0.995737, 0.909344, 0.217772)])));
    this.o28_1 = new Entry_2('twilight', PaletteType_DIVERGING_getInstance(), InterpolatedPalette.paletteConstructor(FixedPalette.u25([colorOf_2(0.8857502, 0.85000926, 0.88797367), colorOf_2(0.8837852, 0.8507294, 0.88723224), colorOf_2(0.88172233, 0.8512759, 0.88638055), colorOf_2(0.87954104, 0.85165673, 0.88541436), colorOf_2(0.8772488, 0.8518703, 0.8843412), colorOf_2(0.8748535, 0.85191524, 0.8831693), colorOf_2(0.8723313, 0.85180163, 0.88189703), colorOf_2(0.8697047, 0.85152406, 0.8805388), colorOf_2(0.86696017, 0.8510896, 0.87909764), colorOf_2(0.86408985, 0.8505039, 0.8775793), colorOf_2(0.86110246, 0.84976757, 0.8759924), colorOf_2(0.8579826, 0.84888935, 0.8743404), colorOf_2(0.85472596, 0.8478749, 0.8726283), colorOf_2(0.85133713, 0.8467274, 0.8708608), colorOf_2(0.8478071, 0.84545463, 0.86904037), colorOf_2(0.84412616, 0.84406483, 0.86716974), colorOf_2(0.8403042, 0.8425606, 0.8652509), colorOf_2(0.8363403, 0.840948, 0.8632853), colorOf_2(0.83222705, 0.8392349, 0.8612756), colorOf_2(0.82796896, 0.837426, 0.859224), colorOf_2(0.8235743, 0.83552486, 0.8571319), colorOf_2(0.81904656, 0.8335365, 0.85500205), colorOf_2(0.8143898, 0.8314656, 0.85283756), colorOf_2(0.8096, 0.82931894, 0.8506444), colorOf_2(0.8046917, 0.82709837, 0.8484245), colorOf_2(0.79967076, 0.8248078, 0.8461821), colorOf_2(0.794543, 0.8224512, 0.84392184), colorOf_2(0.78931445, 0.8200321, 0.84164864), colorOf_2(0.78399104, 0.81755424, 0.83936745), colorOf_2(0.77857894, 0.8150209, 0.83708346), colorOf_2(0.77308416, 0.81243527, 0.83480173), colorOf_2(0.76751107, 0.80980074, 0.8325282), colorOf_2(0.7618691, 0.8071195, 0.8302665), colorOf_2(0.75616443, 0.80439407, 0.8280214), colorOf_2(0.75040346, 0.801627, 0.8257974), colorOf_2(0.7445925, 0.7988205, 0.8235987), colorOf_2(0.7387377, 0.79597664, 0.82142925), colorOf_2(0.7328454, 0.79309744, 0.8192926), colorOf_2(0.7269218, 0.7901847, 0.8171922), colorOf_2(0.72097284, 0.78723997, 0.8151307), colorOf_2(0.715004, 0.78426486, 0.8131112), colorOf_2(0.7090208, 0.7812609, 0.81113595), colorOf_2(0.70302975, 0.77822906, 0.8092062), colorOf_2(0.69703656, 0.7751705, 0.80732334), colorOf_2(0.6910464, 0.7720863, 0.8054884), colorOf_2(0.68506444, 0.7689774, 0.80370206), colorOf_2(0.67909557, 0.7658447, 0.80196464), colorOf_2(0.6731442, 0.7626891, 0.8002763), colorOf_2(0.6672148, 0.7595113, 0.79863673), colorOf_2(0.66131127, 0.756312, 0.7970456), colorOf_2(0.65543693, 0.7530921, 0.7955027), colorOf_2(0.64959574, 0.749852, 0.79400676), colorOf_2(0.6437911, 0.7465924, 0.7925565), colorOf_2(0.6380259, 0.7433138, 0.791151), colorOf_2(0.6323027, 0.7400167, 0.7897889), colorOf_2(0.62662405, 0.7367017, 0.788469), colorOf_2(0.62099195, 0.73336935, 0.78718996), colorOf_2(0.6154085, 0.7300199, 0.78595024), colorOf_2(0.60987544, 0.726654, 0.7847484), colorOf_2(0.6043943, 0.72327185, 0.783583), colorOf_2(0.5989666, 0.71987396, 0.7824526), colorOf_2(0.59359336, 0.7164606, 0.78135586), colorOf_2(0.5882758, 0.7130321, 0.78029144), colorOf_2(0.58301485, 0.7095889, 0.77925783), colorOf_2(0.57781166, 0.70613104, 0.77825344), colorOf_2(0.5726669, 0.70265895, 0.77727705), colorOf_2(0.5675812, 0.6991728, 0.7763275), colorOf_2(0.56255513, 0.6956728, 0.7754036), colorOf_2(0.5575894, 0.6921591, 0.7745041), colorOf_2(0.5526845, 0.68863195, 0.77362794), colorOf_2(0.54784095, 0.68509144, 0.77277386), colorOf_2(0.54305935, 0.6815377, 0.77194077), colorOf_2(0.53834015, 0.6779708, 0.77112734), colorOf_2(0.5336839, 0.6743909, 0.7703325), colorOf_2(0.5290909, 0.6707981, 0.7695555), colorOf_2(0.5245615, 0.66719246, 0.76879543), colorOf_2(0.5200963, 0.6635739, 0.7680512), colorOf_2(0.5156956, 0.6599426, 0.76732194), colorOf_2(0.51135993, 0.6562985, 0.7666066), colorOf_2(0.5070897, 0.6526417, 0.7659045), colorOf_2(0.50288534, 0.64897215, 0.76521444), colorOf_2(0.49874735, 0.6452899, 0.7645358), colorOf_2(0.49467617, 0.6415948, 0.7638672), colorOf_2(0.49067226, 0.63788706, 0.76320815), colorOf_2(0.48673597, 0.6341665, 0.7625578), colorOf_2(0.48286778, 0.630433, 0.7619154), colorOf_2(0.47906816, 0.62668675, 0.76128), colorOf_2(0.47533754, 0.62292755, 0.7606509), colorOf_2(0.4716763, 0.6191554, 0.7600271), colorOf_2(0.4680849, 0.6153703, 0.7594079), colorOf_2(0.46456376, 0.6115721, 0.7587924), colorOf_2(0.46111327, 0.6077608, 0.75817984), colorOf_2(0.45773378, 0.6039363, 0.7575694), colorOf_2(0.45442563, 0.6000986, 0.75696015), colorOf_2(0.4511892, 0.5962476, 0.75635123), colorOf_2(0.44802472, 0.5923833, 0.7557418), colorOf_2(0.44493246, 0.5885056, 0.7551311), colorOf_2(0.4419127, 0.5846144, 0.7545184), colorOf_2(0.43896565, 0.5807097, 0.75390273), colorOf_2(0.4360914, 0.5767914, 0.7532834), colorOf_2(0.4332901, 0.5728594, 0.75265944), colorOf_2(0.43056178, 0.56891376, 0.7520301), colorOf_2(0.4279065, 0.5649543, 0.75139445), colorOf_2(0.42532423, 0.56098104, 0.7507517), colorOf_2(0.42281485, 0.5569939, 0.75010085), colorOf_2(0.42037824, 0.5529929, 0.74944127), colorOf_2(0.41801414, 0.54897785, 0.7487719), colorOf_2(0.41572234, 0.5449488, 0.74809206), colorOf_2(0.41350245, 0.5409058, 0.74740076), colorOf_2(0.41135415, 0.5368486, 0.7466971), colorOf_2(0.4092769, 0.5327773, 0.7459803), colorOf_2(0.4072702, 0.5286919, 0.74524945), colorOf_2(0.40533343, 0.5245923, 0.7445037), colorOf_2(0.40346602, 0.5204785, 0.74374217), colorOf_2(0.40166715, 0.51635045, 0.742964), colorOf_2(0.39993608, 0.51220816, 0.7421684), colorOf_2(0.39827192, 0.5080517, 0.7413545), colorOf_2(0.39667374, 0.5038809, 0.7405214), colorOf_2(0.3951406, 0.49969587, 0.7396682), colorOf_2(0.39367136, 0.49549657, 0.7387941), colorOf_2(0.39226496, 0.491283, 0.73789823), colorOf_2(0.39092016, 0.4870552, 0.7369798), colorOf_2(0.3896358, 0.48281318, 0.73603785), colorOf_2(0.38841054, 0.4785569, 0.7350716), colorOf_2(0.387243, 0.47428647, 0.7340802), colorOf_2(0.38613185, 0.47000185, 0.7330628), colorOf_2(0.38507557, 0.46570307, 0.73201853), colorOf_2(0.3840727, 0.4613902, 0.73094666), colorOf_2(0.38312167, 0.45706323, 0.72984624), colorOf_2(0.38222095, 0.45272225, 0.72871655), colorOf_2(0.38136888, 0.44836727, 0.7275567), colorOf_2(0.3805638, 0.44399837, 0.72636586), colorOf_2(0.37980404, 0.43961558, 0.72514325), colorOf_2(0.3790879, 0.435219, 0.723888), colorOf_2(0.37841365, 0.4308086, 0.7225993), colorOf_2(0.37777948, 0.4263845, 0.7212764), colorOf_2(0.3771837, 0.4219468, 0.71991843), colorOf_2(0.3766245, 0.41749555, 0.7185246), colorOf_2(0.3761, 0.4130308, 0.71709394), colorOf_2(0.37560847, 0.40855268, 0.7156258), colorOf_2(0.37514803, 0.40406126, 0.7141194), colorOf_2(0.37471685, 0.39955664, 0.7125737), colorOf_2(0.37431315, 0.39503896, 0.710988), colorOf_2(0.37393498, 0.39050826, 0.7093613), colorOf_2(0.37358063, 0.38596475, 0.707693), colorOf_2(0.37324816, 0.38140848, 0.705982), colorOf_2(0.37293577, 0.37683964, 0.70422757), colorOf_2(0.37264165, 0.37225834, 0.70242876), colorOf_2(0.37236398, 0.36766478, 0.70058465), colorOf_2(0.3721009, 0.3630591, 0.69869435), colorOf_2(0.3718506, 0.35844147, 0.69675696), colorOf_2(0.37161133, 0.35381213, 0.6947715), colorOf_2(0.37138125, 0.34917128, 0.69273704), colorOf_2(0.37115857, 0.3445191, 0.69065255), colorOf_2(0.37094152, 0.3398559, 0.68851703), colorOf_2(0.37072834, 0.33518195, 0.6863295), colorOf_2(0.37051737, 0.3304974, 0.6840889), colorOf_2(0.37030682, 0.32580268, 0.6817941), colorOf_2(0.37009487, 0.32109815, 0.6794441), colorOf_2(0.3698798, 0.3163841, 0.67703754), colorOf_2(0.36965987, 0.31166098, 0.6745734), colorOf_2(0.36943334, 0.30692923, 0.67205054), colorOf_2(0.36919847, 0.30218932, 0.66946757), colorOf_2(0.36895356, 0.29744175, 0.6668232), colorOf_2(0.3686968, 0.2926871, 0.66411626), colorOf_2(0.36842656, 0.28792596, 0.66134524), colorOf_2(0.36814103, 0.28315902, 0.6585089), colorOf_2(0.36783844, 0.27838698, 0.6556057), colorOf_2(0.36751708, 0.27361062, 0.65263414), colorOf_2(0.36717513, 0.26883087, 0.6495927), colorOf_2(0.36681086, 0.26404858, 0.6464799), colorOf_2(0.36642244, 0.2592648, 0.6432941), colorOf_2(0.36600855, 0.25448045, 0.6400336), colorOf_2(0.36556697, 0.24969684, 0.63669676), colorOf_2(0.3650958, 0.24491537, 0.6332817), colorOf_2(0.3645931, 0.24013747, 0.6297868), colorOf_2(0.36405694, 0.2353647, 0.62621015), colorOf_2(0.36348537, 0.23059876, 0.6225499), colorOf_2(0.36287645, 0.22584149, 0.61880416), colorOf_2(0.3622281, 0.22109489, 0.6149711), colorOf_2(0.3615383, 0.21636112, 0.6110488), colorOf_2(0.36080495, 0.21164252, 0.60703534), colorOf_2(0.3600268, 0.20694123, 0.60292846), colorOf_2(0.3592009, 0.20226038, 0.5987265), colorOf_2(0.3583249, 0.19760294, 0.5944277), colorOf_2(0.35739663, 0.19297208, 0.59003013), colorOf_2(0.3564138, 0.1883712, 0.58553207), colorOf_2(0.35537416, 0.18380393, 0.5809319), colorOf_2(0.35427535, 0.17927413, 0.5762281), colorOf_2(0.35311574, 0.1747857, 0.5714187), colorOf_2(0.35189247, 0.1703432, 0.56650287), colorOf_2(0.35060304, 0.1659513, 0.5614796), colorOf_2(0.34924513, 0.16161478, 0.5563484), colorOf_2(0.34781653, 0.15733863, 0.55110854), colorOf_2(0.3463151, 0.15312803, 0.54576), colorOf_2(0.34473902, 0.1489882, 0.54030246), colorOf_2(0.343086, 0.14492466, 0.53473705), colorOf_2(0.3413541, 0.1409428, 0.529065), colorOf_2(0.33954167, 0.13704802, 0.52328795), colorOf_2(0.33764732, 0.13324562, 0.5174081), colorOf_2(0.3356698, 0.12954074, 0.51142806), colorOf_2(0.33360806, 0.12593818, 0.50535166), colorOf_2(0.33146155, 0.122442454, 0.49918276), colorOf_2(0.32923004, 0.11905764, 0.49292594), colorOf_2(0.3269137, 0.11578735, 0.48658645), colorOf_2(0.32451308, 0.1126346, 0.48017007), colorOf_2(0.32202882, 0.10960114, 0.47368494), colorOf_2(0.31946263, 0.1066888, 0.46713728), colorOf_2(0.31681648, 0.103898615, 0.46053416), colorOf_2(0.3140928, 0.10123078, 0.45388335), colorOf_2(0.31129435, 0.09868477, 0.44719315), colorOf_2(0.30842444, 0.096259385, 0.44047195), colorOf_2(0.30548677, 0.09395277, 0.4337285), colorOf_2(0.30248538, 0.09176119, 0.42697403), colorOf_2(0.29942483, 0.08968225, 0.4202162), colorOf_2(0.29631, 0.08771325, 0.41346258), colorOf_2(0.29314592, 0.085850656, 0.40672177), colorOf_2(0.2899379, 0.08409079, 0.40000215), colorOf_2(0.28669152, 0.08242987, 0.39331183), colorOf_2(0.2834124, 0.080864154, 0.3866587), colorOf_2(0.2801064, 0.07939, 0.38005027), colorOf_2(0.27677938, 0.07800394, 0.37349382), colorOf_2(0.27343738, 0.0767028, 0.36699617), colorOf_2(0.27008638, 0.07548367, 0.36056376), colorOf_2(0.26673234, 0.07434402, 0.35420275), colorOf_2(0.2633812, 0.07328166, 0.3479189), colorOf_2(0.26003894, 0.07229478, 0.34171757), colorOf_2(0.25671193, 0.07138011, 0.3356065), colorOf_2(0.25340685, 0.07053358, 0.32959458), colorOf_2(0.25012845, 0.06975821, 0.323681), colorOf_2(0.24688226, 0.06905364, 0.31786993), colorOf_2(0.24367373, 0.06841986, 0.31216523), colorOf_2(0.24050814, 0.0678571, 0.30657056), colorOf_2(0.23739062, 0.067365885, 0.30108923), colorOf_2(0.23433055, 0.0669356, 0.2957401), colorOf_2(0.23132955, 0.06657619, 0.2905136), colorOf_2(0.22839177, 0.066289976, 0.28541073), colorOf_2(0.22552164, 0.06607817, 0.28043398), colorOf_2(0.22272706, 0.065933794, 0.27559716), colorOf_2(0.22001252, 0.06585792, 0.2709028), colorOf_2(0.21737845, 0.06585966, 0.2663421), colorOf_2(0.21482843, 0.06594039, 0.26191676), colorOf_2(0.2123741, 0.066085026, 0.25765166), colorOf_2(0.21001214, 0.06630857, 0.2535289), colorOf_2(0.20774424, 0.06661453, 0.24954644), colorOf_2(0.20558052, 0.066990465, 0.24572498), colorOf_2(0.20352007, 0.06744418, 0.24205576), colorOf_2(0.20156133, 0.06798327, 0.23852974), colorOf_2(0.19971572, 0.06859271, 0.23517095), colorOf_2(0.19794834, 0.06931406, 0.23194647), colorOf_2(0.1960826, 0.070321225, 0.22874673), colorOf_2(0.19410351, 0.071608305, 0.22558728), colorOf_2(0.19199449, 0.07318283, 0.22243385), colorOf_2(0.18975854, 0.07501986, 0.21930051), colorOf_2(0.18739228, 0.077102095, 0.21618876), colorOf_2(0.18488036, 0.07942573, 0.21307652), colorOf_2(0.18774483, 0.07725159, 0.21387449), colorOf_2(0.19049579, 0.07531128, 0.21465623), colorOf_2(0.19315486, 0.07360682, 0.21542363), colorOf_2(0.19571854, 0.07215778, 0.21617499), colorOf_2(0.19819343, 0.070974626, 0.21690975), colorOf_2(0.2005876, 0.070064574, 0.21762721), colorOf_2(0.20290366, 0.06943525, 0.21833168), colorOf_2(0.20531726, 0.06891959, 0.21911517), colorOf_2(0.20785704, 0.068484396, 0.22000134), colorOf_2(0.21052884, 0.068121955, 0.22098759), colorOf_2(0.21333139, 0.067830145, 0.22207043), colorOf_2(0.2162528, 0.06761633, 0.22324568), colorOf_2(0.21930504, 0.06746579, 0.22451024), colorOf_2(0.22247308, 0.067388214, 0.2258596), colorOf_2(0.22575396, 0.067382134, 0.22728984), colorOf_2(0.2291562, 0.06743473, 0.22879681), colorOf_2(0.232663, 0.067557104, 0.23037617), colorOf_2(0.23627496, 0.0677436, 0.23202361), colorOf_2(0.23999587, 0.06798503, 0.23373434), colorOf_2(0.2438115, 0.06828985, 0.23550427), colorOf_2(0.24772093, 0.06865334, 0.2373288), colorOf_2(0.251729, 0.06906463, 0.2392026), colorOf_2(0.25582135, 0.06953231, 0.2411219), colorOf_2(0.25999463, 0.07005385, 0.2430822), colorOf_2(0.26425514, 0.070616595, 0.2450776), colorOf_2(0.26859096, 0.071226716, 0.24710444), colorOf_2(0.27299702, 0.07188355, 0.24915847), colorOf_2(0.2774715, 0.07258297, 0.25123495), colorOf_2(0.28201747, 0.073315695, 0.253328), colorOf_2(0.2866231, 0.07408846, 0.25543478), colorOf_2(0.29128516, 0.07489905, 0.257551), colorOf_2(0.29600048, 0.07574534, 0.25967246), colorOf_2(0.30077276, 0.07661782, 0.26179293), colorOf_2(0.30559227, 0.077521965, 0.26391006), colorOf_2(0.3104552, 0.07845687, 0.26602006), colorOf_2(0.3153587, 0.079421, 0.26811904), colorOf_2(0.32029986, 0.08041299, 0.27020323), colorOf_2(0.32527888, 0.08142839, 0.27226773), colorOf_2(0.33029175, 0.08246763, 0.2743093), colorOf_2(0.33533353, 0.08353244, 0.27632535), colorOf_2(0.34040165, 0.084622234, 0.27831253), colorOf_2(0.34549356, 0.085736655, 0.2802677), colorOf_2(0.35060677, 0.08687555, 0.2821877), colorOf_2(0.3557389, 0.08803897, 0.2840696), colorOf_2(0.36088753, 0.08922719, 0.28591052), colorOf_2(0.3660503, 0.09044068, 0.28770775), colorOf_2(0.3712251, 0.09168, 0.28945866), colorOf_2(0.3764103, 0.092945196, 0.29116026), colorOf_2(0.38160247, 0.09423873, 0.29281107), colorOf_2(0.3867994, 0.09556182, 0.294409), colorOf_2(0.3919989, 0.09691583, 0.2959521), colorOf_2(0.39719877, 0.09830232, 0.29743856), colorOf_2(0.40239692, 0.09972293, 0.29886675), colorOf_2(0.4075912, 0.10117946, 0.30023518), colorOf_2(0.41277987, 0.102673404, 0.30154225), colorOf_2(0.41796106, 0.10420645, 0.30278653), colorOf_2(0.42313215, 0.10578121, 0.3039676), colorOf_2(0.42829102, 0.10739978, 0.3050848), colorOf_2(0.4334356, 0.10906424, 0.30613768), colorOf_2(0.4385638, 0.11077668, 0.30712602), colorOf_2(0.44367358, 0.11253913, 0.30804974), colorOf_2(0.44876298, 0.11435355, 0.30890906), colorOf_2(0.45383006, 0.11622184, 0.30970442), colorOf_2(0.45887288, 0.11814571, 0.31043637), colorOf_2(0.46389103, 0.120125614, 0.31110343), colorOf_2(0.4688811, 0.12216446, 0.3117091), colorOf_2(0.47384143, 0.12426354, 0.3122547), colorOf_2(0.47877035, 0.12642401, 0.31274173), colorOf_2(0.4836663, 0.12864679, 0.3131719), colorOf_2(0.48852846, 0.13093211, 0.31354553), colorOf_2(0.49335504, 0.13328092, 0.31386563), colorOf_2(0.49814436, 0.1356938, 0.3141352), colorOf_2(0.50289524, 0.13817087, 0.31435663), colorOf_2(0.5076068, 0.14071193, 0.314532), colorOf_2(0.5122784, 0.14331657, 0.31466308), colorOf_2(0.51690847, 0.14598463, 0.31475407), colorOf_2(0.52149653, 0.14871545, 0.31480768), colorOf_2(0.5260419, 0.15150818, 0.31482655), colorOf_2(0.5305442, 0.15436183, 0.314813), colorOf_2(0.53500277, 0.15727541, 0.31477085), colorOf_2(0.5394174, 0.1602477, 0.31470296), colorOf_2(0.5437877, 0.16327739, 0.31461203), colorOf_2(0.5481137, 0.16636309, 0.31450102), colorOf_2(0.5523952, 0.16950339, 0.31437293), colorOf_2(0.5566323, 0.17269677, 0.31423044), colorOf_2(0.560825, 0.1759417, 0.3140764), colorOf_2(0.5649734, 0.17923665, 0.3139136), colorOf_2(0.56907785, 0.18258004, 0.3137444), colorOf_2(0.5731385, 0.18597037, 0.31357127), colorOf_2(0.57715553, 0.18940601, 0.31339705), colorOf_2(0.5811293, 0.19288549, 0.313224), colorOf_2(0.58506024, 0.19640738, 0.31305403), colorOf_2(0.5889486, 0.19997022, 0.31288922), colorOf_2(0.5927948, 0.20357251, 0.31273234), colorOf_2(0.59659916, 0.20721295, 0.31258523), colorOf_2(0.6003621, 0.21089031, 0.31244934), colorOf_2(0.604084, 0.21460332, 0.31232652), colorOf_2(0.60776526, 0.21835071, 0.31221902), colorOf_2(0.6114062, 0.22213125, 0.3121288), colorOf_2(0.6150072, 0.22594403, 0.3120568), colorOf_2(0.61856866, 0.22978799, 0.31200463), colorOf_2(0.6220908, 0.23366219, 0.31197384), colorOf_2(0.6255742, 0.23756535, 0.311967), colorOf_2(0.6290189, 0.24149689, 0.31198448), colorOf_2(0.63242537, 0.245456, 0.31202766), colorOf_2(0.6357937, 0.24944186, 0.31209794), colorOf_2(0.63912433, 0.25345364, 0.3121969), colorOf_2(0.64241755, 0.25749052, 0.3123263), colorOf_2(0.6456735, 0.26155204, 0.31248674), colorOf_2(0.6488923, 0.26563755, 0.3126794), colorOf_2(0.65207416, 0.2697465, 0.3129056), colorOf_2(0.6552193, 0.27387828, 0.31316668), colorOf_2(0.65832806, 0.27803212, 0.31346434), colorOf_2(0.6614004, 0.2822078, 0.31379914), colorOf_2(0.66443634, 0.28640485, 0.31417224), colorOf_2(0.66743606, 0.2906228, 0.31458485), colorOf_2(0.6703996, 0.29486126, 0.31503814), colorOf_2(0.67332727, 0.29911962, 0.31553373), colorOf_2(0.676219, 0.30339763, 0.3160725), colorOf_2(0.67907476, 0.30769497, 0.31665546), colorOf_2(0.6818946, 0.31201133, 0.3172838), colorOf_2(0.6846785, 0.31634635, 0.3179587), colorOf_2(0.68742657, 0.3206997, 0.3186814), colorOf_2(0.69013894, 0.32507092, 0.31945333), colorOf_2(0.6928154, 0.32945985, 0.32027543), colorOf_2(0.6954561, 0.3338662, 0.32114884), colorOf_2(0.6980608, 0.33828977, 0.3220748), colorOf_2(0.70062965, 0.3427302, 0.3230545), colorOf_2(0.7031625, 0.34718725, 0.32408914), colorOf_2(0.7056595, 0.35166052, 0.32518014), colorOf_2(0.7081206, 0.35614985, 0.3263286), colorOf_2(0.71054566, 0.360655, 0.32753575), colorOf_2(0.7129347, 0.3651757, 0.32880273), colorOf_2(0.7152876, 0.3697117, 0.33013088), colorOf_2(0.71760446, 0.37426272, 0.3315214), colorOf_2(0.71988523, 0.3788285, 0.33297557), colorOf_2(0.72213, 0.38340864, 0.3344947), colorOf_2(0.72433865, 0.38800302, 0.33607996), colorOf_2(0.72651124, 0.39261132, 0.33773258), colorOf_2(0.7286477, 0.39723325, 0.33945385), colorOf_2(0.73074824, 0.40186852, 0.34124497), colorOf_2(0.7328127, 0.40651685, 0.34310716), colorOf_2(0.73484135, 0.41117787, 0.3450417), colorOf_2(0.7368342, 0.41585127, 0.34704977), colorOf_2(0.7387914, 0.42053673, 0.3491326), colorOf_2(0.740713, 0.42523393, 0.3512913), colorOf_2(0.7425992, 0.42994255, 0.3535271), colorOf_2(0.7444502, 0.43466216, 0.35584107), colorOf_2(0.7462662, 0.43939245, 0.3582344), colorOf_2(0.7480474, 0.44413298, 0.36070815), colorOf_2(0.7497942, 0.44888332, 0.36326337), colorOf_2(0.75150687, 0.45364314, 0.3659011), colorOf_2(0.7531857, 0.458412, 0.36862236), colorOf_2(0.7548311, 0.46318942, 0.37142804), colorOf_2(0.75644344, 0.46797502, 0.37431908), colorOf_2(0.75802326, 0.47276828, 0.37729636), colorOf_2(0.75957114, 0.47756872, 0.38036066), colorOf_2(0.76108766, 0.4823758, 0.38351277), colorOf_2(0.76257336, 0.48718905, 0.38675335), colorOf_2(0.76402885, 0.49200803, 0.39008307), colorOf_2(0.76545495, 0.49683213, 0.39350253), colorOf_2(0.7668523, 0.5016608, 0.3970122), colorOf_2(0.7682218, 0.5064936, 0.40061256), colorOf_2(0.7695642, 0.5113299, 0.40430397), colorOf_2(0.77088094, 0.51616895, 0.4080867), colorOf_2(0.7721726, 0.5210103, 0.4119609), colorOf_2(0.77344024, 0.52585334, 0.41592678), colorOf_2(0.77468497, 0.53069746, 0.4199844), colorOf_2(0.77590793, 0.5355422, 0.4241337), colorOf_2(0.77711034, 0.54038674, 0.4283745), colorOf_2(0.77829343, 0.54523057, 0.43270665), colorOf_2(0.77945864, 0.5500731, 0.4371298), colorOf_2(0.78060776, 0.55491334, 0.44164333), colorOf_2(0.7817418, 0.559751, 0.44624686), colorOf_2(0.78286225, 0.5645853, 0.45093986), colorOf_2(0.7839706, 0.5694158, 0.45572156), colorOf_2(0.78506845, 0.5742417, 0.46059117), colorOf_2(0.78615737, 0.57906246, 0.46554777), colorOf_2(0.787239, 0.58387744, 0.47059038), colorOf_2(0.7883151, 0.588686, 0.47571793), colorOf_2(0.7893874, 0.59348756, 0.48092914), colorOf_2(0.7904578, 0.5982813, 0.48622257), colorOf_2(0.79152834, 0.6030667, 0.49159667), colorOf_2(0.79260033, 0.6078432, 0.4970502), colorOf_2(0.7936756, 0.6126103, 0.5025816), colorOf_2(0.7947559, 0.6173673, 0.5081892), colorOf_2(0.79584295, 0.62211376, 0.51387125), colorOf_2(0.79693854, 0.62684906, 0.51962584), colorOf_2(0.7980445, 0.6315726, 0.52545106), colorOf_2(0.79916245, 0.6362838, 0.53134495), colorOf_2(0.80029416, 0.64098215, 0.53730536), colorOf_2(0.80144125, 0.645667, 0.5433301), colorOf_2(0.80260533, 0.65033793, 0.5494169), colorOf_2(0.80378795, 0.65499425, 0.5555635), colorOf_2(0.80499053, 0.6596354, 0.56176746), colorOf_2(0.80621463, 0.6642609, 0.5680263), colorOf_2(0.8074614, 0.66887003, 0.5743375), colorOf_2(0.8087322, 0.67346215, 0.5806984), colorOf_2(0.8100281, 0.67803675, 0.5871063), colorOf_2(0.81135017, 0.682593, 0.5935585), colorOf_2(0.8126992, 0.68713033, 0.6000522), colorOf_2(0.8140761, 0.69164795, 0.60658437), colorOf_2(0.8154815, 0.69614506, 0.6131522), colorOf_2(0.81691575, 0.70062083, 0.6197526), colorOf_2(0.8183793, 0.70507437, 0.62638247), colorOf_2(0.8198723, 0.7095047, 0.6330386), colorOf_2(0.82139474, 0.71391094, 0.63971764), colorOf_2(0.82294637, 0.71829176, 0.6464164), colorOf_2(0.8245268, 0.7226461, 0.65313137), colorOf_2(0.8261355, 0.72697276, 0.659859), colorOf_2(0.8277716, 0.73127025, 0.6665957), colorOf_2(0.8294341, 0.7355371, 0.6733377), colorOf_2(0.8311216, 0.73977184, 0.68008125), colorOf_2(0.83283275, 0.7439727, 0.68682235), colorOf_2(0.8345657, 0.74813795, 0.69355696), colorOf_2(0.83631897, 0.7522655, 0.70028), colorOf_2(0.83809125, 0.75635314, 0.7069856), colorOf_2(0.8398784, 0.76039904, 0.7136715), colorOf_2(0.8416775, 0.764401, 0.720333), colorOf_2(0.8434853, 0.7683566, 0.72696537), colorOf_2(0.8452981, 0.7722634, 0.73356366), colorOf_2(0.84711194, 0.7761188, 0.74012274), colorOf_2(0.84892243, 0.7799202, 0.74663717), colorOf_2(0.85072696, 0.7836646, 0.7530975), colorOf_2(0.8525191, 0.78734934, 0.75949943), colorOf_2(0.8542922, 0.790972, 0.765838), colorOf_2(0.85604024, 0.7945296, 0.7721061), colorOf_2(0.8577566, 0.79801965, 0.7782957), colorOf_2(0.85943466, 0.8014392, 0.7843979), colorOf_2(0.86107117, 0.8047852, 0.7903953), colorOf_2(0.862656, 0.8080552, 0.79628265), colorOf_2(0.8641834, 0.81124645, 0.8020461), colorOf_2(0.86564934, 0.81435543, 0.8076697), colorOf_2(0.86705315, 0.81737804, 0.8131342), colorOf_2(0.86839956, 0.82030874, 0.8184164), colorOf_2(0.8696913, 0.8231416, 0.82350475), colorOf_2(0.8709385, 0.8258686, 0.828385), colorOf_2(0.87215334, 0.82848054, 0.83304864), colorOf_2(0.8733517, 0.8309671, 0.83748853), colorOf_2(0.87453794, 0.8333197, 0.84171927), colorOf_2(0.8757146, 0.8355302, 0.8457554), colorOf_2(0.8768785, 0.83759236, 0.8496137), colorOf_2(0.87802297, 0.8395017, 0.8533065), colorOf_2(0.87913245, 0.84125555, 0.85685575), colorOf_2(0.88019294, 0.84285223, 0.860274), colorOf_2(0.8811917, 0.8442907, 0.863566), colorOf_2(0.8821154, 0.8455701, 0.86673766), colorOf_2(0.8829517, 0.8466897, 0.86979616), colorOf_2(0.88369125, 0.8476489, 0.87274146), colorOf_2(0.8843271, 0.84844744, 0.87556785), colorOf_2(0.8848514, 0.84908426, 0.87828237), colorOf_2(0.885259, 0.84955895, 0.8808842), colorOf_2(0.88554716, 0.84987175, 0.88336205), colorOf_2(0.88571155, 0.85002184, 0.8857254)])));
    this.p28_1.x2(arrayListOf([this.m26_1, this.n26_1, this.o26_1, this.p26_1, this.j26_1, this.k26_1, this.l26_1, this.i28_1, this.k28_1, this.m28_1, this.l28_1, this.j28_1, this.n28_1, this.o28_1, this.q26_1, this.r26_1, this.s26_1, this.t26_1, this.u26_1, this.v26_1, this.w26_1, this.x26_1, this.y26_1, this.z26_1, this.a27_1, this.b27_1, this.c27_1, this.d27_1, this.e27_1, this.f27_1, this.g27_1, this.h27_1, this.i27_1, this.j27_1, this.k27_1, this.l27_1, this.m27_1, this.n27_1, this.o27_1, this.p27_1, this.q27_1, this.r27_1, this.s27_1, this.t27_1, this.u27_1, this.v27_1, this.w27_1, this.x27_1, this.y27_1, this.z27_1, this.a28_1, this.b28_1, this.c28_1, this.d28_1, this.e28_1, this.f28_1, this.g28_1, this.h28_1]));
  }
  getEntries() {
    return this.p28_1;
  }
  getPalette(name) {
    return ensureNotNull(this.get(name)).getPalette();
  }
  add(entry) {
    this.p28_1.o(entry);
  }
  get(name) {
    var _iterator__ex2g4s = this.p28_1.x();
    while (_iterator__ex2g4s.y()) {
      var entry = _iterator__ex2g4s.z();
      if (entry.name === name) {
        return entry;
      }
    }
    return null;
  }
  find(palette) {
    var _iterator__ex2g4s = this.p28_1.x();
    while (_iterator__ex2g4s.y()) {
      var entry = _iterator__ex2g4s.z();
      if (equals(entry.getPalette(), palette)) {
        return entry;
      }
    }
    return null;
  }
  createDefaultDivergingPalette() {
    return this.m27_1.getPalette();
  }
  createDefaultSequentialPalette() {
    return this.o27_1.getPalette();
  }
  createDefaultQualititativePalette() {
    return this.n27_1.getPalette();
  }
  createColorGradient(name) {
    var _iterator__ex2g4s = this.p28_1.x();
    while (_iterator__ex2g4s.y()) {
      var entry = _iterator__ex2g4s.z();
      if (entry.name === name) {
        return entry.getPalette();
      }
    }
    return null;
  }
}
class PaletteType extends Enum {}
class ScreenTransformRubberBand {
  constructor(screenTransform) {
    this.q28_1 = SimpleSingleSelection.x14(null);
    this.r28_1 = screenTransform;
  }
  s28() {
    return this.q28_1;
  }
  t28(x, y) {
    var xWorld = this.r28_1.w1l().o15(x);
    var yWorld = this.r28_1.x1l().o15(y);
    this.q28_1.u13(Double_3.p1m(xWorld, yWorld, 0.0, 0.0));
  }
  u28(x, y) {
    if (this.q28_1.a13()) {
      var xWorld = this.r28_1.w1l().o15(x);
      var yWorld = this.r28_1.x1l().o15(y);
      var r = ensureNotNull(this.q28_1.v13());
      this.q28_1.u13(Double_3.p1m(r.w1l(), r.x1l(), xWorld - r.w1l(), yWorld - r.x1l()));
    }
  }
  v28() {
    this.q28_1.e13();
  }
  w28() {
    var tmp;
    if (this.q28_1.a13()) {
      tmp = this.x28(ensureNotNull(this.q28_1.v13())).s1m();
    } else {
      tmp = null;
    }
    return tmp;
  }
  x28(r) {
    var x1 = numberToInt(round(this.r28_1.w1l().q15(r.f1m())));
    var x2 = numberToInt(round(this.r28_1.w1l().q15(r.i1m())));
    var y1 = numberToInt(round(this.r28_1.x1l().q15(r.h1m())));
    var y2 = numberToInt(round(this.r28_1.x1l().q15(r.j1m())));
    var width = x2 - x1 | 0;
    var height = y2 - y1 | 0;
    return Rectangle.from(x1, y1, width, height);
  }
}
class AbstractTwoDScreenTransform {
  static a29() {
    return createThis(this);
  }
}
class AbstractMutableTwoDScreenTransform extends AbstractTwoDScreenTransform {
  static z28() {
    var $this = this.a29();
    $this.y28_1 = CollectionFactory_instance.ll();
    return $this;
  }
  b29(listener) {
    this.y28_1.o(listener);
  }
  j15(event) {
    var _iterator__ex2g4s = this.y28_1.x();
    while (_iterator__ex2g4s.y()) {
      var listener = _iterator__ex2g4s.z();
      listener.k15(event);
    }
  }
}
class SimpleTwoDScreenTransform$intervalListener$1 {
  constructor(this$0) {
    this.n29_1 = this$0;
  }
  fn(event) {
    this.n29_1.j15(new ScreenTransformEvent());
  }
}
class SimpleTwoDScreenTransform extends AbstractMutableTwoDScreenTransform {
  w1l() {
    return this.i29_1;
  }
  x1l() {
    return this.j29_1;
  }
  static o29(x, y, screenWidth, screenHeight, worldAspectRatio) {
    var $this = this.z28();
    init_org_mkui_transform_SimpleTwoDScreenTransform($this);
    $this.g29_1 = x.r15();
    $this.h29_1 = y.r15();
    $this.i29_1 = x;
    $this.j29_1 = y;
    $this.e29_1 = screenWidth;
    $this.f29_1 = screenHeight;
    $this.l29_1 = worldAspectRatio;
    $this.g29_1.addIntervalListener($this.m29_1);
    $this.h29_1.addIntervalListener($this.m29_1);
    return $this;
  }
  c29(screenWidth, screenHeight) {
    if (!(this.e29_1 === screenWidth) || !(this.f29_1 === screenHeight)) {
      this.e29_1 = screenWidth;
      this.f29_1 = screenHeight;
      updateAspectRatio(this);
      this.i29_1.l15(screenWidth);
      this.j29_1.l15(screenHeight);
      this.j15(new ScreenTransformEvent());
    }
  }
  toString() {
    return 'SimpleTwoDScreenTransform{screenWidth=' + this.e29_1 + ', screenHeight=' + this.f29_1 + ', xInterval=' + this.g29_1 + ', yInterval=' + this.h29_1 + toString(_Char___init__impl__6a9atx(125));
  }
}
class CPCanvas {
  constructor() {
    this.p29_1 = CollectionFactory_instance.ll();
    this.q29_1 = CollectionFactory_instance.r16();
    this.r29_1 = ArrayList.e1();
    this.s29_1 = new SimpleProperty(false);
    this.t29_1 = new FunctionalCPCanvas(this.p29_1, this.r29_1, this.s29_1);
    this.u29_1 = this.t29_1.l2a_1;
  }
  n2a() {
    return this.u29_1;
  }
  o2a(d) {
    this.p29_1.o(d);
  }
  p2a() {
    return this.t29_1.g2a_1;
  }
  q2a() {
    return this.t29_1.h2a_1;
  }
  r2a(l) {
    this.r29_1.o(l);
  }
  s2a() {
    this.t29_1.s2a();
  }
  t2a(l) {
    this.t29_1.t2a(l);
  }
  u2a(l) {
    this.t29_1.u2a(l);
  }
  v2a(l) {
    this.t29_1.v2a(l);
  }
  w2a(l) {
    this.t29_1.w2a(l);
  }
  x2a(l) {
    this.t29_1.x2a(l);
  }
}
class FunctionalCPCanvas$timer$1 {
  constructor(this$0) {
    this.g2b_1 = this$0;
  }
  y17() {
    prepare(this.g2b_1);
  }
}
class FunctionalCPCanvas {
  constructor(layers, listeners, showTiming) {
    this.v29_1 = layers;
    this.w29_1 = listeners;
    this.x29_1 = showTiming;
    this.y29_1 = HashSet.x9();
    var tmp = this;
    var tmp_0 = Companion_getInstance_28().h17_1;
    tmp.z29_1 = tmp_0.m17('Canvas$Prepare', 40, true, new FunctionalCPCanvas$timer$1(this));
    this.a2a_1 = new Timing();
    this.b2a_1 = new Timing();
    this.c2a_1 = new Timing();
    this.d2a_1 = true;
    this.f2a_1 = new InteractiveComponentListeners();
    this.g2a_1 = 0;
    this.h2a_1 = 0;
    this.i2a_1 = 1.0;
    this.j2a_1 = 0;
    this.k2a_1 = 0;
    var tmp_1 = this;
    tmp_1.l2a_1 = FC(FunctionalCPCanvas$nativeComponent$lambda(this));
    this.m2a_1 = null;
  }
  e2b() {
    this.z2a();
    var _iterator__ex2g4s = this.v29_1.x();
    while (_iterator__ex2g4s.y()) {
      var layer = _iterator__ex2g4s.z();
      this.y29_1.o(layer);
    }
    if (this.d2a_1) {
      this.z29_1.g15();
    }
  }
  z2a() {
    this.s2a();
  }
  s2a() {
    requestAnimationFrame(FunctionalCPCanvas$redraw$lambda(this));
  }
  f2b(width, height, scaleFactor) {
    return width > 0 && height > 0 && !(this.g2a_1 === width) || !(this.h2a_1 === height) || !(this.i2a_1 === scaleFactor);
  }
  c2b(canvasRef, width, height, scaleFactor) {
    println('syncCanvasDimension  ' + this.g2a_1 + ' x ' + this.h2a_1 + ' - ' + width + ' x ' + height);
    this.g2a_1 = width;
    this.h2a_1 = height;
    this.i2a_1 = scaleFactor;
    this.j2a_1 = numberToInt(width * scaleFactor);
    this.k2a_1 = numberToInt(height * scaleFactor);
    var canvas = canvasRef.current;
    if (!(canvas == null)) {
      println('Resizing ' + width + 'x' + height + '@' + scaleFactor + ' -> ' + this.j2a_1 + 'x' + this.k2a_1);
      canvas.width = this.j2a_1;
      canvas.height = this.k2a_1;
    }
  }
  a2b(g) {
    g.setTransform(this.i2a_1, 0.0, 0.0, this.i2a_1, 0.0, 0.0);
    g.clearRect(0.0, 0.0, this.g2a_1, this.h2a_1);
  }
  n2a() {
    return this.l2a_1;
  }
  d2b(width, height) {
    var _iterator__ex2g4s = this.w29_1.x();
    while (_iterator__ex2g4s.y()) {
      var listener = _iterator__ex2g4s.z();
      listener.h2b(width, height);
    }
  }
  t2a(l) {
    this.f2a_1.l1l_1.o(l);
  }
  u2a(l) {
    this.f2a_1.m1l_1.o(l);
  }
  v2a(l) {
    this.f2a_1.n1l_1.o(l);
  }
  w2a(l) {
    this.f2a_1.o1l_1.o(l);
  }
  x2a(l) {
    this.f2a_1.p1l_1.o(l);
  }
}
class JSMouseEvent {
  constructor(event, clickCount) {
    this.i2b_1 = event;
    this.j2b_1 = clickCount;
  }
  k2b() {
    return this.j2b_1;
  }
  w1l() {
    return numberToInt(this.i2b_1.offsetX);
  }
  x1l() {
    return numberToInt(this.i2b_1.offsetY);
  }
  l2b() {
    return this.i2b_1.ctrlKey || this.i2b_1.metaKey;
  }
  m2b() {
    return this.i2b_1.ctrlKey || this.i2b_1.metaKey;
  }
  n2b() {
    return this.i2b_1.altKey;
  }
  o2b() {
    return this.i2b_1.shiftKey;
  }
  p2b() {
    return false;
  }
  q2b() {
    var tmp = this.i2b_1.button;
    // Inline function 'web.uievents.MouseButton.Companion.MAIN' call
    return equals(tmp, 0);
  }
  r2b() {
    var tmp = this.i2b_1.button;
    // Inline function 'web.uievents.MouseButton.Companion.AUXILIARY' call
    return equals(tmp, 1);
  }
}
class Companion_54 {
  constructor() {
    Companion_instance_54 = this;
    this.a1g_1 = new MkColorFactory();
  }
}
class MkColorFactory {
  constructor() {
    Companion_getInstance_54();
    var tmp = this;
    tmp.i1g_1 = lazy(MkColorFactory$white$delegate$lambda);
    var tmp_0 = this;
    tmp_0.j1g_1 = lazy(MkColorFactory$lightGray$delegate$lambda);
    var tmp_1 = this;
    tmp_1.k1g_1 = lazy(MkColorFactory$gray$delegate$lambda);
    var tmp_2 = this;
    tmp_2.l1g_1 = lazy(MkColorFactory$darkGray$delegate$lambda);
    var tmp_3 = this;
    tmp_3.m1g_1 = lazy(MkColorFactory$black$delegate$lambda);
  }
  n1g() {
    var tmp0 = this.i1g_1;
    // Inline function 'kotlin.getValue' call
    white$factory();
    return tmp0.r2();
  }
  d2c() {
    var tmp0 = this.j1g_1;
    // Inline function 'kotlin.getValue' call
    lightGray$factory();
    return tmp0.r2();
  }
  a1j() {
    var tmp0 = this.k1g_1;
    // Inline function 'kotlin.getValue' call
    gray$factory();
    return tmp0.r2();
  }
  e2c() {
    var tmp0 = this.l1g_1;
    // Inline function 'kotlin.getValue' call
    darkGray$factory();
    return tmp0.r2();
  }
  f2c() {
    var tmp0 = this.m1g_1;
    // Inline function 'kotlin.getValue' call
    black$factory();
    return tmp0.r2();
  }
}
class CPColor {
  static y2b(r, g, b, a) {
    var $this = createThis(this);
    $this.s2b_1 = r;
    $this.t2b_1 = g;
    $this.u2b_1 = b;
    $this.v2b_1 = a;
    $this.w2b_1 = $this.m1e();
    return $this;
  }
  static c2c(r, g, b) {
    return this.y2b(r, g, b, _UByte___init__impl__g9hnc4(-1));
  }
  static z2b(r, g, b) {
    // Inline function 'kotlin.toUByte' call
    var tmp = _UByte___init__impl__g9hnc4(toByte(r));
    // Inline function 'kotlin.toUByte' call
    var tmp_0 = _UByte___init__impl__g9hnc4(toByte(g));
    // Inline function 'kotlin.toUByte' call
    var tmp$ret$2 = _UByte___init__impl__g9hnc4(toByte(b));
    return this.y2b(tmp, tmp_0, tmp$ret$2, _UByte___init__impl__g9hnc4(-1));
  }
  static x2b(r, g, b, a) {
    // Inline function 'kotlin.toUByte' call
    var tmp = _UByte___init__impl__g9hnc4(toByte(r));
    // Inline function 'kotlin.toUByte' call
    var tmp_0 = _UByte___init__impl__g9hnc4(toByte(g));
    // Inline function 'kotlin.toUByte' call
    var tmp_1 = _UByte___init__impl__g9hnc4(toByte(b));
    // Inline function 'kotlin.toUByte' call
    var tmp$ret$3 = _UByte___init__impl__g9hnc4(toByte(a));
    return this.y2b(tmp, tmp_0, tmp_1, tmp$ret$3);
  }
  static a2c(r, g, b) {
    return this.x2b(numberToInt(r * 255 + 0.5), numberToInt(g * 255 + 0.5), numberToInt(b * 255 + 0.5), 255);
  }
  static b2c(rgba) {
    return this.x2b(rgba >> 16 & 255, rgba >> 8 & 255, rgba >> 0 & 255, rgba >> 24 & 255);
  }
  h1e() {
    return this.s2b_1;
  }
  i1e() {
    return this.t2b_1;
  }
  j1e() {
    return this.u2b_1;
  }
  k1e() {
    return this.v2b_1;
  }
}
class ElementalKeyEvent {
  constructor(keyCode) {
    this.g2c_1 = keyCode;
  }
  h2c() {
    return this.g2c_1;
  }
}
class CPInteractiveHandler$registerMouseWheelListener$1$1 {
  constructor($it) {
    this.z2c_1 = $it;
  }
  w1l() {
    return numberToInt(this.z2c_1.x);
  }
  x1l() {
    return numberToInt(this.z2c_1.y);
  }
  a2d() {
    return this.z2c_1.deltaY;
  }
}
class CPInteractiveHandler$registerContextMenuListener$1$1 {
  constructor($it) {
    this.d2d_1 = $it;
  }
  w1l() {
    return this.d2d_1.clientX;
  }
  x1l() {
    return this.d2d_1.clientY;
  }
}
class CPInteractiveHandler {
  constructor(canvas, listeners, interactTiming) {
    listeners = listeners === VOID ? new InteractiveComponentListeners() : listeners;
    interactTiming = interactTiming === VOID ? null : interactTiming;
    this.i2c_1 = canvas;
    this.j2c_1 = listeners;
    this.k2c_1 = interactTiming;
    this.l2c_1 = false;
    this.m2c_1 = false;
    this.n2c_1 = false;
    this.o2c_1 = null;
    var tmp = this;
    tmp.p2c_1 = CPInteractiveHandler$onmousedrag$lambda(this);
    this.f2d();
    this.g2d();
    this.h2d();
    this.i2d();
    this.j2d();
  }
  f2d() {
    if (!(this.i2c_1 == null)) {
      // Inline function 'web.uievents.MouseEvent.Companion.MOUSE_UP' call
      var tmp = 'mouseup';
      addEventHandler(this.i2c_1, tmp, CPInteractiveHandler$registerMouseListener$lambda(this));
      // Inline function 'web.uievents.MouseEvent.Companion.MOUSE_DOWN' call
      var tmp_0 = 'mousedown';
      addEventHandler(this.i2c_1, tmp_0, CPInteractiveHandler$registerMouseListener$lambda_0(this));
      // Inline function 'web.uievents.MouseEvent.Companion.MOUSE_OVER' call
      var tmp_1 = 'mouseover';
      addEventHandler(this.i2c_1, tmp_1, CPInteractiveHandler$registerMouseListener$lambda_1(this));
    }
    // Inline function 'web.uievents.MouseEvent.Companion.MOUSE_OUT' call
    var tmp_2 = 'mouseout';
    addEventHandler(this.i2c_1, tmp_2, CPInteractiveHandler$registerMouseListener$lambda_2(this));
    // Inline function 'web.uievents.MouseEvent.Companion.DBL_CLICK' call
    var tmp_3 = 'dblclick';
    addEventHandler(this.i2c_1, tmp_3, CPInteractiveHandler$registerMouseListener$lambda_3(this));
  }
  g2d() {
    if (!(this.i2c_1 == null)) {
      var tmp = this;
      tmp.o2c_1 = CPInteractiveHandler$registerMouseMotionListener$lambda(this);
      // Inline function 'web.uievents.MouseEvent.Companion.MOUSE_MOVE' call
      var tmp$ret$0 = 'mousemove';
      addEventHandler(this.i2c_1, tmp$ret$0, ensureNotNull(this.o2c_1));
    }
  }
  h2d() {
    if (!(this.i2c_1 == null)) {
      // Inline function 'web.uievents.WheelEvent.Companion.WHEEL' call
      var tmp = 'wheel';
      addEventHandler(this.i2c_1, tmp, CPInteractiveHandler$registerMouseWheelListener$lambda(this));
    }
  }
  u2c() {
    this.n2c_1 = true;
    if (!(this.i2c_1 == null)) {
      // Inline function 'web.uievents.MouseEvent.Companion.MOUSE_MOVE' call
      var tmp$ret$0 = 'mousemove';
      removeEventListener(this.i2c_1, tmp$ret$0, ensureNotNull(this.o2c_1));
      // Inline function 'web.uievents.MouseEvent.Companion.MOUSE_MOVE' call
      var tmp$ret$1 = 'mousemove';
      addEventHandler(this.i2c_1, tmp$ret$1, this.p2c_1);
    }
  }
  s2c() {
    if (this.n2c_1) {
      this.n2c_1 = false;
      // Inline function 'web.uievents.MouseEvent.Companion.MOUSE_MOVE' call
      var tmp$ret$0 = 'mousemove';
      removeEventListener(this.i2c_1, tmp$ret$0, ensureNotNull(this.p2c_1));
      // Inline function 'web.uievents.MouseEvent.Companion.MOUSE_MOVE' call
      var tmp$ret$1 = 'mousemove';
      addEventHandler(this.i2c_1, tmp$ret$1, ensureNotNull(this.o2c_1));
    }
  }
  i2d() {
    this.l2c_1 = true;
    // Inline function 'web.uievents.KeyboardEvent.Companion.KEY_DOWN' call
    var tmp = 'keydown';
    addEventHandler(this.i2c_1, tmp, CPInteractiveHandler$registerKeyListener$lambda(this));
  }
  j2d() {
    // Inline function 'web.uievents.MouseEvent.Companion.CONTEXT_MENU' call
    var tmp = 'contextmenu';
    addEventHandler(this.i2c_1, tmp, CPInteractiveHandler$registerContextMenuListener$lambda(this));
  }
}
class CPPopupMenu {
  constructor() {
    var tmp = this;
    var reason = 'Not yet implemented';
    throw NotImplementedError.bk('An operation is not implemented: ' + reason);
  }
  l2d(command) {
  }
  m2d(component, x, y) {
  }
  n2a() {
    return this.k2d_1;
  }
}
class Companion_55 {
  constructor() {
    Companion_instance_55 = this;
    this.a24_1 = new CPFontFactory();
  }
}
class CPFontFactory {
  constructor() {
    Companion_getInstance_55();
  }
  n2d(family) {
    return new CPFont(ensureNotNull(family), 12.0);
  }
  b24() {
    return ensureNotNull(this.n2d('Arial'));
  }
}
class CPFont {
  constructor(family, size, weight, posture) {
    weight = weight === VOID ? Weight_NORMAL_getInstance() : weight;
    posture = posture === VOID ? Posture_REGULAR_getInstance() : posture;
    this.o2d_1 = family;
    this.p2d_1 = size;
    this.q2d_1 = weight;
    this.r2d_1 = posture;
    var tmp = this;
    tmp.s2d_1 = lazy(CPFont$name$delegate$lambda(this));
  }
  t2d() {
    return this.p2d_1;
  }
  u2d(fontSize) {
    return new CPFont(this.o2d_1, fontSize, this.q2d_1, this.r2d_1);
  }
  v2d() {
    return this.p2d_1;
  }
  w2d(weight) {
    return new CPFont(this.o2d_1, this.p2d_1, weight, this.r2d_1);
  }
  toString() {
    return _get_name__das4rk(this);
  }
}
class CPImage {
  constructor(width, height) {
    this.x2d_1 = width;
    this.y2d_1 = height;
    this.z2d_1 = new Image(this.x2d_1, this.y2d_1);
    this.a2e_1 = CPImageFactory_getInstance().d2e_1;
    this.b2e_1 = CPImageFactory_getInstance().e2e_1;
    this.c2e_1 = ensureNotNull(this.b2e_1).createImageData(this.x2d_1, this.y2d_1);
  }
  f2e() {
    return _get__nativeImage__47l87u(this);
  }
  g2e(x, y, w, h, iArray) {
    var data = ensureNotNull(this.c2e_1).data;
    var inductionVariable = 0;
    var last = ensureNotNull(iArray).length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        data[i] = toShort(iArray[i]);
      }
       while (inductionVariable <= last);
    ensureNotNull(this.a2e_1).width = _get__nativeImage__47l87u(this).width;
    ensureNotNull(this.a2e_1).height = _get__nativeImage__47l87u(this).height;
    ensureNotNull(this.b2e_1).putImageData(ensureNotNull(this.c2e_1), 0, 0);
    _get__nativeImage__47l87u(this).src = ensureNotNull(this.a2e_1).toDataURL('image/png');
  }
  h2e() {
    return true;
  }
  i2e() {
    return _get__nativeImage__47l87u(this).complete;
  }
  ac() {
    this.a2e_1 = null;
    this.b2e_1 = null;
    this.z2d_1 = null;
    this.c2e_1 = null;
  }
}
class CPImageFactory {
  constructor() {
    CPImageFactory_instance = this;
    var tmp = this;
    var tmp_0 = document.createElement('canvas');
    tmp.d2e_1 = tmp_0 instanceof HTMLCanvasElement ? tmp_0 : THROW_CCE();
    var tmp_1 = this;
    // Inline function 'web.canvas.CanvasRenderingContext2D.Companion.ID' call
    var tmp_2 = this.d2e_1.getContext('2d');
    tmp_1.e2e_1 = tmp_2 instanceof CanvasRenderingContext2D ? tmp_2 : THROW_CCE();
  }
}
class AbstractAggregation {
  a3() {
    return toString_1(this);
  }
}
class SumAggregation extends AbstractAggregation {
  constructor(column, filter) {
    filter = filter === VOID ? null : filter;
    super();
    this.k2e_1 = column;
    this.l2e_1 = filter;
  }
  h26() {
    var tmp = PrimitiveClasses_getInstance().le();
    return isInterface(tmp, KClass) ? tmp : THROW_CCE();
  }
  j2e(cuboid, group) {
    var distributiveStatistics = ensureNotNull(cuboid).m2e(group, this.k2e_1, this.l2e_1);
    return distributiveStatistics == null ? null : distributiveStatistics.p2e_1;
  }
  toString() {
    return 'Sum(' + toString_0(this.k2e_1.a3()) + ')';
  }
}
class Companion_56 {
  t2e(path) {
    return new ArrayGroup(path.slice());
  }
}
class Group {}
class ArrayGroup {
  constructor(path) {
    this.u2e_1 = path;
  }
  v2e() {
    return this.u2e_1;
  }
  w2e(i) {
    return ensureNotNull(ensureNotNull(this.v2e())[i]);
  }
  equals(o) {
    if (this === o)
      return true;
    if (!(!(o == null) ? isInterface(o, Group) : false))
      return false;
    var path1 = isInterface(o, Group) ? o : THROW_CCE();
    return contentEquals(this.v2e(), ensureNotNull(path1).v2e());
  }
  hashCode() {
    return contentHashCode(this.v2e());
  }
  toString() {
    return 'ArrayGroup{path=' + contentToString(this.v2e()) + toString(_Char___init__impl__6a9atx(125));
  }
}
class Companion_57 {
  x2e(path) {
    return get_2(this, path.slice());
  }
}
class Dice {
  constructor(path) {
    this.y2e_1 = path;
  }
  equals(o) {
    if (this === o)
      return true;
    if (!(o instanceof Dice))
      return false;
    return contentEquals(this.y2e_1, o.y2e_1);
  }
  hashCode() {
    return contentHashCode(this.y2e_1);
  }
  toString() {
    return 'Dice{path=' + contentToString(this.y2e_1) + toString(_Char___init__impl__6a9atx(125));
  }
}
class Companion_58 {
  z2e(path) {
    return get_3(this, path.slice());
  }
}
class Dimensions {
  constructor(path) {
    this.a2f_1 = path;
    this.b2f_1 = HashMap.d8();
    var inductionVariable = 0;
    var last = path.length;
    if (inductionVariable < last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var column = path[i];
        // Inline function 'kotlin.collections.set' call
        ensureNotNull(this.b2f_1).i7(column, i);
      }
       while (inductionVariable < last);
  }
  equals(o) {
    if (this === o)
      return true;
    if (!(o instanceof Dimensions))
      return false;
    var path1 = o instanceof Dimensions ? o : THROW_CCE();
    return contentEquals(this.a2f_1, ensureNotNull(path1).a2f_1);
  }
  hashCode() {
    return contentHashCode(this.a2f_1);
  }
  c2f(column) {
    return ensureNotNull(this.b2f_1).u2(column);
  }
}
class DistributiveStatistics {
  static d2f() {
    var $this = createThis(this);
    $this.n2e_1 = new Long(0, 0);
    $this.o2e_1 = new Long(0, 0);
    $this.p2e_1 = null;
    $this.q2e_1 = null;
    $this.r2e_1 = null;
    $this.s2e_1 = null;
    return $this;
  }
  static e2f(series, keys, filter) {
    var $this = this.d2f();
    var _iterator__ex2g4s = ensureNotNull(keys).x();
    while (_iterator__ex2g4s.y()) {
      var row = _iterator__ex2g4s.z();
      if (filter == null || filter.i2f(row)) {
        var value = series.u2(row);
        if (!(value == null)) {
          if (isNumber(value)) {
            $this.h2f(value);
          } else {
            if (value instanceof Quantity) {
              $this.h2f(value.g2f_1);
            }
          }
        } else {
          $this.f2f();
        }
      }
    }
    return $this;
  }
  h2f(value) {
    var count = this.n2e_1;
    var countOfMissing = this.o2e_1;
    var sum = this.p2e_1;
    var uncorrectedSumOfSquares = this.q2e_1;
    var minimum = this.r2e_1;
    var maximum = this.s2e_1;
    var v = numberToDouble(value);
    if (!(sum == null)) {
      sum = sum + v;
    } else {
      sum = v;
    }
    if (!(uncorrectedSumOfSquares == null)) {
      uncorrectedSumOfSquares = uncorrectedSumOfSquares + v * v;
    } else {
      uncorrectedSumOfSquares = v * v;
    }
    if (minimum == null || v < numberToDouble(minimum)) {
      minimum = value;
    }
    if (maximum == null || v > numberToDouble(maximum)) {
      maximum = value;
    }
    count = count.m3();
    this.n2e_1 = count;
    this.o2e_1 = countOfMissing;
    this.p2e_1 = sum;
    this.q2e_1 = uncorrectedSumOfSquares;
    this.r2e_1 = minimum;
    this.s2e_1 = maximum;
  }
  f2f() {
    this.o2e_1 = this.o2e_1.m3();
  }
  j2f(distributiveStatistics) {
    var sum = this.p2e_1;
    var uncorrectedSumOfSquares = this.q2e_1;
    var minimum = this.r2e_1;
    var maximum = this.s2e_1;
    this.n2e_1 = this.n2e_1.h3(distributiveStatistics.n2e_1);
    this.o2e_1 = this.o2e_1.h3(distributiveStatistics.o2e_1);
    var osum = distributiveStatistics.p2e_1;
    if (!(osum == null)) {
      if (!(sum == null)) {
        sum = sum + osum;
      } else {
        this.p2e_1 = osum;
      }
    }
    var otherUncorrectedSumOfSquares = distributiveStatistics.q2e_1;
    if (!(otherUncorrectedSumOfSquares == null)) {
      if (!(uncorrectedSumOfSquares == null)) {
        uncorrectedSumOfSquares = uncorrectedSumOfSquares + otherUncorrectedSumOfSquares;
      } else {
        uncorrectedSumOfSquares = otherUncorrectedSumOfSquares;
      }
    }
    var otherMinimum = distributiveStatistics.r2e_1;
    if (minimum == null || (!(otherMinimum == null) && numberToDouble(otherMinimum) < numberToDouble(minimum))) {
      minimum = otherMinimum;
    }
    var otherMaximum = distributiveStatistics.s2e_1;
    if (maximum == null || (!(otherMaximum == null) && numberToDouble(otherMaximum) > numberToDouble(maximum))) {
      maximum = otherMaximum;
    }
    this.p2e_1 = sum;
    this.q2e_1 = uncorrectedSumOfSquares;
    this.r2e_1 = minimum;
    this.s2e_1 = maximum;
  }
  k2f() {
    var tmp;
    if (this.n2e_1.m1(new Long(0, 0)) > 0) {
      tmp = ensureNotNull(this.p2e_1) / this.n2e_1.a4();
    } else {
      tmp = null;
    }
    return tmp;
  }
  l2f() {
    var mean = this.k2f();
    var tmp;
    if (!(mean == null)) {
      tmp = ensureNotNull(this.q2e_1) / this.n2e_1.a4() - mean * mean;
    } else {
      tmp = null;
    }
    return tmp;
  }
  m2f() {
    var variance = this.l2f();
    var tmp;
    if (!(variance == null)) {
      // Inline function 'kotlin.math.sqrt' call
      tmp = Math.sqrt(variance);
    } else {
      tmp = null;
    }
    return tmp;
  }
  toString() {
    return 'DistributiveStatistics{count=' + this.n2e_1 + ', countOfMissing=' + this.o2e_1 + ', sum=' + this.p2e_1 + ', uncorrectedSumOfSquares=' + this.q2e_1 + ', minimum=' + this.r2e_1 + ', maximum=' + this.s2e_1 + ', mean=' + this.k2f() + ', variance=' + this.l2f() + ', stdDev=' + this.m2f() + toString(_Char___init__impl__6a9atx(125));
  }
}
class GroupFactory {
  n2f() {
    var tmp;
    if (false) {
      tmp = Companion_instance_56.t2e([]);
    } else {
      tmp = LinkedGroup.s2f();
    }
    return tmp;
  }
}
class DimensionsDiceStructure {
  constructor(dimensions, dice, structure) {
    this.t2f_1 = dimensions;
    this.u2f_1 = dice;
    this.v2f_1 = structure;
  }
  equals(o) {
    if (this === o)
      return true;
    if (o == null || !getKClassFromExpression(this).equals(getKClassFromExpression(o)))
      return false;
    var that = o instanceof DimensionsDiceStructure ? o : THROW_CCE();
    if (!ensureNotNull(this.u2f_1).equals(that.u2f_1))
      return false;
    return !equals(this.t2f_1, that.t2f_1) ? false : equals(this.v2f_1, that.v2f_1);
  }
  hashCode() {
    // Inline function 'kotlin.hashCode' call
    var tmp0_safe_receiver = this.t2f_1;
    var tmp1_elvis_lhs = tmp0_safe_receiver == null ? null : hashCode(tmp0_safe_receiver);
    var result = tmp1_elvis_lhs == null ? 0 : tmp1_elvis_lhs;
    var tmp = imul_0(31, result);
    // Inline function 'kotlin.hashCode' call
    var tmp0_safe_receiver_0 = this.u2f_1;
    var tmp1_elvis_lhs_0 = tmp0_safe_receiver_0 == null ? null : hashCode(tmp0_safe_receiver_0);
    result = tmp + (tmp1_elvis_lhs_0 == null ? 0 : tmp1_elvis_lhs_0) | 0;
    var tmp_0 = imul_0(31, result);
    // Inline function 'kotlin.hashCode' call
    var tmp0_safe_receiver_1 = this.v2f_1;
    var tmp1_elvis_lhs_1 = tmp0_safe_receiver_1 == null ? null : hashCode(tmp0_safe_receiver_1);
    result = tmp_0 + (tmp1_elvis_lhs_1 == null ? 0 : tmp1_elvis_lhs_1) | 0;
    return result;
  }
  toString() {
    return 'DimensionsDiceStructure{dimensions=' + this.t2f_1 + ', dice=' + this.u2f_1 + ', structure=' + this.v2f_1 + toString(_Char___init__impl__6a9atx(125));
  }
}
class InMemoryCube$listener$1 {
  constructor(this$0) {
    this.w2f_1 = this$0;
  }
  x2f(event) {
    var _iterator__ex2g4s = this.w2f_1.d2g_1.h7().x();
    while (_iterator__ex2g4s.y()) {
      var cuboid = _iterator__ex2g4s.z();
      cuboid.g2g(true);
    }
  }
  h2g(event) {
    return this.x2f(event);
  }
}
class InMemoryCube {
  constructor(dataFrame) {
    this.d2g_1 = HashMap.d8();
    this.e2g_1 = HashMap.d8();
    var tmp = this;
    tmp.f2g_1 = new InMemoryCube$listener$1(this);
    this.y2f_1 = dataFrame;
    this.a2g_1 = Companion_instance_58.z2e([]);
    this.b2g_1 = Companion_instance_57.x2e([]);
    this.c2g_1 = Companion_instance_61.i2g(booleanArrayOf([]));
    this.z2f_1 = new ApexCuboid(this, this.a2g_1);
    var tmp0 = this.d2g_1;
    var tmp1 = new DimensionsDiceStructure(this.a2g_1, this.b2g_1, this.c2g_1);
    // Inline function 'kotlin.collections.set' call
    var value = this.z2f_1;
    tmp0.i7(tmp1, value);
    dataFrame.j2g(this.f2g_1);
  }
  k2g() {
    return this.y2f_1;
  }
  l2g() {
    return this.z2f_1;
  }
  m2g(cuboid) {
    return this.e2g_1.u2(cuboid);
  }
  toString() {
    return 'InMemoryCube{cuboids=' + this.d2g_1.g7() + toString(_Char___init__impl__6a9atx(125));
  }
}
class LinkedGroup {
  static s2f() {
    var $this = createThis(this);
    init_org_molap_aggregates_cube_LinkedGroup($this);
    $this.o2f_1 = 0;
    $this.p2f_1 = null;
    $this.q2f_1 = null;
    return $this;
  }
  w2e(level) {
    var current = this;
    var inductionVariable = this.o2f_1 - 1 | 0;
    var last = level + 1 | 0;
    if (last <= inductionVariable)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + -1 | 0;
        current = ensureNotNull(current).p2f_1;
      }
       while (!(i === last));
    return ensureNotNull(current).q2f_1;
  }
  v2e() {
    // Inline function 'kotlin.arrayOfNulls' call
    var size = this.o2f_1;
    var path = fillArrayVal(Array(size), null);
    var current = this;
    var inductionVariable = this.o2f_1 - 1 | 0;
    if (0 <= inductionVariable)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + -1 | 0;
        path[i] = ensureNotNull(current).q2f_1;
        current = current.p2f_1;
      }
       while (0 <= inductionVariable);
    return path;
  }
  toString() {
    return 'LinkedGroup{path=' + contentToString(this.v2e()) + toString(_Char___init__impl__6a9atx(125));
  }
}
class GroupColumn {
  constructor(group, column, rowFilter) {
    this.n2g_1 = group;
    this.o2g_1 = column;
    this.p2g_1 = rowFilter;
  }
  equals(o) {
    if (this === o)
      return true;
    if (o == null || !getKClassFromExpression(this).equals(getKClassFromExpression(o)))
      return false;
    var that = o instanceof GroupColumn ? o : THROW_CCE();
    if (!equals(this.n2g_1, that.n2g_1))
      return false;
    return !equals(this.o2g_1, that.o2g_1) ? false : !(!(this.p2g_1 == null) ? !equals(this.p2g_1, that.p2g_1) : !(that.p2g_1 == null));
  }
  hashCode() {
    // Inline function 'kotlin.hashCode' call
    var tmp0_safe_receiver = this.n2g_1;
    var tmp1_elvis_lhs = tmp0_safe_receiver == null ? null : hashCode(tmp0_safe_receiver);
    var result = tmp1_elvis_lhs == null ? 0 : tmp1_elvis_lhs;
    var tmp = imul_0(31, result);
    // Inline function 'kotlin.hashCode' call
    var tmp0_safe_receiver_0 = this.o2g_1;
    var tmp1_elvis_lhs_0 = tmp0_safe_receiver_0 == null ? null : hashCode(tmp0_safe_receiver_0);
    result = tmp + (tmp1_elvis_lhs_0 == null ? 0 : tmp1_elvis_lhs_0) | 0;
    result = imul_0(31, result) + (!(this.p2g_1 == null) ? hashCode(this.p2g_1) : 0) | 0;
    return result;
  }
  toString() {
    var tmp = 'GroupColumn{group=' + this.n2g_1 + 'group=';
    // Inline function 'kotlin.hashCode' call
    var tmp0_safe_receiver = this.n2g_1;
    var tmp1_elvis_lhs = tmp0_safe_receiver == null ? null : hashCode(tmp0_safe_receiver);
    var tmp_0 = tmp + (tmp1_elvis_lhs == null ? 0 : tmp1_elvis_lhs) + ', column=' + this.o2g_1 + ', column=';
    // Inline function 'kotlin.hashCode' call
    var tmp0_safe_receiver_0 = this.o2g_1;
    var tmp1_elvis_lhs_0 = tmp0_safe_receiver_0 == null ? null : hashCode(tmp0_safe_receiver_0);
    return tmp_0 + (tmp1_elvis_lhs_0 == null ? 0 : tmp1_elvis_lhs_0) + toString(_Char___init__impl__6a9atx(125));
  }
}
class AbstractCuboid {
  constructor(cube) {
    this.q2g_1 = cube;
    this.r2g_1 = true;
    this.s2g_1 = null;
    this.t2g_1 = null;
    this.u2g_1 = null;
    this.v2g_1 = null;
  }
  w2g() {
    return this.q2g_1;
  }
  g2g(_set____db54di) {
    this.r2g_1 = _set____db54di;
  }
  x2g() {
    return this.r2g_1;
  }
  ob() {
    this.g2g(false);
    this.s2g_1 = CollectionFactory_instance.r16();
    this.t2g_1 = CollectionFactory_instance.r16();
    this.u2g_1 = CollectionFactory_instance.r16();
    this.v2g_1 = CollectionFactory_instance.r16();
  }
  m2e(group, column, rowExcluder) {
    if (this.x2g()) {
      this.ob();
    }
    var tmp;
    if (!(group == null)) {
      var key = new GroupColumn(group, column, rowExcluder);
      if (!ensureNotNull(this.s2g_1).s2(key)) {
        var child = this.w2g().m2g(this);
        var distributiveStatistics;
        if (!(child == null)) {
          distributiveStatistics = DistributiveStatistics.d2f();
          var _iterator__ex2g4s = ensureNotNull(child.z2g(group)).x();
          while (_iterator__ex2g4s.y()) {
            var childGroup = _iterator__ex2g4s.z();
            var childDistributiveStatistics = child.m2e(childGroup, column, rowExcluder);
            distributiveStatistics.j2f(ensureNotNull(childDistributiveStatistics));
          }
        } else {
          var rows = this.y2g(group);
          if (!(rows == null)) {
            distributiveStatistics = DistributiveStatistics.e2f(column, rows, rowExcluder);
          } else {
            distributiveStatistics = null;
          }
        }
        var tmp0 = ensureNotNull(this.s2g_1);
        // Inline function 'kotlin.collections.set' call
        var value = distributiveStatistics;
        tmp0.i7(key, value);
        return distributiveStatistics;
      }
      tmp = ensureNotNull(this.s2g_1).u2(key);
    } else {
      tmp = null;
    }
    return tmp;
  }
}
class ApexCuboid$listener$1 {
  constructor(this$0) {
    this.c2h_1 = this$0;
  }
  x2f(event) {
    this.c2h_1.g2g(true);
  }
  h2g(event) {
    return this.x2f(event);
  }
}
class ApexCuboid extends AbstractCuboid {
  constructor(cube, dimensions) {
    super(cube);
    this.j2h_1 = cube;
    this.l2h_1 = GroupFactory_instance.n2f();
    this.m2h_1 = listOf(this.l2h_1);
    var tmp = this;
    tmp.n2h_1 = new ApexCuboid$listener$1(this);
    this.o2h_1 = emptySet();
    this.k2h_1 = dimensions;
    cube.y2f_1.j2g(this.n2h_1);
  }
  w2g() {
    return this.j2h_1;
  }
  a2h() {
    return this.k2h_1;
  }
  b2h() {
    return this.m2h_1;
  }
  z2g(group) {
    return null;
  }
  y2g(group) {
    return this.j2h_1.k2g().p2h();
  }
}
class Cuboid$Companion$ALL$1 {
  toString() {
    return '(all)';
  }
}
class Companion_59 {
  constructor() {
    Companion_instance_59 = this;
    var tmp = this;
    tmp.q2h_1 = new Cuboid$Companion$ALL$1();
  }
}
class WeakQueryListener {
  constructor($outer, listener) {
    this.s2h_1 = $outer;
    this.r2h_1 = new WeakReference(listener);
  }
  t2h() {
    var l = this.hl();
    if (!(l == null)) {
      l.t2h();
    } else {
      this.s2h_1.w2h(this);
    }
  }
  hl() {
    return this.r2h_1.xk();
  }
  toString() {
    var l = this.hl();
    var tmp;
    if (!(l == null)) {
      tmp = 'Weak[' + toString_0(l) + ']';
    } else {
      tmp = anyToString(this);
    }
    return tmp;
  }
}
class Companion_60 {}
class AbstractQuery {
  static x2h() {
    var $this = createThis(this);
    $this.u2h_1 = true;
    $this.v2h_1 = CollectionFactory_instance.ll();
    return $this;
  }
  y2h(listener) {
    var weakListener = new WeakQueryListener(this, listener);
    this.v2h_1.o(weakListener);
  }
  w2h(listener) {
    if (listener instanceof WeakQueryListener) {
      var removed = this.v2h_1.w2(listener);
    } else {
      var toRemove = null;
      var _iterator__ex2g4s = this.v2h_1.x();
      while (_iterator__ex2g4s.y()) {
        var queryListener = _iterator__ex2g4s.z();
        var comparable;
        if (queryListener instanceof WeakQueryListener) {
          comparable = queryListener.hl();
        } else {
          comparable = queryListener;
        }
        if (equals(listener, comparable)) {
          toRemove = queryListener;
        }
      }
      if (!(toRemove == null)) {
        var removed_0 = this.v2h_1.w2(toRemove);
      }
    }
  }
  z2h() {
    var _iterator__ex2g4s = this.v2h_1.x();
    while (_iterator__ex2g4s.y()) {
      var listener = _iterator__ex2g4s.z();
      listener.t2h();
    }
  }
}
class CuboidQuery$queryListener$1 {
  constructor(this$0) {
    this.m2i_1 = this$0;
  }
  t2h() {
    this.m2i_1.f2i_1 = null;
    this.m2i_1.u2h_1 = true;
    this.m2i_1.z2h();
  }
}
class CuboidQuery$dataFrameListener$1 {
  constructor(this$0) {
    this.n2i_1 = this$0;
  }
  x2f(event) {
    this.n2i_1.u2h_1 = true;
    this.n2i_1.z2h();
  }
  h2g(event) {
    return this.x2f(event);
  }
}
class CuboidQuery extends AbstractQuery {
  c2i() {
    if (this.f2i_1 == null) {
      this.f2i_1 = ensureNotNull(this.h2i_1).o2i(ensureNotNull(this.g2i_1).c2i());
    }
    return this.f2i_1;
  }
  b2i() {
    return this.i2i_1;
  }
  b2h() {
    if (this.u2h_1) {
      run(this);
    }
    return this.j2i_1;
  }
  static p2i(cuboid, aggregations) {
    var $this = this.x2h();
    init_org_molap_aggregates_query_CuboidQuery($this);
    $this.f2i_1 = cuboid;
    var tmp = $this;
    tmp.i2i_1 = isArray(aggregations) ? aggregations : THROW_CCE();
    ensureNotNull(ensureNotNull($this.c2i()).w2g()).k2g().j2g($this.l2i_1);
    return $this;
  }
  a2i(path, aggregation) {
    return ensureNotNull(aggregation.j2e(this.c2i(), path));
  }
  a2h() {
    return ensureNotNull(ensureNotNull(this.c2i()).a2h());
  }
}
class Series {}
class AbstractSeries {
  static g2j($box) {
    return createThis(this, $box);
  }
  toString() {
    var tmp;
    if (!(this.a3() == null)) {
      tmp = toString_0(this.a3());
    } else {
      tmp = anyToString(this);
    }
    return tmp;
  }
}
class DimensionSeries extends AbstractSeries {
  static f2j($outer, dataFrame, column, columnIndex, $box) {
    if ($box === VOID)
      $box = {};
    $box.e2j_1 = $outer;
    var $this = this.g2j($box);
    $this.b2j_1 = dataFrame;
    $this.c2j_1 = column;
    $this.d2j_1 = columnIndex;
    return $this;
  }
  a3() {
    return this.c2j_1;
  }
  h26() {
    return this.b2j_1.h2j(this.c2j_1);
  }
  i2j(key) {
    var tmp;
    if (!(key == null)) {
      tmp = key.w2e(this.d2j_1);
    } else {
      tmp = null;
    }
    return tmp;
  }
  u2(key) {
    return this.i2j((key == null ? true : isInterface(key, Group)) ? key : THROW_CCE());
  }
}
class AggregationSeries extends AbstractSeries {
  static m2j($outer, aggregation, column, $box) {
    if ($box === VOID)
      $box = {};
    $box.l2j_1 = $outer;
    var $this = this.g2j($box);
    $this.j2j_1 = aggregation;
    $this.k2j_1 = column;
    return $this;
  }
  a3() {
    return this.k2j_1;
  }
  h26() {
    var tmp = PrimitiveClasses_getInstance().le();
    return isInterface(tmp, KClass) ? tmp : THROW_CCE();
  }
  i2j(key) {
    return this.l2j_1.s2i_1.a2i(key, this.j2j_1);
  }
  u2(key) {
    return this.i2j((key == null ? true : isInterface(key, Group)) ? key : THROW_CCE());
  }
}
class QueryDataFrame$queryListener$1 {
  constructor(this$0) {
    this.n2j_1 = this$0;
  }
  t2h() {
    this.n2j_1.u2i_1 = null;
    this.n2j_1.v2i_1 = null;
    this.n2j_1.q2j(new DataFrameEvent(emptyList(), null, true));
  }
}
class DataFrame {}
class AbstractDataFrame {
  static s2j() {
    var $this = createThis(this);
    $this.o2j_1 = CollectionFactory_instance.ll();
    var tmp = $this;
    tmp.p2j_1 = lazy(AbstractDataFrame$cube$delegate$lambda($this));
    return $this;
  }
  w2g() {
    var tmp0 = this.p2j_1;
    // Inline function 'kotlin.getValue' call
    cube$factory();
    return tmp0.r2();
  }
  p2h() {
    return this.t2j().c2k();
  }
  b2k() {
    return this.u2j().c2k();
  }
  d2k(index) {
    return this.t2j().fm(index);
  }
  a2j(index) {
    return this.u2j().fm(index);
  }
  u2k(row) {
    return this.t2j().w2j(row);
  }
  f2k(column) {
    return this.u2j().w2j(column);
  }
  g2k() {
    return this.t2j().a1();
  }
  z2i() {
    return this.u2j().a1();
  }
  a2k(column) {
    return ColumnSeries.q2k(this, column);
  }
  v2k(aggregations) {
    return this.h2k(true, aggregations.slice());
  }
  h2k(includeIndex, aggregations) {
    var query = CuboidQuery.p2i(this.w2g().l2g(), aggregations.slice());
    return QueryDataFrame.r2j(query, includeIndex);
  }
  w2k(column) {
    var tmp = this.a2k(column);
    return new SumAggregation((!(tmp == null) ? isInterface(tmp, Series) : false) ? tmp : THROW_CCE());
  }
  i2k(column) {
    return column == null ? null : toString_1(column);
  }
  x2k() {
    var _iterator__ex2g4s = this.b2k().x();
    while (_iterator__ex2g4s.y()) {
      var column = _iterator__ex2g4s.z();
      print(Companion_instance_62.s2k(this.i2k(column), 19));
      print(': ');
      var value = this.h2j(column);
      print(Companion_instance_62.s2k(!(value == null) ? value.td() : '', 19));
      println_0();
    }
  }
  k1u() {
    var _iterator__ex2g4s = this.b2k().x();
    while (_iterator__ex2g4s.y()) {
      var column = _iterator__ex2g4s.z();
      print(Companion_instance_62.t2k(20, Companion_instance_62.s2k(this.i2k(column), 19)));
    }
    println_0();
    var _iterator__ex2g4s_0 = ensureNotNull(this.p2h()).x();
    while (_iterator__ex2g4s_0.y()) {
      var row = _iterator__ex2g4s_0.z();
      var _iterator__ex2g4s_1 = ensureNotNull(this.b2k()).x();
      while (_iterator__ex2g4s_1.y()) {
        var column_0 = _iterator__ex2g4s_1.z();
        var value = this.y2j(row, column_0);
        if (!(value == null)) {
          print(Companion_instance_62.t2k(20, Companion_instance_62.s2k(toString_1(value), 19)));
        } else {
          print(Companion_instance_62.t2k(20, Companion_instance_62.s2k('(null)', 19)));
        }
      }
      println_0();
    }
  }
  y2k(listener) {
    this.o2j_1.o(listener);
  }
  j2g(listener) {
    this.o2j_1.o(new WeakDataFrameListener(this, listener));
  }
  j2k(listener) {
    if (listener instanceof WeakDataFrameListener) {
      this.o2j_1.w2(listener);
    } else {
      var toRemove = null;
      var _iterator__ex2g4s = this.o2j_1.x();
      while (_iterator__ex2g4s.y()) {
        var dataFrameListener = _iterator__ex2g4s.z();
        var comparable;
        if (dataFrameListener instanceof WeakDataFrameListener) {
          comparable = dataFrameListener.hl();
        } else {
          comparable = dataFrameListener;
        }
        if (equals(listener, comparable)) {
          toRemove = dataFrameListener;
        }
      }
      if (!(toRemove == null)) {
        this.o2j_1.w2(toRemove);
      }
    }
  }
  z2k() {
    this.o2j_1.o5();
  }
  q2j(event) {
    var _iterator__ex2g4s = this.o2j_1.x();
    while (_iterator__ex2g4s.y()) {
      var listener = _iterator__ex2g4s.z();
      listener.h2g(event);
    }
  }
}
class QueryDataFrame extends AbstractDataFrame {
  static r2j(query, includeIndex) {
    var $this = this.s2j();
    $this.u2i_1 = null;
    $this.v2i_1 = null;
    var tmp = $this;
    tmp.w2i_1 = new QueryDataFrame$queryListener$1($this);
    $this.s2i_1 = query;
    $this.t2i_1 = includeIndex;
    query.y2h($this.w2i_1);
    return $this;
  }
  t2j() {
    return ensureNotNull(_get_cacheRowIndex__mo0sbb(this));
  }
  u2j() {
    return ensureNotNull(_get_cacheColumnIndex__9igbhr(this));
  }
  v2j(column) {
    var columnIndex = this.u2j().w2j(ensureNotNull(column));
    var tmp;
    if (columnIndex >= 0) {
      if (this.t2i_1) {
        if (columnIndex < ensureNotNull(this.s2i_1.a2h()).a2f_1.length) {
          var c = ensureNotNull(this.s2i_1.a2h()).a2f_1[columnIndex];
          var dataFrame = ensureNotNull(ensureNotNull(this.s2i_1.c2i()).w2g()).k2g();
          return dataFrame.h2j(c);
        }
        columnIndex = columnIndex - ensureNotNull(this.s2i_1.a2h()).a2f_1.length | 0;
      }
      tmp = this.s2i_1.b2i()[columnIndex].h26();
    } else {
      tmp = PrimitiveClasses_getInstance().de();
    }
    return tmp;
  }
  h2j(column) {
    return this.v2j((column == null ? true : typeof column === 'string') ? column : THROW_CCE());
  }
  x2j(path, column) {
    var columnIndex = this.u2j().w2j(ensureNotNull(column));
    var tmp;
    if (columnIndex == null || columnIndex >= 0) {
      if (path == null) {
        println('QueryDataFrame: path is null');
      }
      if (this.t2i_1) {
        if (ensureNotNull(columnIndex) < ensureNotNull(this.s2i_1.a2h()).a2f_1.length) {
          if (!(this.s2i_1.a2h() == null)) {
            var c = ensureNotNull(this.s2i_1.a2h()).a2f_1[columnIndex];
            columnIndex = ensureNotNull(this.s2i_1.a2h()).c2f(c);
          }
          var tmp_0;
          if (!(path == null)) {
            tmp_0 = path.w2e(ensureNotNull(columnIndex));
          } else {
            tmp_0 = null;
          }
          return tmp_0;
        }
        columnIndex = columnIndex - ensureNotNull(this.s2i_1.a2h()).a2f_1.length | 0;
      }
      tmp = this.s2i_1.a2i(path, this.s2i_1.b2i()[ensureNotNull(columnIndex)]);
    } else {
      tmp = null;
    }
    return tmp;
  }
  y2j(row, column) {
    var tmp = (row == null ? true : isInterface(row, Group)) ? row : THROW_CCE();
    return this.x2j(tmp, (column == null ? true : typeof column === 'string') ? column : THROW_CCE());
  }
  z2j(column) {
    var columnIndex = this.u2j().w2j(ensureNotNull(column));
    if (this.t2i_1) {
      if (columnIndex < ensureNotNull(this.s2i_1.a2h()).a2f_1.length) {
        var tmp = ensureNotNull(ensureNotNull(this.s2i_1.c2i()).w2g()).k2g();
        return DimensionSeries.f2j(this, isInterface(tmp, DataFrame) ? tmp : THROW_CCE(), column, columnIndex);
      }
      columnIndex = columnIndex - ensureNotNull(this.s2i_1.a2h()).a2f_1.length | 0;
    }
    return AggregationSeries.m2j(this, this.s2i_1.b2i()[columnIndex], column);
  }
  a2k(column) {
    return this.z2j((column == null ? true : typeof column === 'string') ? column : THROW_CCE());
  }
  p2h() {
    var tmp = this.s2i_1.b2h();
    return (!(tmp == null) ? isInterface(tmp, Iterable) : false) ? tmp : THROW_CCE();
  }
  b2k() {
    return this.u2j().c2k();
  }
  d2k(index) {
    var tmp = ensureNotNull(this.s2i_1).b2h();
    var groups = (!(tmp == null) ? isInterface(tmp, KtList_0) : false) ? tmp : THROW_CCE();
    var tmp_0;
    if (index >= 0 && index < groups.a1()) {
      tmp_0 = groups.b1(index);
    } else {
      tmp_0 = null;
    }
    return tmp_0;
  }
  a2j(index) {
    var index_0 = index;
    if (this.t2i_1) {
      if (index_0 < ensureNotNull(this.s2i_1.a2h()).a2f_1.length) {
        return toString_0(ensureNotNull(this.s2i_1.a2h()).a2f_1[index_0]);
      }
      index_0 = index_0 - ensureNotNull(this.s2i_1.a2h()).a2f_1.length | 0;
    }
    return ensureNotNull(this.s2i_1.b2i()[index_0].a3());
  }
  e2k(column) {
    return this.u2j().w2j(ensureNotNull(column));
  }
  f2k(column) {
    return this.e2k((column == null ? true : typeof column === 'string') ? column : THROW_CCE());
  }
  g2k() {
    return ensureNotNull(this.s2i_1.b2h()).a1();
  }
  z2i() {
    var tmp;
    if (this.t2i_1) {
      tmp = ensureNotNull(this.s2i_1.a2h()).a2f_1.length + this.s2i_1.b2i().length | 0;
    } else {
      tmp = this.s2i_1.b2i().length;
    }
    return tmp;
  }
}
class Companion_61 {
  i2g(path) {
    return get_4(this, taggedArrayCopy(path));
  }
}
class Structure {
  constructor(path) {
    this.k2k_1 = path;
  }
  equals(o) {
    if (this === o)
      return true;
    if (!(o instanceof Structure))
      return false;
    return contentEquals_0(this.k2k_1, o.k2k_1);
  }
  hashCode() {
    return contentHashCode_0(this.k2k_1);
  }
  toString() {
    return 'Structure{path=' + contentToString_0(this.k2k_1) + toString(_Char___init__impl__6a9atx(125));
  }
}
class WeakDataFrameListener {
  constructor($outer, listener) {
    this.m2k_1 = $outer;
    this.l2k_1 = new WeakReference(listener);
  }
  n2k(event) {
    var l = this.hl();
    if (!(l == null)) {
      l.h2g(event);
    } else {
      this.m2k_1.j2k(this);
    }
  }
  h2g(event) {
    return this.n2k(event);
  }
  hl() {
    return this.l2k_1.xk();
  }
}
class ColumnSeries extends AbstractSeries {
  static q2k($outer, column, $box) {
    if ($box === VOID)
      $box = {};
    $box.p2k_1 = $outer;
    var $this = this.g2j($box);
    $this.o2k_1 = column;
    $this.o2k_1 = $this.o2k_1;
    return $this;
  }
  a3() {
    return this.o2k_1;
  }
  h26() {
    return this.p2k_1.h2j(this.o2k_1);
  }
  r2k(key) {
    return this.p2k_1.y2j(key, this.o2k_1);
  }
  u2(key) {
    return this.r2k((key == null ? true : !(key == null)) ? key : THROW_CCE());
  }
}
class Companion_62 {
  s2k(str, maxWidth) {
    if (str == null) {
      return null;
    }
    var tmp;
    if (str.length <= maxWidth) {
      tmp = str;
    } else {
      // Inline function 'kotlin.text.substring' call
      var endIndex = maxWidth - 3 | 0;
      // Inline function 'kotlin.js.asDynamic' call
      tmp = str.substring(0, endIndex) + '...';
    }
    return tmp;
  }
  t2k(width, str) {
    if (str == null) {
      return null;
    }
    var tmp;
    if (str.length < width) {
      var tmp_0 = 0;
      var tmp_1 = width - str.length | 0;
      var tmp_2 = charArray(tmp_1);
      while (tmp_0 < tmp_1) {
        tmp_2[tmp_0] = _Char___init__impl__6a9atx(32);
        tmp_0 = tmp_0 + 1 | 0;
      }
      tmp = str + concatToString(tmp_2);
    } else {
      // Inline function 'kotlin.text.substring' call
      // Inline function 'kotlin.js.asDynamic' call
      tmp = str.substring(0, width);
    }
    return tmp;
  }
}
class ColumnStatistics {
  constructor(min, max, sum, count) {
    this.a2l_1 = min;
    this.b2l_1 = max;
    this.c2l_1 = sum;
    this.d2l_1 = count;
  }
  toString() {
    return 'ColumnStatistics{min=' + this.a2l_1 + ', max=' + this.b2l_1 + ', sum=' + this.c2l_1 + ', count=' + this.d2l_1 + toString(_Char___init__impl__6a9atx(125));
  }
}
class DataFrameEvent {
  constructor(affectedRows, affectedColumns, isStructureChanged) {
    this.e2l_1 = affectedRows;
    this.f2l_1 = affectedColumns;
    this.g2l_1 = isStructureChanged;
  }
}
class DataFrameHelper {
  h2l(dataFrame, column) {
    var min = null;
    var max = null;
    var sum = 0.0;
    var count = new Long(0, 0);
    var series = ensureNotNull(dataFrame.a2k(column));
    var _iterator__ex2g4s = dataFrame.p2h().x();
    while (_iterator__ex2g4s.y()) {
      var row = _iterator__ex2g4s.z();
      var value = series.u2(row);
      if (!(value == null)) {
        if (isNumber(value)) {
          var number = value;
          var d = numberToDouble(number);
          if (typeof number === 'number') {
            if (!isNaN_3(d) && !isInfinite_1(d)) {
              if (min == null || d < numberToDouble(min)) {
                min = number;
              }
              if (max == null || d > numberToDouble(max)) {
                max = number;
              }
              sum = sum + number;
              count = count.m3();
            }
          } else {
            if (typeof number === 'number') {
              var f = number;
              if (!isNaN_4(f) && !isInfinite_2(f)) {
                if (min == null || d < numberToDouble(min)) {
                  min = number;
                }
                if (max == null || d > numberToDouble(max)) {
                  max = number;
                }
              }
            } else {
              if (min == null || d < numberToDouble(min)) {
                min = number;
              }
              if (max == null || d > numberToDouble(max)) {
                max = number;
              }
              sum = sum + d;
              count = count.m3();
            }
          }
        }
      }
    }
    return new ColumnStatistics(min, max, sum, count);
  }
}
class DefaultDataFrame extends AbstractDataFrame {
  constructor(dataFrame) {
    return new.target.s2l(dataFrame);
  }
  static s2l(dataFrame) {
    var $this = this.s2j();
    $this.q2l_1 = IntegerRangeUniqueIndex.v2l(0, dataFrame.g2k() - 1 | 0);
    var columns = ArrayList.o7(dataFrame.z2i());
    var series = ArrayList.o7(dataFrame.z2i());
    var c = 0;
    var _iterator__ex2g4s = dataFrame.b2k().x();
    while (_iterator__ex2g4s.y()) {
      var column = _iterator__ex2g4s.z();
      var columnKey = dataFrame.a2j(c);
      if (!(columnKey == null)) {
        var toString = toString_1(columnKey);
        var serie = createSeries($this, dataFrame, column);
        if (!(serie == null)) {
          columns.o(toString);
          series.o(serie);
        }
      }
      c = c + 1 | 0;
    }
    var tmp = $this;
    // Inline function 'kotlin.collections.toTypedArray' call
    var tmp$ret$0 = copyToArray(columns);
    tmp.r2l_1 = DefaultUniqueIndex.y2i(tmp$ret$0.slice());
    var tmp_0 = $this;
    // Inline function 'kotlin.collections.toTypedArray' call
    tmp_0.series = copyToArray(series);
    return $this;
  }
  t2j() {
    return this.q2l_1;
  }
  u2j() {
    return this.r2l_1;
  }
  w2l() {
    return this.series;
  }
  x2l(row) {
    return PrimitiveClasses_getInstance().de();
  }
  y2l(row) {
    return this.x2l((!(row == null) ? typeof row === 'number' : false) ? row : THROW_CCE());
  }
  z2l(column) {
    return this.series[this.r2l_1.w2j(column)].h26();
  }
  h2j(column) {
    return this.z2l((!(column == null) ? typeof column === 'string' : false) ? column : THROW_CCE());
  }
  a2m(row, column) {
    return this.series[this.r2l_1.w2j(column)].u2(row);
  }
  y2j(row, column) {
    var tmp = (!(row == null) ? typeof row === 'number' : false) ? row : THROW_CCE();
    return this.a2m(tmp, (!(column == null) ? typeof column === 'string' : false) ? column : THROW_CCE());
  }
  b2m(column) {
    var serie = this.series[this.f2k(column)];
    return serie;
  }
  a2k(column) {
    return this.b2m((!(column == null) ? typeof column === 'string' : false) ? column : THROW_CCE());
  }
}
class AbstractUniqueIndex$keys$1$iterator$1 {
  constructor(this$0) {
    this.d2m_1 = this$0;
    this.c2m_1 = 0;
  }
  y() {
    return this.c2m_1 < this.d2m_1.a1();
  }
  z() {
    var _unary__edvuaz = this.c2m_1;
    this.c2m_1 = _unary__edvuaz + 1 | 0;
    return this.d2m_1.fm(_unary__edvuaz);
  }
  n5() {
    throw UnsupportedOperationException.h4();
  }
}
class AbstractUniqueIndex$keys$1 {
  constructor(this$0) {
    this.e2m_1 = this$0;
  }
  x() {
    return new AbstractUniqueIndex$keys$1$iterator$1(this.e2m_1);
  }
}
class AbstractUniqueIndex extends AbstractIndex {
  static f2m() {
    return this.em();
  }
  c2k() {
    return new AbstractUniqueIndex$keys$1(this);
  }
}
class Lazy {
  constructor($outer, $box) {
    boxApply(this, $box);
    this.l2m_1 = $outer;
    var tmp = this;
    tmp.g2m_1 = lazy(DefaultUniqueIndex$Lazy$indexDelegate$lambda(this));
    this.h2m_1 = this.g2m_1;
    var tmp_0 = this;
    tmp_0.i2m_1 = lazy(DefaultUniqueIndex$Lazy$listDelegate$lambda(this));
    this.j2m_1 = this.i2m_1;
    this.k2m_1 = false;
  }
  o2m() {
    var tmp0 = this.h2m_1;
    // Inline function 'kotlin.getValue' call
    index$factory();
    return tmp0.r2();
  }
  b1c() {
    var tmp0 = this.j2m_1;
    // Inline function 'kotlin.getValue' call
    list$factory();
    return tmp0.r2();
  }
  w2j(key) {
    var index = this.o2m();
    if (!this.k2m_1) {
      this.p2m(index);
      this.k2m_1 = true;
    }
    var i = index.u2(key);
    if (!(i == null)) {
      return i;
    } else {
      throw RuntimeException.ja('Illegal key');
    }
  }
  a1() {
    return this.b1c().a1();
  }
  p2m(index) {
  }
}
class Companion_63 {}
class DefaultUniqueIndex$3 extends Lazy {
  constructor(this$0, $index, $list, $box) {
    if ($box === VOID)
      $box = {};
    $box.w2m_1 = $index;
    $box.x2m_1 = $list;
    super(this$0, $box);
  }
  m2m() {
    return this.w2m_1;
  }
  n2m() {
    return this.x2m_1;
  }
}
class DefaultUniqueIndex extends AbstractUniqueIndex {
  static y2i(keys) {
    return this.y2m(Duplicate_UseFirstWarn_getInstance(), keys.slice());
  }
  static y2m(duplicate, keys) {
    var $this = this.f2m();
    init_org_molap_index_DefaultUniqueIndex($this);
    var tmp0_elvis_lhs = keys.length;
    var index = HashMap.r8(tmp0_elvis_lhs == null ? 0 : tmp0_elvis_lhs);
    var list = ArrayList.e1();
    var inductionVariable = 0;
    var last = keys.length;
    if (inductionVariable < last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var key = keys[i];
        if (!index.s2(key)) {
          index.i7(key, i);
          list.o(key);
        } else {
          switch (duplicate.z2_1) {
            case 2:
              break;
            case 3:
              try {
                throw IllegalStateException.n4('Index not unique for value ' + toString_0(key) + ' (address=' + i + ')');
              } catch ($p) {
                if ($p instanceof IllegalStateException) {
                  var e = $p;
                } else {
                  throw $p;
                }
              }

              break;
            case 4:
              index.i7(key, i);
              list.w2(key);
              list.o(key);
              println('Index not unique for value ' + toString_0(key) + ' (address=' + i + '): will use last');
              break;
            case 0:
              index.i7(key, i);
              list.w2(key);
              list.o(key);
              println('Index not unique for value ' + toString_0(key) + ' (address=' + i + '): will remove first');
              break;
            case 1:
              break;
            case 5:
              throw IllegalStateException.n4('Index not unique for value ' + toString_0(key) + ' (address=' + i + ')');
            default:
              noWhenBranchMatchedException();
              break;
          }
        }
      }
       while (inductionVariable < last);
    var tmp = $this;
    tmp.x2i_1 = new DefaultUniqueIndex$3($this, index, list);
    return $this;
  }
  w2j(key) {
    return ensureNotNull(this.x2i_1).w2j(key);
  }
  c2k() {
    return ensureNotNull(this.x2i_1).b1c();
  }
  fm(i) {
    var tmp;
    if (i >= 0 && i < this.a1()) {
      tmp = ensureNotNull(this.x2i_1).b1c().b1(i);
    } else {
      throw RuntimeException.ja('Key is out of range');
    }
    return tmp;
  }
  a1() {
    return ensureNotNull(this.x2i_1).a1();
  }
}
class IntegerRangeUniqueIndex$keys$1$iterator$1 {
  constructor(this$0) {
    this.a2n_1 = this$0;
    this.z2m_1 = this$0.t2l_1;
  }
  y() {
    return this.z2m_1 <= this.a2n_1.u2l_1;
  }
  z() {
    var _unary__edvuaz = this.z2m_1;
    this.z2m_1 = _unary__edvuaz + 1 | 0;
    return _unary__edvuaz;
  }
  n5() {
    throw UnsupportedOperationException.h4();
  }
}
class IntegerRangeUniqueIndex$keys$1 {
  constructor(this$0) {
    this.b2n_1 = this$0;
  }
  x() {
    return new IntegerRangeUniqueIndex$keys$1$iterator$1(this.b2n_1);
  }
}
class IntegerRangeUniqueIndex extends AbstractUniqueIndex {
  static v2l(from, to) {
    var $this = this.f2m();
    $this.t2l_1 = from;
    $this.u2l_1 = to;
    return $this;
  }
  c2n(key) {
    return this.ti(key) ? key - this.t2l_1 | 0 : -1;
  }
  w2j(key) {
    return this.c2n((!(key == null) ? typeof key === 'number' : false) ? key : THROW_CCE());
  }
  ti(key) {
    return key >= this.t2l_1 && key <= this.u2l_1;
  }
  fm(i) {
    return this.t2l_1 + i | 0;
  }
  c2k() {
    return new IntegerRangeUniqueIndex$keys$1(this);
  }
  a1() {
    return (this.u2l_1 - this.t2l_1 | 0) + 1 | 0;
  }
  toString() {
    return 'IntegerRangeUniqueIndex{from=' + this.t2l_1 + ', to=' + this.u2l_1 + toString(_Char___init__impl__6a9atx(125));
  }
}
class Duplicate extends Enum {}
class Graph {}
class MutableSeries {}
class DefaultSeries extends AbstractSeries {
  a3() {
    return this.f2n_1;
  }
  h26() {
    return this.i2n_1;
  }
  static j2n(values, name, type, index) {
    name = name === VOID ? null : name;
    type = type === VOID ? PrimitiveClasses_getInstance().de() : type;
    index = index === VOID ? IntegerRangeUniqueIndex.v2l(0, values.length - 1 | 0) : index;
    var $this = this.g2j();
    init_org_molap_series_DefaultSeries($this);
    $this.g2n_1 = values;
    $this.i2n_1 = type;
    $this.f2n_1 = name;
    $this.h2n_1 = index;
    return $this;
  }
  b1(key) {
    return this.g2n_1[key];
  }
  u2(key) {
    return this.b1((!(key == null) ? typeof key === 'number' : false) ? key : THROW_CCE());
  }
}
class DoubleSeries extends AbstractSeries {
  a3() {
    return this.k2n_1;
  }
  static o2n(values, available) {
    var $this = this.g2j();
    init_org_molap_series_DoubleSeries($this);
    $this.k2n_1 = null;
    $this.m2n_1 = values;
    $this.n2n_1 = IntegerRangeUniqueIndex.v2l(0, values.length - 1 | 0);
    $this.l2n_1 = available;
    return $this;
  }
  h26() {
    var tmp = PrimitiveClasses_getInstance().le();
    return isInterface(tmp, KClass) ? tmp : THROW_CCE();
  }
  b1(key) {
    var tmp;
    if (this.p2n(key)) {
      tmp = (null == null ? true : typeof null === 'number') ? null : THROW_CCE();
    } else {
      tmp = this.m2n_1[key];
    }
    return tmp;
  }
  u2(key) {
    return this.b1((!(key == null) ? typeof key === 'number' : false) ? key : THROW_CCE());
  }
  p2n(key) {
    return !(this.l2n_1 == null) && !this.l2n_1[key];
  }
}
class FloatSeries extends AbstractSeries {
  a3() {
    return this.q2n_1;
  }
  static u2n(values, available) {
    var $this = this.g2j();
    init_org_molap_series_FloatSeries($this);
    $this.q2n_1 = null;
    $this.s2n_1 = values;
    $this.t2n_1 = IntegerRangeUniqueIndex.v2l(0, values.length - 1 | 0);
    $this.r2n_1 = available;
    return $this;
  }
  h26() {
    var tmp = PrimitiveClasses_getInstance().ke();
    return isInterface(tmp, KClass) ? tmp : THROW_CCE();
  }
  b1(key) {
    var tmp;
    if (this.p2n(key)) {
      tmp = (null == null ? true : typeof null === 'number') ? null : THROW_CCE();
    } else {
      tmp = this.s2n_1[key];
    }
    return tmp;
  }
  u2(key) {
    return this.b1((!(key == null) ? typeof key === 'number' : false) ? key : THROW_CCE());
  }
  p2n(key) {
    return !(this.r2n_1 == null) && !this.r2n_1[key];
  }
}
class IntegerSeries extends AbstractSeries {
  a3() {
    return this.v2n_1;
  }
  static z2n(values, available) {
    var $this = this.g2j();
    init_org_molap_series_IntegerSeries($this);
    $this.v2n_1 = null;
    $this.x2n_1 = values;
    $this.y2n_1 = IntegerRangeUniqueIndex.v2l(0, values.length - 1 | 0);
    $this.w2n_1 = available;
    return $this;
  }
  h26() {
    var tmp = PrimitiveClasses_getInstance().je();
    return isInterface(tmp, KClass) ? tmp : THROW_CCE();
  }
  b1(key) {
    return this.p2n(key) ? null : this.x2n_1[key];
  }
  u2(key) {
    return this.b1((!(key == null) ? typeof key === 'number' : false) ? key : THROW_CCE());
  }
  p2n(key) {
    return !(this.w2n_1 == null) && !this.w2n_1[key];
  }
}
class LongSeries extends AbstractSeries {
  a3() {
    return this.a2o_1;
  }
  static e2o(values, available) {
    var $this = this.g2j();
    init_org_molap_series_LongSeries($this);
    $this.a2o_1 = null;
    $this.c2o_1 = values;
    $this.d2o_1 = IntegerRangeUniqueIndex.v2l(0, values.length - 1 | 0);
    $this.b2o_1 = available;
    return $this;
  }
  h26() {
    var tmp = getKClass(Long);
    return isInterface(tmp, KClass) ? tmp : THROW_CCE();
  }
  b1(key) {
    var tmp;
    if (this.p2n(key)) {
      tmp = (null == null ? true : null instanceof Long) ? null : THROW_CCE();
    } else {
      tmp = this.c2o_1[key];
    }
    return tmp;
  }
  u2(key) {
    return this.b1((!(key == null) ? typeof key === 'number' : false) ? key : THROW_CCE());
  }
  p2n(key) {
    return !(this.b2o_1 == null) && !this.b2o_1[key];
  }
}
class Companion_64 {
  constructor() {
    Companion_instance_64 = this;
    this.i2l_1 = new SeriesFactory();
  }
  n2l(values, available) {
    return buildInteger(this.i2l_1, values, available);
  }
  m2l(values, available) {
    return buildLong(this.i2l_1, values, available);
  }
  l2l(values, available) {
    return buildFloat(this.i2l_1, values, available);
  }
  k2l(values, available) {
    return buildDouble(this.i2l_1, values, available);
  }
  j2l(values, type) {
    return build(this.i2l_1, values, type);
  }
}
class SeriesFactory {
  constructor() {
    Companion_getInstance_64();
  }
}
class JsonDataFrame extends AbstractDataFrame {
  constructor(array) {
    return new.target.m2o(array);
  }
  static m2o(array) {
    var $this = this.s2j();
    $this.h2o_1 = array;
    var columns = LinkedHashSet.d1();
    var types = HashMap.d8();
    var inductionVariable = 0;
    var last = $this.h2o_1.length;
    if (inductionVariable < last)
      do {
        var row = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        // Inline function 'kotlin.js.unsafeCast' call
        // Inline function 'kotlin.js.asDynamic' call
        var o = $this.h2o_1[row];
        var _iterator__ex2g4s = iterator(Object.keys(o));
        while (_iterator__ex2g4s.y()) {
          var column = _iterator__ex2g4s.z();
          if (!columns.j2(column)) {
            columns.o(column);
            var value = o[column];
            var type = getClass($this, value);
            if (!(type == null)) {
              // Inline function 'kotlin.collections.set' call
              types.i7(column, type);
            }
          } else {
            var value_0 = o[column];
            var type_0 = getClass($this, value_0);
            if (!(type_0 == null)) {
              var currentType = types.u2(column);
              if (currentType == null) {
                // Inline function 'kotlin.collections.set' call
                types.i7(column, type_0);
              } else if (!equals(currentType, type_0)) {
                // Inline function 'kotlin.collections.set' call
                var value_1 = PrimitiveClasses_getInstance().de();
                types.i7(column, value_1);
              }
            }
          }
        }
      }
       while (inductionVariable < last);
    var tmp = $this;
    // Inline function 'kotlin.collections.toTypedArray' call
    tmp.i2o_1 = copyToArray(columns);
    var tmp_0 = $this;
    // Inline function 'kotlin.arrayOfNulls' call
    var size = columns.a1();
    tmp_0.j2o_1 = fillArrayVal(Array(size), null);
    var index = 0;
    var _iterator__ex2g4s_0 = columns.x();
    while (_iterator__ex2g4s_0.y()) {
      var column_0 = _iterator__ex2g4s_0.z();
      var type_1 = types.u2(column_0);
      $this.j2o_1[index] = !(type_1 == null) ? type_1 : PrimitiveClasses_getInstance().de();
      index = index + 1 | 0;
    }
    var tmp_1 = $this;
    tmp_1.k2o_1 = lazy(JsonDataFrame$rowIndex$delegate$lambda($this));
    var tmp_2 = $this;
    tmp_2.l2o_1 = lazy(JsonDataFrame$columnIndex$delegate$lambda($this));
    return $this;
  }
  t2j() {
    var tmp0 = this.k2o_1;
    // Inline function 'kotlin.getValue' call
    rowIndex$factory();
    return tmp0.r2();
  }
  u2j() {
    var tmp0 = this.l2o_1;
    // Inline function 'kotlin.getValue' call
    columnIndex$factory();
    return tmp0.r2();
  }
  static fromString(json) {
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var tmp$ret$1 = JSON.parse(json)['data'];
    return this.m2o(tmp$ret$1);
  }
  n2o(column) {
    return this.i2o_1[this.u2j().w2j(column)];
  }
  i2k(column) {
    return this.n2o((!(column == null) ? typeof column === 'string' : false) ? column : THROW_CCE());
  }
  z2l(column) {
    var address = this.u2j().w2j(column);
    return ensureNotNull(this.j2o_1[address]);
  }
  h2j(column) {
    return this.z2l((!(column == null) ? typeof column === 'string' : false) ? column : THROW_CCE());
  }
  g2k() {
    return this.h2o_1.length;
  }
  z2i() {
    return this.i2o_1.length;
  }
  x2l(row) {
    return PrimitiveClasses_getInstance().de();
  }
  y2l(row) {
    return this.x2l((!(row == null) ? typeof row === 'number' : false) ? row : THROW_CCE());
  }
  a2m(row, column) {
    var jsonObject = this.h2o_1[row];
    if (!(jsonObject == null)) {
      var jsonValue = ((!(jsonObject == null) ? !(jsonObject == null) : false) ? jsonObject : THROW_CCE())[ensureNotNull(column)];
      var tmp;
      if (jsonValue == null) {
        tmp = null;
      } else {
        var tmp_0;
        if (this.z2l(column).equals(PrimitiveClasses_getInstance().le())) {
          tmp_0 = isNumber(jsonValue) ? jsonValue : THROW_CCE();
        } else if (this.z2l(column).equals(PrimitiveClasses_getInstance().ge())) {
          tmp_0 = (!(jsonValue == null) ? typeof jsonValue === 'boolean' : false) ? jsonValue : THROW_CCE();
        } else {
          var tmp_1;
          try {
            tmp_1 = getObject(this, jsonValue);
          } catch ($p) {
            var tmp_2;
            if ($p instanceof ClassCastException) {
              var e = $p;
              printStackTrace(e);
              tmp_2 = null;
            } else {
              throw $p;
            }
            tmp_1 = tmp_2;
          }
          tmp_0 = tmp_1;
        }
        tmp = tmp_0;
      }
      return tmp;
    } else {
      return null;
    }
  }
  y2j(row, column) {
    var tmp = (!(row == null) ? typeof row === 'number' : false) ? row : THROW_CCE();
    return this.a2m(tmp, (!(column == null) ? typeof column === 'string' : false) ? column : THROW_CCE());
  }
}
class Scale {}
class AbsScale {
  o2o(value, min, max) {
    // Inline function 'kotlin.math.absoluteValue' call
    return Math.abs(value);
  }
  toString() {
    return 'Absolute value';
  }
}
class Algorithm {}
class AbstractAlgorithm {
  f24() {
    return null;
  }
  p2o(shape, parent, children, sumSizes, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    return false;
  }
  q2o(bounds, model, root, worker) {
  }
  r2o(bounds, model, root) {
  }
  s2o() {
    return true;
  }
  t2o() {
    return true;
  }
  u2o() {
    return false;
  }
  v2o() {
    return true;
  }
  w2o(children, start, end, accessor) {
    var sum = 0.0;
    var inductionVariable = start;
    if (inductionVariable <= end)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        sum = sum + accessor.getSize(children[i]);
      }
       while (!(i === end));
    return sum;
  }
}
class Companion_65 {
  constructor() {
    this.z2o_1 = 0.15;
    this.a2p_1 = 0.5;
  }
  b2p(shape, y, height) {
    var tmp;
    if (shape instanceof Rectangle) {
      var bounds = shape;
      tmp = Rectangle.from(bounds.q20_1, y, bounds.s20_1, height);
    } else {
      if (isInterface(shape, Rectangle2D)) {
        var bounds_0 = shape;
        // Inline function 'kotlin.math.ceil' call
        var x = bounds_0.w1l();
        var tmp$ret$0 = Math.ceil(x);
        var tmp_0 = numberToInt(tmp$ret$0);
        // Inline function 'kotlin.math.floor' call
        var x_0 = bounds_0.cm();
        var tmp$ret$1 = Math.floor(x_0);
        tmp = Rectangle.from(tmp_0, y, numberToInt(tmp$ret$1), height);
      } else {
        var bounds_1 = shape.y1l();
        var hh = 0.001;
        var topHit = Double_3.p1m(bounds_1.w1l(), y, bounds_1.cm(), hh);
        var bottomHit = Double_3.p1m(bounds_1.w1l(), (y + height | 0) - hh, bounds_1.cm(), hh);
        var shapeArea = Area.j1r(shape);
        var topArea = Area.j1r(topHit);
        topArea.k1r(shapeArea);
        var bottomArea = Area.j1r(bottomHit);
        bottomArea.k1r(shapeArea);
        var topBounds = topArea.y1l();
        var bottomBounds = bottomArea.y1l();
        var tmp2 = topBounds.f1m();
        // Inline function 'kotlin.math.max' call
        var b = bottomBounds.f1m();
        // Inline function 'kotlin.math.ceil' call
        var x_1 = Math.max(tmp2, b);
        var tmp$ret$3 = Math.ceil(x_1);
        var x_2 = numberToInt(tmp$ret$3);
        var tmp5 = topBounds.i1m();
        // Inline function 'kotlin.math.min' call
        var b_0 = bottomBounds.i1m();
        // Inline function 'kotlin.math.floor' call
        var x_3 = Math.min(tmp5, b_0);
        var tmp$ret$5 = Math.floor(x_3);
        var width = numberToInt(tmp$ret$5) - x_2 | 0;
        tmp = Rectangle.from(x_2, y, width, height);
      }
    }
    return tmp;
  }
  c2p(points) {
    var N = points.length;
    var cx = 0.0;
    var cy = 0.0;
    var area = calcSignedPolygonArea(this, points);
    var i;
    var j;
    var factor;
    i = 0;
    while (i < N) {
      j = (i + 1 | 0) % N | 0;
      factor = points[i].w1l() * points[j].x1l() - points[j].w1l() * points[i].x1l();
      cx = cx + (points[i].w1l() + points[j].w1l()) * factor;
      cy = cy + (points[i].x1l() + points[j].x1l()) * factor;
      i = i + 1 | 0;
    }
    area = area * 6.0;
    factor = 1 / area;
    cx = cx * factor;
    cy = cy * factor;
    return Double_2.s1p(cx, cy);
  }
  d2p(shape) {
    var points = this.e2p(shape);
    return this.c2p(points);
  }
  e2p(shape) {
    var pointList = ArrayList.o7(32);
    var pathIterator = shape.d1m();
    var lastMoveToIndex = -1;
    while (!pathIterator.b17()) {
      var coordinates = new Float64Array(6);
      switch (pathIterator.i1q(coordinates)) {
        case 0:
          pointList.o(Double_2.s1p(coordinates[0], coordinates[1]));
          lastMoveToIndex = lastMoveToIndex + 1 | 0;
          break;
        case 1:
          pointList.o(Double_2.s1p(coordinates[0], coordinates[1]));
          break;
        case 2:
          pointList.o(Double_2.s1p(coordinates[0], coordinates[1]));
          pointList.o(Double_2.s1p(coordinates[2], coordinates[3]));
          break;
        case 3:
          pointList.o(Double_2.s1p(coordinates[0], coordinates[1]));
          pointList.o(Double_2.s1p(coordinates[2], coordinates[3]));
          pointList.o(Double_2.s1p(coordinates[4], coordinates[5]));
          break;
        case 4:
          if (lastMoveToIndex >= 0) {
            pointList.o(pointList.b1(lastMoveToIndex));
          }

          break;
      }
      pathIterator.h1q();
    }
    // Inline function 'kotlin.collections.toTypedArray' call
    var points = copyToArray(pointList);
    return points;
  }
}
class Labeling {}
class AbstractLabeling {
  f2p(model, shape, node) {
    return shape;
  }
  g2p(model) {
    return 0.0;
  }
  h2p(model) {
    return 0.0;
  }
  i2p(g2, shape, bounds, node, view) {
    var model = ensureNotNull(view.j2p());
    if (!model.filter.ol(node) && !model.search.ol(node)) {
      var columns = model.settings.labelsColumns;
      // Inline function 'kotlin.collections.isNotEmpty' call
      if (!columns.c1()) {
        var initialY;
        var parent = ensureNotNull(model.getParent(node));
        var tmp;
        if (!model.isRoot(parent)) {
          var groupByColumnSettings = model.settings.getColumnSettings(ensureNotNull(model.getGroupByColumn(parent)));
          var labeling = ensureNotNull(groupByColumnSettings.getLabeling());
          tmp = bounds.r20_1 + numberToInt(round(labeling.k2p(parent, node, view, model))) | 0;
        } else {
          tmp = bounds.r20_1;
        }
        initialY = tmp;
        var y = initialY;
        var todo = columns.a1();
        // Inline function 'kotlin.run' call
        // Inline function 'com.treemap.AbstractLabeling.paintLeaf.<anonymous>' call
        var topFields = this.l2p(model, columns, 1);
        if (!(topFields == null)) {
          var topHeight = this.m2p(g2, shape, bounds, node, view, model, topFields, true, y);
          if (topHeight > 0) {
            y = y + topHeight | 0;
            todo = todo - topFields.a1() | 0;
          } else {
            return Unit_instance;
          }
        }
        if (todo > 0) {
          var centerFields = this.l2p(model, columns, 0);
          if (!(centerFields == null)) {
            var centerHeight = this.m2p(g2, shape, bounds, node, view, model, centerFields, false, initialY);
            if (centerHeight > 0) {
              var center = bounds.r20_1 + ((bounds.t20_1 - centerHeight | 0) / 2 | 0) | 0;
              if (center > y) {
                y = center;
              }
              this.m2p(g2, shape, bounds, node, view, model, centerFields, true, y);
              y = y + centerHeight | 0;
              todo = todo - centerFields.a1() | 0;
            } else {
              return Unit_instance;
            }
          }
        }
        if (todo > 0) {
          var bottomFields = this.l2p(model, columns, 3);
          if (!(bottomFields == null)) {
            var bottomHeight = this.m2p(g2, shape, bounds, node, view, model, bottomFields, false, initialY);
            if (bottomHeight > 0) {
              var top = bounds.r20_1 + (bounds.t20_1 - bottomHeight | 0) | 0;
              if (top > y) {
                y = top;
              }
              this.m2p(g2, shape, bounds, node, view, model, bottomFields, true, y);
              y = y + bottomHeight | 0;
            } else {
              return Unit_instance;
            }
          }
        }
      }
    }
  }
  l2p(model, columns, alignement) {
    var list = null;
    var _iterator__ex2g4s = columns.x();
    while (_iterator__ex2g4s.y()) {
      var column = _iterator__ex2g4s.z();
      if (model.settings.getColumnSettings(column).getLabelingVerticalAlignment() === alignement) {
        if (list == null) {
          list = ArrayList.e1();
        }
        list.o(column);
      }
    }
    return list;
  }
  m2p(g2, shape, bounds, node, view, model, columns, paint, y) {
    var height = 0;
    var _iterator__ex2g4s = columns.x();
    $l$loop: while (_iterator__ex2g4s.y()) {
      var column = _iterator__ex2g4s.z();
      if (!(column == null)) {
        var columnSettings = model.settings.getColumnSettings(column);
        var background = columnSettings.getLabelingEffectColor();
        var foreground = columnSettings.getLabelingForeground();
        if (!(foreground == null)) {
          var font = columnSettings.getLabelingFont();
          var shrink = ensureNotNull(columnSettings.getLabelingShrinkTextToFitShape());
          var expand = ensureNotNull(columnSettings.getLabelingResizeTextToFitShape());
          if (!shrink && !expand) {
            if (getFontSize(ensureNotNull(font)) <= bounds.dm() && bounds.cm() > 4) {
              var zoomFactor = view.u2p();
              var derivedFont;
              var tmp;
              if (!(zoomFactor === 1.0)) {
                var tmp_0 = getFontSize(font);
                // Inline function 'kotlin.math.sqrt' call
                var zoomedSize = tmp_0 * (1.0 + (Math.sqrt(zoomFactor) - 1.0) * 0.15);
                var tmp_1;
                if (!(zoomedSize === getFontSize(font))) {
                  tmp_1 = font.u2d(zoomedSize);
                } else {
                  tmp_1 = font;
                }
                tmp = tmp_1;
              } else {
                tmp = font;
              }
              derivedFont = tmp;
              if (getFontSize(derivedFont) <= bounds.dm()) {
                var label = ensureNotNull(view.n2p()).o2p(view, column, node, Dimension.bm(bounds.s20_1, bounds.t20_1));
                if (!(label == null)) {
                  var nodeColor = model.getColor(node);
                  if (!(!(background == null) || nodeColor == null)) {
                    foreground = this.p2p(columnSettings, foreground, nodeColor);
                  }
                  label.setFont(derivedFont);
                  label.setForeground(foreground);
                  label.setBackground(background);
                  var size = g2.q2p(label, bounds.s20_1, bounds.t20_1);
                  var preferredHeight = size.v2p();
                  var cy = y + height | 0;
                  if (cy + preferredHeight <= bounds.x1l() + bounds.dm()) {
                    if (paint) {
                      var drawingArea = Companion_instance_65.b2p(shape, cy, numberToInt(preferredHeight));
                      this.t2p(g2, node, column, label, bounds, drawingArea);
                    }
                    if (!ensureNotNull(columnSettings.getLabelingFloat())) {
                      height = height + numberToInt(preferredHeight) | 0;
                    }
                  } else {
                    break $l$loop;
                  }
                }
              }
            }
          } else {
            if (bounds.cm() > 5 && bounds.dm() > 5 && (expand && bounds.dm() >= getFontSize(ensureNotNull(font)) || shrink)) {
              var elabel = ensureNotNull(view.n2p()).o2p(view, column, node, Dimension.bm(bounds.s20_1, bounds.t20_1));
              if (!(elabel == null)) {
                var innerWidth;
                var innerHeight;
                var insetWidth;
                var insetHeight;
                insetWidth = elabel.getInsetRight() + elabel.getInsetLeft() | 0;
                insetHeight = elabel.getInsetTop() + elabel.getInsetBottom() | 0;
                innerWidth = bounds.s20_1 - insetWidth | 0;
                innerHeight = bounds.t20_1 - insetHeight | 0;
                elabel.setFont(ensureNotNull(font));
                var nodeColor_0 = model.getColor(node);
                if (!(!(background == null) || nodeColor_0 == null)) {
                  foreground = this.p2p(columnSettings, foreground, nodeColor_0);
                }
                elabel.setForeground(foreground);
                elabel.setBackground(background);
                var pf = g2.q2p(elabel, bounds.s20_1, bounds.t20_1);
                var fontSize;
                var scaleFactor = 0.9;
                var tmp_2;
                if (!(columnSettings.getLabelingRendering() === Rendering_WordWrap_getInstance())) {
                  var legacy = true;
                  var tmp_3;
                  if (legacy) {
                    var preferredSize = pf.s2p();
                    var scaleX = bounds.cm() / preferredSize.cm();
                    var scaleY = bounds.dm() / preferredSize.dm();
                    // Inline function 'kotlin.math.min' call
                    var scale = Math.min(scaleX, scaleY);
                    tmp_3 = getFontSize(font) * scale * scaleFactor;
                  } else {
                    var preferredSize_0 = pf.s2p();
                    var w = preferredSize_0.cm() - insetWidth;
                    var h = preferredSize_0.dm() - insetHeight;
                    var scaleX_0 = innerWidth / w;
                    var scaleY_0 = innerHeight / h;
                    // Inline function 'kotlin.math.min' call
                    var scale_0 = Math.min(scaleX_0, scaleY_0);
                    // Inline function 'kotlin.math.floor' call
                    var x = getFontSize(font) * scale_0 * 1.0;
                    tmp_3 = Math.floor(x);
                  }
                  tmp_2 = tmp_3;
                } else {
                  tmp_2 = g2.r2p(elabel, pf, font, bounds, scaleFactor, expand);
                }
                fontSize = tmp_2;
                if (!shrink) {
                  var tmp6 = getFontSize(font);
                  // Inline function 'kotlin.math.max' call
                  var b = fontSize;
                  fontSize = Math.max(tmp6, b);
                }
                if (!expand) {
                  var tmp8 = getFontSize(font);
                  // Inline function 'kotlin.math.min' call
                  var b_0 = fontSize;
                  fontSize = Math.min(tmp8, b_0);
                }
                if (fontSize >= 5.0) {
                  var scaledFont = font.u2d(fontSize);
                  elabel.setFont(scaledFont);
                  equals(columnSettings.getLabelingRendering(), Rendering_WordWrap_getInstance());
                  var preferredSize_1 = pf.s2p();
                  if (paint) {
                    var cy_0 = y + height | 0;
                    var drawingArea_0 = Companion_instance_65.b2p(shape, cy_0, preferredSize_1.zl_1);
                    this.t2p(g2, node, column, elabel, bounds, drawingArea_0);
                  }
                  if (!ensureNotNull(columnSettings.getLabelingFloat())) {
                    height = height + preferredSize_1.zl_1 | 0;
                  }
                }
              }
            }
          }
        }
      }
    }
    return height;
  }
  t2p(g2, node, column, label, bounds, drawingArea) {
    g2.w2p(label, drawingArea.q20_1, drawingArea.r20_1, drawingArea.s20_1, drawingArea.t20_1);
  }
  p2p(settings, foreground, nodeColor) {
    return ensureNotNull(settings.getLabelingContrastEnhancement()).p22(foreground, nodeColor);
  }
  k2p(parent, node, view, model) {
    return 0.0;
  }
}
class Companion_66 {
  constructor() {
    this.y2p_1 = true;
  }
}
class Nesting {}
class AbstractNesting {
  a2q(treeMapModel, currentRoot, node, shape) {
    var tmp;
    if (true || !(node === currentRoot)) {
      var r;
      var nested;
      var columnSettings = treeMapModel.settings.getColumnSettings(treeMapModel.getGroupByColumn(node));
      var tmp_0;
      if (columnSettings.getAlgorithm().v2o()) {
        tmp_0 = this.z2p(treeMapModel, shape, node, ensureNotNull(columnSettings.getNestingAmount()));
      } else {
        tmp_0 = shape;
      }
      nested = tmp_0;
      var tmp_1;
      if (columnSettings.getAlgorithm().v2o()) {
        var label = ensureNotNull(columnSettings.getLabeling()).f2p(treeMapModel, shape, node);
        var tmp_2;
        var tmp_3;
        var tmp_4;
        if (!(label === nested)) {
          tmp_4 = !(label == null) ? isInterface(label, Rectangle2D) : false;
        } else {
          tmp_4 = false;
        }
        if (tmp_4) {
          tmp_3 = isInterface(nested, Rectangle2D);
        } else {
          tmp_3 = false;
        }
        if (tmp_3) {
          var n = nested;
          var l = label;
          var tmp0 = n.f1m();
          // Inline function 'kotlin.math.max' call
          var b = l.f1m();
          var x1 = Math.max(tmp0, b);
          var tmp2 = n.h1m();
          // Inline function 'kotlin.math.max' call
          var b_0 = l.h1m();
          var y1 = Math.max(tmp2, b_0);
          var tmp4 = n.i1m();
          // Inline function 'kotlin.math.min' call
          var b_1 = l.i1m();
          var x2 = Math.min(tmp4, b_1);
          var tmp6 = n.j1m();
          // Inline function 'kotlin.math.min' call
          var b_2 = l.j1m();
          var y2 = Math.min(tmp6, b_2);
          tmp_2 = Double_3.p1m(x1, y1, x2 - x1, y2 - y1);
        } else {
          tmp_2 = nested;
        }
        tmp_1 = tmp_2;
      } else {
        tmp_1 = nested;
      }
      r = tmp_1;
      tmp = r;
    } else {
      tmp = shape;
    }
    return tmp;
  }
}
class AbstractNodeRenderer {
  b2q(view, root, pass) {
    return ensureNotNull(view.j2p()).preorderEnumeration(root);
  }
}
class Companion_67 {
  constructor() {
    this.g2q_1 = 0.5;
  }
  h2q(bounds, font, elabel, pf, fontSize, shrink, expand) {
    elabel.setFont(font.u2d(fontSize));
    var preferredSize = pf.s2p();
    var preferredWidth = preferredSize.cm() - elabel.getInsetLeft() - (-elabel.getInsetRight() | 0);
    var preferredHeight = preferredSize.dm() - elabel.getInsetTop() - (-elabel.getInsetBottom() | 0);
    var targetWidth = bounds.cm();
    var targetheight = bounds.dm();
    var tmp0 = targetWidth * fontSize / preferredWidth;
    // Inline function 'kotlin.math.min' call
    var b = targetheight * fontSize / preferredHeight;
    var s = Math.min(tmp0, b) * 0.9;
    if (!shrink) {
      // Inline function 'kotlin.math.max' call
      var b_0 = s;
      s = Math.max(fontSize, b_0);
    }
    if (!expand) {
      // Inline function 'kotlin.math.min' call
      var b_1 = s;
      s = Math.min(fontSize, b_1);
    }
    return font.u2d(s);
  }
}
class AbstractRendering$getOrder$1 {
  constructor($view, $model) {
    this.i2q_1 = $view;
    this.j2q_1 = $model;
  }
  k2q(a, b) {
    var p1 = this.i2q_1.l2q(a);
    var p2 = this.i2q_1.l2q(b);
    var tmp;
    if (!(p1 == null)) {
      var tmp_0;
      if (!(p2 == null)) {
        var dimension = this.j2q_1.settings.getDimension();
        var tmp_1;
        if (!(dimension == null)) {
          var width = dimension.cm();
          var height = dimension.dm();
          var rx1 = p1.y1l().a1m() / width;
          var ry1 = p1.y1l().c1m() / height;
          var rx2 = p2.y1l().a1m() / width;
          var ry2 = p2.y1l().c1m() / height;
          tmp_1 = compare_0(rx1 + ry1, rx2 + ry2);
        } else {
          tmp_1 = compare_0(p1.y1l().a1m() + p1.y1l().c1m(), p2.y1l().a1m() + p2.y1l().c1m());
        }
        tmp_0 = tmp_1;
      } else {
        tmp_0 = 1;
      }
      tmp = tmp_0;
    } else {
      var tmp_2;
      if (!(p2 == null)) {
        tmp_2 = -1;
      } else {
        tmp_2 = 0;
      }
      tmp = tmp_2;
    }
    return tmp;
  }
  compare(a, b) {
    var tmp = (a == null ? true : !(a == null)) ? a : THROW_CCE();
    return this.k2q(tmp, (b == null ? true : !(b == null)) ? b : THROW_CCE());
  }
}
class Rendering_0 {}
class AbstractRendering {
  getPasses(model) {
    var heightColumn = model.settings.heightColumn;
    var tmp;
    if (!(heightColumn == null) && (model.isNumericType(heightColumn) || model.isTemporalType(heightColumn))) {
      tmp = 2;
    } else {
      tmp = 1;
    }
    return tmp;
  }
  getParentOrder(view, root, pass) {
    return pass === 0 ? ensureNotNull(view.j2p()).parentPreorderEnumeration(root) : emptyList();
  }
  getOrder(view, root, pass) {
    var model = ensureNotNull(view.j2p());
    var tmp;
    if (pass === 0) {
      tmp = model.preorderEnumeration(root);
    } else {
      var nodes = ArrayList.e1();
      var _iterator__ex2g4s = model.preorderEnumeration(root).x();
      while (_iterator__ex2g4s.y()) {
        var node = _iterator__ex2g4s.z();
        if (model.hasNoChildren(node)) {
          nodes.o(node);
        }
      }
      sortedWith_0(nodes, new AbstractRendering$getOrder$1(view, model));
      tmp = nodes;
    }
    return tmp;
  }
  paintParent(g, view, node, pass, bounds, shape) {
    var model = ensureNotNull(view.j2p());
    if (pass === 0 && !model.hasNoChildren(node)) {
      var depth = model.getLevel(node) - model.getLevel(ensureNotNull(model.currentRoot)) | 0;
      var algorithm = model.settings.getColumnSettings(model.getGroupByColumn(node)).getAlgorithm();
      if (ensureNotNull(model.settings.getDepth()).p2q(depth + 1 | 0) && algorithm.y2o(model.getShape(node)) && !algorithm.u2o()) {
        var color = this.getNestingBackground(node, model);
        if (!(color == null)) {
          g.n2q(color);
        } else {
          g.n2q(view.m2q());
        }
        g.o2q(shape);
      } else {
        if (!(model.currentRoot === node)) {
          this.paintNode(g, view, node, pass, bounds, shape);
        }
      }
    }
  }
  getRenderedShape(view, model, node, shape) {
    if (!(node == null) && model.hasNoChildren(node)) {
      var heightColumn = model.settings.heightColumn;
      if (!(heightColumn == null) && (model.isNumericType(heightColumn) || model.isTemporalType(heightColumn))) {
        var minHeight = model.getNumericMin(heightColumn);
        var maxHeight = model.getNumericMax(heightColumn);
        var value = model.getValueAt(node, heightColumn);
        if (!(value == null) && !(maxHeight == null) && !(minHeight == null)) {
          var height;
          var tmp;
          if (isNumber(value)) {
            tmp = numberToDouble(value);
          } else {
            tmp = 0.0;
          }
          height = tmp;
          var range = maxHeight - minHeight;
          // Inline function 'kotlin.math.abs' call
          var x = (height - minHeight) / range;
          var ratio = Math.abs(x);
          if (isInterface(shape, Rectangle2D)) {
            var top = shape;
            var tmp_0 = view.u2p() * -model.settings.getMaximumHeight();
            var tmp1 = ensureNotNull(model.settings.getDimension()).cm();
            // Inline function 'kotlin.math.min' call
            var b = ensureNotNull(model.settings.getDimension()).dm();
            var maxSize = tmp_0 * Math.min(tmp1, b);
            var shift = numberToInt(maxSize * ratio);
            var at = RectangularTransform.u2q();
            at.e1o(shift, shift);
            return at.v2q(top);
          }
        }
      }
    }
    return shape;
  }
  paintBackground(g, view, node, pass, passes, bounds, shape) {
    var shape_0 = shape;
    if (pass === (passes - 1 | 0)) {
      var model = ensureNotNull(view.j2p());
      shape_0 = this.getRenderedShape(view, model, node, shape_0);
      var bounds_0 = computeBounds(this, shape_0);
      g.w2q();
      g.x2q(shape_0);
      var column = model.settings.backgroundColumn;
      if (!(column == null)) {
        if (bounds_0.cm() > 1 && bounds_0.dm() > 1) {
          var columnSettings = model.settings.getColumnSettings(column);
          var font = columnSettings.getLabelingFont();
          if (bounds_0.cm() > 5 && bounds_0.dm() >= getFontSize(ensureNotNull(font))) {
            var elabel = ensureNotNull(ensureNotNull(view.n2p()).o2p(view, column, node, Dimension.bm(bounds_0.s20_1, bounds_0.t20_1)));
            var pf = g.q2p(elabel, bounds_0.s20_1, bounds_0.t20_1);
            var innerWidth = (bounds_0.s20_1 - elabel.getInsetRight() | 0) - elabel.getInsetLeft() | 0;
            var innerHeight = (bounds_0.t20_1 - elabel.getInsetTop() | 0) - elabel.getInsetBottom() | 0;
            var background = model.settings.getColumnSettings(column).getLabelingEffectColor();
            var foreground = model.settings.getColumnSettings(column).getLabelingForeground();
            var nodeColor = model.getColor(node);
            if (!(foreground == null)) {
              if (!(!(background == null) || nodeColor == null)) {
                foreground = ensureNotNull(model.settings.getColumnSettings(column).getLabelingContrastEnhancement()).p22(foreground, nodeColor);
              }
            }
            elabel.setFont(font);
            elabel.setForeground(ensureNotNull(foreground));
            elabel.setBackground(background);
            var preferredSize = pf.s2p();
            var fontSize;
            var tmp;
            if (!(columnSettings.getLabelingRendering() === Rendering_WordWrap_getInstance())) {
              var scaleX = innerWidth / (preferredSize.cm() - elabel.getInsetRight() - elabel.getInsetLeft());
              var scaleY = innerHeight / (preferredSize.dm() - elabel.getInsetTop() - elabel.getInsetBottom());
              // Inline function 'kotlin.math.min' call
              var scale = Math.min(scaleX, scaleY);
              var tmp2 = getFontSize(font);
              // Inline function 'kotlin.math.max' call
              var b = getFontSize(font) * scale * 1.0;
              tmp = Math.max(tmp2, b);
            } else {
              var tmp4 = getFontSize(font);
              // Inline function 'kotlin.math.max' call
              var b_0 = g.r2p(elabel, pf, font, Rectangle.from(0, 0, innerWidth, innerHeight), 0.9, true);
              tmp = Math.max(tmp4, b_0);
            }
            fontSize = tmp;
            if (fontSize >= getFontSize(font) / 4) {
              var scaledFont = font.u2d(fontSize);
              elabel.setFont(scaledFont);
              if (!(columnSettings.getLabelingRendering() === Rendering_WordWrap_getInstance())) {
                scaledFont = Companion_instance_67.h2q(bounds_0, font, elabel, pf, fontSize, false, true);
                elabel.setFont(scaledFont);
              }
              preferredSize = pf.s2p();
              var y = 0;
              switch (model.settings.getColumnSettings(column).getLabelingVerticalAlignment()) {
                case 1:
                  y = bounds_0.r20_1;
                  break;
                case 0:
                  var tmp_0;
                  if (bounds_0.t20_1 > preferredSize.dm()) {
                    tmp_0 = bounds_0.r20_1 + ((bounds_0.t20_1 - preferredSize.zl_1 | 0) / 2 | 0) | 0;
                  } else {
                    tmp_0 = bounds_0.r20_1;
                  }

                  y = tmp_0;
                  break;
                case 3:
                  var tmp_1;
                  if (bounds_0.t20_1 > preferredSize.zl_1) {
                    tmp_1 = bounds_0.r20_1 + (bounds_0.t20_1 - preferredSize.zl_1 | 0) | 0;
                  } else {
                    tmp_1 = bounds_0.r20_1;
                  }

                  y = tmp_1;
                  break;
              }
              var drawingArea = Companion_instance_65.b2p(shape_0, y, preferredSize.zl_1);
              g.w2p(elabel, drawingArea.q20_1, drawingArea.r20_1, drawingArea.s20_1, drawingArea.t20_1);
            }
          }
        }
      }
      g.y2q();
    }
  }
  getNestingBackground(node, model) {
    return model.settings.getColumnSettings(model.getGroupByColumn(node)).getNestingBackground();
  }
  paintLabel(g, view, node, pass, passes, bounds, shape) {
    var bounds_0 = bounds;
    var shape_0 = shape;
    if (pass === (passes - 1 | 0)) {
      var model = ensureNotNull(view.j2p());
      var algorithm;
      var parent = ensureNotNull(model.getParent(node));
      if (!(parent == null)) {
        var groupByColumn = model.getGroupByColumn(parent);
        var tmp;
        if (!(groupByColumn == null)) {
          var columnSettings = model.settings.getColumnSettings(groupByColumn);
          tmp = columnSettings.getAlgorithm();
        } else {
          tmp = model.settings.getDefaultColumnSettings().getAlgorithm();
        }
        algorithm = tmp;
        if (algorithm.s2o()) {
          shape_0 = this.getRenderedShape(view, model, node, shape_0);
          g.w2q();
          g.x2q(shape_0);
          bounds_0 = computeBounds(this, shape_0);
          ensureNotNull(model.settings.getColumnSettings(model.getGroupByColumn(node)).getLabeling()).i2p(g, shape_0, bounds_0, node, view);
          g.y2q();
        }
      }
    }
  }
  paintParentBorder(g, node, bounds, shape, model) {
    if (bounds.cm() > 1 && bounds.dm() > 1) {
      if (!model.isRoot(node) && !model.hasNoChildren(node)) {
        if (!model.filter.ol(node) && !model.search.ol(node)) {
          var borderThickness = model.settings.getColumnSettings(model.getGroupByColumn(node)).getBorderThickness();
          var tmp;
          if (borderThickness > 0) {
            tmp = !(shape instanceof TextShape);
          } else {
            tmp = false;
          }
          if (tmp) {
            g.w2q();
            g.z2q(borderThickness);
            g.a2r(model.settings.getColumnSettings(model.getGroupByColumn(node)).getBorderColor());
            g.b2r(shape);
            g.y2q();
          }
        }
      }
    }
  }
  paintParentHighlight(g2, view, node, pass, bounds, shape) {
    var model = ensureNotNull(view.j2p());
    if (!model.isRoot(node) && !model.filter.ol(node) && !model.search.ol(node)) {
      if (model.highlighting.a13() && model.highlighting.b13(node)) {
        g2.w2q();
        g2.z2q(2.0);
        g2.a2r(model.settings.getProbingColor());
        g2.b2r(shape);
        g2.y2q();
      }
    }
  }
}
class Companion_68 {
  constructor() {
    this.c2r_1 = null;
  }
}
class TreeMap {}
class AbstractTreeMap {
  static g2r() {
    var $this = createThis(this);
    $this.d2r_1 = null;
    $this.e2r_1 = null;
    $this.f2r_1 = null;
    return $this;
  }
  h2r(view) {
    if (!(this.d2r_1 === view)) {
      if (!(this.d2r_1 == null)) {
        ensureNotNull(this.d2r_1).i2r(null);
      }
      this.d2r_1 = view;
      if (!(view == null)) {
        view.i2r(this.model);
        ensureNotNull(this.d2r_1).j2r(Companion_instance_68.c2r_1);
      }
    }
  }
  k2r(_set____db54di) {
    return this.view = _set____db54di;
  }
  l2r() {
    return this.d2r_1;
  }
  m2r(controller) {
    if (!(this.e2r_1 === controller)) {
      if (!(this.e2r_1 == null)) {
        ensureNotNull(this.e2r_1).n2r(null);
      }
      this.e2r_1 = controller;
      if (!(controller == null)) {
        controller.n2r(this.view);
      }
    }
  }
  o2r(_set____db54di) {
    return this.controller = _set____db54di;
  }
  p2r() {
    return this.e2r_1;
  }
  q2r(model) {
    if (!(this.f2r_1 === model)) {
      this.f2r_1 = model;
      if (!(this.view == null)) {
        ensureNotNull(this.view).i2r(model);
      }
    }
  }
  i2r(_set____db54di) {
    return this.model = _set____db54di;
  }
  j2p() {
    return this.f2r_1;
  }
  setGroupBy(columns) {
    ensureNotNull(this.model).settings.setGroupBy(columns.slice());
  }
  setGroupByByNames(columnNames) {
    ensureNotNull(this.model).settings.setGroupByByNames(columnNames.slice());
  }
  setLabels(columns) {
    ensureNotNull(this.model).settings.setLabels(columns.slice());
  }
  setLabelsByNames(columnNames) {
    ensureNotNull(this.model).settings.setLabelsByNames(columnNames.slice());
  }
  setBackground(column) {
    ensureNotNull(this.model).settings.setBackground(column);
  }
  setBackgroundByName(columnName) {
    ensureNotNull(this.model).settings.setBackgroundByName(columnName);
  }
  setSize(column) {
    ensureNotNull(this.model).settings.setSize(column);
  }
  setSizeByName(columnName) {
    ensureNotNull(this.model).settings.setSizeByName(columnName);
  }
  setColor(column) {
    ensureNotNull(this.model).settings.setColor(column);
  }
  setColorByName(columnName) {
    ensureNotNull(this.model).settings.setColorByName(columnName);
  }
  setHeight(column) {
    ensureNotNull(this.model).settings.setHeight(column);
  }
  setHeightByName(columnName) {
    ensureNotNull(this.model).settings.setHeightByName(columnName);
  }
  setToolTip(columns) {
    ensureNotNull(this.model).settings.setToolTip(columns.slice());
  }
  setToolTipByNames(columnNames) {
    ensureNotNull(this.model).settings.setToolTipByNames(columnNames.slice());
  }
  setAlgorithm(algorithm) {
    ensureNotNull(this.model).settings.getDefaultColumnSettings().setAlgorithm(algorithm);
  }
  setAggregation(aggregation) {
    ensureNotNull(this.model).settings.getDefaultColumnSettings().setAggregation(aggregation);
  }
  setScale(scale) {
    ensureNotNull(this.model).settings.getDefaultColumnSettings().setScale(scale);
  }
  setNesting(nesting) {
    ensureNotNull(this.model).settings.getDefaultColumnSettings().setNesting(ensureNotNull(nesting));
  }
  setOrdering(ordering) {
    ensureNotNull(this.model).settings.getDefaultColumnSettings().setOrdering(ordering);
  }
  setDepth(depth) {
    ensureNotNull(this.model).settings.setDepth(depth);
  }
  setLabeling(labeling) {
    ensureNotNull(this.model).settings.getDefaultColumnSettings().setLabeling(labeling);
  }
  setRendering(rendering) {
    ensureNotNull(this.model).settings.rendering = rendering;
  }
  setLightSourceHeight(value) {
    ensureNotNull(this.model).settings.setLightSourceHeight(value);
  }
  setLightSourceAmbient(value) {
    ensureNotNull(this.model).settings.setLightSourceAmbient(value);
  }
  setLightSourceX(value) {
    ensureNotNull(this.model).settings.setLightSourceX(value);
  }
  setLightSourceY(value) {
    ensureNotNull(this.model).settings.setLightSourceY(value);
  }
  setLightSourceZ(value) {
    ensureNotNull(this.model).settings.setLightSourceZ(value);
  }
  setLabelingFont(font) {
    ensureNotNull(this.model).settings.getDefaultColumnSettings().setLabelingFont(font);
  }
  setLabelingForegroundColor(color) {
    ensureNotNull(this.model).settings.getDefaultColumnSettings().setLabelingForeground(color);
  }
  setLabelingBackgroundColor(color) {
    ensureNotNull(this.model).settings.getDefaultColumnSettings().setLabelingEffectColor(color);
  }
  setHeaderFont(font) {
    ensureNotNull(this.model).settings.getDefaultColumnSettings().setHeaderFont(font);
  }
  setHeaderForegroundColor(color) {
    ensureNotNull(this.model).settings.getDefaultColumnSettings().setHeaderForeground(color);
  }
  setHeaderBackgroundColor(color) {
    ensureNotNull(this.model).settings.getDefaultColumnSettings().setHeaderBackground(color);
  }
  get view() {
    return this.l2r();
  }
  set view(value) {
    this.h2r(value);
  }
  get controller() {
    return this.p2r();
  }
  set controller(value) {
    this.m2r(value);
  }
  get model() {
    return this.j2p();
  }
  set model(value) {
    this.q2r(value);
  }
  get component() {
    return this.r2r();
  }
}
class Companion_69 {
  constructor() {
    this.s2r_1 = 'algorithm';
    this.t2r_1 = 'aggregation';
    this.u2r_1 = 'scale';
    this.v2r_1 = 'nesting';
    this.w2r_1 = 'ordering';
    this.x2r_1 = 'orderingDirection';
    this.y2r_1 = 'orderingVerticalVanishingPoint';
    this.z2r_1 = 'orderingHorizontalVanishingPoint';
    this.a2s_1 = 'labeling';
    this.b2s_1 = 'labelingForeground';
    this.c2s_1 = 'labelingEffectColor';
    this.d2s_1 = 'labelingFont';
    this.e2s_1 = 'labelingEffect';
    this.f2s_1 = 'labelingHorizontalAlignment';
    this.g2s_1 = 'labelingVerticalAlignment';
    this.h2s_1 = 'labelingRendering';
    this.i2s_1 = 'labelingMinimumCharactersToDisplay';
    this.j2s_1 = 'labelingEffectOpacity';
    this.k2s_1 = 'labelingShrinkTextToFitShape';
    this.l2s_1 = 'labelingResizeTextToFitShape';
    this.m2s_1 = 'labelingFloat';
    this.n2s_1 = 'labelingContrastEnhancement';
    this.o2s_1 = 'nestingAmount';
    this.p2s_1 = 'nestingBackground';
    this.q2s_1 = 'headerForeground';
    this.r2s_1 = 'headerEffectColor';
    this.s2s_1 = 'headerBackground';
    this.t2s_1 = 'headerFont';
    this.u2s_1 = 'headerEffect';
    this.v2s_1 = 'headerHorizontalAlignment';
    this.w2s_1 = 'headerVerticalAlignment';
    this.x2s_1 = 'headerRendering';
    this.y2s_1 = 'headerMinimumCharactersToDisplay';
    this.z2s_1 = 'headerEffectOpacity';
    this.a2t_1 = 'headerInsets';
    this.b2t_1 = 'tooltipForeground';
    this.c2t_1 = 'tooltipFont';
    this.d2t_1 = 'tooltipRendering';
    this.e2t_1 = 'borderColor';
    this.f2t_1 = 'borderThickness';
    this.g2t_1 = 'format';
    this.h2t_1 = 'showLabel';
    this.i2t_1 = 'colormap';
    this.j2t_1 = 'overrideDefaults';
  }
}
class TreeMapColumnSettings {}
class AbstractTreeMapColumnSettings {
  setProperty(property, value) {
    switch (property) {
      case 'algorithm':
        this.setAlgorithm((!(value == null) ? isInterface(value, Algorithm) : false) ? value : THROW_CCE());
        break;
      case 'aggregation':
        this.setAggregation((!(value == null) ? isInterface(value, Aggregation) : false) ? value : THROW_CCE());
        break;
      case 'scale':
        this.setScale((!(value == null) ? isInterface(value, Scale) : false) ? value : THROW_CCE());
        break;
      case 'nesting':
        this.setNesting((!(value == null) ? isInterface(value, Nesting) : false) ? value : THROW_CCE());
        break;
      case 'ordering':
        this.setOrdering((!(value == null) ? isInterface(value, Ordering) : false) ? value : THROW_CCE());
        break;
      case 'orderingDirection':
        this.setOrderingDirection(value instanceof SortOrder ? value : THROW_CCE());
        break;
      case 'orderingHorizontalVanishingPoint':
        this.setOrderingHorizontalVanishingPoint((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'orderingVerticalVanishingPoint':
        this.setOrderingVerticalVanishingPoint((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'labeling':
        this.setLabeling((!(value == null) ? isInterface(value, Labeling) : false) ? value : THROW_CCE());
        break;
      case 'labelingForeground':
        this.setLabelingForeground(value instanceof CPColor ? value : THROW_CCE());
        break;
      case 'labelingEffectColor':
        this.setLabelingEffectColor(value instanceof CPColor ? value : THROW_CCE());
        break;
      case 'labelingFont':
        this.setLabelingFont(value instanceof CPFont ? value : THROW_CCE());
        break;
      case 'labelingEffect':
        this.setLabelingEffect(value instanceof Effect ? value : THROW_CCE());
        break;
      case 'labelingHorizontalAlignment':
        this.setLabelingHorizontalAlignment((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'labelingVerticalAlignment':
        this.setLabelingVerticalAlignment((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'labelingRendering':
        this.setLabelingRendering(value instanceof Rendering ? value : THROW_CCE());
        break;
      case 'labelingMinimumCharactersToDisplay':
        this.setLabelingMinimumCharactersToDisplay((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'labelingEffectOpacity':
        this.setLabelingEffectOpacity((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'labelingShrinkTextToFitShape':
        this.setLabelingShrinkTextToFitShape((!(value == null) ? typeof value === 'boolean' : false) ? value : THROW_CCE());
        break;
      case 'labelingResizeTextToFitShape':
        this.setLabelingResizeTextToFitShape((!(value == null) ? typeof value === 'boolean' : false) ? value : THROW_CCE());
        break;
      case 'labelingFloat':
        this.setLabelingFloat((!(value == null) ? typeof value === 'boolean' : false) ? value : THROW_CCE());
        break;
      case 'nestingAmount':
        this.setNestingAmount((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'nestingBackground':
        this.setNestingBackground(value instanceof CPColor ? value : THROW_CCE());
        break;
      case 'headerForeground':
        this.setHeaderForeground(value instanceof CPColor ? value : THROW_CCE());
        break;
      case 'headerEffectColor':
        this.setHeaderEffectColor(value instanceof CPColor ? value : THROW_CCE());
        break;
      case 'headerBackground':
        this.setHeaderBackground(value instanceof CPColor ? value : THROW_CCE());
        break;
      case 'headerFont':
        this.setHeaderFont(value instanceof CPFont ? value : THROW_CCE());
        break;
      case 'headerEffect':
        this.setHeaderEffect(value instanceof Effect ? value : THROW_CCE());
        break;
      case 'headerHorizontalAlignment':
        this.setHeaderHorizontalAlignment((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'headerVerticalAlignment':
        this.setHeaderVerticalAlignment((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'headerRendering':
        this.setHeaderRendering(value instanceof Rendering ? value : THROW_CCE());
        break;
      case 'headerMinimumCharactersToDisplay':
        this.setHeaderMinimumCharactersToDisplay((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'headerEffectOpacity':
        this.setHeaderEffectOpacity((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'tooltipForeground':
        this.setTooltipForeground(value instanceof CPColor ? value : THROW_CCE());
        break;
      case 'tooltipFont':
        this.setTooltipFont(value instanceof CPFont ? value : THROW_CCE());
        break;
      case 'tooltipRendering':
        this.setTooltipRendering(value instanceof Rendering ? value : THROW_CCE());
        break;
      case 'borderColor':
        this.setBorderColor(value instanceof CPColor ? value : THROW_CCE());
        break;
      case 'borderThickness':
        this.setBorderThickness((!(value == null) ? typeof value === 'number' : false) ? value : THROW_CCE());
        break;
      case 'format':
        this.setFormat((!(value == null) ? isInterface(value, CPFormat) : false) ? value : THROW_CCE());
        break;
      case 'showLabel':
        this.setShowLabel((!(value == null) ? typeof value === 'boolean' : false) ? value : THROW_CCE());
        break;
      case 'colormap':
        this.setColorMap((!(value == null) ? !(value == null) : false) ? value : THROW_CCE());
        break;
      default:
        println('Unknonw property ' + property);
        break;
    }
  }
  get properties() {
    return this.f24();
  }
}
class Mode_1 extends Enum {}
class Range {
  constructor($outer, _amount, _center, _start, _extent, _minRange, _maxRange, _maxExtent) {
    this.k2u_1 = $outer;
    this.b2u_1 = _amount;
    this.c2u_1 = _center;
    this.d2u_1 = _start;
    this.e2u_1 = _extent;
    this.f2u_1 = _minRange;
    this.g2u_1 = _maxRange;
    this.h2u_1 = _maxExtent;
    this.i2u_1 = 0.0;
    this.j2u_1 = 0.0;
  }
  m2u() {
    return this.i2u_1;
  }
  n2u() {
    return this.j2u_1;
  }
  l2u() {
    var range = this.e2u_1;
    var tmp0 = this.h2u_1;
    // Inline function 'kotlin.math.min' call
    var b = range + range * this.b2u_1;
    var newRange = Math.min(tmp0, b);
    if (!(this.c2u_1 == null)) {
      this.i2u_1 = this.c2u_1 - newRange * ((this.c2u_1 - this.d2u_1) / range);
      this.j2u_1 = this.c2u_1 + newRange * ((this.d2u_1 + this.e2u_1 - this.c2u_1) / range);
    } else {
      this.i2u_1 = this.d2u_1;
      this.j2u_1 = this.d2u_1 + newRange;
    }
    if (this.i2u_1 < this.f2u_1) {
      this.j2u_1 = this.j2u_1 + (this.f2u_1 - this.i2u_1);
      this.i2u_1 = this.f2u_1;
    }
    if (this.j2u_1 > this.g2u_1) {
      this.i2u_1 = this.i2u_1 - (this.j2u_1 - this.g2u_1);
      this.j2u_1 = this.g2u_1;
    }
    var tmp = this;
    var tmp2 = this.f2u_1;
    // Inline function 'kotlin.math.max' call
    var b_0 = this.i2u_1;
    tmp.i2u_1 = Math.max(tmp2, b_0);
    var tmp_0 = this;
    var tmp4 = this.g2u_1;
    // Inline function 'kotlin.math.min' call
    var b_1 = this.j2u_1;
    tmp_0.j2u_1 = Math.min(tmp4, b_1);
    return this;
  }
}
class DefaultMouseListener {
  constructor($outer) {
    this.x2t_1 = $outer;
    this.s2t_1 = null;
    this.t2t_1 = null;
    this.u2t_1 = null;
    this.v2t_1 = null;
    this.w2t_1 = null;
  }
  r2c(event) {
  }
  v2c(event) {
    if (!(this.x2t_1.k2t_1 == null) && !(ensureNotNull(this.x2t_1.k2t_1).j2p() == null)) {
      this.w2t_1 = new Point(event.w1l(), event.x1l());
      if (event.k2b() > 1) {
        ensureNotNull(this.x2t_1.k2t_1).w2v(ensureNotNull(this.w2t_1).h20_1, ensureNotNull(this.w2t_1).i20_1);
      } else {
        var bestrow = ensureNotNull(this.x2t_1.k2t_1).t2v(new Point(event.w1l(), event.x1l()));
        if (!(bestrow == null)) {
          if (!event.m2b()) {
            if (!ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).selection.b13(bestrow) || ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).selection.d13() > 1) {
              ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).selection.e13();
              ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).selection.f13(bestrow);
              ensureNotNull(this.x2t_1.k2t_1).u2v(ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).selection.b13(bestrow));
            }
          } else {
            ensureNotNull(this.x2t_1.k2t_1).u2v(!ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).selection.b13(bestrow));
            if (ensureNotNull(this.x2t_1.k2t_1).v2v()) {
              ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).selection.g13(bestrow, true);
            } else {
              ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).selection.g13(bestrow, false);
            }
          }
        } else {
          ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).selection.e13();
        }
      }
    }
  }
  t2c(event) {
    if (!(this.x2t_1.k2t_1 == null) && !(ensureNotNull(this.x2t_1.k2t_1).j2p() == null)) {
      if (!event.p2b()) {
        if (!(this.t2t_1 == null)) {
          if (event.q2b()) {
            ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).selection.e13();
            if (this.x2t_1.m2t_1) {
              addToSelection(this, ensureNotNull(this.t2t_1));
            } else {
              setSelection(this, this.t2t_1);
            }
            this.t2t_1 = null;
          }
        }
        if (!(this.u2t_1 == null)) {
          event.q2b();
          this.u2t_1 = null;
        }
        ensureNotNull(this.x2t_1.k2t_1).s28().v28();
      } else {
        if (this.x2t_1.n2t_1) {
          var node = ensureNotNull(this.x2t_1.k2t_1).t2v(new Point(event.w1l(), event.x1l()));
          setSelection(this, node);
        }
      }
      this.s2t_1 = null;
    }
  }
  w2c(event) {
    if (!(this.x2t_1.k2t_1 == null)) {
      if (!(ensureNotNull(this.x2t_1.k2t_1).j2p() == null)) {
        ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).probing.f13(ensureNotNull(this.x2t_1.k2t_1).t2v(new Point(event.w1l(), event.x1l())));
      }
    }
  }
  x2c(event) {
    if (!(this.x2t_1.k2t_1 == null)) {
      if (!(ensureNotNull(this.x2t_1.k2t_1).j2p() == null)) {
        ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).probing.e13();
      }
    }
  }
  q2c(event) {
    if (!(this.x2t_1.k2t_1 == null)) {
      if (!(ensureNotNull(this.x2t_1.k2t_1).j2p() == null)) {
        if (!(this.s2t_1 == null)) {
          switch (this.x2t_1.l2t_1.z2_1) {
            case 0:
              if (event.q2b()) {
                if (event.n2b() || event.o2b()) {
                  ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).probing.e13();
                  if (this.x2t_1.m2t_1) {
                    if (!ensureNotNull(this.x2t_1.k2t_1).s28().s28().a13()) {
                      ensureNotNull(this.x2t_1.k2t_1).s28().t28(ensureNotNull(this.w2t_1).h20_1, ensureNotNull(this.w2t_1).i20_1);
                    }
                    ensureNotNull(this.x2t_1.k2t_1).s28().u28(event.w1l(), event.x1l());
                    var r = ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).s28().w28());
                    var rect = Rectangle.from(numberToInt(r.w1l()), numberToInt(r.x1l()), numberToInt(r.cm()), numberToInt(r.dm()));
                    if (!(rect == null)) {
                      var toSelect = ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).x2v(rect));
                      if (event.m2b()) {
                        addToSelection_0(this, toSelect);
                      } else {
                        ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).selection.j13(toSelect);
                      }
                      this.t2t_1 = null;
                    }
                  }
                } else {
                  var observation = ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).t2v(new Point(event.w1l(), event.x1l())));
                  ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).probing.f13(observation);
                  this.t2t_1 = null;
                  var isAlreadySelected = !(ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).selection == null) && ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).selection.b13(observation);
                  if (!isAlreadySelected && !event.l2b()) {
                    ensureNotNull(ensureNotNull(this.x2t_1.k2t_1).j2p()).selection.e13();
                  }
                  if (event.l2b()) {
                    if (this.x2t_1.m2t_1) {
                      addToSelection(this, observation);
                    } else {
                      setSelection(this, observation);
                    }
                  } else {
                    if (isAlreadySelected) {
                      this.t2t_1 = observation;
                    } else {
                      if (this.x2t_1.m2t_1) {
                        addToSelection(this, observation);
                      } else {
                        setSelection(this, observation);
                      }
                    }
                  }
                }
              }

              break;
            case 2:
              if (event.q2b()) {
                var viewport = this.x2t_1.y2v();
                var world = this.x2t_1.z2v();
                var x1 = ensureNotNull(this.x2t_1.k2t_1).a2w().w1l().o15(ensureNotNull(this.s2t_1).w1l());
                var x2 = ensureNotNull(this.x2t_1.k2t_1).a2w().w1l().o15(event.w1l());
                var worldDiffX = x1 - x2;
                var xMin = viewport.f1m() + worldDiffX;
                var xMax = viewport.i1m() + worldDiffX;
                var y1 = ensureNotNull(this.x2t_1.k2t_1).a2w().x1l().o15(ensureNotNull(this.s2t_1).x1l());
                var y2 = ensureNotNull(this.x2t_1.k2t_1).a2w().x1l().o15(event.x1l());
                var worldDiffY = y1 - y2;
                var yMin = viewport.h1m() + worldDiffY;
                var yMax = viewport.h1m() + worldDiffY;
                if (xMin < world.f1m()) {
                  xMax = xMax + (world.f1m() - xMin);
                  xMin = world.f1m();
                }
                if (xMax > world.i1m()) {
                  xMin = xMin - (xMax - world.i1m());
                  xMax = world.i1m();
                }
                var tmp0 = world.f1m();
                // Inline function 'kotlin.math.max' call
                var b = xMin;
                xMin = Math.max(tmp0, b);
                var tmp2 = world.i1m();
                // Inline function 'kotlin.math.min' call
                var b_0 = xMax;
                xMax = Math.min(tmp2, b_0);
                if (yMin < world.h1m()) {
                  yMax = yMax + (world.h1m() - yMin);
                  yMin = world.h1m();
                }
                if (yMax > world.j1m()) {
                  yMin = yMin - (yMax - world.j1m());
                  yMax = world.j1m();
                }
                var tmp4 = world.h1m();
                // Inline function 'kotlin.math.max' call
                var b_1 = yMin;
                yMin = Math.max(tmp4, b_1);
                var tmp6 = world.j1m();
                // Inline function 'kotlin.math.min' call
                var b_2 = yMax;
                yMax = Math.min(tmp6, b_2);
                if (xMin < xMax && yMin < yMax) {
                  ensureNotNull(this.x2t_1.k2t_1).o2u(false, xMin, xMax, yMin, yMax);
                }
              }

              break;
            case 1:
              if (event.r2b()) {
                zoom(this.x2t_1, event.x1l() - ensureNotNull(this.s2t_1).x1l() / 100.0, ensureNotNull(this.x2t_1.k2t_1).a2w().w1l().o15(event.w1l()), ensureNotNull(this.x2t_1.k2t_1).a2w().x1l().o15(event.x1l()));
                this.u2t_1 = null;
              }

              break;
            default:
              noWhenBranchMatchedException();
              break;
          }
        }
        this.s2t_1 = event;
      }
    }
  }
  y2c(event) {
    var tmp0_safe_receiver = this.x2t_1.k2t_1;
    var closest = tmp0_safe_receiver == null ? null : tmp0_safe_receiver.t2v(new Point(event.w1l(), event.x1l()));
    var tmp1_safe_receiver = this.x2t_1.k2t_1;
    var tmp2_safe_receiver = tmp1_safe_receiver == null ? null : tmp1_safe_receiver.j2p();
    var tmp3_safe_receiver = tmp2_safe_receiver == null ? null : tmp2_safe_receiver.probing;
    if (tmp3_safe_receiver == null)
      null;
    else {
      tmp3_safe_receiver.f13(closest);
    }
  }
  b2d(event) {
    if (!(this.x2t_1.k2t_1 == null)) {
      var amount = event.a2d();
      zoom(this.x2t_1, amount / 500.0, ensureNotNull(this.x2t_1.k2t_1).a2w().w1l().o15(event.w1l()), ensureNotNull(this.x2t_1.k2t_1).a2w().x1l().o15(event.x1l()));
    }
  }
}
class AbstractTreeMapController$keyListener$1 {
  constructor(this$0, $view) {
    this.c2w_1 = this$0;
    this.d2w_1 = $view;
    this.b2w_1 = null;
  }
  c2d(event) {
    if (event.h2c() === 83) {
      if (this.b2w_1 == null) {
        this.b2w_1 = this.c2w_1.l2t_1;
      }
      this.c2w_1.l2t_1 = Mode_Selection_getInstance();
    }
    if (event.h2c() === 90 || event.h2c() === 16) {
      if (this.b2w_1 == null) {
        this.b2w_1 = this.c2w_1.l2t_1;
      }
      this.c2w_1.l2t_1 = Mode_Zooming_getInstance();
    }
    if (event.h2c() === 90 || event.h2c() === 32) {
      if (this.b2w_1 == null) {
        this.b2w_1 = this.c2w_1.l2t_1;
      }
      this.c2w_1.l2t_1 = Mode_Panning_getInstance();
    }
    if (event.h2c() === 40) {
      this.d2w_1.e2w();
    }
    if (event.h2c() === 38) {
      this.d2w_1.f2w();
    }
    if (event.h2c() === 34) {
      this.d2w_1.g2w();
    }
    if (event.h2c() === 33) {
      this.d2w_1.h2w();
    }
  }
}
class AbstractTreeMapController$setView$1 {
  constructor(this$0) {
    this.i2w_1 = this$0;
  }
  e2d(event) {
    openPopupMenu(this.i2w_1, event);
  }
}
class AbstractTreeMapController$openPopupMenu$drillDownCommand$1 extends AbstractUICommand {
  static x2u(this$0, $x, $y, $box) {
    if ($box === VOID)
      $box = {};
    $box.u2u_1 = this$0;
    $box.v2u_1 = $x;
    $box.w2u_1 = $y;
    return this.el('Drill down', $box);
  }
}
class AbstractTreeMapController$openPopupMenu$drillUpCommand$1 extends AbstractUICommand {
  static e2v(this$0, $box) {
    if ($box === VOID)
      $box = {};
    $box.d2v_1 = this$0;
    return this.el('Drill up', $box);
  }
}
class AbstractTreeMapController$openPopupMenu$zoomInCommand$1 extends AbstractUICommand {
  static l2v(this$0, $box) {
    if ($box === VOID)
      $box = {};
    $box.k2v_1 = this$0;
    return this.el('Zoom in', $box);
  }
}
class AbstractTreeMapController$openPopupMenu$zoomOutCommand$1 extends AbstractUICommand {
  static s2v(this$0, $box) {
    if ($box === VOID)
      $box = {};
    $box.r2v_1 = this$0;
    return this.el('Zoom out', $box);
  }
}
class AbstractTreeMapController {
  constructor(view) {
    this.k2t_1 = null;
    this.l2t_1 = Mode_Selection_getInstance();
    this.m2t_1 = true;
    this.n2t_1 = false;
    this.o2t_1 = true;
    this.p2t_1 = false;
    this.q2t_1 = new DefaultMouseListener(this);
    var tmp = this;
    tmp.r2t_1 = new AbstractTreeMapController$keyListener$1(this, view);
    this.n2r(view);
  }
  a2u(center) {
    // Inline function 'kotlin.math.tanh' call
    var x = center * 3;
    return tanh(x);
  }
  n2r(view) {
    this.k2t_1 = view;
    if (!(view == null)) {
      view.w2a(this.r2t_1);
      view.t2a(this.q2t_1);
      view.u2a(this.q2t_1);
      view.v2a(this.q2t_1);
      view.x2a(new AbstractTreeMapController$setView$1(this));
    }
  }
  y2v() {
    return Double_3.p1m(ensureNotNull(this.k2t_1).j2w().start, ensureNotNull(this.k2t_1).j2w().start, ensureNotNull(this.k2t_1).j2w().extent, ensureNotNull(this.k2t_1).j2w().extent);
  }
  z2v() {
    return Double_3.p1m(ensureNotNull(this.k2t_1).k2w().bn(), ensureNotNull(this.k2t_1).k2w().bn(), ensureNotNull(this.k2t_1).k2w().cn() - ensureNotNull(this.k2t_1).j2w().bn(), ensureNotNull(this.k2t_1).k2w().cn() - ensureNotNull(this.k2t_1).k2w().bn());
  }
}
class NodeField {
  constructor($outer, node, field) {
    this.o2y_1 = $outer;
    this.m2y_1 = node;
    this.n2y_1 = field;
  }
  equals(other) {
    if (this === other)
      return true;
    if (other == null || !getKClassFromExpression(this).equals(getKClassFromExpression(other)))
      return false;
    if (!(other instanceof NodeField))
      THROW_CCE();
    if (!equals(this.m2y_1, other.m2y_1))
      return false;
    if (!equals(this.n2y_1, other.n2y_1))
      return false;
    return true;
  }
  hashCode() {
    var tmp0_safe_receiver = this.m2y_1;
    var tmp1_elvis_lhs = tmp0_safe_receiver == null ? null : hashCode(tmp0_safe_receiver);
    var result = tmp1_elvis_lhs == null ? 0 : tmp1_elvis_lhs;
    var tmp = imul_0(31, result);
    // Inline function 'kotlin.hashCode' call
    var tmp0_safe_receiver_0 = this.n2y_1;
    var tmp1_elvis_lhs_0 = tmp0_safe_receiver_0 == null ? null : hashCode(tmp0_safe_receiver_0);
    result = tmp + (tmp1_elvis_lhs_0 == null ? 0 : tmp1_elvis_lhs_0) | 0;
    return result;
  }
}
class Worker {
  constructor($outer) {
    this.m2w_1 = $outer;
    this.l2w_1 = false;
  }
  d17() {
    return this.l2w_1;
  }
  p2y() {
    try {
      if (this.m2w_1.l2x_1 || this.m2w_1.m2x_1 || this.m2w_1.n2x_1) {
        if (!this.l2w_1) {
          this.q2y(0);
          var newRoot;
          var newCurrentRoot;
          if (this.m2w_1.l2x_1) {
            if (!this.l2w_1) {
              var groupByTreeMapColumns = this.m2w_1.settings.groupByColumns;
              var tmp;
              if (groupByTreeMapColumns == null || groupByTreeMapColumns.a1() === 0) {
                var tmp_0 = this.m2w_1.settings.sizeColumn;
                tmp = this.m2w_1.r2y((tmp_0 == null ? true : !(tmp_0 == null)) ? tmp_0 : THROW_CCE());
              } else {
                tmp = this.m2w_1.r2y(groupByTreeMapColumns.b1(0));
              }
              newRoot = tmp;
              newCurrentRoot = newRoot;
              this.m2w_1.s2y(newRoot, this);
              if (this.l2w_1) {
                this.m2w_1.l2x_1 = true;
                return Unit_instance;
              } else {
                this.m2w_1.root = newRoot;
                this.m2w_1.o2x_1 = true;
                this.m2w_1.l2x_1 = false;
                this.m2w_1.m2x_1 = true;
                this.m2w_1.i2x_1.vo(newCurrentRoot);
              }
            } else {
              newRoot = this.m2w_1.root;
              newCurrentRoot = this.m2w_1.i2x_1.r2();
            }
          } else {
            newRoot = this.m2w_1.root;
            newCurrentRoot = this.m2w_1.i2x_1.r2();
          }
          if (this.m2w_1.m2x_1) {
            if (!this.l2w_1 && !(newCurrentRoot == null) && !(this.m2w_1.settings.getDimension() == null)) {
              this.m2w_1.t2y(newCurrentRoot, this);
            }
            if (this.l2w_1) {
              this.m2w_1.m2x_1 = true;
              return Unit_instance;
            } else {
              this.m2w_1.p2x_1 = true;
              this.m2w_1.m2x_1 = false;
              this.m2w_1.n2x_1 = true;
            }
          }
          if (this.m2w_1.n2x_1) {
            if (!this.l2w_1 && !(newRoot == null)) {
              this.m2w_1.u2y();
              this.m2w_1.v2y(newRoot, this);
            }
            if (this.l2w_1) {
              this.m2w_1.n2x_1 = true;
              return Unit_instance;
            } else {
              this.m2w_1.q2x_1 = true;
              this.m2w_1.n2x_1 = false;
            }
          }
          if (!this.l2w_1) {
            this.m2w_1.root = newRoot;
            this.m2w_1.i2x_1.vo(newCurrentRoot);
            this.m2w_1.w2y();
            this.m2w_1.x2y(new TreeMapEvent(this.m2w_1.o2x_1, this.m2w_1.p2x_1, this.m2w_1.q2x_1));
            this.m2w_1.o2x_1 = false;
            this.m2w_1.p2x_1 = false;
            this.m2w_1.q2x_1 = false;
            this.q2y(100);
          }
        }
      }
    } catch ($p) {
      if ($p instanceof Error) {
        var e = $p;
        printStackTrace(e);
      } else {
        throw $p;
      }
    }
    return Unit_instance;
  }
  a17() {
    this.p2y();
    return Unit_instance;
  }
  c18() {
    this.l2w_1 = true;
    this.q2y(0);
  }
  q2y(progress) {
    this.m2w_1.q2y(progress);
  }
}
class Companion_70 {
  constructor() {
    this.y2y_1 = 40;
    this.z2y_1 = 'progress';
    this.a2z_1 = 'currentRoot';
  }
}
class AbstractTreeMapModel$colorMapListener$1 {
  constructor(this$0) {
    this.b2z_1 = this$0;
  }
  o1e(event) {
    this.b2z_1.c2z();
  }
}
class AbstractTreeMapModel$colorProvider$1 {
  d2z(node) {
    return ensureNotNull(node.e2z());
  }
  f2z(element) {
    return this.d2z(element instanceof AbstractTreeMapNode ? element : THROW_CCE());
  }
}
class AbstractTreeMapModel$groupByColumns$1 {
  constructor(this$0) {
    this.g2z_1 = this$0;
  }
  h2z(column) {
    return column == null || !this.g2z_1.isEveryValueUnique(column) || this.g2z_1.w2x_1.s17(ensureNotNull(this.g2z_1.getColumnClass(column)));
  }
  pk(var1) {
    return this.h2z((var1 == null ? true : !(var1 == null)) ? var1 : THROW_CCE());
  }
}
class AbstractTreeMapModel$sizeColumns$1 {
  constructor(this$0) {
    this.i2z_1 = this$0;
  }
  h2z(column) {
    return column == null || this.i2z_1.isNumericType(column) || this.i2z_1.isTemporalType(column);
  }
  pk(var1) {
    return this.h2z((var1 == null ? true : !(var1 == null)) ? var1 : THROW_CCE());
  }
}
class AbstractTreeMapModel$colorColumns$1 {
  constructor(this$0) {
    this.j2z_1 = this$0;
  }
  h2z(column) {
    return column == null || !this.j2z_1.w2x_1.s17(ensureNotNull(this.j2z_1.getColumnClass(column)));
  }
  pk(var1) {
    return this.h2z((var1 == null ? true : !(var1 == null)) ? var1 : THROW_CCE());
  }
}
class AbstractTreeMapModel$heightColumns$1 {
  constructor(this$0) {
    this.k2z_1 = this$0;
  }
  h2z(column) {
    return column == null || this.k2z_1.isNumericType(column) || this.k2z_1.isTemporalType(column);
  }
  pk(var1) {
    return this.h2z((var1 == null ? true : !(var1 == null)) ? var1 : THROW_CCE());
  }
}
class AbstractTreeMapModel$labelsColumns$1 {
  constructor(this$0) {
    this.l2z_1 = this$0;
  }
  h2z(column) {
    return !(column == null) && !this.l2z_1.isVisualType(column);
  }
  pk(var1) {
    return this.h2z((var1 == null ? true : !(var1 == null)) ? var1 : THROW_CCE());
  }
}
class AbstractTreeMapModel$tooltipColumns$1 {
  constructor(this$0) {
    this.m2z_1 = this$0;
  }
  h2z(column) {
    return !(column == null) && !this.m2z_1.isVisualType(column);
  }
  pk(var1) {
    return this.h2z((var1 == null ? true : !(var1 == null)) ? var1 : THROW_CCE());
  }
}
class AbstractTreeMapModel$parentPreorderEnumeration$1 {
  constructor(this$0, $parent) {
    this.n2z_1 = this$0;
    this.o2z_1 = $parent;
  }
  x() {
    return new ParentPreorderIterator(this.n2z_1, this.o2z_1);
  }
}
class AbstractTreeMapModel$preorderEnumeration$1 {
  constructor(this$0, $parent) {
    this.p2z_1 = this$0;
    this.q2z_1 = $parent;
  }
  x() {
    return new PreorderIterator(this.p2z_1, this.q2z_1);
  }
}
class AbstractTreeMapModel$breadthFirstIterator$1 {
  constructor(this$0, $parent) {
    this.r2z_1 = this$0;
    this.s2z_1 = $parent;
  }
  x() {
    return new BreadthFirstIterator(this.r2z_1, this.s2z_1);
  }
}
class AbstractTreeMapModel$depthFirstIterator$1 {
  constructor(this$0, $parent) {
    this.t2z_1 = this$0;
    this.u2z_1 = $parent;
  }
  x() {
    return new PostorderIterator(this.t2z_1, this.u2z_1);
  }
}
class AbstractTreeMapModel$1 {
  constructor(this$0) {
    this.v2z_1 = this$0;
  }
  y17() {
    this.v2z_1.w2z();
  }
}
class AbstractTreeMapModel$2 {
  constructor(this$0) {
    this.x2z_1 = this$0;
  }
  y2z(event) {
    if (event.g30()) {
      this.x2z_1.f30();
    } else if (event.e30()) {
      this.x2z_1.d30();
    } else if (event.c30()) {
      this.x2z_1.c2z();
    } else {
      this.x2z_1.x2y(new TreeMapEvent(false, false, false));
    }
  }
}
class AbstractTreeMapModel$3 {
  constructor(this$0) {
    this.h30_1 = this$0;
  }
  i30(event) {
    var node = event.c15_1;
    if (!(node == null)) {
      var toHighlight = ArrayList.e1();
      do {
        toHighlight.o(ensureNotNull(node));
        node = this.h30_1.getParent(node);
      }
       while (!(node == null));
      this.h30_1.highlighting.j13(toHighlight);
    } else {
      this.h30_1.highlighting.e13();
    }
  }
  t13(event) {
    return this.i30(event);
  }
}
class AbstractTreeMapModel$4 {
  constructor(this$0) {
    this.j30_1 = this$0;
  }
  k30(name, event) {
    if (equals('aggregation', name)) {
      this.j30_1.w2y();
    }
  }
  zx(name, event) {
    return this.k30((name == null ? true : typeof name === 'string') ? name : THROW_CCE(), event);
  }
}
class AbstractTreeMapModel$5 {
  constructor(this$0) {
    this.l30_1 = this$0;
  }
}
class AbstractTreeMapModel$6 {
  constructor(this$0) {
    this.m30_1 = this$0;
  }
}
class AbstractTreeMapModel$7 {
  constructor(this$0) {
    this.n30_1 = this$0;
  }
  o30(event) {
    this.n30_1.selection.e13();
    this.n30_1.d30();
  }
  qo(event) {
    return this.o30(event);
  }
}
class TreeMapModel {}
class AbstractTreeMapModel {
  constructor() {
    this.n2w_1 = Companion_getInstance_54().a1g_1;
    this.o2w_1 = Companion_getInstance_55().a24_1;
    this.p2w_1 = new ColorMapFactory(Companion_getInstance_53().instance);
    this.q2w_1 = this.p30();
    this.r2w_1 = new SimpleProperties();
    this.s2w_1 = HashMap.d8();
    this.t2w_1 = HashMap.d8();
    this.u2w_1 = SimpleSingleSelection.x14(null);
    this.v2w_1 = SimpleSelection.m14();
    this.w2w_1 = SimpleSelection.m14();
    this.x2w_1 = new SimpleFilter();
    this.y2w_1 = new SimpleFilter();
    this.b2x_1 = true;
    this.c2x_1 = true;
    this.d2x_1 = true;
    this.f2x_1 = CollectionFactory_instance.r16();
    var tmp = this;
    tmp.g2x_1 = new AbstractTreeMapModel$colorMapListener$1(this);
    this.h2x_1 = null;
    this.i2x_1 = this.properties.vy('currentRoot', null);
    this.j2x_1 = null;
    this.k2x_1 = null;
    this.l2x_1 = true;
    this.m2x_1 = true;
    this.n2x_1 = true;
    this.o2x_1 = false;
    this.p2x_1 = false;
    this.q2x_1 = false;
    this.r2x_1 = 0.0;
    this.s2x_1 = 0.0;
    this.t2x_1 = 0.0;
    this.u2x_1 = this.properties.vy('progress', 0);
    this.v2x_1 = 0.0;
    this.w2x_1 = Companion_getInstance_28().h17_1;
    var tmp_0 = this;
    tmp_0.y2x_1 = new AbstractTreeMapModel$colorProvider$1();
    this.z2x_1 = HashMap.d8();
    this.a2y_1 = HashMap.d8();
    this.b2y_1 = HashMap.d8();
    this.x2x_1 = Companion_getInstance_29().k18_1;
    this.z2w_1 = CollectionFactory_instance.ll();
    this.e2x_1 = this.b2x_1 ? Companion_getInstance_28().h17_1.k17(ensureNotNull(getKClassFromExpression(getSelf(this)).td()), 0, 1) : null;
    var tmp_1 = this;
    tmp_1.a2x_1 = this.w2x_1.m17('TreeMapModelUpdater', 40, true, new AbstractTreeMapModel$1(this));
    var tmp_2 = this.settings;
    tmp_2.addTreeMapSettingsListener(new AbstractTreeMapModel$2(this));
    this.u2y();
    var tmp_3 = this.probing;
    tmp_3.q13(new AbstractTreeMapModel$3(this));
    var tmp_4 = this.settings.properties;
    tmp_4.cy(new AbstractTreeMapModel$4(this));
    var tmp_5 = this.filter;
    tmp_5.ml(new AbstractTreeMapModel$5(this));
    var tmp_6 = this.search;
    tmp_6.ml(new AbstractTreeMapModel$6(this));
    this.i2x_1.uo(new AbstractTreeMapModel$7(this));
  }
  q30() {
    return this.n2w_1;
  }
  r30() {
    return this.o2w_1;
  }
  s30() {
    return this.p2w_1;
  }
  t30() {
    return this.q2w_1;
  }
  f24() {
    return this.r2w_1;
  }
  u30() {
    return this.s2w_1;
  }
  v30() {
    return this.t2w_1;
  }
  w30() {
    return this.u2w_1;
  }
  x30() {
    return this.v2w_1;
  }
  y30() {
    return this.w2w_1;
  }
  z30() {
    return this.x2w_1;
  }
  a31() {
    return this.y2w_1;
  }
  b31(_set____db54di) {
    this.h2x_1 = _set____db54di;
  }
  c31() {
    return this.h2x_1;
  }
  d31(_set____db54di) {
    this.j2x_1 = _set____db54di;
  }
  e31() {
    return this.j2x_1;
  }
  f31(_set____db54di) {
    this.k2x_1 = _set____db54di;
  }
  g31() {
    return this.k2x_1;
  }
  x2g() {
    return this.n2x_1 || this.m2x_1 || this.l2x_1;
  }
  h31(_set____db54di) {
    this.r2x_1 = _set____db54di;
  }
  i31() {
    return this.r2x_1;
  }
  j31(_set____db54di) {
    this.s2x_1 = _set____db54di;
  }
  k31() {
    return this.s2x_1;
  }
  l31(_set____db54di) {
    this.t2x_1 = _set____db54di;
  }
  m31() {
    return this.t2x_1;
  }
  n31(_set____db54di) {
    this.v2x_1 = _set____db54di;
  }
  o31() {
    return this.v2x_1;
  }
  p31() {
    return this.w2x_1;
  }
  q31() {
    return this.x2x_1;
  }
  r31(colorProvider) {
    if (!(this.y2x_1 === colorProvider)) {
      this.y2x_1 = colorProvider;
      this.c2z();
    }
  }
  s31(_set____db54di) {
    return this.colorProvider = _set____db54di;
  }
  t31() {
    return this.y2x_1;
  }
  u31() {
    var tmp = Iterables_instance;
    var tmp_0 = this.getTreeMapColumnsInclude(true);
    return tmp.ok(tmp_0, new AbstractTreeMapModel$groupByColumns$1(this));
  }
  v31() {
    var tmp = Iterables_instance;
    var tmp_0 = this.getTreeMapColumnsInclude(true);
    return tmp.ok(tmp_0, new AbstractTreeMapModel$sizeColumns$1(this));
  }
  w31() {
    var tmp = Iterables_instance;
    var tmp_0 = this.getTreeMapColumnsInclude(true);
    return tmp.ok(tmp_0, new AbstractTreeMapModel$colorColumns$1(this));
  }
  x31() {
    var tmp = Iterables_instance;
    var tmp_0 = this.getTreeMapColumnsInclude(true);
    return tmp.ok(tmp_0, new AbstractTreeMapModel$heightColumns$1(this));
  }
  y31() {
    var tmp = Iterables_instance;
    var tmp_0 = this.getTreeMapColumnsInclude(false);
    return tmp.ok(tmp_0, new AbstractTreeMapModel$labelsColumns$1(this));
  }
  z31() {
    var tmp = Iterables_instance;
    var tmp_0 = this.getTreeMapColumnsInclude(false);
    return tmp.ok(tmp_0, new AbstractTreeMapModel$tooltipColumns$1(this));
  }
  getTreeMapColumnsInclude(includeNone) {
    var list = ArrayList.e1();
    if (includeNone) {
      list.o(null);
    }
    var inductionVariable = 0;
    var last = this.columnCount;
    if (inductionVariable < last)
      do {
        var c = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        list.o(this.getTreeMapColumn(c));
      }
       while (inductionVariable < last);
    return list;
  }
  isNumericType(column) {
    var type = this.getColumnClass(column);
    return !(type == null) && this.w2x_1.p17(type);
  }
  isTemporalType(column) {
    var type = this.getColumnClass(column);
    return !(type == null) && this.w2x_1.q17(type);
  }
  isVisualType(column) {
    var type = this.getColumnClass(column);
    return !(type == null) && this.w2x_1.r17(type);
  }
  a32() {
    var groupBy;
    var label;
    var background;
    var color;
    var size;
    var height = null;
    var firstCategorical = null;
    var secondCategorical = null;
    var inductionVariable = 0;
    var last = this.columnCount;
    if (inductionVariable < last)
      $l$loop: do {
        var c = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var column = this.getTreeMapColumn(c);
        if (equals(this.getColumnClass(ensureNotNull(column)), PrimitiveClasses_getInstance().ne())) {
          if (firstCategorical == null) {
            firstCategorical = column;
          } else {
            if (!this.isEveryValueUnique(column)) {
              secondCategorical = column;
            }
            break $l$loop;
          }
        }
      }
       while (inductionVariable < last);
    var inductionVariable_0 = 0;
    var last_0 = this.columnCount;
    if (inductionVariable_0 < last_0)
      $l$loop_0: do {
        var c_0 = inductionVariable_0;
        inductionVariable_0 = inductionVariable_0 + 1 | 0;
        var column_0 = this.getTreeMapColumn(c_0);
        if (this.w2x_1.s17(ensureNotNull(this.getColumnClass(ensureNotNull(column_0))))) {
          secondCategorical = column_0;
          break $l$loop_0;
        }
      }
       while (inductionVariable_0 < last_0);
    label = firstCategorical;
    groupBy = secondCategorical;
    var firstVisual = null;
    var inductionVariable_1 = 0;
    var last_1 = this.columnCount;
    if (inductionVariable_1 < last_1)
      $l$loop_1: do {
        var c_1 = inductionVariable_1;
        inductionVariable_1 = inductionVariable_1 + 1 | 0;
        var column_1 = this.getTreeMapColumn(c_1);
        if (!(column_1 == null) && this.isVisualType(column_1) && !this.w2x_1.o17(getKClass(CPColor), ensureNotNull(this.getColumnClass(column_1)))) {
          if (firstVisual == null) {
            firstVisual = column_1;
            break $l$loop_1;
          }
        }
      }
       while (inductionVariable_1 < last_1);
    background = firstVisual;
    var firstNumerical = null;
    var secondNumerical = null;
    var inductionVariable_2 = 0;
    var last_2 = this.columnCount;
    if (inductionVariable_2 < last_2)
      $l$loop_2: do {
        var c_2 = inductionVariable_2;
        inductionVariable_2 = inductionVariable_2 + 1 | 0;
        var column_2 = this.getTreeMapColumn(c_2);
        if (this.w2x_1.p17(ensureNotNull(this.getColumnClass(ensureNotNull(column_2))))) {
          if (firstNumerical == null) {
            firstNumerical = column_2;
          } else {
            secondNumerical = column_2;
            break $l$loop_2;
          }
        }
      }
       while (inductionVariable_2 < last_2);
    var firstColor = null;
    var inductionVariable_3 = 0;
    var last_3 = this.columnCount;
    if (inductionVariable_3 < last_3)
      $l$loop_3: do {
        var c_3 = inductionVariable_3;
        inductionVariable_3 = inductionVariable_3 + 1 | 0;
        var column_3 = this.getTreeMapColumn(c_3);
        if (this.w2x_1.o17(getKClass(CPColor), ensureNotNull(this.getColumnClass(ensureNotNull(column_3))))) {
          firstColor = column_3;
          break $l$loop_3;
        }
      }
       while (inductionVariable_3 < last_3);
    size = firstNumerical;
    var tmp;
    if (!(firstColor == null)) {
      tmp = firstColor;
    } else {
      var tmp_0;
      if (!(secondNumerical == null)) {
        tmp_0 = secondNumerical;
      } else {
        tmp_0 = firstNumerical;
      }
      tmp = tmp_0;
    }
    color = tmp;
    if (!(groupBy == null)) {
      var columns = listOf(groupBy);
      this.settings.groupByColumns = columns;
    } else {
      this.f30();
    }
    var columns_0 = listOfNotNull(label);
    this.settings.labelsColumns = columns_0;
    this.settings.sizeColumn = size;
    this.settings.heightColumn = height;
    this.settings.colorColumn = color;
    this.settings.backgroundColumn = background;
    var count = 0;
    // Inline function 'kotlin.run' call
    // Inline function 'com.treemap.AbstractTreeMapModel.initDefaults.<anonymous>' call
    var i = 0;
    while (i < this.columnCount && count < 5) {
      var column_4 = this.getTreeMapColumn(i);
      if (this.w2x_1.o17(PrimitiveClasses_getInstance().ne(), ensureNotNull(this.getColumnClass(ensureNotNull(column_4)))) || this.isNumericType(column_4)) {
        this.settings.setShowPopup(this.getTreeMapColumn(i), true);
        count = count + 1 | 0;
      }
      i = i + 1 | 0;
    }
    var inductionVariable_4 = 0;
    var last_4 = this.columnCount;
    if (inductionVariable_4 < last_4)
      do {
        var i_0 = inductionVariable_4;
        inductionVariable_4 = inductionVariable_4 + 1 | 0;
        var column_5 = this.getTreeMapColumn(i_0);
        if (this.isNumericType(ensureNotNull(column_5))) {
          this.settings.getColumnSettings(column_5).setShowLabel(true);
        }
      }
       while (inductionVariable_4 < last_4);
  }
  f30() {
    cancelDoUpdate(this);
    this.l2x_1 = true;
    if (this.c2x_1) {
      this.a2x_1.g15();
    } else {
      this.w2z();
    }
  }
  w2z() {
    var dimension = this.settings.getDimension();
    if (!(dimension == null) && dimension.cm() > 0 && dimension.dm() > 0) {
      if (!(this.workerFuture == null) && ensureNotNull(this.workerFuture).b17()) {
        try {
          ensureNotNull(this.workerFuture).xk();
        } catch ($p) {
          if ($p instanceof IllegalStateException) {
            var e = $p;
          } else {
            if ($p instanceof Exception) {
              var e_0 = $p;
              printStackTrace(e_0);
            } else {
              throw $p;
            }
          }
        }
      }
      cancelDoUpdate(this);
      this.worker = new Worker(this);
      if (this.b2x_1 && !(this.e2x_1 == null)) {
        try {
          this.workerFuture = this.e2x_1.e17(this.worker);
        } catch ($p) {
          if ($p instanceof Error) {
            var t = $p;
            printStackTrace(t);
          } else {
            throw $p;
          }
        }
      } else {
        try {
          ensureNotNull(this.worker).p2y();
          this.worker = null;
        } catch ($p) {
          if ($p instanceof Error) {
            var e_1 = $p;
            printStackTrace(e_1);
          } else {
            throw $p;
          }
        }
      }
    }
  }
  p30() {
    return new DefaultTreeMapSettings(this, this.colorFactory, this.o2w_1, this.p2w_1);
  }
  w2y() {
    this.f2x_1.o5();
  }
  c2z() {
    cancelDoUpdate(this);
    this.n2x_1 = true;
    if (this.c2x_1) {
      this.a2x_1.g15();
    } else {
      this.w2z();
    }
  }
  u2y() {
    var lx = this.settings.getLightSourceX();
    var ly = this.settings.getLightSourceY();
    var lz = this.settings.getLightSourceZ();
    // Inline function 'kotlin.math.sqrt' call
    var x = lx * lx + ly * ly + lz * lz;
    var len = Math.sqrt(x);
    this.normalizedLightSourceX = lx / len;
    this.normalizedLightSourceY = ly / len;
    this.normalizedLightSourceZ = lz / len;
  }
  b32() {
    var _iterator__ex2g4s = this.z2w_1.x();
    while (_iterator__ex2g4s.y()) {
      var treeMapListener = _iterator__ex2g4s.z();
      treeMapListener.c32();
    }
  }
  x2y(event) {
    var _iterator__ex2g4s = this.z2w_1.x();
    while (_iterator__ex2g4s.y()) {
      var treeMapListener = _iterator__ex2g4s.z();
      treeMapListener.d32(event);
    }
  }
  getTreeMapColumnsByIndices(columns) {
    // Inline function 'kotlin.collections.mapIndexed' call
    // Inline function 'kotlin.collections.mapIndexedTo' call
    var destination = ArrayList.o7(columns.length);
    var index = 0;
    var inductionVariable = 0;
    var last = columns.length;
    while (inductionVariable < last) {
      var item = columns[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      index = index + 1 | 0;
      // Inline function 'com.treemap.AbstractTreeMapModel.getTreeMapColumns.<anonymous>' call
      var tmp$ret$0 = this.getTreeMapColumn(columns[item]);
      destination.o(tmp$ret$0);
    }
    var mapIndexed = destination;
    return filterNotNull(mapIndexed);
  }
  getTreeMapColumns(columns) {
    return filterNotNull(toList(columns));
  }
  getTreeMapColumnsByNames(columnNames) {
    // Inline function 'kotlin.collections.mapIndexed' call
    // Inline function 'kotlin.collections.mapIndexedTo' call
    var destination = ArrayList.o7(columnNames.length);
    var index = 0;
    var inductionVariable = 0;
    var last = columnNames.length;
    while (inductionVariable < last) {
      var item = columnNames[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      index = index + 1 | 0;
      // Inline function 'com.treemap.AbstractTreeMapModel.getTreeMapColumns.<anonymous>' call
      var tmp$ret$0 = this.getTreeMapColumnByName(item);
      destination.o(tmp$ret$0);
    }
    var mapIndexed = destination;
    return filterNotNull(mapIndexed);
  }
  t2y(parent, worker) {
    this.maximumSize = 0.0;
    this.e32(parent, worker);
    this.w2y();
    var dimension = this.settings.getDimension();
    var tmp;
    if (!(dimension == null)) {
      var viewport = this.y2v();
      this.f32(parent, viewport);
      tmp = this.g32(parent, worker);
    } else {
      tmp = false;
    }
    return tmp;
  }
  y2v() {
    var d = ensureNotNull(this.settings.getDimension());
    var heightColumn = this.settings.heightColumn;
    var border = this.settings.getDefaultColumnSettings().getBorderThickness();
    var halfBorder = border / 2;
    var tmp;
    if (!(heightColumn == null) && (this.isNumericType(heightColumn) || this.isTemporalType(heightColumn))) {
      var tmp_0 = -this.settings.getMaximumHeight();
      var tmp0 = d.cm();
      // Inline function 'kotlin.math.min' call
      var b = d.dm();
      var tmp$ret$0 = Math.min(tmp0, b);
      var shift = numberToInt(tmp_0 * tmp$ret$0);
      var labeling = this.settings.getDefaultColumnSettings().getLabeling();
      var levels = this.settings.groupByColumns.a1();
      var xShift = -(shift + levels * ensureNotNull(labeling).h2p(this));
      // Inline function 'kotlin.math.min' call
      var b_0 = shift + levels * labeling.g2p(this);
      var yShift = -Math.min(0.0, b_0);
      tmp = Double_3.p1m(xShift + halfBorder, yShift + halfBorder, d.cm() - xShift - border, d.dm() - yShift - border);
    } else {
      tmp = Double_3.p1m(0 + halfBorder, 0 + halfBorder, d.cm() - border, d.dm() - border);
    }
    return tmp;
  }
  e32(node, worker) {
    this.h32(node, worker);
    this.i32(node, worker);
    this.j32(node, worker);
  }
  h32(root, worker) {
    var sizeColumn = this.settings.sizeColumn;
    var min = this.getNumericMin(sizeColumn);
    var max = this.getNumericMax(sizeColumn);
    if (min == null || max == null) {
      min = 0.0;
      max = 1.0;
    }
    var scale = this.settings.getColumnSettings(sizeColumn).getScale();
    var hideFilterResults = ensureNotNull(this.settings.isHideFilterResults());
    var hideSearchResults = ensureNotNull(this.settings.isHideSearchResults());
    var _iterator__ex2g4s = this.s2w_1.h7().x();
    while (_iterator__ex2g4s.y()) {
      var node = _iterator__ex2g4s.z();
      var size;
      if (hideFilterResults && this.filter.ol(node)) {
        size = 0.0;
      } else {
        if (hideSearchResults && this.search.ol(node)) {
          size = 0.0;
        } else {
          if (this.c2y(node)) {
            if (sizeColumn == null || this.isRoot(node)) {
              size = 1.0;
            } else {
              var o = this.getValueAt(node, sizeColumn);
              if (!(o == null)) {
                var tmp;
                if (isNumber(o)) {
                  tmp = ensureNotNull(scale).o2o(numberToDouble(o), min, max);
                } else {
                  tmp = 0.0;
                }
                size = tmp;
              } else {
                size = 0.0;
              }
            }
          } else {
            size = 0.0;
          }
        }
      }
      if (isInfinite(size) || isNaN_0(size)) {
        node.k32(0.0);
      } else {
        // Inline function 'kotlin.math.max' call
        var b = size;
        var tmp$ret$0 = Math.max(0.0, b);
        node.k32(tmp$ret$0);
        if (node.l32()) {
          var tmp2 = this.maximumSize;
          // Inline function 'kotlin.math.max' call
          var b_0 = size;
          this.maximumSize = Math.max(tmp2, b_0);
        }
      }
    }
  }
  i32(node, worker) {
    if (!node.w32()) {
      if (worker == null || !worker.d17()) {
        var size;
        var sizeColumn = this.settings.sizeColumn;
        if (sizeColumn == null || this.settings.getColumnSettings(sizeColumn).getAggregation() === Companion_getInstance_73().o32_1) {
          var sumSizes = new Float64Array(this.getChildCount(node));
          var c = 0;
          var _iterator__ex2g4s = this.getChildren(node).x();
          while (_iterator__ex2g4s.y()) {
            var child = _iterator__ex2g4s.z();
            this.i32(child, worker);
            var value = child.a1();
            sumSizes[c] = value;
            c = c + 1 | 0;
          }
          size = Companion_getInstance_73().o32_1.m32(sumSizes);
        } else {
          var _iterator__ex2g4s_0 = this.getChildren(node).x();
          while (_iterator__ex2g4s_0.y()) {
            var child_0 = _iterator__ex2g4s_0.z();
            this.i32(child_0, worker);
          }
          var columnIndex = sizeColumn;
          var count = 0;
          var _iterator__ex2g4s_1 = this.preorderEnumeration(node).x();
          while (_iterator__ex2g4s_1.y()) {
            var child_1 = _iterator__ex2g4s_1.z();
            if (this.isLeaf(child_1) && !this.filter.ol(child_1)) {
              var tmp = this.getValueAt(child_1, columnIndex);
              var value_0 = (tmp == null ? true : isNumber(tmp)) ? tmp : THROW_CCE();
              if (!(value_0 == null)) {
                count = count + 1 | 0;
              }
            }
          }
          var sizes = new Float64Array(count);
          var i = 0;
          var _iterator__ex2g4s_2 = this.preorderEnumeration(node).x();
          while (_iterator__ex2g4s_2.y()) {
            var child_2 = _iterator__ex2g4s_2.z();
            if (this.isLeaf(child_2) && !this.filter.ol(child_2)) {
              var tmp_0 = this.getValueAt(child_2, columnIndex);
              var value_1 = (tmp_0 == null ? true : isNumber(tmp_0)) ? tmp_0 : THROW_CCE();
              if (!(value_1 == null) && i < sizes.length) {
                sizes[i] = child_2.a1();
                i = i + 1 | 0;
              }
            }
          }
          var d = ensureNotNull(this.settings.getColumnSettings(sizeColumn).getAggregation()).m32(sizes);
          size = d == null ? count : d;
        }
        if (size == null || isInfinite(size) || isNaN_0(size)) {
          node.k32(0.0);
        } else {
          // Inline function 'kotlin.math.max' call
          var b = size;
          var tmp$ret$0 = Math.max(0.0, b);
          node.k32(tmp$ret$0);
          if (node.l32()) {
            var tmp2 = this.maximumSize;
            // Inline function 'kotlin.math.max' call
            var b_0 = size;
            this.maximumSize = Math.max(tmp2, b_0);
          }
        }
      }
    }
  }
  j32(node, worker) {
    if (!node.w32()) {
      if (worker == null || !worker.d17()) {
        var size;
        var sumSizes = new Float64Array(this.getChildCount(node));
        var c = 0;
        var _iterator__ex2g4s = this.getChildren(node).x();
        while (_iterator__ex2g4s.y()) {
          var child = _iterator__ex2g4s.z();
          this.j32(child, worker);
          var value = child.a1();
          sumSizes[c] = value;
          c = c + 1 | 0;
        }
        size = ensureNotNull(Companion_getInstance_73().o32_1.m32(sumSizes));
        node.x32(size);
      }
    }
  }
  g32(currentRoot, worker) {
    if (!worker.d17()) {
      var rootAlgorithm = this.settings.getColumnSettings(this.getGroupByColumn(currentRoot)).getAlgorithm();
      rootAlgorithm.q2o(ensureNotNull(this.l2y(currentRoot)).y1l(), this, currentRoot, worker);
    }
    if (!worker.d17()) {
      var iterable = this.depthFirstIterator(currentRoot);
      var _iterator__ex2g4s = iterable.x();
      while (_iterator__ex2g4s.y()) {
        var node = _iterator__ex2g4s.z();
        if (!worker.d17()) {
          if (!this.c2y(node)) {
            var columnSettings = this.settings.getColumnSettings(this.getGroupByColumn(node));
            var sortOrder = !(columnSettings.getOrderingDirection() == null) ? ensureNotNull(columnSettings.getOrderingDirection()) : SortOrder_Descending_getInstance();
            var arrayList = ArrayList.l(toList_0(this.getChildren(node)));
            // Inline function 'kotlin.collections.toTypedArray' call
            var array = copyToArray(arrayList);
            var sizes = array;
            sizes = columnSettings.getOrdering().y32(this, sizes, sortOrder);
            // Inline function 'kotlin.collections.isNotEmpty' call
            // Inline function 'kotlin.collections.isEmpty' call
            if (!(sizes.length === 0)) {
              var algorithm = columnSettings.getAlgorithm();
              var horizontalVashingPoint = columnSettings.getOrderingHorizontalVanishingPoint();
              var verticalVashingPoint = columnSettings.getOrderingVerticalVanishingPoint();
              var tmp = currentRoot === node ? this.l2y(node) : null;
              var tmp_0 = sizes;
              var tmp_1 = this.getSumSize(node);
              var tmp_2 = horizontalVashingPoint == null ? 4 : horizontalVashingPoint;
              algorithm.p2o(tmp, node, tmp_0, tmp_1, tmp_2, verticalVashingPoint == null ? 3 : verticalVashingPoint, this, worker);
            }
          }
        } else {
          return true;
        }
      }
    } else {
      return true;
    }
    if (!worker.d17()) {
      var iterable_0 = this.breadthFirstIterator(currentRoot);
      var progress = 0;
      var _iterator__ex2g4s_0 = iterable_0.x();
      while (_iterator__ex2g4s_0.y()) {
        var node_0 = _iterator__ex2g4s_0.z();
        if (!worker.d17()) {
          if (!this.c2y(node_0)) {
            if (currentRoot === this.getParent(node_0)) {
              this.q2y(imul_0(progress, 99) / this.getChildCount(currentRoot) | 0);
              progress = progress + 1 | 0;
            }
            var arrayList_0 = ArrayList.l(toList_0(this.getChildren(node_0)));
            // Inline function 'kotlin.collections.toTypedArray' call
            var array_0 = copyToArray(arrayList_0);
            var sizes_0 = array_0;
            var columnSettings_0 = this.settings.getColumnSettings(this.getGroupByColumn(node_0));
            var sortOrder_0 = !(columnSettings_0.getOrderingDirection() == null) ? columnSettings_0.getOrderingDirection() : SortOrder_Descending_getInstance();
            sizes_0 = columnSettings_0.getOrdering().y32(this, sizes_0, ensureNotNull(sortOrder_0));
            // Inline function 'kotlin.collections.isNotEmpty' call
            // Inline function 'kotlin.collections.isEmpty' call
            if (!(sizes_0.length === 0)) {
              var algorithm_0 = columnSettings_0.getAlgorithm();
              var shape = this.l2y(node_0);
              if (algorithm_0.y2o(shape)) {
                shape = ensureNotNull(columnSettings_0.getNesting()).a2q(this, currentRoot, node_0, ensureNotNull(shape));
                node_0.a33(shape);
                var horizontalVashingPoint_0 = ensureNotNull(columnSettings_0.getOrderingHorizontalVanishingPoint());
                var verticalVashingPoint_0 = ensureNotNull(columnSettings_0.getOrderingVerticalVanishingPoint());
                algorithm_0.x2o(shape, node_0, sizes_0, this.getSumSize(node_0), horizontalVashingPoint_0, verticalVashingPoint_0, this, worker);
              } else {
                var indexedObject = sizes_0;
                var inductionVariable = 0;
                var last = indexedObject.length;
                while (inductionVariable < last) {
                  var child = indexedObject[inductionVariable];
                  inductionVariable = inductionVariable + 1 | 0;
                  child.z32(null);
                }
              }
            }
          }
        } else {
          return true;
        }
      }
    } else {
      return true;
    }
    var tmp_3;
    if (!worker.d17()) {
      var rootAlgorithm_0 = this.settings.getColumnSettings(this.getChildrenGroupByColumn(currentRoot)).getAlgorithm();
      rootAlgorithm_0.r2o(Double_3.p1m(0.0, 0.0, ensureNotNull(this.settings.getDimension()).cm(), ensureNotNull(this.settings.getDimension()).dm()), this, currentRoot);
      tmp_3 = false;
    } else {
      tmp_3 = true;
    }
    return tmp_3;
  }
  getSumSize(node) {
    return node.b33();
  }
  v2y(parent, worker) {
    var selected = this.settings.colorColumn;
    if (!(selected == null)) {
      var colorMap = this.getColorMapCurrent();
      var _iterator__ex2g4s = this.preorderEnumeration(parent).x();
      while (_iterator__ex2g4s.y()) {
        var node = _iterator__ex2g4s.z();
        if (worker == null || !worker.d17()) {
          if (this.c2y(node)) {
            var object = this.getValueAt(node, selected);
            if (!(colorMap == null)) {
              var color = colorMap.getColor(object);
              this.setColor(node, color);
            } else {
              var tmp;
              if (!(object == null)) {
                tmp = object instanceof CPColor;
              } else {
                tmp = false;
              }
              if (tmp) {
                this.setColor(node, object);
              } else {
                this.setColor(node, this.colorFactory.d2c());
              }
            }
          } else {
            var object_0;
            var tmp_0;
            if (this.w2x_1.o17(PrimitiveClasses_getInstance().ee(), ensureNotNull(this.getColumnClass(selected)))) {
              var sizes = getSizeWeightedValues(this, node, selected);
              tmp_0 = Companion_getInstance_73().p32_1.m32(sizes);
            } else {
              tmp_0 = this.getAggregateValue(node, selected);
            }
            object_0 = tmp_0;
            if (!(colorMap == null)) {
              var color_0 = colorMap.getColor(object_0);
              this.setColor(node, color_0);
            } else {
              var tmp_1;
              if (!(object_0 == null)) {
                tmp_1 = object_0 instanceof CPColor;
              } else {
                tmp_1 = false;
              }
              if (tmp_1) {
                this.setColor(node, object_0);
              } else {
                this.setColor(node, this.colorFactory.d2c());
              }
            }
          }
        } else {
          return true;
        }
      }
    }
    return false;
  }
  getColorMapCurrent() {
    var column = this.settings.colorColumn;
    return this.getColorMap(column);
  }
  getColorMap(column) {
    var tmp;
    if (!(column == null)) {
      var columnSettings = this.settings.getColumnSettings(column);
      var colorMap = columnSettings.getColorMap();
      if (colorMap == null) {
        colorMap = this.createDefaultColorMap(column);
        columnSettings.setColorMap(colorMap);
      }
      tmp = colorMap;
    } else {
      tmp = null;
    }
    return tmp;
  }
  getCategoricalColorMap(column) {
    var colorMap = this.z2x_1.u2(column);
    if (colorMap == null) {
      colorMap = this.c33(column);
      var tmp0 = this.z2x_1;
      // Inline function 'kotlin.collections.set' call
      var value = colorMap;
      tmp0.i7(column, value);
    }
    return colorMap;
  }
  getPredefinedColorMap(column) {
    var colorMap = this.a2y_1.u2(column);
    if (colorMap == null) {
      colorMap = this.p2w_1.g1g(this.getNumericMin(column), this.getNumericMax(column));
      var tmp0 = this.a2y_1;
      // Inline function 'kotlin.collections.set' call
      var value = colorMap;
      tmp0.i7(column, value);
    }
    return colorMap;
  }
  getCustomColorMap(column) {
    var colorMap = this.b2y_1.u2(column);
    if (colorMap == null) {
      colorMap = this.p2w_1.h1g(this.getNumericMin(column), this.getNumericMax(column));
      var tmp0 = this.b2y_1;
      // Inline function 'kotlin.collections.set' call
      var value = colorMap;
      tmp0.i7(column, value);
    }
    return colorMap;
  }
  d33(node) {
    return node.a1();
  }
  getSize(node) {
    return this.d33(node instanceof AbstractTreeMapNode ? node : THROW_CCE());
  }
  f32(node, shape) {
    node.z32(shape);
  }
  setShape(node, shape) {
    return this.f32(node instanceof AbstractTreeMapNode ? node : THROW_CCE(), shape);
  }
  l2y(node) {
    return node.e33();
  }
  getShape(node) {
    return this.l2y(node instanceof AbstractTreeMapNode ? node : THROW_CCE());
  }
  setNestedShape(node, shape) {
    node.a33(shape);
  }
  getNestedShape(node) {
    return ensureNotNull(node.f33());
  }
  g33(node) {
    return ensureNotNull(node.v1l());
  }
  getBounds(node) {
    return this.g33(node instanceof AbstractTreeMapNode ? node : THROW_CCE());
  }
  h33(node) {
    return node.i33();
  }
  getLevel(node) {
    return this.h33(node instanceof AbstractTreeMapNode ? node : THROW_CCE());
  }
  getGroupByColumn(node) {
    return node.j33();
  }
  getChildrenGroupByColumn(node) {
    return node.k33();
  }
  c2y(node) {
    return node == null || node.l32();
  }
  hasNoChildren(node) {
    return this.c2y(node instanceof AbstractTreeMapNode ? node : THROW_CCE());
  }
  isLeaf(node) {
    return node.w32();
  }
  parentPreorderEnumeration(parent) {
    return new AbstractTreeMapModel$parentPreorderEnumeration$1(this, parent);
  }
  preorderEnumeration(parent) {
    return new AbstractTreeMapModel$preorderEnumeration$1(this, parent);
  }
  breadthFirstIterator(parent) {
    return new AbstractTreeMapModel$breadthFirstIterator$1(this, parent);
  }
  depthFirstIterator(parent) {
    return new AbstractTreeMapModel$depthFirstIterator$1(this, parent);
  }
  getAggregateValue(node, column) {
    var tmp;
    if (!(column == null)) {
      var columnIndex = column;
      var tmp_0;
      if (this.c2y(node)) {
        tmp_0 = this.getValueAt(node, columnIndex);
      } else {
        var key = new NodeField(this, node, column);
        var tmp_1;
        if (this.f2x_1.s2(key)) {
          tmp_1 = this.f2x_1.u2(key);
        } else {
          var tmp_2;
          if (this.w2x_1.o17(PrimitiveClasses_getInstance().ee(), ensureNotNull(this.getColumnClass(columnIndex)))) {
            var agg = this.settings.getColumnSettings(columnIndex).getAggregation();
            var tmp_3;
            if (agg === Companion_getInstance_73().o32_1) {
              var count = 0;
              var _iterator__ex2g4s = this.getChildren(node).x();
              while (_iterator__ex2g4s.y()) {
                var child = _iterator__ex2g4s.z();
                if (!this.filter.ol(child) && !this.search.ol(child)) {
                  count = count + 1 | 0;
                }
              }
              var sizes = new Float64Array(count);
              var i = 0;
              var _iterator__ex2g4s_0 = this.getChildren(node).x();
              while (_iterator__ex2g4s_0.y()) {
                var child_0 = _iterator__ex2g4s_0.z();
                if (!this.filter.ol(child_0) && !this.search.ol(child_0)) {
                  var tmp_4 = this.getAggregateValue(child_0, column);
                  var value = (tmp_4 == null ? true : isNumber(tmp_4)) ? tmp_4 : THROW_CCE();
                  if (!(value == null)) {
                    sizes[i] = numberToDouble(value);
                  } else {
                    sizes[i] = NaN;
                  }
                  i = i + 1 | 0;
                }
              }
              var aggregate = agg.m32(sizes);
              if (!(aggregate == null)) {
                // Inline function 'kotlin.collections.set' call
                this.f2x_1.i7(key, aggregate);
              }
              tmp_3 = aggregate;
            } else {
              var values;
              var tmp_5;
              if (ensureNotNull(agg).l33()) {
                tmp_5 = getSizeWeightedValues(this, node, column);
              } else {
                tmp_5 = getValues(this, node, column);
              }
              values = tmp_5;
              var aggregate_0 = agg.m32(values);
              if (!(aggregate_0 == null)) {
                // Inline function 'kotlin.collections.set' call
                this.f2x_1.i7(key, aggregate_0);
              }
              tmp_3 = aggregate_0;
            }
            tmp_2 = tmp_3;
          } else if (this.w2x_1.o17(PrimitiveClasses_getInstance().ne(), ensureNotNull(this.getColumnClass(columnIndex)))) {
            var aggregate_1 = null;
            var first = true;
            var _iterator__ex2g4s_1 = this.getChildren(node).x();
            $l$loop: while (_iterator__ex2g4s_1.y()) {
              var child_1 = _iterator__ex2g4s_1.z();
              if (!this.filter.ol(child_1) && !this.search.ol(child_1)) {
                var tmp_6 = this.getAggregateValue(child_1, column);
                var value_0 = (tmp_6 == null ? true : typeof tmp_6 === 'string') ? tmp_6 : THROW_CCE();
                if (first) {
                  aggregate_1 = value_0;
                  first = false;
                } else {
                  if (!(aggregate_1 == null) && !(aggregate_1 == value_0)) {
                    aggregate_1 = null;
                    break $l$loop;
                  }
                }
              }
            }
            tmp_2 = aggregate_1;
          } else {
            tmp_2 = null;
          }
          tmp_1 = tmp_2;
        }
        tmp_0 = tmp_1;
      }
      tmp = tmp_0;
    } else {
      tmp = null;
    }
    return tmp;
  }
  getStringValue(node, column) {
    var tmp;
    if (!(column == null) && !(node == null)) {
      var value;
      if (this.c2y(node)) {
        value = this.getValueAt(node, column);
      } else {
        value = this.getAggregateValue(node, column);
      }
      var format = this.settings.getColumnSettings(column).getFormat();
      var tmp_0;
      if (!(format == null)) {
        var tmp_1;
        try {
          tmp_1 = format.wl(value, false);
        } catch ($p) {
          var tmp_2;
          if ($p instanceof IllegalArgumentException) {
            var e = $p;
            tmp_2 = ' ';
          } else {
            throw $p;
          }
          tmp_1 = tmp_2;
        }
        tmp_0 = tmp_1;
      } else {
        if (value == null) {
          value = ' ';
        }
        var string;
        var tmp_3;
        if (!(value == null) ? typeof value === 'string' : false) {
          tmp_3 = value;
        } else {
          if (isNumber(value)) {
            tmp_3 = ensureNotNull(this.x2x_1.n18().wl(value, false));
          } else {
            tmp_3 = toString_1(value);
          }
        }
        string = tmp_3;
        tmp_0 = string;
      }
      tmp = tmp_0;
    } else {
      tmp = null;
    }
    return tmp;
  }
  m33(currentRoot) {
    this.i2x_1.vo(currentRoot);
  }
  n33(_set____db54di) {
    return this.currentRoot = (_set____db54di == null ? true : _set____db54di instanceof AbstractTreeMapNode) ? _set____db54di : THROW_CCE();
  }
  o33() {
    return this.i2x_1.r2();
  }
  d30() {
    cancelDoUpdate(this);
    this.m2x_1 = true;
    if (this.c2x_1) {
      this.a2x_1.g15();
    } else {
      this.w2z();
    }
  }
  addListener(treeMapListener) {
    this.z2w_1.o(treeMapListener);
  }
  removeListener(treeMapListener) {
    this.z2w_1.w2(treeMapListener);
  }
  getNode(position) {
    if (!(position == null)) {
      var currentRoot = this.currentRoot;
      if (!(currentRoot == null)) {
        var rectangle = this.l2y(currentRoot);
        if (!(rectangle == null) && rectangle.z1l(position)) {
          var node = visit(this, currentRoot, position);
          if (!(node == null) && !(node === currentRoot) && !this.filter.ol(node) && !this.search.ol(node)) {
            return node;
          }
        }
      }
    }
    return null;
  }
  waitUntilReady() {
    this.w2x_1.n17(new Long(80, 0));
    while (this.isDirty) {
      this.w2x_1.n17(new Long(50, 0));
      while (this.root == null || this.l2y(ensureNotNull(this.root)) == null) {
        this.w2x_1.n17(new Long(50, 0));
      }
      var workerFuture = this.workerFuture;
      while (workerFuture == null || !workerFuture.b17() || workerFuture.d17()) {
        try {
          ensureNotNull(workerFuture).xk();
        } catch ($p) {
          if ($p instanceof IllegalStateException) {
            var e = $p;
          } else {
            if ($p instanceof Exception) {
              var e_0 = $p;
              printStackTrace(e_0);
            } else {
              throw $p;
            }
          }
        }
        workerFuture = this.workerFuture;
      }
    }
  }
  getColor(node) {
    return this.colorProvider.f2z(node);
  }
  setColor(node, color) {
    node.p33(color);
  }
  progressProperty() {
    return this.u2x_1;
  }
  q2y(progress) {
    this.u2x_1.vo(progress);
  }
  getFormatPattern(columnIndex) {
    var format = this.settings.getColumnSettings(this.getTreeMapColumn(columnIndex)).getFormat();
    var tmp;
    if (!(format == null)) {
      tmp = format.xl();
    } else {
      tmp = null;
    }
    return tmp;
  }
  setFormatPattern(columnIndex, pattern) {
    var column = this.getTreeMapColumn(columnIndex);
    if (!(column == null)) {
      if (this.isNumericType(column)) {
        this.settings.getColumnSettings(column).setFormat(this.x2x_1.p18(pattern));
      } else if (this.isTemporalType(column)) {
        this.settings.getColumnSettings(column).setFormat(this.x2x_1.o18(pattern));
      }
    }
  }
  get colorFactory() {
    return this.q30();
  }
  get settings() {
    return this.t30();
  }
  get properties() {
    return this.f24();
  }
  get probing() {
    return this.w30();
  }
  get highlighting() {
    return this.x30();
  }
  get selection() {
    return this.y30();
  }
  get filter() {
    return this.z30();
  }
  get search() {
    return this.a31();
  }
  get root() {
    return this.c31();
  }
  get worker() {
    return this.e31();
  }
  get workerFuture() {
    return this.g31();
  }
  get isDirty() {
    return this.x2g();
  }
  get normalizedLightSourceX() {
    return this.i31();
  }
  get normalizedLightSourceY() {
    return this.k31();
  }
  get normalizedLightSourceZ() {
    return this.m31();
  }
  get maximumSize() {
    return this.o31();
  }
  get colorProvider() {
    return this.t31();
  }
  set colorProvider(value) {
    this.r31(value);
  }
  get groupByColumns() {
    return this.u31();
  }
  get sizeColumns() {
    return this.v31();
  }
  get colorColumns() {
    return this.w31();
  }
  get heightColumns() {
    return this.x31();
  }
  get labelsColumns() {
    return this.y31();
  }
  get tooltipColumns() {
    return this.z31();
  }
  get currentRoot() {
    return this.o33();
  }
  set currentRoot(value) {
    this.m33(value);
  }
  get dataFrame() {
    return this.k2g();
  }
  get rowCount() {
    return this.g2k();
  }
  get columnCount() {
    return this.z2i();
  }
}
class AbstractTreeMapNode {
  constructor(model) {
    this.d2y_1 = 1.0;
    this.e2y_1 = null;
    this.g2y_1 = null;
    this.h2y_1 = null;
    this.i2y_1 = null;
    this.j2y_1 = null;
    this.k2y_1 = 0;
    this.f2y_1 = model;
    this.p33(!(model == null) ? model.colorFactory.d2c() : null);
  }
  k32(_set____db54di) {
    this.d2y_1 = _set____db54di;
  }
  a1() {
    return this.d2y_1;
  }
  z32(shape) {
    if (this.e2y_1 == null || !equals(ensureNotNull(this.e2y_1), shape)) {
      this.e2y_1 = shape;
      this.h2y_1 = null;
      if (!(this.i2y_1 == null)) {
        var cushionImage = ensureNotNull(this.i2y_1).xk();
        if (!(cushionImage == null)) {
          cushionImage.ac();
        }
        this.i2y_1 = null;
      }
    }
  }
  e33() {
    return this.e2y_1;
  }
  p33(c) {
    this.g2y_1 = c;
    this.h2y_1 = null;
    if (!(this.i2y_1 == null)) {
      var cushionImage = ensureNotNull(this.i2y_1).xk();
      if (!(cushionImage == null)) {
        cushionImage.ac();
      }
      this.i2y_1 = null;
    }
  }
  e2z() {
    return this.g2y_1;
  }
  a33(value) {
  }
  f33() {
    return this.e33();
  }
  t33(_set____db54di) {
    this.k2y_1 = _set____db54di;
  }
  i33() {
    return this.k2y_1;
  }
  v33() {
    return this.j2y_1;
  }
  w33() {
    return this.j2y_1 == null;
  }
  a34(parent) {
    this.j2y_1 = parent;
    this.t33(ensureNotNull(this.v33()).i33() + 1 | 0);
  }
  e34() {
    if (!(this.f2y_1.settings.backgroundColumn == null)) {
      var column = this.f2y_1.settings.backgroundColumn;
      if (!(column == null) && this.l32()) {
        var tmp;
        if (!this.f2y_1.isNumericType(column)) {
          var value = this.f2y_1.getValueAt(this, column);
          tmp = value == null ? null : toString_1(value);
        } else {
          var value_0 = this.f2y_1.getValueAt(this, column);
          tmp = value_0 == null ? null : toString_1(value_0);
        }
        return tmp;
      }
    }
    var tmp_0;
    var tmp_1;
    if (!(this.f2y_1.settings.labelsColumns == null)) {
      // Inline function 'kotlin.collections.isNotEmpty' call
      tmp_1 = !this.f2y_1.settings.labelsColumns.c1();
    } else {
      tmp_1 = false;
    }
    if (tmp_1) {
      var column_0 = this.f2y_1.settings.labelsColumns.b1(0);
      var tmp_2;
      if (!(column_0 == null) || !this.l32()) {
        var tmp_3;
        if (!(this.c34() == null)) {
          tmp_3 = toString_0(this.c34());
        } else {
          tmp_3 = null;
        }
        tmp_2 = tmp_3;
      } else if (!this.f2y_1.isNumericType(column_0)) {
        var value_1 = this.f2y_1.getValueAt(this, column_0);
        tmp_2 = value_1 == null ? null : toString_1(value_1);
      } else {
        var value_2 = this.f2y_1.getValueAt(this, column_0);
        tmp_2 = value_2 == null ? null : toString_1(value_2);
      }
      tmp_0 = tmp_2;
    } else {
      var tmp_4;
      if (!(this.c34() == null)) {
        tmp_4 = toString_0(this.c34());
      } else {
        tmp_4 = null;
      }
      tmp_0 = tmp_4;
    }
    return tmp_0;
  }
  v1l() {
    var tmp;
    if (!(this.e33() == null)) {
      tmp = ensureNotNull(this.e33()).y1l();
    } else {
      tmp = null;
    }
    return tmp;
  }
  toString() {
    return ensureNotNull(this.e34());
  }
  q33() {
    var tmp;
    if (!(this.h2y_1 == null)) {
      tmp = this.h2y_1;
    } else {
      var data = null;
      var parent = this.v33();
      if (!(parent == null) && !(this.e33() == null)) {
        var bounds;
        var tmp_0 = this.e33();
        if (tmp_0 instanceof Rectangle) {
          var tmp_1 = this.e33();
          bounds = tmp_1 instanceof Rectangle ? tmp_1 : THROW_CCE();
        } else {
          var b = ensureNotNull(this.e33()).y1l();
          bounds = Rectangle.from(numberToInt(b.w1l()), numberToInt(b.x1l()), numberToInt(b.cm()), numberToInt(b.dm()));
        }
        var top = bounds.r20_1;
        var bottom = bounds.r20_1 + bounds.t20_1 | 0;
        var left = bounds.q20_1;
        var right = bounds.q20_1 + bounds.s20_1 | 0;
        if (parent.v33() == null) {
          data = Cushion.g34(this.f2y_1, left, right, bounds.s20_1, top, bottom, bounds.t20_1);
        } else {
          data = Cushion.f34(parent.q33(), this.f2y_1, left, right, bounds.s20_1, top, bottom, bounds.t20_1);
        }
      }
      this.h2y_1 = data;
      tmp = data;
    }
    return tmp;
  }
  h34() {
    var tmp;
    if (this.i2y_1 == null) {
      var image = createCushionImage(this);
      var tmp_0;
      if (!(image == null)) {
        this.i2y_1 = new SoftReference(image);
        tmp_0 = image;
      } else {
        tmp_0 = null;
      }
      tmp = tmp_0;
    } else {
      var image_0 = ensureNotNull(this.i2y_1).xk();
      if (image_0 == null) {
        image_0 = createCushionImage(this);
        if (!(image_0 == null)) {
          this.i2y_1 = new SoftReference(image_0);
        } else {
          return null;
        }
      }
      tmp = image_0;
    }
    return tmp;
  }
  i34() {
    if (this.e33() == null)
      return null;
    var bounds;
    var tmp = this.e33();
    if (tmp instanceof Rectangle) {
      var tmp_0 = this.e33();
      bounds = tmp_0 instanceof Rectangle ? tmp_0 : THROW_CCE();
    } else {
      var b = ensureNotNull(this.e33()).y1l();
      bounds = Rectangle.from(numberToInt(b.w1l()), numberToInt(b.x1l()), numberToInt(b.cm()), numberToInt(b.dm()));
    }
    // Inline function 'kotlin.math.max' call
    var b_0 = bounds.s20_1;
    var width = Math.max(1, b_0);
    // Inline function 'kotlin.math.max' call
    var b_1 = bounds.t20_1;
    var height = Math.max(1, b_1);
    return ensureNotNull(this.q33()).j34(this.f2y_1, this.e2z(), bounds.q20_1, bounds.r20_1, width, height);
  }
  k34() {
    return this;
  }
}
class Companion_71 {
  constructor() {
    this.l34_1 = 'sizeField';
    this.m34_1 = 'colorField';
    this.n34_1 = 'labelsField';
    this.o34_1 = 'toolTipField';
    this.p34_1 = 'backgroundField';
    this.q34_1 = 'heightField';
    this.r34_1 = 'groupByField';
    this.s34_1 = 'depth';
    this.t34_1 = 'rendering';
    this.u34_1 = 'background';
    this.v34_1 = 'tooltipBackground';
    this.w34_1 = 'probingColor';
    this.x34_1 = 'selectionColor';
    this.y34_1 = 'hideSearchResults';
    this.z34_1 = 'hideFilterResults';
    this.a35_1 = 'dimension';
    this.b35_1 = 'dimensionFixed';
    this.c35_1 = 'maximumHeight';
    this.d35_1 = 'lightSourceHeight';
    this.e35_1 = 'lightSourceAmbient';
    this.f35_1 = 'lightSourceX';
    this.g35_1 = 'lightSourceY';
    this.h35_1 = 'lightSourceZ';
  }
}
class TreeMapSettings {}
class AbstractTreeMapSettings {
  constructor() {
    this.i35_1 = CollectionFactory_instance.ll();
  }
  addTreeMapSettingsListener(listener) {
    this.i35_1.o(listener);
  }
  removeTreeMapSettingsListener(listener) {
    this.i35_1.w2(listener);
  }
  removeTreeMapSettingsListeners() {
    this.i35_1.o5();
  }
  j35(event) {
    var _iterator__ex2g4s = this.i35_1.x();
    while (_iterator__ex2g4s.y()) {
      var listener = _iterator__ex2g4s.z();
      listener.y2z(event);
    }
  }
  get properties() {
    return this.f24();
  }
  get groupByColumns() {
    return this.u31();
  }
  set groupByColumns(value) {
    this.k35(value);
  }
  get sizeColumn() {
    return this.m35();
  }
  set sizeColumn(value) {
    this.l35(value);
  }
  get colorColumn() {
    return this.o35();
  }
  set colorColumn(value) {
    this.n35(value);
  }
  get labelsColumns() {
    return this.y31();
  }
  set labelsColumns(value) {
    this.p35(value);
  }
  get toolTipColumns() {
    return this.r35();
  }
  set toolTipColumns(value) {
    this.q35(value);
  }
  get backgroundColumn() {
    return this.t35();
  }
  set backgroundColumn(value) {
    this.s35(value);
  }
  get heightColumn() {
    return this.v35();
  }
  set heightColumn(value) {
    this.u35(value);
  }
  get rendering() {
    return this.x35();
  }
  set rendering(value) {
    this.w35(value);
  }
  get renderingSelection() {
    return this.y35();
  }
  get maximumHeightInterval() {
    return this.z35();
  }
  get lightSourceHeightInterval() {
    return this.a36();
  }
  get lightSourceAmbientInterval() {
    return this.b36();
  }
  get lightSourceXInterval() {
    return this.c36();
  }
  get lightSourceYInterval() {
    return this.d36();
  }
  get lightSourceZInterval() {
    return this.e36();
  }
}
class Companion_72 {
  constructor() {
    this.f36_1 = 7;
    this.g36_1 = 20;
  }
}
class AbstractTreeMapToolTip {
  constructor(view) {
    this.i36_1 = null;
    this.j36_1 = null;
    this.k36_1 = 230;
    this.l36_1 = new ToolTipTreeMapRenderer();
    this.h36_1 = view;
  }
  m36(node) {
    if (!(this.i36_1 === node)) {
      this.i36_1 = node;
      if (this.i36_1 == null) {
        this.n36();
      }
    }
  }
  o36() {
    return this.i36_1;
  }
  p36() {
    if (this.j36_1 == null) {
      this.j36_1 = this.q36();
    }
    return this.j36_1;
  }
  r36() {
    return this.k36_1;
  }
  s36() {
    return this.l36_1;
  }
  t36() {
    return new Insets(2, 2, 2, 2);
  }
  u36(g) {
    var model = this.h36_1.j2p();
    if (!(model == null)) {
      if (!(this.o36() == null)) {
        var bounds = this.s36().w36(g, this.h36_1, model, ensureNotNull(this.o36()), this.r36(), 20, 7, false);
        var tmp;
        if (!(bounds == null)) {
          var insets = this.t36();
          tmp = Dimension.bm(((bounds.s20_1 + 1 | 0) + insets.k22_1 | 0) + insets.m22_1 | 0, ((bounds.t20_1 + 1 | 0) + insets.j22_1 | 0) + insets.l22_1 | 0);
        } else {
          tmp = null;
        }
        return tmp;
      }
    }
    return null;
  }
  x36() {
    var probingColor = ensureNotNull(this.h36_1.j2p()).settings.getProbingColor();
    var tmp;
    if (!(probingColor == null)) {
      tmp = alpha(probingColor, 0.5);
    } else {
      tmp = null;
    }
    return tmp;
  }
  y36(g) {
    var background = ensureNotNull(this.h36_1.j2p()).settings.getTooltipBackground();
    if (!(background == null)) {
      var insets = this.t36();
      var x = insets.k22_1;
      var y = insets.j22_1;
      var width = (this.cm() - insets.k22_1 | 0) - insets.m22_1 | 0;
      var height = (this.dm() - insets.j22_1 | 0) - insets.l22_1 | 0;
      g.n2q(background);
      g.z36(x, y, width, height, 10.0, 10.0);
      var borderColor = this.x36();
      if (!(borderColor == null)) {
        g.a2r(borderColor);
        var borderThickness = insets.k22_1;
        g.z2q(borderThickness);
        var halfThickness = borderThickness / 2;
        g.a37(halfThickness, halfThickness, width, height, 10.0, 10.0);
      }
    }
  }
  b37(g) {
    var insets = this.t36();
    var x = insets.k22_1;
    var y = insets.j22_1;
    var width = (this.cm() - insets.k22_1 | 0) - insets.m22_1 | 0;
    var height = (this.dm() - insets.j22_1 | 0) - insets.l22_1 | 0;
    g.w2q();
    g.e1o(x, y);
    g.x2q(Double_3.p1m(0, 0, width, height));
    g.c37(true);
    this.s36().d37(g, this.h36_1, this.o36(), this.r36(), 20, 7, null);
    g.y2q();
  }
  e37() {
    var tmp;
    if (!(this.p36() == null)) {
      tmp = ensureNotNull(this.p36()).f37();
    } else {
      tmp = null;
    }
    return tmp;
  }
  q36() {
    return new DefaultTreeMapPopup(this.h36_1);
  }
  g37(node) {
    if (!(this.o36() === node)) {
      this.m36(node);
      var tooltipPosition = this.h37();
      var tooltipDimension = this.u36(null);
      if (!(tooltipPosition == null) && !(tooltipDimension == null)) {
        var popup = this.p36();
        if (!(popup == null)) {
          this.i37(tooltipPosition.h20_1, tooltipPosition.i20_1);
        }
      }
      if (node == null) {
        this.n36();
      }
      if (!(this.p36() == null)) {
        ensureNotNull(this.p36()).j37();
      }
    }
  }
  k37(p) {
    var p_0 = p;
    var model = ensureNotNull(this.h36_1.j2p());
    if (!(model == null)) {
      if (!(this.o36() == null)) {
        var shape = this.h36_1.l37(ensureNotNull(model.currentRoot));
        if (p_0 == null) {
          var nodeShape = this.h36_1.l37(ensureNotNull(this.o36()));
          if (!(nodeShape == null)) {
            p_0 = new Point(numberToInt(nodeShape.y1l().a1m()), numberToInt(nodeShape.y1l().c1m()));
          } else {
            return null;
          }
        }
        var mouseX = p_0.h20_1;
        var mouseY = p_0.i20_1;
        if (!(shape == null)) {
          var size = this.u36(null);
          if (!(size == null)) {
            var width = size.yl_1;
            var height = size.zl_1;
            var bounds = Rectangle.from(mouseX + 20 | 0, mouseY + 7 | 0, width, height);
            var d = this.h36_1.a1();
            if (mouseX > d.cm() - 20 - width)
              bounds.q20_1 = mouseX - (20 + width | 0) | 0;
            if (mouseY > d.dm() - height - 7)
              bounds.r20_1 = (d.zl_1 - height | 0) - 7 | 0;
            return new Point(bounds.q20_1, bounds.r20_1);
          }
        }
      }
    }
    return null;
  }
  i37(x, y) {
    var popup = this.p36();
    if (!(popup == null)) {
      popup.m37(x, y, this.h36_1.r2r());
    }
  }
  n36() {
    var popup = this.p36();
    if (!(popup == null)) {
      popup.n36();
    }
  }
}
class AbstractTreeMapView$probingListener$1 {
  constructor(this$0) {
    this.q38_1 = this$0;
  }
  r38(event) {
    var toolTip = this.q38_1.s38();
    if (!(toolTip == null)) {
      var node = ensureNotNull(this.q38_1.j2p()).probing.v13();
      ensureNotNull(this.q38_1.h38_1).g37(node);
    }
    this.q38_1.j37();
  }
  t13(event) {
    return this.r38(event);
  }
}
class AbstractTreeMapView$selectionListener$1 {
  constructor(this$0) {
    this.t38_1 = this$0;
  }
  u38(event) {
    var toolTip = this.t38_1.v38();
    if (!(toolTip == null)) {
      if (ensureNotNull(this.t38_1.j2p()).selection.a13() && ensureNotNull(this.t38_1.j2p()).selection.d13() === 1) {
        var node = ensureNotNull(this.t38_1.j2p()).selection.x().z();
        ensureNotNull(this.t38_1.v38()).g37(node);
      } else {
        ensureNotNull(this.t38_1.v38()).g37(null);
      }
    }
    this.t38_1.j37();
  }
  x13(event) {
    return this.u38(event);
  }
}
class AbstractTreeMapView$_treeMapListener$1 {
  constructor(this$0) {
    this.w38_1 = this$0;
  }
  c32() {
  }
  d32(event) {
    if (event.a39_1) {
      this.w38_1.y38();
      this.w38_1.j37();
    } else {
      this.w38_1.x38();
    }
  }
}
class AbstractTreeMapView$modelPropertyChangeListener$1 {
  constructor(this$0) {
    this.c39_1 = this$0;
  }
  k30(name, event) {
    if (!equals('progress', name)) {
      this.c39_1.j37();
    } else {
      this.c39_1.y38();
      this.c39_1.d39(new Long(300, 0));
    }
  }
  zx(name, event) {
    return this.k30((name == null ? true : typeof name === 'string') ? name : THROW_CCE(), event);
  }
}
class AbstractTreeMapView$filterListener$1 {
  constructor(this$0) {
    this.e39_1 = this$0;
  }
}
class AbstractTreeMapView$propertyChangeListener$1 {
  constructor(this$0) {
    this.f39_1 = this$0;
  }
  k30(name, event) {
    if (equals('dimension', name) || equals('labeling', name) || equals('heightField', name) || equals('groupByField', name)) {
      this.f39_1.h39();
    } else if (equals('dimensionFixed', name)) {
      this.f39_1.g39();
    }
    this.f39_1.j37();
  }
  zx(name, event) {
    return this.k30((name == null ? true : typeof name === 'string') ? name : THROW_CCE(), event);
  }
}
class AbstractTreeMapView$1 {
  constructor(this$0) {
    this.i39_1 = this$0;
  }
  j39(event) {
    this.i39_1.j37();
  }
  t13(event) {
    return this.j39(event);
  }
}
class AbstractTreeMapView$2 {
  constructor(this$0) {
    this.k39_1 = this$0;
  }
  k15(event) {
    this.k39_1.y38();
    this.k39_1.j37();
  }
}
class AbstractTreeMapView {
  constructor(headless) {
    this.o37_1 = headless;
    var tmp = this;
    tmp.x37_1 = new AbstractTreeMapView$probingListener$1(this);
    var tmp_0 = this;
    tmp_0.y37_1 = new AbstractTreeMapView$selectionListener$1(this);
    var tmp_1 = this;
    tmp_1.z37_1 = new AbstractTreeMapView$_treeMapListener$1(this);
    var tmp_2 = this;
    tmp_2.a38_1 = new AbstractTreeMapView$modelPropertyChangeListener$1(this);
    var tmp_3 = this;
    tmp_3.b38_1 = new AbstractTreeMapView$filterListener$1(this);
    var tmp_4 = this;
    tmp_4.c38_1 = new AbstractTreeMapView$propertyChangeListener$1(this);
    this.d38_1 = null;
    this.e38_1 = DefaultTreeMapLabelRenderer.i3a();
    this.f38_1 = DefaultTreeMapHeaderRenderer.h3b();
    this.g38_1 = DefaultTreeMapTooltipRenderer.f3c();
    this.h38_1 = new DefaultTreeMapToolTip(this);
    this.i38_1 = null;
    this.j38_1 = true;
    this.k38_1 = Progressive_Disabled_getInstance();
    this.l38_1 = false;
    this.m38_1 = true;
    this.o38_1 = true;
    this.s37_1 = ArrayList.e1();
    this.t37_1 = ArrayList.e1();
    this.u37_1 = ArrayList.e1();
    this.v37_1 = ArrayList.e1();
    this.w37_1 = HashMap.d8();
    this.s37_1.o(new BackgroundRootNodeTreeMapRenderer());
    this.s37_1.o(NodesTreeMapRenderer.i3c(new BackgroundParentNodeRenderer(), 0));
    this.t37_1.o(NodesTreeMapRenderer.i3c(new LeafNodeRenderer(false), 0));
    this.t37_1.o(NodesTreeMapRenderer.i3c(new LeafNodeRenderer(false), 1));
    this.u37_1.o(NodesTreeMapRenderer.i3c(new LeafNodeRenderer(true), 0));
    this.u37_1.o(NodesTreeMapRenderer.i3c(new TextParentNodeRenderer(), 0));
    this.u37_1.o(NodesTreeMapRenderer.i3c(new BorderParentNodeRenderer(), 0));
    this.u37_1.o(NodesTreeMapRenderer.i3c(new HighlightParentNodeRenderer(), 0));
    this.v37_1.o(NodesTreeMapRenderer.i3c(new LeafNodeRenderer(true), 1));
    this.v37_1.o(NodesTreeMapRenderer.i3c(new TextParentNodeRenderer(), 1));
    this.v37_1.o(NodesTreeMapRenderer.j3c(new SelectionNodeRenderer()));
    this.k3c(null);
    var width = 0;
    var height = 0;
    this.p37_1 = SimpleBoundedInterval.lp(0.0, width, 0.0, width);
    this.q37_1 = SimpleBoundedInterval.lp(0.0, height, 0.0, height);
    this.r37_1 = SimpleTwoDScreenTransform.o29(SimpleOneDScreenTransform.o16(this.p37_1, width), SimpleOneDScreenTransform.p16(this.q37_1, height, true, true), width, height, 1.0);
    this.n38_1 = new ScreenTransformRubberBand(this.r37_1);
    this.n38_1.q28_1.q13(new AbstractTreeMapView$1(this));
    new RangesScreenTransformCoordinator(this.p37_1, this.q37_1);
    this.r37_1.b29(new AbstractTreeMapView$2(this));
    this.p37_1.ip(10.0);
    this.q37_1.ip(10.0);
  }
  l3c() {
    return this.o37_1;
  }
  j2w() {
    return this.p37_1;
  }
  k2w() {
    return this.q37_1;
  }
  a2w() {
    return this.r37_1;
  }
  m3c() {
    return this.s37_1;
  }
  n3c() {
    return this.u37_1;
  }
  o3c() {
    return this.v37_1;
  }
  i2r(model) {
    if (!(this.d38_1 == null)) {
      ensureNotNull(this.d38_1).removeListener(this.z37_1);
      ensureNotNull(this.d38_1).properties.by(this.a38_1);
      ensureNotNull(this.d38_1).filter.nl(this.b38_1);
      ensureNotNull(this.d38_1).search.nl(this.b38_1);
      ensureNotNull(this.d38_1).settings.properties.by(this.c38_1);
      ensureNotNull(this.d38_1).probing.r13(this.x37_1);
      ensureNotNull(this.d38_1).selection.y12(this.y37_1);
    }
    this.d38_1 = model;
    this.y38();
    if (!(this.d38_1 == null)) {
      ensureNotNull(this.d38_1).addListener(this.z37_1);
      ensureNotNull(this.d38_1).properties.cy(this.a38_1);
      ensureNotNull(this.d38_1).filter.ml(this.b38_1);
      ensureNotNull(this.d38_1).search.ml(this.b38_1);
      ensureNotNull(this.d38_1).settings.properties.cy(this.c38_1);
      ensureNotNull(this.d38_1).probing.q13(this.x37_1);
      ensureNotNull(this.d38_1).selection.x12(this.y37_1);
    }
    this.g39();
    this.h39();
  }
  j2p() {
    return this.d38_1;
  }
  n2p() {
    return this.e38_1;
  }
  p3c() {
    return this.f38_1;
  }
  q3c() {
    return this.g38_1;
  }
  k3c(tooltip) {
    if (!(this.i38_1 === tooltip)) {
      this.i38_1 = tooltip;
      this.j37();
    }
  }
  v38() {
    return this.i38_1;
  }
  r3c() {
    return this.j38_1;
  }
  s3c() {
    return this.l38_1;
  }
  u2v(_set____db54di) {
    this.m38_1 = _set____db54di;
  }
  v2v() {
    return this.m38_1;
  }
  s28() {
    return this.n38_1;
  }
  g2g(_set____db54di) {
    this.o38_1 = _set____db54di;
  }
  y2t() {
    return Companion_instance_47.v20(this.p37_1.start, this.q37_1.start, this.p37_1.start + this.p37_1.extent, this.q37_1.start + this.q37_1.extent);
  }
  x38() {
    this.g2g(true);
    this.j37();
  }
  y38() {
    this.g2g(true);
    if (!(this.w37_1 == null)) {
      this.w37_1.o5();
    }
  }
  l2q(node) {
    var tmp0_safe_receiver = this.w37_1;
    var shape = tmp0_safe_receiver == null ? null : tmp0_safe_receiver.u2(node);
    if (!(this.j2p() == null) && shape == null && !(node == null)) {
      shape = ensureNotNull(this.j2p()).getShape(node);
      if (!(shape == null)) {
        shape = this.t3c(shape);
        var tmp0 = ensureNotNull(this.w37_1);
        // Inline function 'kotlin.collections.set' call
        var value = shape;
        tmp0.i7(node, value);
      }
    }
    return shape;
  }
  t3c(shape) {
    var shape_0 = shape;
    var tmp;
    if (isInterface(shape_0, Rectangle2D)) {
      var r = shape_0;
      tmp = this.u3c(r);
    } else {
      if (shape_0 instanceof TextShape) {
        var at = ScreenTransformHelper_instance.y21(this.r37_1.w1l(), this.r37_1.x1l());
        tmp = shape_0.d22(at);
      } else {
        var at_0 = ScreenTransformHelper_instance.y21(this.r37_1.w1l(), this.r37_1.x1l());
        tmp = ensureNotNull(at_0.s1o(shape_0));
      }
    }
    shape_0 = tmp;
    return shape_0;
  }
  worldToScreenShape(shape) {
    return this.t3c(shape);
  }
  l37(node) {
    var screenShape = this.l2q(node);
    if (!(screenShape == null)) {
      return ensureNotNull(ensureNotNull(this.j2p()).settings.rendering).getRenderedShape(this, ensureNotNull(this.j2p()), node, screenShape);
    } else {
      return Rectangle.from(0, 0, 0, 0);
    }
  }
  z2t() {
    return Companion_instance_47.v20(this.p37_1.bn(), this.q37_1.bn(), this.p37_1.cn(), this.q37_1.cn());
  }
  v3c(x) {
    return getXCoordinateAxis(this).p15(x);
  }
  w3c(y) {
    return getYCoordinateAxis(this).p15(y);
  }
  o2u(animate, x1, x2, y1, y2) {
    this.p37_1.lo(x1, x2 - x1);
    this.q37_1.lo(y1, y2 - y1);
  }
  t2v(p) {
    if (!(this.j2p() == null) && !(p == null)) {
      var currentRoot = ensureNotNull(this.j2p()).currentRoot;
      if (!(currentRoot == null)) {
        var rectangle = this.l37(currentRoot);
        if (!(rectangle == null) && this.p38(p, rectangle)) {
          var node = visit_0(this, ensureNotNull(this.j2p()), currentRoot, p);
          if (!(node == null) && !(node === currentRoot) && !ensureNotNull(this.j2p()).filter.ol(node) && !ensureNotNull(this.j2p()).search.ol(node)) {
            return node;
          }
        }
      }
    }
    return null;
  }
  p38(p, shape) {
    var tmp;
    if (shape instanceof TextShape) {
      tmp = shape.y1l().z1l(p);
    } else {
      tmp = shape.z1l(p);
    }
    return tmp;
  }
  x2v(rect) {
    if (!(this.j2p() == null) && !(rect == null)) {
      var list = ArrayList.e1();
      var currentRoot = ensureNotNull(ensureNotNull(this.j2p()).currentRoot);
      if (this.l37(currentRoot).b1m(rect)) {
        if (ensureNotNull(this.j2p()).hasNoChildren(currentRoot)) {
          list.o(ensureNotNull(currentRoot));
        }
        visit_1(this, ensureNotNull(this.j2p()), ensureNotNull(currentRoot), rect, list);
      }
      return list;
    }
    return null;
  }
  x3c(rectangle) {
    var x1 = numberToInt(round(this.r37_1.w1l().q15(rectangle.f1m())));
    var x2 = numberToInt(round(this.r37_1.w1l().q15(rectangle.i1m())));
    var y1 = numberToInt(round(this.r37_1.x1l().q15(rectangle.h1m())));
    var y2 = numberToInt(round(this.r37_1.x1l().q15(rectangle.j1m())));
    var width = x2 - x1 | 0;
    var height = y2 - y1 | 0;
    var tmp;
    if (width < 0 || height < 0) {
      tmp = Rectangle.from(x1, y1, 0, 0);
    } else {
      tmp = Rectangle.from(x1, y1, width, height);
    }
    return tmp;
  }
  u3c(r) {
    var x1 = this.r37_1.w1l().q15(r.f1m());
    var x2 = this.r37_1.w1l().q15(r.i1m());
    var y1 = this.r37_1.x1l().q15(r.h1m());
    var y2 = this.r37_1.x1l().q15(r.j1m());
    var width = x2 - x1;
    var height = y2 - y1;
    var tmp;
    if (width < 0 || height < 0) {
      tmp = Double_3.p1m(x1, y1, 0.0, 0.0);
    } else {
      tmp = Double_3.p1m(x1, y1, width, height);
    }
    return tmp;
  }
  u2p() {
    var zoomFactorX = this.p37_1.kp() / this.p37_1.extent;
    var zoomFactorY = this.q37_1.kp() / this.q37_1.extent;
    // Inline function 'kotlin.math.min' call
    return Math.min(zoomFactorX, zoomFactorY);
  }
  s38() {
    return this.h38_1;
  }
  j37() {
    this.d39(new Long(0, 0));
  }
  w2v(x, y) {
    var model = ensureNotNull(this.j2p());
    var root = ensureNotNull(model.currentRoot);
    model.probing.e13();
    var location = new Point(x, y);
    if (!(location == null)) {
      var v = ArrayList.e1();
      var _iterator__ex2g4s = model.breadthFirstIterator(root).x();
      $l$loop_0: while (_iterator__ex2g4s.y()) {
        var treeMapNode = _iterator__ex2g4s.z();
        if (this.p38(location, this.l37(treeMapNode))) {
          if (model.hasNoChildren(treeMapNode)) {
            var world = this.z2t();
            this.o2u(false, world.f1m(), world.i1m(), world.h1m(), world.j1m());
            model.currentRoot = model.root;
            break $l$loop_0;
          }
          v.o(treeMapNode);
          if (v.a1() > 1) {
            var world_0 = this.z2t();
            this.o2u(false, world_0.f1m(), world_0.i1m(), world_0.h1m(), world_0.j1m());
            model.currentRoot = v.b1(1);
            break $l$loop_0;
          }
        }
      }
    }
  }
  e2w() {
    var model = ensureNotNull(this.j2p());
    var node = model.probing.v13();
    if (!(node == null)) {
      $l$loop: while (!(model.getParent(ensureNotNull(node)) === model.currentRoot)) {
        node = model.getParent(ensureNotNull(node));
        if (node == null) {
          break $l$loop;
        }
      }
    }
    if (!(node == null)) {
      if (!model.hasNoChildren(node)) {
        var xRange = this.p37_1;
        var yRange = this.q37_1;
        this.o2u(false, xRange.bn(), xRange.cn(), yRange.bn(), yRange.cn());
        model.currentRoot = node;
      }
    }
  }
  f2w() {
    var model = ensureNotNull(this.j2p());
    model.probing.e13();
    if (!model.isRoot(ensureNotNull(model.currentRoot))) {
      var xRange = this.p37_1;
      var yRange = this.q37_1;
      this.o2u(false, xRange.bn(), xRange.cn(), yRange.bn(), yRange.cn());
      var root = model.getParent(ensureNotNull(model.currentRoot));
      model.currentRoot = ensureNotNull(root);
    }
  }
  g2w() {
    var model = ensureNotNull(this.j2p());
    var node = model.probing.v13();
    if (!(node == null)) {
      $l$loop: while (!(model.getParent(ensureNotNull(node)) === model.currentRoot)) {
        node = model.getParent(ensureNotNull(node));
        if (node == null) {
          break $l$loop;
        }
      }
    }
    if (!(node == null) && !model.hasNoChildren(node)) {
      var rect = model.getBounds(node);
      var world = this.z2t();
      var xExtent = rect.cm();
      var yExtent = rect.dm();
      var xRangeRatio = xExtent / world.cm();
      var yRangeRatio = yExtent / world.dm();
      // Inline function 'kotlin.math.max' call
      var rangeRatio = Math.max(xRangeRatio, yRangeRatio);
      xExtent = rangeRatio * world.cm();
      yExtent = rangeRatio * world.dm();
      var x1 = rect.w1l();
      var x2 = x1 + xExtent;
      var y1 = world.j1m() - (rect.x1l() + yExtent);
      var y2 = world.j1m() - rect.x1l();
      if (x1 < world.f1m()) {
        x1 = world.f1m();
        x2 = x1 + xExtent;
      }
      if (x2 > world.i1m()) {
        x1 = world.i1m() - xExtent;
        x2 = world.i1m();
      }
      if (y1 < world.h1m()) {
        y1 = world.h1m();
        y2 = y1 + yExtent;
      }
      if (y2 > world.j1m()) {
        y1 = world.j1m() - yExtent;
        y2 = world.j1m();
      }
      this.o2u(true, x1, x2, y1, y2);
    }
  }
  h2w() {
    var world = this.z2t();
    this.o2u(true, world.f1m(), world.i1m(), world.h1m(), world.j1m());
  }
}
class Aggregation {}
class Companion_73 {
  constructor() {
    Companion_instance_73 = this;
    this.n32_1 = new NoneAggregation();
    this.o32_1 = new SumAggregation_0();
    this.p32_1 = new SizeWeightedAggregation();
    this.q32_1 = new AverageAggregation();
    this.r32_1 = new CountAggregation();
    this.s32_1 = new MinAggregation();
    this.t32_1 = new MaxAggregation();
    this.u32_1 = new StdDevAggregation();
    this.v32_1 = new AggregationFactory([this.n32_1, this.o32_1, this.p32_1, this.q32_1, this.r32_1, this.s32_1, this.t32_1, this.u32_1]);
  }
  y3c() {
    return this.v32_1;
  }
}
class AggregationFactory {
  constructor(entries) {
    Companion_getInstance_73();
    this.z3c_1 = ArrayList.e1();
    addAll(this.z3c_1, entries);
  }
  a3d() {
    return Companion_getInstance_73().o32_1;
  }
}
class Companion_74 {
  constructor() {
    Companion_instance_74 = this;
    this.BINARY_TREE = new BinaryTreeAlgorithm();
    this.SLICE = new SliceAndDiceAlgorithm();
    this.SQUARIFIED = new SquarifiedAlgorithm();
    this.SQUARIFIEDPLUS = new SquarifiedPlusAlgorithm();
    this.STRIP = new StripAlgorithm();
    this.PIVOT_BY_SPLIT_SIZE = new PivotByAlgorithm();
    this.SPLIT = new SplitAlgorithm();
    this.CIRCULAR = new CircularAlgorithm();
    this.CIRCLEPACKING = new CirclePackingAlgorithm();
    this.PIE = new PieAlgorithm();
    this.BAR = new BarAlgorithm();
    this.MATRIX = new MatrixAlgorithm();
    this.SUNBURST = new SunburstAlgorithm();
    this.ICICLE = new IcicleAlgorithm();
    this.b3d_1 = new AlgorithmFactory([this.BINARY_TREE, this.SLICE, this.SQUARIFIED, this.SQUARIFIEDPLUS, this.STRIP, this.PIVOT_BY_SPLIT_SIZE, this.SPLIT, this.CIRCULAR, this.BAR, this.PIE, this.SUNBURST, this.MATRIX, this.ICICLE]);
  }
  c3d() {
    return this.BINARY_TREE;
  }
  d3d() {
    return this.SLICE;
  }
  e3d() {
    return this.SQUARIFIED;
  }
  f3d() {
    return this.SQUARIFIEDPLUS;
  }
  g3d() {
    return this.STRIP;
  }
  h3d() {
    return this.PIVOT_BY_SPLIT_SIZE;
  }
  i3d() {
    return this.SPLIT;
  }
  j3d() {
    return this.CIRCULAR;
  }
  k3d() {
    return this.CIRCLEPACKING;
  }
  l3d() {
    return this.PIE;
  }
  m3d() {
    return this.BAR;
  }
  n3d() {
    return this.MATRIX;
  }
  o3d() {
    return this.SUNBURST;
  }
  p3d() {
    return this.ICICLE;
  }
  getInstance() {
    return this.b3d_1;
  }
}
class AlgorithmFactory {
  constructor(entries) {
    Companion_getInstance_74();
    this.q3d_1 = ArrayList.e1();
    addAll(this.q3d_1, entries);
  }
  add(entry) {
    this.q3d_1.o(entry);
  }
  getDefault() {
    return Companion_getInstance_74().SQUARIFIEDPLUS;
  }
  getAlgorithms() {
    return this.q3d_1;
  }
  get(name) {
    var _iterator__ex2g4s = this.q3d_1.x();
    while (_iterator__ex2g4s.y()) {
      var algorithm = _iterator__ex2g4s.z();
      if (equals(toString_1(algorithm), name)) {
        return algorithm;
      }
    }
    return this.getDefault();
  }
}
class AverageAggregation {
  m32(values) {
    var count = 0;
    var sum = 0.0;
    var inductionVariable = 0;
    var last = values.length;
    while (inductionVariable < last) {
      var value = values[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      if (!isInfinite(value) && !isNaN_0(value)) {
        count = count + 1 | 0;
        sum = sum + value;
      }
    }
    return sum / count;
  }
  l33() {
    return false;
  }
  toString() {
    return 'Average';
  }
}
class BackgroundParentNodeRenderer extends AbstractNodeRenderer {
  c2q(view) {
    return true;
  }
  b2q(view, root, pass) {
    return ensureNotNull(ensureNotNull(view.j2p()).settings.rendering).getParentOrder(view, root, pass);
  }
  e2q(view, node) {
    var model = ensureNotNull(view.j2p());
    return !model.isRoot(node) && !model.hasNoChildren(node);
  }
  d2q(model) {
    return ensureNotNull(model.settings.rendering).getPasses(model);
  }
  f2q(g, view, node, pass, passes, bounds, shape) {
    var model = view.j2p();
    if (!(model == null) && bounds.cm() > 0 && bounds.dm() > 0) {
      var rendering = ensureNotNull(model.settings.rendering);
      rendering.paintParent(g, view, node, pass, bounds, shape);
    }
    return true;
  }
}
class BackgroundRootNodeTreeMapRenderer {
  r3d(g, view, progress) {
    var model = view.j2p();
    if (!((model == null ? null : model.currentRoot) == null)) {
      var shape = view.l37(ensureNotNull(model.currentRoot));
      if (!(shape == null)) {
        var background = model.settings.getBackground();
        if (background == null) {
          background = view.m2q();
          if (background == null) {
            background = colorOf_4(_UByte___init__impl__g9hnc4(-17), _UByte___init__impl__g9hnc4(-17), _UByte___init__impl__g9hnc4(-17));
          }
        }
        if (!(background == null)) {
          g.n2q(background);
          var d = view.a1();
          g.s3d(0.0, 0.0, d.cm(), d.dm());
        }
      }
    }
  }
}
class Orientation extends Enum {}
class BarAlgorithm extends AbstractAlgorithm {
  constructor(marginProportion, orientation) {
    marginProportion = marginProportion === VOID ? 0.0 : marginProportion;
    orientation = orientation === VOID ? Orientation_Horizontal_getInstance() : orientation;
    super();
    this.t3d_1 = marginProportion;
    this.u3d_1 = orientation;
  }
  x2o(shape, parent, children, sumSizes, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    var bounds = shape.y1l();
    var maxSize = 0.0;
    var count = 0;
    var inductionVariable = 0;
    var last = children.length;
    while (inductionVariable < last) {
      var child = children[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      if (accessor.getSize(child) > maxSize) {
        maxSize = accessor.getSize(child);
      }
      if (accessor.getSize(child) > 0) {
        count = count + 1 | 0;
      }
    }
    switch (this.u3d_1.z2_1) {
      case 0:
        var margin = bounds.dm() * this.t3d_1 / count;
        var size = bounds.dm() * (1.0 - this.t3d_1) / count;
        var start = bounds.h1m() + margin / 2;
        var inductionVariable_0 = 0;
        var last_0 = children.length;
        while (inductionVariable_0 < last_0) {
          var child_0 = children[inductionVariable_0];
          inductionVariable_0 = inductionVariable_0 + 1 | 0;
          if (accessor.getSize(child_0) > 0) {
            var w = bounds.cm() * accessor.getSize(child_0) / maxSize;
            accessor.setShape(child_0, Double_3.p1m(0.0, start, w, size));
            start = start + (size + margin);
          } else {
            accessor.setShape(child_0, null);
          }
        }

        break;
      case 1:
        var margin_0 = bounds.cm() * this.t3d_1 / count;
        var size_0 = bounds.cm() * (1.0 - this.t3d_1) / count;
        var start_0 = bounds.f1m() + margin_0 / 2;
        var inductionVariable_1 = 0;
        var last_1 = children.length;
        while (inductionVariable_1 < last_1) {
          var child_1 = children[inductionVariable_1];
          inductionVariable_1 = inductionVariable_1 + 1 | 0;
          if (accessor.getSize(child_1) > 0) {
            var h = bounds.dm() * accessor.getSize(child_1) / maxSize;
            accessor.setShape(child_1, Double_3.p1m(start_0, bounds.j1m() - h, size_0, h));
            start_0 = start_0 + (size_0 + margin_0);
          } else {
            accessor.setShape(child_1, null);
          }
        }

        break;
      default:
        noWhenBranchMatchedException();
        break;
    }
    return false;
  }
  y2o(shape) {
    return !(shape == null) ? isInterface(shape, Rectangle2D) : false;
  }
  toString() {
    return 'Bar';
  }
}
class BinaryTreeAlgorithm extends AbstractAlgorithm {
  constructor(vertical) {
    vertical = vertical === VOID ? true : vertical;
    super();
    this.v3d_1 = vertical;
  }
  x2o(shape, parent, children, sumSizes, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    var bounds = shape.y1l();
    this.w3d(children, 0, children.length - 1 | 0, bounds, this.v3d_1, accessor);
    return false;
  }
  w3d(items, start, end, bounds, vertical, accessor) {
    if (start < end) {
      var total = this.w2o(items, start, end, accessor);
      var middle = (start + end | 0) / 2 | 0;
      var first = this.w2o(items, start, middle, accessor);
      var share = first / total;
      var x = bounds.w1l();
      var y = bounds.x1l();
      var w = bounds.cm();
      var h = bounds.dm();
      var r1;
      var r2;
      if (vertical) {
        r1 = Double_3.p1m(x, y, w * share, h);
        r2 = Double_3.p1m(x + w * share, y, w * (1 - share), h);
      } else {
        r1 = Double_3.p1m(x, y, w, h * share);
        r2 = Double_3.p1m(x, y + h * share, w, h * (1 - share));
      }
      this.w3d(items, start, middle, r1, !vertical, accessor);
      this.w3d(items, middle + 1 | 0, end, r2, !vertical, accessor);
    } else {
      accessor.setShape(items[start], bounds);
    }
  }
  y2o(shape) {
    return !(shape == null) ? isInterface(shape, Rectangle2D) : false;
  }
  x3d() {
    return 'Binary Tree';
  }
  toString() {
    return this.x3d();
  }
}
class BorderParentNodeRenderer extends AbstractNodeRenderer {
  c2q(view) {
    return true;
  }
  b2q(view, root, pass) {
    return ensureNotNull(ensureNotNull(view.j2p()).settings.rendering).getParentOrder(view, root, pass);
  }
  e2q(view, node) {
    return !ensureNotNull(view.j2p()).hasNoChildren(node);
  }
  d2q(model) {
    return ensureNotNull(model.settings.rendering).getPasses(model);
  }
  f2q(g, view, node, pass, passes, bounds, shape) {
    var model = ensureNotNull(view.j2p());
    if (bounds.cm() > 0 && bounds.dm() > 0) {
      var rendering = ensureNotNull(model.settings.rendering);
      rendering.paintParentBorder(g, node, bounds, shape, model);
    }
    return true;
  }
}
class Queue {
  constructor($outer) {
    this.a3e_1 = $outer;
    this.y3d_1 = null;
    this.z3d_1 = null;
  }
  b3e(anObject) {
    if (this.y3d_1 == null) {
      this.z3d_1 = new QNode(this.a3e_1, anObject, null);
      this.y3d_1 = this.z3d_1;
    } else {
      ensureNotNull(this.z3d_1).d3e_1 = new QNode(this.a3e_1, anObject, null);
      this.z3d_1 = ensureNotNull(this.z3d_1).d3e_1;
    }
  }
  f3e() {
    var head = this.y3d_1;
    if (!(head == null)) {
      var retval = head.c3e_1;
      var oldHead = head;
      this.y3d_1 = head.d3e_1;
      if (head == null) {
        this.z3d_1 = null;
      } else {
        oldHead.d3e_1 = null;
      }
      return retval;
    } else {
      throw NoSuchElementException.s('No more elements');
    }
  }
  g3e() {
    var head = this.y3d_1;
    if (!(head == null)) {
      return head.c3e_1;
    } else {
      throw NoSuchElementException.s('No more elements');
    }
  }
  c1() {
    return this.y3d_1 == null;
  }
}
class QNode {
  constructor($outer, _object, next) {
    this.e3e_1 = $outer;
    this.c3e_1 = _object;
    this.d3e_1 = next;
  }
}
class BreadthFirstIterator {
  constructor(model, rootNode) {
    this.i3e_1 = model;
    var v = ArrayList.o7(1);
    v.o(rootNode);
    this.h3e_1 = new Queue(this);
    this.h3e_1.b3e(v.x());
  }
  y() {
    return !this.h3e_1.c1() && this.h3e_1.g3e().y();
  }
  z() {
    var enumer = this.h3e_1.g3e();
    var node = enumer.z();
    var children = this.i3e_1.getChildren(node).x();
    if (!enumer.y()) {
      this.h3e_1.f3e();
    }
    if (children.y()) {
      this.h3e_1.b3e(children);
    }
    return node;
  }
  n5() {
    throw UnsupportedOperationException.h4();
  }
}
class Circle {
  static v3e() {
    var $this = createThis(this);
    init_com_treemap_CirclePackingAlgorithm_Circle($this);
    return $this;
  }
  static m3e(cx, cy, r) {
    var $this = createThis(this);
    init_com_treemap_CirclePackingAlgorithm_Circle($this);
    $this.j3e_1 = cx;
    $this.k3e_1 = cy;
    $this.l3e_1 = r;
    return $this;
  }
  x3e() {
    return Double_3.p1m(this.j3e_1 - this.l3e_1, this.k3e_1 - this.l3e_1, this.l3e_1 * 2.0, this.l3e_1 * 2);
  }
  y3e(c2) {
    var cmp = this.l3e_1 - c2.l3e_1;
    return cmp < 0 ? 1 : cmp > 0 ? -1 : 0;
  }
  d(other) {
    return this.y3e(other instanceof Circle ? other : THROW_CCE());
  }
  equals(other) {
    if (this === other)
      return true;
    if (other == null || !getKClassFromExpression(this).equals(getKClassFromExpression(other)))
      return false;
    if (!(other instanceof Circle))
      THROW_CCE();
    if (!(this.j3e_1 === other.j3e_1))
      return false;
    if (!(this.k3e_1 === other.k3e_1))
      return false;
    if (!(this.l3e_1 === other.l3e_1))
      return false;
    return true;
  }
  hashCode() {
    var result = getNumberHashCode(this.j3e_1);
    result = imul_0(31, result) + getNumberHashCode(this.k3e_1) | 0;
    result = imul_0(31, result) + getNumberHashCode(this.l3e_1) | 0;
    return result;
  }
  toString() {
    return toString_1(getKClassFromExpression(this)) + '[x:' + this.j3e_1 + ',y:' + this.k3e_1 + ',r:' + this.l3e_1 + ']';
  }
}
class Complex {
  constructor(x, y) {
    this.n3e_1 = x;
    this.o3e_1 = y;
  }
  t3e() {
    return this.n3e_1;
  }
  u3e() {
    return this.o3e_1;
  }
  q3e(that) {
    return new Complex(this.n3e_1 + that.n3e_1, this.o3e_1 + that.o3e_1);
  }
  r3e(that) {
    return new Complex(this.n3e_1 - that.n3e_1, this.o3e_1 - that.o3e_1);
  }
  p3e(that) {
    return new Complex(this.n3e_1 * that.n3e_1 - this.o3e_1 * that.o3e_1, this.n3e_1 * that.o3e_1 + this.o3e_1 * that.n3e_1);
  }
  s3e(that) {
    return new Complex((this.n3e_1 * that.n3e_1 + this.o3e_1 * that.o3e_1) / (that.n3e_1 * that.n3e_1 + that.o3e_1 * that.o3e_1), (this.o3e_1 * that.n3e_1 - this.n3e_1 * that.o3e_1) / (that.n3e_1 * that.n3e_1 + that.o3e_1 * that.o3e_1));
  }
  z3e() {
    var tmp0 = this.o3e_1;
    // Inline function 'kotlin.math.atan2' call
    var x = this.n3e_1;
    return Math.atan2(tmp0, x);
  }
  a3f() {
    // Inline function 'kotlin.math.sqrt' call
    var x = this.n3e_1 * this.n3e_1 + this.o3e_1 * this.o3e_1;
    return Math.sqrt(x);
  }
  xv() {
    // Inline function 'kotlin.math.sqrt' call
    var x = this.a3f();
    var r = Math.sqrt(x);
    var theta = this.z3e() / 2;
    // Inline function 'kotlin.math.cos' call
    var tmp = r * Math.cos(theta);
    // Inline function 'kotlin.math.sin' call
    var tmp$ret$2 = Math.sin(theta);
    return new Complex(tmp, r * tmp$ret$2);
  }
  equals(o) {
    if (o instanceof Complex) {
      var that = o;
      return that.n3e_1 === this.n3e_1 && that.o3e_1 === this.o3e_1;
    }
    return false;
  }
  hashCode() {
    var bits = doubleToLongBits(this.n3e_1);
    var tmp = bits;
    // Inline function 'kotlin.Long.times' call
    var tmp$ret$0 = doubleToLongBits(this.o3e_1).j3(toLong(31));
    bits = tmp.v3(tmp$ret$0);
    return bits.l1() ^ bits.r3(32).l1();
  }
  toString() {
    var tmp;
    if (this.o3e_1 >= 0) {
      tmp = '(' + this.n3e_1 + '+' + this.o3e_1 + 'i)';
    } else {
      tmp = '(' + this.n3e_1 + '' + this.o3e_1 + 'i)';
    }
    return tmp;
  }
  w3e() {
    return isNaN_0(this.n3e_1) || isNaN_0(this.o3e_1);
  }
}
class Companion_75 {
  constructor() {
    this.b3f_1 = true;
  }
  c3f(circles) {
    var tmp;
    switch (circles.a1()) {
      case 0:
        tmp = circles;
        break;
      case 1:
        var circle = circles.b1(0);
        circle.j3e_1 = 0.0;
        circle.k3e_1 = 0.0;
        tmp = circles;
        break;
      default:
        var placed_circles = ArrayList.e1();
        var _eps = 2.220446049250313E-16;
        var _iterator__ex2g4s = circles.x();
        $l$loop: while (_iterator__ex2g4s.y()) {
          var value = _iterator__ex2g4s.z();
          println('Processing ' + value.toString());
          var radius = value.l3e_1;
          var n_circles = placed_circles.a1();
          if (n_circles <= 1) {
            var x = n_circles === 0 ? radius : -radius;
            var circle_0;
            if (false) {
              circle_0 = Circle.m3e(x, 0.0, radius);
            } else {
              circle_0 = value;
              circle_0.j3e_1 = x;
              circle_0.k3e_1 = 0.0;
              circle_0.l3e_1 = radius;
            }
            placed_circles.o(circle_0);
            println('Initial ' + circle_0.toString());
            continue $l$loop;
          }
          var mhd = null;
          var lead_candidate = null;
          var _iterator__ex2g4s_0 = Itertools_instance.d3f(placed_circles, 2).x();
          while (_iterator__ex2g4s_0.y()) {
            var c = _iterator__ex2g4s_0.z();
            var c1 = c.b1(0);
            var c2 = c.b1(1);
            var indexedObject = get_placement_candidates(this, radius, c1, c2, _eps);
            var inductionVariable = 0;
            var last = indexedObject.length;
            $l$loop_1: while (inductionVariable < last) {
              var cand = indexedObject[inductionVariable];
              inductionVariable = inductionVariable + 1 | 0;
              if (!(cand == null)) {
                var other_placed_circles = ArrayList.l(placed_circles);
                if (!(c1 == null)) {
                  other_placed_circles.w2(c1);
                }
                if (!(c2 == null)) {
                  other_placed_circles.w2(c2);
                }
                var overlap = false;
                var _iterator__ex2g4s_1 = other_placed_circles.x();
                $l$loop_0: while (_iterator__ex2g4s_1.y()) {
                  var pc = _iterator__ex2g4s_1.z();
                  var dist = distance(this, pc, cand);
                  if (dist < -_eps) {
                    overlap = true;
                    break $l$loop_0;
                  }
                }
                if (overlap) {
                  continue $l$loop_1;
                }
                var hd = get_hole_degree(this, cand, placed_circles, c1, c2);
                if (mhd == null || hd > mhd) {
                  mhd = hd;
                  lead_candidate = cand;
                }
              }
            }
          }
          if (lead_candidate == null) {
            println('cannot place circle for value ' + value.toString());
            var _iterator__ex2g4s_2 = circles.x();
            while (_iterator__ex2g4s_2.y()) {
              var circle_1 = _iterator__ex2g4s_2.z();
              println('Circle: ' + circle_1.toString());
            }
            lead_candidate = value;
          }
          println('Placing ' + toString_0(lead_candidate));
          placed_circles.o(lead_candidate);
        }

        tmp = placed_circles;
        break;
    }
    return tmp;
  }
}
class CirclePackingAlgorithm {
  constructor() {
    this.e3f_1 = 0;
    this.f3f_1 = 0;
    this.g3f_1 = true;
    this.h3f_1 = true;
    this.i3f_1 = false;
    this.j3f_1 = true;
    this.k3f_1 = false;
  }
  f24() {
    return null;
  }
  q2o(bounds, model, root, worker) {
  }
  p2o(shape, parent, children, sumSizes, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    var circles = ArrayList.e1();
    var inductionVariable = 0;
    var last = children.length;
    while (inductionVariable < last) {
      var child = children[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      var circle = Circle.v3e();
      if (accessor.hasNoChildren(child)) {
        var tmp = circle;
        // Inline function 'kotlin.math.sqrt' call
        var x = accessor.getSize(child) / 3.141592653589793;
        // Inline function 'kotlin.math.max' call
        var b = Math.sqrt(x);
        tmp.l3e_1 = Math.max(0.0, b);
      } else {
        var s = accessor.getShape(child);
        if (!(s == null)) {
          if (!(s == null) ? isInterface(s, Ellipse2D) : false) {
            var b_0 = s;
            circle.l3e_1 = b_0.cm() / 2;
          } else {
            var tmp_0 = circle;
            // Inline function 'kotlin.math.sqrt' call
            var x_0 = accessor.getSize(child) / 3.141592653589793;
            // Inline function 'kotlin.math.max' call
            var b_1 = Math.sqrt(x_0);
            tmp_0.l3e_1 = Math.max(0.0, b_1);
          }
        } else {
          var tmp_1 = circle;
          // Inline function 'kotlin.math.sqrt' call
          var x_1 = accessor.getSize(child) / 3.141592653589793;
          // Inline function 'kotlin.math.max' call
          var b_2 = Math.sqrt(x_1);
          tmp_1.l3e_1 = Math.max(0.0, b_2);
        }
      }
      circles.o(circle);
    }
    var sorted = ArrayList.l(circles);
    sort(sorted);
    var placed_circles = Companion_instance_75.c3f(sorted);
    var inductionVariable_0 = 0;
    var last_0 = placed_circles.a1() - 1 | 0;
    if (inductionVariable_0 <= last_0)
      do {
        var i = inductionVariable_0;
        inductionVariable_0 = inductionVariable_0 + 1 | 0;
        var circle_0 = placed_circles.b1(i);
        var t = sorted.b1(i);
        t.j3e_1 = circle_0.j3e_1;
        t.k3e_1 = circle_0.k3e_1;
        t.l3e_1 = circle_0.l3e_1;
      }
       while (inductionVariable_0 <= last_0);
    var boundingCircle_0 = boundingCircle(Companion_instance_75, circles);
    var _iterator__ex2g4s = circles.x();
    while (_iterator__ex2g4s.y()) {
      var child_0 = _iterator__ex2g4s.z();
      child_0.j3e_1 = child_0.j3e_1 - boundingCircle_0.j3e_1;
      child_0.k3e_1 = child_0.k3e_1 - boundingCircle_0.k3e_1;
    }
    boundingCircle_0 = boundingCircle(Companion_instance_75, circles);
    if (shape == null) {
      if (!(boundingCircle_0 == null) && !isNaN_3(boundingCircle_0.l3e_1)) {
        var b_3 = boundingCircle_0.x3e();
        accessor.setShape(parent, new Double_0(b_3.w1l(), b_3.x1l(), b_3.cm(), b_3.dm()));
      } else {
        accessor.setShape(parent, null);
      }
    }
    var inductionVariable_1 = 0;
    var last_1 = children.length - 1 | 0;
    if (inductionVariable_1 <= last_1)
      do {
        var i_0 = inductionVariable_1;
        inductionVariable_1 = inductionVariable_1 + 1 | 0;
        var circle_1 = circles.b1(i_0);
        var child_1 = children[i_0];
        if (!isNaN_3(circle_1.l3e_1) && circle_1.l3e_1 > 0) {
          var b_4 = circle_1.x3e();
          accessor.setShape(child_1, new Double_0(b_4.w1l(), b_4.x1l(), b_4.cm(), b_4.dm()));
        } else {
          accessor.setShape(child_1, null);
        }
      }
       while (inductionVariable_1 <= last_1);
    return false;
  }
  x2o(shape, parent, children, sumSizes, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    var bounds = shape.y1l();
    var cb = computeBoundingBox(this, children, accessor);
    if (!(cb == null)) {
      var tmp0 = bounds.cm();
      // Inline function 'kotlin.math.min' call
      var b = bounds.dm();
      var size = Math.min(tmp0, b);
      var xs = size / cb.cm();
      var ys = size / cb.dm();
      var inductionVariable = 0;
      var last = children.length;
      while (inductionVariable < last) {
        var node = children[inductionVariable];
        inductionVariable = inductionVariable + 1 | 0;
        var tx = -cb.f1m() * xs + bounds.w1l();
        var ty = -cb.h1m() * ys + bounds.x1l();
        var tmp0_subject = this.f3f_1;
        if (tmp0_subject === 0)
          tx = tx + (bounds.cm() - size) / 2;
        else if (tmp0_subject === 2)
          tx = tx + (bounds.cm() - size);
        var tmp1_subject = this.e3f_1;
        if (tmp1_subject === 0)
          ty = ty + (bounds.dm() - size) / 2;
        else if (tmp1_subject === 3)
          ty = ty + (bounds.dm() - size);
        var at = AffineTransform.c1o(xs, 0.0, 0.0, ys, tx, ty);
        var s = accessor.getShape(node);
        if (!(s == null)) {
          var b1 = s.y1l();
          var x = ensureNotNull(at.s1o(Double_3.p1m(b1.w1l(), b1.x1l(), b1.cm(), b1.dm())));
          var b_0 = x.y1l();
          accessor.setShape(node, new Double_0(b_0.w1l(), b_0.x1l(), b_0.cm(), b_0.dm()));
        } else {
          accessor.setShape(node, null);
        }
      }
    } else {
      var inductionVariable_0 = 0;
      var last_0 = children.length;
      while (inductionVariable_0 < last_0) {
        var node_0 = children[inductionVariable_0];
        inductionVariable_0 = inductionVariable_0 + 1 | 0;
        accessor.setShape(node_0, null);
      }
    }
    return false;
  }
  r2o(bounds, model, root) {
  }
  y2o(shape) {
    var tmp;
    if (!(shape == null) ? isInterface(shape, Rectangle2D) : false) {
      tmp = true;
    } else {
      tmp = !(shape == null) ? isInterface(shape, Ellipse2D) : false;
    }
    return tmp;
  }
  s2o() {
    return this.g3f_1;
  }
  t2o() {
    return this.h3f_1;
  }
  u2o() {
    return this.i3f_1;
  }
  v2o() {
    return this.j3f_1;
  }
  toString() {
    return 'CirclePackging';
  }
}
class Pair_0 {
  static r3f(ca, cb) {
    var $this = createThis(this);
    init_com_treemap_CircularAlgorithm_Pair($this);
    $this.l3f_1 = ca;
    $this.m3f_1 = cb;
    return $this;
  }
  static s3f(ca, cb, innerSoddyRadius) {
    var $this = createThis(this);
    init_com_treemap_CircularAlgorithm_Pair($this);
    $this.l3f_1 = ca;
    $this.m3f_1 = cb;
    $this.n3f_1 = innerSoddyRadius;
    return $this;
  }
}
class Circle_0 {
  static c3g() {
    var $this = createThis(this);
    init_com_treemap_CircularAlgorithm_Circle($this);
    return $this;
  }
  static b3g(cx, cy, r) {
    var $this = createThis(this);
    init_com_treemap_CircularAlgorithm_Circle($this);
    $this.o3f_1 = cx;
    $this.p3f_1 = cy;
    $this.q3f_1 = r;
    return $this;
  }
  u3f(that, error) {
    var dist = (this.o3f_1 - that.o3f_1) * (this.o3f_1 - that.o3f_1) + (this.p3f_1 - that.p3f_1) * (this.p3f_1 - that.p3f_1);
    return dist < (this.q3f_1 + that.q3f_1) * (this.q3f_1 + that.q3f_1) - error;
  }
  t3f(that) {
    var dist = (this.o3f_1 - that.o3f_1) * (this.o3f_1 - that.o3f_1) + (this.p3f_1 - that.p3f_1) * (this.p3f_1 - that.p3f_1);
    // Inline function 'kotlin.math.sqrt' call
    return Math.sqrt(dist) - that.q3f_1;
  }
  x3e() {
    return Double_3.p1m(this.o3f_1 - this.q3f_1, this.p3f_1 - this.q3f_1, this.q3f_1 * 2.0, this.q3f_1 * 2);
  }
  d3g(c2) {
    var cmp = this.q3f_1 - c2.q3f_1;
    return cmp < 0 ? 1 : cmp > 0 ? -1 : 0;
  }
  d(other) {
    return this.d3g(other instanceof Circle_0 ? other : THROW_CCE());
  }
  toString() {
    return toString_1(getKClassFromExpression(this)) + '[x:' + this.o3f_1 + ',y:' + this.p3f_1 + ',r:' + this.q3f_1 + ']';
  }
}
class Complex_0 {
  constructor(x, y) {
    this.v3f_1 = x;
    this.w3f_1 = y;
  }
  t3e() {
    return this.v3f_1;
  }
  u3e() {
    return this.w3f_1;
  }
  y3f(that) {
    return new Complex_0(this.v3f_1 + that.v3f_1, this.w3f_1 + that.w3f_1);
  }
  z3f(that) {
    return new Complex_0(this.v3f_1 - that.v3f_1, this.w3f_1 - that.w3f_1);
  }
  x3f(that) {
    return new Complex_0(this.v3f_1 * that.v3f_1 - this.w3f_1 * that.w3f_1, this.v3f_1 * that.w3f_1 + this.w3f_1 * that.v3f_1);
  }
  a3g(that) {
    return new Complex_0((this.v3f_1 * that.v3f_1 + this.w3f_1 * that.w3f_1) / (that.v3f_1 * that.v3f_1 + that.w3f_1 * that.w3f_1), (this.w3f_1 * that.v3f_1 - this.v3f_1 * that.w3f_1) / (that.v3f_1 * that.v3f_1 + that.w3f_1 * that.w3f_1));
  }
  z3e() {
    var tmp0 = this.w3f_1;
    // Inline function 'kotlin.math.atan2' call
    var x = this.v3f_1;
    return Math.atan2(tmp0, x);
  }
  a3f() {
    // Inline function 'kotlin.math.sqrt' call
    var x = this.v3f_1 * this.v3f_1 + this.w3f_1 * this.w3f_1;
    return Math.sqrt(x);
  }
  xv() {
    // Inline function 'kotlin.math.sqrt' call
    var x = this.a3f();
    var r = Math.sqrt(x);
    var theta = this.z3e() / 2;
    // Inline function 'kotlin.math.cos' call
    var tmp = r * Math.cos(theta);
    // Inline function 'kotlin.math.sin' call
    var tmp$ret$2 = Math.sin(theta);
    return new Complex_0(tmp, r * tmp$ret$2);
  }
  equals(o) {
    if (o instanceof Complex_0) {
      var that = o;
      return that.v3f_1 === this.v3f_1 && that.w3f_1 === this.w3f_1;
    }
    return false;
  }
  hashCode() {
    var bits = doubleToLongBits(this.v3f_1);
    var tmp = bits;
    // Inline function 'kotlin.Long.times' call
    var tmp$ret$0 = doubleToLongBits(this.w3f_1).j3(toLong(31));
    bits = tmp.v3(tmp$ret$0);
    return bits.l1() ^ bits.r3(32).l1();
  }
  toString() {
    var tmp;
    if (this.w3f_1 >= 0) {
      tmp = '(' + this.v3f_1 + '+' + this.w3f_1 + 'i)';
    } else {
      tmp = '(' + this.v3f_1 + '' + this.w3f_1 + 'i)';
    }
    return tmp;
  }
  w3e() {
    return isNaN_3(this.v3f_1) || isNaN_3(this.w3f_1);
  }
}
class Companion_76 {}
class CircularAlgorithm extends AbstractAlgorithm {
  constructor() {
    super();
    this.e3g_1 = 0;
    this.f3g_1 = 0;
  }
  f24() {
    return null;
  }
  q2o(bounds, model, root, worker) {
  }
  p2o(shape, parent, children, sumSizes, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    var equalSize = true;
    var lastRadius = null;
    var circles = ArrayList.e1();
    var inductionVariable = 0;
    var last = children.length;
    while (inductionVariable < last) {
      var child = children[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      var circle = Circle_0.c3g();
      if (accessor.hasNoChildren(child)) {
        var tmp = circle;
        // Inline function 'kotlin.math.sqrt' call
        var x = accessor.getSize(child) / 3.141592653589793;
        // Inline function 'kotlin.math.max' call
        var b = Math.sqrt(x);
        tmp.q3f_1 = Math.max(0.0, b);
      } else {
        var s = ensureNotNull(accessor.getShape(child));
        if (!(s == null)) {
          if (isInterface(s, Ellipse2D)) {
            var b_0 = s;
            circle.q3f_1 = b_0.cm() / 2;
          } else {
            var tmp_0 = circle;
            // Inline function 'kotlin.math.sqrt' call
            var x_0 = accessor.getSize(child) / 3.141592653589793;
            // Inline function 'kotlin.math.max' call
            var b_1 = Math.sqrt(x_0);
            tmp_0.q3f_1 = Math.max(0.0, b_1);
          }
        } else {
          var tmp_1 = circle;
          // Inline function 'kotlin.math.sqrt' call
          var x_1 = accessor.getSize(child) / 3.141592653589793;
          // Inline function 'kotlin.math.max' call
          var b_2 = Math.sqrt(x_1);
          tmp_1.q3f_1 = Math.max(0.0, b_2);
        }
      }
      if (equalSize) {
        if (lastRadius == null) {
          lastRadius = circle.q3f_1;
        } else {
          if (!(lastRadius === circle.q3f_1)) {
            equalSize = false;
          }
        }
      }
      circles.o(circle);
    }
    if (equalSize && circles.a1() > 1 && circles.a1() <= EqualCirclesInCircle_getInstance().g3g_1.length) {
      var coordinates = EqualCirclesInCircle_getInstance().g3g_1[circles.a1() - 1 | 0];
      var radii = EqualCirclesInCircle_getInstance().h3g_1[circles.a1() - 1 | 0];
      var scale = ensureNotNull(lastRadius);
      var inductionVariable_0 = 0;
      var last_0 = circles.a1() - 1 | 0;
      if (inductionVariable_0 <= last_0)
        do {
          var i = inductionVariable_0;
          inductionVariable_0 = inductionVariable_0 + 1 | 0;
          var circle_0 = circles.b1(i);
          circle_0.o3f_1 = coordinates[imul_0(i, 2)] / radii * scale;
          circle_0.p3f_1 = coordinates[imul_0(i, 2) + 1 | 0] / radii * scale;
        }
         while (inductionVariable_0 <= last_0);
    } else {
      pairPack(Companion_instance_76, circles);
    }
    var boundingCircle = boundingCircle_0(Companion_instance_76, circles);
    var _iterator__ex2g4s = circles.x();
    while (_iterator__ex2g4s.y()) {
      var child_0 = _iterator__ex2g4s.z();
      child_0.o3f_1 = child_0.o3f_1 - boundingCircle.o3f_1;
      child_0.p3f_1 = child_0.p3f_1 - boundingCircle.p3f_1;
    }
    boundingCircle = boundingCircle_0(Companion_instance_76, circles);
    if (shape == null) {
      if (!(boundingCircle == null) && !isNaN_3(boundingCircle.q3f_1)) {
        var b_3 = boundingCircle.x3e();
        accessor.setShape(parent, new Double_0(b_3.w1l(), b_3.x1l(), b_3.cm(), b_3.dm()));
      } else {
        accessor.setShape(parent, null);
      }
    }
    var inductionVariable_1 = 0;
    var last_1 = children.length - 1 | 0;
    if (inductionVariable_1 <= last_1)
      do {
        var i_0 = inductionVariable_1;
        inductionVariable_1 = inductionVariable_1 + 1 | 0;
        var circle_1 = circles.b1(i_0);
        var child_1 = children[i_0];
        if (!isNaN_3(circle_1.q3f_1) && circle_1.q3f_1 > 0) {
          var b_4 = circle_1.x3e();
          accessor.setShape(child_1, new Double_0(b_4.w1l(), b_4.x1l(), b_4.cm(), b_4.dm()));
        } else {
          accessor.setShape(child_1, null);
        }
      }
       while (inductionVariable_1 <= last_1);
    return false;
  }
  x2o(shape, parent, children, sumSizes, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    var bounds = shape.y1l();
    var cb = computeBoundingBox_0(this, children, accessor);
    if (!(cb == null)) {
      var tmp0 = bounds.cm();
      // Inline function 'kotlin.math.min' call
      var b = bounds.dm();
      var size = Math.min(tmp0, b);
      var xs = size / cb.cm();
      var ys = size / cb.dm();
      var inductionVariable = 0;
      var last = children.length;
      while (inductionVariable < last) {
        var node = children[inductionVariable];
        inductionVariable = inductionVariable + 1 | 0;
        var tx = -cb.f1m() * xs + bounds.w1l();
        var ty = -cb.h1m() * ys + bounds.x1l();
        var tmp0_subject = this.f3g_1;
        if (tmp0_subject === 0)
          tx = tx + (bounds.cm() - size) / 2;
        else if (tmp0_subject === 2)
          tx = tx + (bounds.cm() - size);
        var tmp1_subject = this.e3g_1;
        if (tmp1_subject === 0)
          ty = ty + (bounds.dm() - size) / 2;
        else if (tmp1_subject === 3)
          ty = ty + (bounds.dm() - size);
        var at = AffineTransform.c1o(xs, 0.0, 0.0, ys, tx, ty);
        var s = accessor.getShape(node);
        if (!(s == null)) {
          var b1 = s.y1l();
          var x = ensureNotNull(at.s1o(b1));
          var b_0 = x.y1l();
          accessor.setShape(node, new Double_0(b_0.w1l(), b_0.x1l(), b_0.cm(), b_0.dm()));
        } else {
          accessor.setShape(node, null);
        }
      }
    } else {
      var inductionVariable_0 = 0;
      var last_0 = children.length;
      while (inductionVariable_0 < last_0) {
        var node_0 = children[inductionVariable_0];
        inductionVariable_0 = inductionVariable_0 + 1 | 0;
        accessor.setShape(node_0, null);
      }
    }
    return false;
  }
  r2o(bounds, model, root) {
  }
  y2o(shape) {
    var tmp;
    if (!(shape == null) ? isInterface(shape, Rectangle2D) : false) {
      tmp = true;
    } else {
      tmp = !(shape == null) ? isInterface(shape, Ellipse2D) : false;
    }
    return tmp;
  }
  s2o() {
    return true;
  }
  t2o() {
    return true;
  }
  u2o() {
    return true;
  }
  v2o() {
    return false;
  }
  x3d() {
    return 'Circular';
  }
  toString() {
    return this.x3d();
  }
}
class AscendingTreeMapNodeComparator {
  constructor(model, universal) {
    this.i3g_1 = model;
    this.j3g_1 = universal;
  }
  k2q(a, b) {
    var column = this.i3g_1.settings.colorColumn;
    return this.j3g_1.compare(this.i3g_1.getAggregateValue(a, column), this.i3g_1.getAggregateValue(b, column));
  }
  compare(a, b) {
    var tmp = (a == null ? true : !(a == null)) ? a : THROW_CCE();
    return this.k2q(tmp, (b == null ? true : !(b == null)) ? b : THROW_CCE());
  }
}
class DescendingTreeMapNodeComparator {
  constructor(model, universal) {
    this.k3g_1 = model;
    this.l3g_1 = universal;
  }
  k2q(a, b) {
    var column = this.k3g_1.settings.colorColumn;
    return this.l3g_1.compare(this.k3g_1.getAggregateValue(b, column), this.k3g_1.getAggregateValue(a, column));
  }
  compare(a, b) {
    var tmp = (a == null ? true : !(a == null)) ? a : THROW_CCE();
    return this.k2q(tmp, (b == null ? true : !(b == null)) ? b : THROW_CCE());
  }
}
class Companion_77 {
  m3g(model, nodes, sortOrder) {
    // Inline function 'kotlin.collections.copyOf' call
    // Inline function 'kotlin.js.asDynamic' call
    var copy = nodes.slice();
    var universal = new UniversalComparator();
    var comparator;
    var tmp;
    switch (sortOrder.z2_1) {
      case 0:
        tmp = new AscendingTreeMapNodeComparator(model, universal);
        break;
      case 1:
        tmp = new DescendingTreeMapNodeComparator(model, universal);
        break;
      default:
        noWhenBranchMatchedException();
        break;
    }
    comparator = tmp;
    sortedWith(copy, comparator);
    return copy;
  }
}
class Ordering {}
class ColorOrdering {
  y32(model, nodes, sortOrder) {
    return Companion_instance_77.m3g(model, nodes, sortOrder);
  }
  toString() {
    return 'By color';
  }
}
class SurroundLabeling extends AbstractLabeling {
  constructor() {
    super();
    this.t3g_1 = null;
    this.u3g_1 = 0.0;
    this.v3g_1 = 0.0;
  }
  g2p(model) {
    var font = ensureNotNull(model).settings.getDefaultColumnSettings().getHeaderFont();
    return numberToDouble(!(font == null) ? getFontSize(font) + 2 : 0);
  }
  h2p(model) {
    return 3.0;
  }
  f2p(model, shape, node) {
    var tmp;
    var tmp_0;
    if (!ensureNotNull(model).isRoot(node)) {
      var tmp_1 = model.getShape(node);
      tmp_0 = !(tmp_1 == null) ? isInterface(tmp_1, Rectangle2D) : false;
    } else {
      tmp_0 = false;
    }
    if (tmp_0) {
      var rectangle = (!(shape == null) ? isInterface(shape, Rectangle2D) : false) ? shape : THROW_CCE();
      var preferredHeight = this.w3g(model, null, rectangle, node);
      var allocatedHeight = computeAllocatedHeight(this, preferredHeight, rectangle);
      var thickness = computeThickness(this, model, rectangle, node);
      var width = rectangle.cm() - 2 * thickness;
      var height = rectangle.dm() - (thickness + allocatedHeight);
      var tmp_2;
      if (width > 0 && height > 0) {
        tmp_2 = Double_3.p1m(rectangle.w1l() + thickness, rectangle.x1l() + allocatedHeight, width, height);
      } else {
        tmp_2 = rectangle;
      }
      tmp = tmp_2;
    } else {
      tmp = shape;
    }
    return tmp;
  }
  w3g(model, g2, rectangle, node) {
    var height = 0.0;
    var columnSettings = model.settings.getColumnSettings(model.getGroupByColumn(node));
    var headerFont = columnSettings.getHeaderFont();
    if (!(headerFont == null) && !(model.getLabelName(node) == null)) {
      try {
        if (!(rectangle == null) && rectangle.dm() > 3) {
          var headerRenderer = DefaultTreeMapHeaderRenderer.h3b();
          headerRenderer.setFont(headerFont);
          var elabel = headerRenderer.m3m(model, node, Dimension.bm(numberToInt(rectangle.cm()), numberToInt(rectangle.dm())));
          var pf = ensureNotNull(this.t3g_1).y3z(elabel, g2, numberToInt(rectangle.cm()), numberToInt(rectangle.dm()));
          return pf.v2p();
        }
      } catch ($p) {
        if ($p instanceof NullPointerException) {
          var e = $p;
          printStackTrace(e);
          height = 0.0;
        } else {
          throw $p;
        }
      }
    } else {
      height = 0.0;
    }
    return height;
  }
  x2p(g2, bounds, node, view, pass, passes) {
    if (pass === 0) {
      var model = ensureNotNull(view.j2p());
      var column = model.getGroupByColumn(node);
      var columnSettings = model.settings.getColumnSettings(column);
      var headerFont = columnSettings.getHeaderFont();
      if (!(headerFont == null) && !(model.getLabelName(node) == null)) {
        var shape = ensureNotNull(model.getShape(node));
        var rectangle = shape.y1l();
        var position;
        if (isInterface(shape, Arc2D)) {
          position = Companion_instance_65.d2p(shape);
        } else {
          position = null;
        }
        var preferedHeight = this.w3g(model, g2, rectangle, node);
        var height = computeAllocatedHeight(this, preferedHeight, rectangle);
        if (!(rectangle == null) || (!(position == null) && height > 0)) {
          var screenRectangle = view.u3c(rectangle);
          var fontSize = getFontSize(headerFont) * view.u2p();
          var rect;
          var elabel;
          if (fontSize >= 5.0) {
            var foreground = this.q3g(node, model);
            elabel = ensureNotNull(view.p3c()).m3m(model, node, Dimension.bm(bounds.s20_1, bounds.t20_1));
            var pf = g2.q2p(elabel, bounds.s20_1, bounds.t20_1);
            var insets = ensureNotNull(columnSettings.getHeaderInsets());
            elabel.setInsets(numberToInt(insets.j22_1 * view.u2p()), numberToInt(insets.k22_1 * view.u2p()), numberToInt(insets.l22_1 * view.u2p()), numberToInt(insets.m22_1 * view.u2p()));
            var background = this.s3g(node, model);
            var derivedFont;
            var tmp;
            if (!(fontSize === getFontSize(headerFont))) {
              tmp = headerFont.u2d(fontSize);
            } else {
              tmp = headerFont;
            }
            derivedFont = tmp;
            elabel.setFont(derivedFont);
            elabel.setForeground(ensureNotNull(foreground));
            elabel.setBackground(ensureNotNull(background));
            var size = pf.s2p();
            if (!(position == null)) {
              var tmp0 = size.cm();
              // Inline function 'kotlin.math.min' call
              var b = screenRectangle.cm();
              var w = Math.min(tmp0, b);
              if (isInterface(shape, Arc2D)) {
                var arc = shape;
                var startPoint = arc.q1p();
                var endPoint = arc.r1p();
                var s = Double_2.s1p(view.v3c(startPoint.w1l()), view.w3c(startPoint.x1l()));
                var e = Double_2.s1p(view.v3c(endPoint.w1l()), view.w3c(endPoint.x1l()));
                var tmp2 = s.j20(e);
                // Inline function 'kotlin.math.min' call
                var b_0 = w;
                w = Math.min(tmp2, b_0);
              }
              var tmp4 = size.dm();
              // Inline function 'kotlin.math.min' call
              var b_1 = screenRectangle.dm();
              var h = Math.min(tmp4, b_1);
              var x = view.v3c(position.w1l()) - w / 2;
              var y = view.w3c(position.x1l()) - h / 2;
              rect = Double_3.p1m(x, y, w, h).k1m(bounds);
            } else {
              var nestedShapeWorld = model.getNestedShape(node);
              var nestedShapeWorldBounds = ensureNotNull(nestedShapeWorld).y1l();
              var preferredHeight = this.w3g(model, null, rectangle, node);
              var allocatedHeight = computeAllocatedHeight(this, preferredHeight, rectangle);
              var thickness = computeThickness(this, model, rectangle, node);
              rect = view.u3c(Double_3.p1m(nestedShapeWorldBounds.w1l() + thickness, rectangle.x1l(), nestedShapeWorldBounds.cm() - 2 * thickness, allocatedHeight));
            }
          } else {
            elabel = null;
            var nestedShapeWorld_0 = model.getNestedShape(node);
            var nestedShapeWorldBounds_0 = ensureNotNull(nestedShapeWorld_0).y1l();
            var preferredHeight_0 = this.w3g(model, null, rectangle, node);
            var allocatedHeight_0 = computeAllocatedHeight(this, preferredHeight_0, rectangle);
            var thickness_0 = computeThickness(this, model, rectangle, node);
            rect = view.u3c(Double_3.p1m(nestedShapeWorldBounds_0.w1l() + thickness_0, rectangle.x1l(), nestedShapeWorldBounds_0.cm() - 2 * thickness_0, allocatedHeight_0));
          }
          if (isInterface(shape, Rectangle2D)) {
            var backgroundColor = this.r3g(node, model);
            g2.n2q(backgroundColor);
            g2.s3d(rect.w1l(), rect.x1l(), rect.cm(), rect.dm());
          }
          if (!(elabel == null) && rect.cm() > 8) {
            var b_2 = rect.y1l();
            elabel.setDesiredWidth(numberToInt(b_2.cm() - elabel.getInsetLeft() - elabel.getInsetRight()));
            elabel.setDesiredHeight(numberToInt(b_2.dm() - elabel.getInsetTop() - elabel.getInsetBottom()));
            var font = ensureNotNull(elabel.getFont());
            var pf_0 = g2.q2p(elabel, numberToInt(b_2.cm()), numberToInt(b_2.dm()));
            var shrink = true;
            var expand = false;
            var tmp_0;
            if (!(columnSettings.getHeaderRendering() === Rendering_WordWrap_getInstance())) {
              var preferredSize = pf_0.s2p();
              var scaleY = (b_2.dm() - elabel.getInsetTop() - elabel.getInsetBottom()) / (preferredSize.dm() - elabel.getInsetTop() - elabel.getInsetBottom());
              tmp_0 = getFontSize(headerFont) * view.u2p() * scaleY * 1;
            } else {
              tmp_0 = g2.r2p(elabel, pf_0, font, b_2, 0.99, expand);
            }
            fontSize = tmp_0;
            if (!shrink) {
              var tmp6 = getFontSize(font);
              // Inline function 'kotlin.math.max' call
              var b_3 = fontSize;
              fontSize = Math.max(tmp6, b_3);
            }
            if (!expand) {
              var tmp8 = getFontSize(font);
              // Inline function 'kotlin.math.min' call
              var b_4 = fontSize;
              fontSize = Math.min(tmp8, b_4);
            }
            var derivedFont_0;
            var tmp_1;
            if (!(fontSize === getFontSize(ensureNotNull(elabel.getFont())))) {
              tmp_1 = ensureNotNull(elabel.getFont()).u2d(fontSize);
            } else {
              tmp_1 = ensureNotNull(elabel.getFont());
            }
            derivedFont_0 = tmp_1;
            elabel.setFont(derivedFont_0);
            g2.w2p(elabel, numberToInt(b_2.w1l()), numberToInt(b_2.x1l()), numberToInt(b_2.cm()), numberToInt(b_2.dm()));
          }
        }
      }
    }
  }
  r3g(node, model) {
    return model.settings.getColumnSettings(model.getGroupByColumn(node)).getHeaderBackground();
  }
  q3g(node, model) {
    return model.settings.getColumnSettings(model.getGroupByColumn(node)).getHeaderForeground();
  }
  s3g(node, model) {
    return model.settings.getColumnSettings(model.getGroupByColumn(node)).getHeaderEffectColor();
  }
  toString() {
    return 'Surround';
  }
}
class ColoredSurroundLabeling extends SurroundLabeling {
  q3g(node, model) {
    var foreground = model.settings.getColumnSettings(model.getGroupByColumn(node)).getHeaderForeground();
    var background = this.r3g(node, model);
    if (!(background == null)) {
      foreground = ensureNotNull(model.settings.getColumnSettings(model.getGroupByColumn(node)).getLabelingContrastEnhancement()).p22(ensureNotNull(foreground), background);
    }
    return foreground;
  }
  s3g(node, model) {
    return model.settings.getColumnSettings(model.getGroupByColumn(node)).getHeaderEffectColor();
  }
  r3g(node, model) {
    return model.getColor(node);
  }
  toString() {
    return 'Surround (Colored)';
  }
}
class CombinationGenerator {
  x3g(n, r) {
    var rfact = 1;
    var nfact = 1;
    var nrfact = 1;
    var temp1 = n - r | 0;
    var temp2 = r;
    if (r > (n - r | 0)) {
      temp1 = r;
      temp2 = n - r | 0;
    }
    var inductionVariable = 1;
    if (inductionVariable <= n)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        if (i <= temp2) {
          rfact = imul_0(rfact, i);
          nrfact = imul_0(nrfact, i);
        } else if (i <= temp1) {
          nrfact = imul_0(nrfact, i);
        }
        nfact = imul_0(nfact, i);
      }
       while (!(i === n));
    return nfact / imul_0(rfact, nrfact);
  }
  y3g(temp, n, r) {
    var m = r;
    var maxVal = n;
    while (temp[m - 1 | 0] === maxVal) {
      m = m - 1 | 0;
      maxVal = maxVal - 1 | 0;
    }
    var _index_0__fvwizt = m - 1 | 0;
    temp[_index_0__fvwizt] = temp[_index_0__fvwizt] + 1 | 0;
    var inductionVariable = m;
    if (inductionVariable < r)
      do {
        var j = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        temp[j] = temp[j - 1 | 0] + 1 | 0;
      }
       while (inductionVariable < r);
    return temp;
  }
}
class CountAggregation {
  m32(values) {
    var count = 0;
    var inductionVariable = 0;
    var last = values.length;
    while (inductionVariable < last) {
      var value = values[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      if (!isInfinite(value) && !isNaN_0(value)) {
        count = count + 1 | 0;
      }
    }
    return count;
  }
  l33() {
    return false;
  }
  toString() {
    return 'Count';
  }
}
class Cushion {
  static g34(model, left, right, width, top, bottom, height) {
    var $this = createThis(this);
    init_com_treemap_Cushion($this);
    var h4 = 4 * model.settings.getLightSourceHeight();
    var wf;
    var tmp;
    if (width <= 0) {
      tmp = 0.0;
    } else {
      tmp = h4 / width;
    }
    wf = tmp;
    $this.r33_1[2] = wf * (right + left | 0);
    $this.r33_1[0] = -wf;
    var hf;
    var tmp_0;
    if (height <= 0) {
      tmp_0 = 0.0;
    } else {
      tmp_0 = h4 / height;
    }
    hf = tmp_0;
    $this.r33_1[3] = +(hf * (bottom + top | 0));
    $this.r33_1[1] = -hf;
    return $this;
  }
  static f34(master, model, left, right, width, top, bottom, height) {
    var $this = createThis(this);
    init_com_treemap_Cushion($this);
    if (!(master == null)) {
      var h4 = 4 * ensureNotNull(model).settings.getLightSourceHeight();
      var wf;
      var tmp;
      if (width <= 0) {
        tmp = 0.0;
      } else {
        tmp = h4 / width;
      }
      wf = tmp;
      $this.r33_1[2] = master.r33_1[2] + wf * (right + left | 0);
      $this.r33_1[0] = master.r33_1[0] - wf;
      var hf;
      var tmp_0;
      if (height <= 0) {
        tmp_0 = 0.0;
      } else {
        tmp_0 = h4 / height;
      }
      hf = tmp_0;
      $this.r33_1[3] = master.r33_1[3] + hf * (bottom + top | 0);
      $this.r33_1[1] = master.r33_1[1] - hf;
    }
    return $this;
  }
  s33(model, color, x, y, width, height, raster) {
    if (!(color == null)) {
      var bottom = y + height | 0;
      var right = x + width | 0;
      // Inline function 'kotlin.UByte.toDouble' call
      // Inline function 'kotlin.UByte.toInt' call
      var this_0 = getURed(color);
      var tmp$ret$0 = _UByte___get_data__impl__jof9qr(this_0) & 255;
      var colR = uintToDouble(tmp$ret$0);
      // Inline function 'kotlin.UByte.toDouble' call
      // Inline function 'kotlin.UByte.toInt' call
      var this_1 = getUGreen(color);
      var tmp$ret$2 = _UByte___get_data__impl__jof9qr(this_1) & 255;
      var colG = uintToDouble(tmp$ret$2);
      // Inline function 'kotlin.UByte.toDouble' call
      // Inline function 'kotlin.UByte.toInt' call
      var this_2 = getUBlue(color);
      var tmp$ret$4 = _UByte___get_data__impl__jof9qr(this_2) & 255;
      var colB = uintToDouble(tmp$ret$4);
      var ia = ensureNotNull(model).settings.getLightSourceAmbient();
      var is = 1 - model.settings.getLightSourceAmbient();
      var lx = model.normalizedLightSourceX;
      var ly = model.normalizedLightSourceY;
      var lz = model.normalizedLightSourceZ;
      var s0 = 2 * this.r33_1[0];
      var s1 = 2 * this.r33_1[1];
      var s2 = this.r33_1[2];
      var s3 = this.r33_1[3];
      if (!raster.h2e()) {
        var base = 0;
        var data = new Int32Array(imul_0(width, height));
        var inductionVariable = y;
        if (inductionVariable < bottom)
          do {
            var iy = inductionVariable;
            inductionVariable = inductionVariable + 1 | 0;
            var ny = -(s1 * (iy + 0.5) + s3);
            var inductionVariable_0 = x;
            if (inductionVariable_0 < right)
              do {
                var ix = inductionVariable_0;
                inductionVariable_0 = inductionVariable_0 + 1 | 0;
                var nx = -(s0 * (ix + 0.5) + s2);
                var tmp = nx * lx + ny * ly + lz;
                // Inline function 'kotlin.math.sqrt' call
                var x_0 = nx * nx + ny * ny + 1.0;
                // Inline function 'kotlin.math.min' call
                var b = tmp / Math.sqrt(x_0);
                var cosa = Math.min(1.0, b);
                // Inline function 'kotlin.math.max' call
                var b_0 = is * cosa + ia;
                // Inline function 'kotlin.math.min' call
                var b_1 = Math.max(0.0, b_0);
                var pixel = Math.min(1.0, b_1);
                var red = numberToInt(colR * pixel);
                var green = numberToInt(colG * pixel);
                var blue = numberToInt(colB * pixel);
                // Inline function 'kotlin.UByte.toInt' call
                var this_3 = getUAlpha(color);
                var alpha = _UByte___get_data__impl__jof9qr(this_3) & 255;
                data[base] = (((alpha << 24) + (red << 16) | 0) + (green << 8) | 0) + blue | 0;
                base = base + 1 | 0;
              }
               while (inductionVariable_0 < right);
          }
           while (inductionVariable < bottom);
        raster.g2e(0, 0, width, height, data);
      } else {
        var base_0 = 0;
        var data_0 = new Int32Array(imul_0(width, height) << 2);
        var inductionVariable_1 = y;
        if (inductionVariable_1 < bottom)
          do {
            var iy_0 = inductionVariable_1;
            inductionVariable_1 = inductionVariable_1 + 1 | 0;
            var ny_0 = -(s1 * (iy_0 + 0.5) + s3);
            var inductionVariable_2 = x;
            if (inductionVariable_2 < right)
              do {
                var ix_0 = inductionVariable_2;
                inductionVariable_2 = inductionVariable_2 + 1 | 0;
                var nx_0 = -(s0 * (ix_0 + 0.5) + s2);
                var tmp_0 = nx_0 * lx + ny_0 * ly + lz;
                // Inline function 'kotlin.math.sqrt' call
                var x_1 = nx_0 * nx_0 + ny_0 * ny_0 + 1.0;
                // Inline function 'kotlin.math.min' call
                var b_2 = tmp_0 / Math.sqrt(x_1);
                var cosa_0 = Math.min(1.0, b_2);
                // Inline function 'kotlin.math.max' call
                var b_3 = is * cosa_0 + ia;
                // Inline function 'kotlin.math.min' call
                var b_4 = Math.max(0.0, b_3);
                var pixel_0 = Math.min(1.0, b_4);
                var red_0 = numberToInt(colR * pixel_0);
                var green_0 = numberToInt(colG * pixel_0);
                var blue_0 = numberToInt(colB * pixel_0);
                // Inline function 'kotlin.UByte.toInt' call
                var this_4 = getUAlpha(color);
                var alpha_0 = _UByte___get_data__impl__jof9qr(this_4) & 255;
                var _unary__edvuaz = base_0;
                base_0 = _unary__edvuaz + 1 | 0;
                data_0[_unary__edvuaz] = red_0;
                var _unary__edvuaz_0 = base_0;
                base_0 = _unary__edvuaz_0 + 1 | 0;
                data_0[_unary__edvuaz_0] = green_0;
                var _unary__edvuaz_1 = base_0;
                base_0 = _unary__edvuaz_1 + 1 | 0;
                data_0[_unary__edvuaz_1] = blue_0;
                var _unary__edvuaz_2 = base_0;
                base_0 = _unary__edvuaz_2 + 1 | 0;
                data_0[_unary__edvuaz_2] = alpha_0;
              }
               while (inductionVariable_2 < right);
          }
           while (inductionVariable_1 < bottom);
        raster.g2e(0, 0, width, height, data_0);
      }
    }
  }
  j34(model, color, x, y, width, height) {
    var tmp;
    if (!(color == null)) {
      var bottom = y + height | 0;
      var right = x + width | 0;
      // Inline function 'kotlin.UByte.toDouble' call
      // Inline function 'kotlin.UByte.toInt' call
      var this_0 = getURed(color);
      var tmp$ret$0 = _UByte___get_data__impl__jof9qr(this_0) & 255;
      var colR = uintToDouble(tmp$ret$0);
      // Inline function 'kotlin.UByte.toDouble' call
      // Inline function 'kotlin.UByte.toInt' call
      var this_1 = getUGreen(color);
      var tmp$ret$2 = _UByte___get_data__impl__jof9qr(this_1) & 255;
      var colG = uintToDouble(tmp$ret$2);
      // Inline function 'kotlin.UByte.toDouble' call
      // Inline function 'kotlin.UByte.toInt' call
      var this_2 = getUBlue(color);
      var tmp$ret$4 = _UByte___get_data__impl__jof9qr(this_2) & 255;
      var colB = uintToDouble(tmp$ret$4);
      var ia = model.settings.getLightSourceAmbient();
      var is = 1 - model.settings.getLightSourceAmbient();
      var lx = model.normalizedLightSourceX;
      var ly = model.normalizedLightSourceY;
      var lz = model.normalizedLightSourceZ;
      var s0 = 2 * this.r33_1[0];
      var s1 = 2 * this.r33_1[1];
      var s2 = this.r33_1[2];
      var s3 = this.r33_1[3];
      var iy = (y + bottom | 0) / 2 | 0;
      var ix = (x + right | 0) / 2 | 0;
      var nx = -(s0 * (ix + 0.5) + s2);
      var ny = -(s1 * (iy + 0.5) + s3);
      var tmp_0 = nx * lx + ny * ly + lz;
      // Inline function 'kotlin.math.sqrt' call
      var x_0 = nx * nx + ny * ny + 1.0;
      // Inline function 'kotlin.math.min' call
      var b = tmp_0 / Math.sqrt(x_0);
      var cosa = Math.min(1.0, b);
      // Inline function 'kotlin.math.max' call
      var b_0 = is * cosa + ia;
      // Inline function 'kotlin.math.min' call
      var b_1 = Math.max(0.0, b_0);
      var pixel = Math.min(1.0, b_1);
      var red = numberToInt(colR * pixel);
      var green = numberToInt(colG * pixel);
      var blue = numberToInt(colB * pixel);
      tmp = colorOf_1(red, green, blue);
    } else {
      tmp = null;
    }
    return tmp;
  }
}
class CushionRendering extends AbstractRendering {
  constructor() {
    super();
    this.d3h_1 = false;
  }
  paintNode(g, view, node, pass, bounds, shape) {
    var completed = true;
    var model = ensureNotNull(view.j2p());
    if (pass === 0) {
      if (!model.filter.ol(node) && !model.search.ol(node)) {
        if (shape instanceof TextShape) {
          var textShape = shape;
          var cushionColor = model.getCushionColor(node);
          var color = !(cushionColor == null) ? cushionColor : model.getColor(node);
          if (!(color == null)) {
            g.n2q(color);
            if (textShape.c22()) {
              g.o2q(shape);
            } else {
              g.h3h(ensureNotNull(textShape.b22_1));
              var bounds2D = textShape.y1l();
              g.i3h(textShape.z21_1, bounds2D.w1l(), bounds2D.j1m());
            }
          }
        } else {
          var image;
          var tmp;
          var tmp_0;
          var tmp_1;
          if (isInterface(shape, Rectangle2D)) {
            tmp_1 = bounds.cm() > 4;
          } else {
            tmp_1 = false;
          }
          if (tmp_1) {
            tmp_0 = bounds.dm() > 4;
          } else {
            tmp_0 = false;
          }
          if (tmp_0) {
            tmp = true;
          } else {
            var tmp_2;
            var tmp_3;
            if (!isInterface(shape, Rectangle2D)) {
              tmp_3 = bounds.cm() > 6;
            } else {
              tmp_3 = false;
            }
            if (tmp_3) {
              tmp_2 = bounds.dm() > 6;
            } else {
              tmp_2 = false;
            }
            tmp = tmp_2;
          }
          var cushionEnabled = tmp;
          var tmp_4;
          if (cushionEnabled) {
            var tmp_5;
            try {
              tmp_5 = model.getCushionImage(node);
            } catch ($p) {
              var tmp_6;
              if ($p instanceof Error) {
                var e = $p;
                printStackTrace(e);
                tmp_6 = null;
              } else {
                throw $p;
              }
              tmp_5 = tmp_6;
            }
            tmp_4 = tmp_5;
          } else {
            tmp_4 = null;
          }
          image = tmp_4;
          if (!(image == null)) {
            completed = paintCushion(this, g, view, image, bounds, shape);
          } else {
            var cushionColor_0 = model.getCushionColor(node);
            var color_0 = !(cushionColor_0 == null) ? cushionColor_0 : model.getColor(node);
            if (!(color_0 == null)) {
              g.n2q(color_0);
              g.o2q(shape);
            }
          }
        }
      } else {
        var color_1 = view.m2q();
        if (!(color_1 == null)) {
          g.n2q(color_1);
          g.o2q(shape);
        }
      }
    } else if (pass === 1) {
      if (isInterface(shape, Rectangle2D)) {
        if (!model.filter.ol(node) && !model.search.ol(node)) {
          var bottom = shape;
          var tmp_7 = this.getRenderedShape(view, model, node, shape);
          var top = isInterface(tmp_7, Rectangle2D) ? tmp_7 : THROW_CCE();
          var image_0;
          var cushionEnabled_0 = bounds.cm() > 4 && bounds.dm() > 4;
          var tmp_8;
          if (cushionEnabled_0) {
            var tmp_9;
            try {
              tmp_9 = model.getCushionImage(node);
            } catch ($p) {
              var tmp_10;
              if ($p instanceof Error) {
                var e_0 = $p;
                printStackTrace(e_0);
                tmp_10 = null;
              } else {
                throw $p;
              }
              tmp_9 = tmp_10;
            }
            tmp_8 = tmp_9;
          } else {
            tmp_8 = null;
          }
          image_0 = tmp_8;
          if (!(image_0 == null)) {
            var b = top.y1l();
            completed = paintCushion(this, g, view, image_0, Rectangle.from(numberToInt(b.w1l()), numberToInt(b.x1l()), numberToInt(b.cm()), numberToInt(b.dm())), top);
          } else {
            var cushionColor_1 = model.getCushionColor(node);
            g.n2q(!(cushionColor_1 == null) ? cushionColor_1 : model.getColor(node));
            g.o2q(shape);
          }
          var color_2 = ensureNotNull(model.getColor(node));
          var g2 = g.e3h();
          g2.h22();
          g2.c20(top.f1m(), top.j1m());
          g2.d20(bottom.w1l(), bottom.j1m());
          g2.d20(bottom.i1m(), bottom.j1m());
          g2.d20(top.i1m(), top.j1m());
          g2.g20();
          g2.g22(darker(color_2));
          g2.i22();
          g2.h22();
          g2.c20(top.i1m(), top.j1m());
          g2.d20(bottom.i1m(), bottom.j1m());
          g2.d20(bottom.i1m(), bottom.h1m());
          g2.d20(top.i1m(), top.h1m());
          g2.g20();
          g2.g22(darker(color_2));
          g2.i22();
          if (this.d3h_1) {
            g.a2r(g.q30().e2c());
            g.f3h(top.w1l(), top.x1l(), top.cm(), top.dm());
            g.g3h(numberToInt(top.f1m()), numberToInt(top.j1m()), numberToInt(bottom.w1l()), numberToInt(bottom.j1m()));
            g.g3h(numberToInt(top.i1m()), numberToInt(top.j1m()), numberToInt(bottom.i1m()), numberToInt(bottom.j1m()));
            g.g3h(numberToInt(top.i1m()), numberToInt(top.h1m()), numberToInt(bottom.i1m()), numberToInt(bottom.h1m()));
          }
        }
      }
    }
    return completed;
  }
  paintBorder(g2, view, node, pass, bounds, shape) {
  }
  toString() {
    return 'Cushion';
  }
}
class DefaultAlgorithmFactory_0 {
  i26() {
    return Companion_getInstance_74().getInstance();
  }
  get instance() {
    return this.i26();
  }
}
class DefaultTreeMap extends AbstractTreeMap {
  static m3h() {
    var $this = this.g2r();
    $this.view = $this.n3h();
    $this.controller = $this.o3h($this.view);
    return $this;
  }
  static p3h(model) {
    var $this = this.m3h();
    $this.model = model;
    return $this;
  }
  r2r() {
    return ensureNotNull(this.view).r2r();
  }
  q3h(dataFrame) {
    this.model = this.r3h(dataFrame);
  }
  r3h(dataFrame) {
    return new DefaultTreeMapModel(dataFrame);
  }
  n3h() {
    return new DefaultTreeMapView();
  }
  o3h(view) {
    return new DefaultTreeMapController(ensureNotNull(view));
  }
  get component() {
    return this.r2r();
  }
  get view() {
    return this.l2r();
  }
  set view(value) {
    this.h2r(value);
  }
  get controller() {
    return this.p2r();
  }
  set controller(value) {
    this.m2r(value);
  }
  get model() {
    return this.j2p();
  }
  set model(value) {
    this.q2r(value);
  }
}
class Companion_78 {
  constructor() {
    this.s3h_1 = 'Tahoma, Trebuchet MS, Arial, Helvetica, sans-serif';
  }
  getDefaultTooltipFont(fontFactory) {
    return findFont(this, 'Tahoma, Trebuchet MS, Arial, Helvetica, sans-serif', 0, 12.0, fontFactory.b24(), fontFactory);
  }
  getDefaultLabelingFont(fontFactory) {
    return findFont(this, 'Tahoma, Trebuchet MS, Arial, Helvetica, sans-serif', 0, 12.0, fontFactory.b24(), fontFactory);
  }
  getDefaultHeaderFont(fontFactory) {
    return findFont(this, 'Tahoma, Trebuchet MS, Arial, Helvetica, sans-serif', 0, 13.0, fontFactory.b24(), fontFactory);
  }
}
class DefaultTreeMapColumnSettings extends AbstractTreeMapColumnSettings {
  constructor(colorFactory, fontFactory, colorMapFactory) {
    super();
    this.t3h_1 = new SimpleProperties();
    this.borderThickness = SimpleBoundedInterval.lp(0.0, 0.0, 10.0);
    this.format = null;
    this.colorMap = null;
    this.u3h_1 = colorFactory;
    this.v3h_1 = fontFactory;
    this._algorithm = this.t3h_1.wy('algorithm', new MutableAlgorithmProperty(Companion_getInstance_74().getInstance().getDefault()));
    this.algorithm = PropertySingleSelection.h14(this._algorithm);
    this._aggregation = this.t3h_1.vy('aggregation', Companion_getInstance_73().y3c().a3d());
    this._scale = this.t3h_1.vy('scale', Companion_getInstance_92().g3i_1.i3i());
    this._nesting = this.t3h_1.vy('nesting', Companion_getInstance_85().y3c().a3d());
    this._ordering = this.t3h_1.vy('ordering', Companion_getInstance_87().y3c().a3d());
    this.orderingDirection = this.t3h_1.vy('orderingDirection', SortOrder_Descending_getInstance());
    this.orderingHorizontalVanishingPoint = this.t3h_1.vy('orderingHorizontalVanishingPoint', 4);
    this.orderingVerticalVanishingPoint = this.t3h_1.vy('orderingVerticalVanishingPoint', 3);
    this._labeling = this.t3h_1.vy('labeling', Companion_getInstance_83().y3c().a3d());
    this._labelingFont = this.t3h_1.vy('labelingFont', Companion_instance_78.getDefaultLabelingFont(fontFactory));
    this._labelingForeground = this.t3h_1.vy('labelingForeground', colorOf_1(32, 32, 32));
    this._labelingBackground = this.t3h_1.vy('labelingEffectColor', null);
    this.labelingEffect = this.t3h_1.vy('labelingEffect', null);
    this.labelingHorizontalAlignment = this.t3h_1.vy('labelingHorizontalAlignment', 2);
    this.labelingVerticalAlignment = this.t3h_1.vy('labelingVerticalAlignment', 1);
    this.labelingRendering = this.t3h_1.vy('labelingRendering', Rendering_Clip_getInstance());
    this.labelingMinimumCharactersToDisplay = this.t3h_1.vy('labelingMinimumCharactersToDisplay', 1);
    this.labelingEffectOpacity = this.t3h_1.vy('labelingEffectOpacity', null);
    this.labelingShrinkTextToFitShape = this.t3h_1.vy('labelingShrinkTextToFitShape', false);
    this.labelingResizeTextToFitShape = this.t3h_1.vy('labelingResizeTextToFitShape', false);
    this.labelingFloat = this.t3h_1.vy('labelingFloat', false);
    this.labelingContrastEnhancement = this.t3h_1.vy('labelingContrastEnhancement', Brightness_getInstance());
    this.nestingAmount = this.t3h_1.vy('nestingAmount', 1.0);
    this.nestingBackground = this.t3h_1.vy('nestingBackground', colorOf_1(180, 180, 180));
    this._headerFont = this.t3h_1.vy('headerFont', Companion_instance_78.getDefaultHeaderFont(fontFactory));
    this._headerForeground = this.t3h_1.vy('headerForeground', colorOf_1(64, 64, 64));
    this._headerEffectColor = this.t3h_1.vy('headerEffectColor', colorOf_1(255, 255, 255));
    this._headerBackground = this.t3h_1.vy('headerBackground', colorOf_1(204, 204, 204));
    this.headerEffect = this.t3h_1.vy('headerEffect', null);
    this.headerHorizontalAlignment = this.t3h_1.vy('headerHorizontalAlignment', 0);
    this.headerVerticalAlignment = this.t3h_1.vy('headerVerticalAlignment', 0);
    this.headerRendering = this.t3h_1.vy('headerRendering', Rendering_Clip_getInstance());
    this.headerMinimumCharactersToDisplay = this.t3h_1.vy('headerMinimumCharactersToDisplay', 1);
    this.headerEffectOpacity = this.t3h_1.vy('headerEffectOpacity', null);
    this.headerInsets = this.t3h_1.vy('headerInsets', new Insets(1, 1, 0, 1));
    this.tooltipFont = this.t3h_1.vy('tooltipFont', Companion_instance_78.getDefaultLabelingFont(fontFactory));
    this.tooltipForeground = this.t3h_1.vy('tooltipForeground', colorOf_1(32, 32, 32));
    this.tooltipShowLabel = this.t3h_1.vy('showLabel', false);
    this.tooltipRendering = this.t3h_1.vy('tooltipRendering', Rendering_Truncate_getInstance());
    this._borderThickness = this.t3h_1.wy('borderThickness', new BoundedIntervalProperty(this.borderThickness, StartEnd_Start_getInstance()));
    this.borderColor = this.t3h_1.vy('borderColor', colorOf_1(96, 96, 96));
    this.format = this.t3h_1.vy('format', null);
    this.colorMap = this.t3h_1.wy('colormap', new MutableColorMapProperty(null));
    this.reset();
  }
  f24() {
    return this.t3h_1;
  }
  b3j() {
    return this.algorithm;
  }
  c3j() {
    return this.borderThickness;
  }
  d3j(_set____db54di) {
    this.labelingEffect = _set____db54di;
  }
  e3j() {
    return this.labelingEffect;
  }
  f3j(_set____db54di) {
    this.labelingHorizontalAlignment = _set____db54di;
  }
  g3j() {
    return this.labelingHorizontalAlignment;
  }
  h3j(_set____db54di) {
    this.labelingVerticalAlignment = _set____db54di;
  }
  i3j() {
    return this.labelingVerticalAlignment;
  }
  j3j(_set____db54di) {
    this.labelingRendering = _set____db54di;
  }
  k3j() {
    return this.labelingRendering;
  }
  l3j(_set____db54di) {
    this.headerEffect = _set____db54di;
  }
  m3j() {
    return this.headerEffect;
  }
  n3j(_set____db54di) {
    this.headerHorizontalAlignment = _set____db54di;
  }
  o3j() {
    return this.headerHorizontalAlignment;
  }
  p3j(_set____db54di) {
    this.headerVerticalAlignment = _set____db54di;
  }
  q3j() {
    return this.headerVerticalAlignment;
  }
  r3j(_set____db54di) {
    this.headerRendering = _set____db54di;
  }
  s3j() {
    return this.headerRendering;
  }
  t3j(_set____db54di) {
    this.tooltipRendering = _set____db54di;
  }
  u3j() {
    return this.tooltipRendering;
  }
  v3j(_set____db54di) {
    this._algorithm = _set____db54di;
  }
  w3j() {
    return this._algorithm;
  }
  x3j(_set____db54di) {
    this._aggregation = _set____db54di;
  }
  y3j() {
    return this._aggregation;
  }
  z3j(_set____db54di) {
    this._scale = _set____db54di;
  }
  a3k() {
    return this._scale;
  }
  b3k(_set____db54di) {
    this._nesting = _set____db54di;
  }
  c3k() {
    return this._nesting;
  }
  d3k(_set____db54di) {
    this._ordering = _set____db54di;
  }
  e3k() {
    return this._ordering;
  }
  f3k(_set____db54di) {
    this.orderingDirection = _set____db54di;
  }
  g3k() {
    return this.orderingDirection;
  }
  h3k(_set____db54di) {
    this.orderingHorizontalVanishingPoint = _set____db54di;
  }
  i3k() {
    return this.orderingHorizontalVanishingPoint;
  }
  j3k(_set____db54di) {
    this.orderingVerticalVanishingPoint = _set____db54di;
  }
  k3k() {
    return this.orderingVerticalVanishingPoint;
  }
  l3k(_set____db54di) {
    this._labeling = _set____db54di;
  }
  m3k() {
    return this._labeling;
  }
  n3k(_set____db54di) {
    this._labelingFont = _set____db54di;
  }
  o3k() {
    return this._labelingFont;
  }
  p3k(_set____db54di) {
    this._labelingForeground = _set____db54di;
  }
  q3k() {
    return this._labelingForeground;
  }
  r3k(_set____db54di) {
    this._labelingBackground = _set____db54di;
  }
  s3k() {
    return this._labelingBackground;
  }
  t3k(_set____db54di) {
    this.labelingMinimumCharactersToDisplay = _set____db54di;
  }
  u3k() {
    return this.labelingMinimumCharactersToDisplay;
  }
  v3k(_set____db54di) {
    this.labelingEffectOpacity = _set____db54di;
  }
  w3k() {
    return this.labelingEffectOpacity;
  }
  x3k(_set____db54di) {
    this.labelingShrinkTextToFitShape = _set____db54di;
  }
  y3k() {
    return this.labelingShrinkTextToFitShape;
  }
  z3k(_set____db54di) {
    this.labelingResizeTextToFitShape = _set____db54di;
  }
  a3l() {
    return this.labelingResizeTextToFitShape;
  }
  b3l(_set____db54di) {
    this.labelingFloat = _set____db54di;
  }
  c3l() {
    return this.labelingFloat;
  }
  d3l(_set____db54di) {
    this.labelingContrastEnhancement = _set____db54di;
  }
  e3l() {
    return this.labelingContrastEnhancement;
  }
  f3l(_set____db54di) {
    this.nestingAmount = _set____db54di;
  }
  g3l() {
    return this.nestingAmount;
  }
  h3l(_set____db54di) {
    this.nestingBackground = _set____db54di;
  }
  i3l() {
    return this.nestingBackground;
  }
  j3l(_set____db54di) {
    this._headerFont = _set____db54di;
  }
  k3l() {
    return this._headerFont;
  }
  l3l(_set____db54di) {
    this._headerForeground = _set____db54di;
  }
  m3l() {
    return this._headerForeground;
  }
  n3l(_set____db54di) {
    this._headerEffectColor = _set____db54di;
  }
  o3l() {
    return this._headerEffectColor;
  }
  p3l(_set____db54di) {
    this._headerBackground = _set____db54di;
  }
  q3l() {
    return this._headerBackground;
  }
  r3l(_set____db54di) {
    this.headerMinimumCharactersToDisplay = _set____db54di;
  }
  s3l() {
    return this.headerMinimumCharactersToDisplay;
  }
  t3l(_set____db54di) {
    this.headerEffectOpacity = _set____db54di;
  }
  u3l() {
    return this.headerEffectOpacity;
  }
  v3l(_set____db54di) {
    this.headerInsets = _set____db54di;
  }
  w3l() {
    return this.headerInsets;
  }
  x3l(_set____db54di) {
    this.tooltipFont = _set____db54di;
  }
  y3l() {
    return this.tooltipFont;
  }
  z3l(_set____db54di) {
    this.tooltipForeground = _set____db54di;
  }
  a3m() {
    return this.tooltipForeground;
  }
  b3m(_set____db54di) {
    this.tooltipShowLabel = _set____db54di;
  }
  c3m() {
    return this.tooltipShowLabel;
  }
  d3m(_set____db54di) {
    this.borderColor = _set____db54di;
  }
  e3m() {
    return this.borderColor;
  }
  f3m(_set____db54di) {
    this._borderThickness = _set____db54di;
  }
  g3m() {
    return this._borderThickness;
  }
  h3m(_set____db54di) {
    this.format = _set____db54di;
  }
  i3m() {
    return this.format;
  }
  j3m(_set____db54di) {
    this.colorMap = _set____db54di;
  }
  k3m() {
    return this.colorMap;
  }
  getAlgorithmProperty() {
    return this._algorithm;
  }
  getAlgorithm() {
    return ensureNotNull(this._algorithm.r2());
  }
  setAlgorithm(algorithm) {
    this._algorithm.vo(algorithm);
  }
  getAlgorithmSelection() {
    return this.algorithm;
  }
  getAggregationProperty() {
    return this._aggregation;
  }
  getAggregation() {
    return this._aggregation.r2();
  }
  setAggregation(aggregation) {
    this._aggregation.vo(aggregation);
  }
  getScaleProperty() {
    return this._scale;
  }
  getScale() {
    return ensureNotNull(this._scale.r2());
  }
  setScale(scale) {
    this._scale.vo(scale);
  }
  getNestingProperty() {
    return this._nesting;
  }
  getNesting() {
    return this._nesting.r2();
  }
  setNesting(nesting) {
    this._nesting.vo(nesting);
  }
  getOrderingProperty() {
    return this._ordering;
  }
  getOrdering() {
    return ensureNotNull(this._ordering.r2());
  }
  setOrdering(ordering) {
    this._ordering.vo(ordering);
  }
  getOrderingDirectionProperty() {
    return this.orderingDirection;
  }
  getOrderingDirection() {
    return ensureNotNull(this.orderingDirection.r2());
  }
  setOrderingDirection(sortOrder) {
    this.orderingDirection.vo(sortOrder);
  }
  getOrderingVerticalVanishingPointProperty() {
    return this.orderingVerticalVanishingPoint;
  }
  getOrderingVerticalVanishingPoint() {
    return this.orderingVerticalVanishingPoint.r2();
  }
  setOrderingVerticalVanishingPoint(verticalVanishingPoint) {
    this.orderingVerticalVanishingPoint.vo(verticalVanishingPoint);
  }
  getOrderingHorizontalVanishingPointProperty() {
    return this.orderingHorizontalVanishingPoint;
  }
  getOrderingHorizontalVanishingPoint() {
    return this.orderingHorizontalVanishingPoint.r2();
  }
  setOrderingHorizontalVanishingPoint(horizontalVanishingPoint) {
    this.orderingHorizontalVanishingPoint.vo(horizontalVanishingPoint);
  }
  getLabelingProperty() {
    return this._labeling;
  }
  getLabeling() {
    return this._labeling.r2();
  }
  setLabeling(labeling) {
    this._labeling.vo(labeling);
  }
  getLabelingFontProperty() {
    return this._labelingFont;
  }
  getLabelingFont() {
    return this._labelingFont.r2();
  }
  setLabelingFont(font) {
    this._labelingFont.vo(font);
  }
  getLabelingForegroundProperty() {
    return this._labelingForeground;
  }
  getLabelingForeground() {
    return this._labelingForeground.r2();
  }
  setLabelingForeground(color) {
    this._labelingForeground.vo(color);
  }
  getLabelingEffectColorProperty() {
    return this._labelingBackground;
  }
  getLabelingEffectColor() {
    return this._labelingBackground.r2();
  }
  setLabelingEffectColor(color) {
    this._labelingBackground.vo(color);
  }
  getLabelingEffectProperty() {
    return this.labelingEffect;
  }
  getLabelingEffect() {
    return this.labelingEffect.r2();
  }
  setLabelingEffect(effect) {
    this.labelingEffect.vo(effect);
  }
  getLabelingHorizontalAlignmentProperty() {
    return this.labelingHorizontalAlignment;
  }
  getLabelingHorizontalAlignment() {
    return this.labelingHorizontalAlignment.r2();
  }
  setLabelingHorizontalAlignment(alignment) {
    this.labelingHorizontalAlignment.vo(alignment);
  }
  getLabelingVerticalAlignmentProperty() {
    return this.labelingVerticalAlignment;
  }
  getLabelingVerticalAlignment() {
    return this.labelingVerticalAlignment.r2();
  }
  setLabelingVerticalAlignment(alignment) {
    this.labelingVerticalAlignment.vo(alignment);
  }
  getLabelingRenderingProperty() {
    return this.labelingRendering;
  }
  getLabelingRendering() {
    return this.labelingRendering.r2();
  }
  setLabelingRendering(rendering) {
    this.labelingRendering.vo(rendering);
  }
  getLabelingMinimumCharactersToDisplayProperty() {
    return this.labelingMinimumCharactersToDisplay;
  }
  getLabelingMinimumCharactersToDisplay() {
    return this.labelingMinimumCharactersToDisplay.r2();
  }
  setLabelingMinimumCharactersToDisplay(minimumCharactersToDisplay) {
    this.labelingMinimumCharactersToDisplay.vo(minimumCharactersToDisplay);
  }
  getLabelingEffectOpacityProperty() {
    return this.labelingEffectOpacity;
  }
  getLabelingEffectOpacity() {
    return this.labelingEffectOpacity.r2();
  }
  setLabelingEffectOpacity(opacity) {
    this.labelingEffectOpacity.vo(opacity);
  }
  getLabelingShrinkTextToFitShapeProperty() {
    return this.labelingShrinkTextToFitShape;
  }
  getLabelingShrinkTextToFitShape() {
    return this.labelingShrinkTextToFitShape.r2();
  }
  setLabelingShrinkTextToFitShape(labelingShrinkTextToFitShape) {
    this.labelingShrinkTextToFitShape.vo(labelingShrinkTextToFitShape);
  }
  getLabelingResizeTextToFitShapeProperty() {
    return this.labelingResizeTextToFitShape;
  }
  getLabelingResizeTextToFitShape() {
    return this.labelingResizeTextToFitShape.r2();
  }
  setLabelingResizeTextToFitShape(labelingResizeTextToFitShape) {
    this.labelingResizeTextToFitShape.vo(labelingResizeTextToFitShape);
  }
  getLabelingFloatProperty() {
    return this.labelingFloat;
  }
  getLabelingFloat() {
    return this.labelingFloat.r2();
  }
  setLabelingFloat(labelingFloat) {
    this.labelingFloat.vo(labelingFloat);
  }
  getLabelingContrastEnhancementProperty() {
    return this.labelingContrastEnhancement;
  }
  getLabelingContrastEnhancement() {
    return this.labelingContrastEnhancement.r2();
  }
  setLabelingContrastEnhancement(contrastEnhancement) {
    this.labelingContrastEnhancement.vo(contrastEnhancement);
  }
  getNestingAmountProperty() {
    return this.nestingAmount;
  }
  getNestingAmount() {
    return this.nestingAmount.r2();
  }
  setNestingAmount(amount) {
    this.nestingAmount.vo(amount);
  }
  getNestingBackgroundProperty() {
    return this.nestingBackground;
  }
  getNestingBackground() {
    return this.nestingBackground.r2();
  }
  setNestingBackground(color) {
    this.nestingBackground.vo(color);
  }
  getHeaderFontProperty() {
    return this._headerFont;
  }
  getHeaderFont() {
    return this._headerFont.r2();
  }
  setHeaderFont(font) {
    this._headerFont.vo(font);
  }
  getHeaderForegroundProperty() {
    return this._headerForeground;
  }
  getHeaderForeground() {
    return this._headerForeground.r2();
  }
  setHeaderForeground(color) {
    this._headerForeground.vo(color);
  }
  getHeaderBackgroundProperty() {
    return this._headerBackground;
  }
  getHeaderBackground() {
    return this._headerBackground.r2();
  }
  setHeaderBackground(color) {
    this._headerBackground.vo(color);
  }
  getHeaderEffectColorProperty() {
    return this._headerEffectColor;
  }
  getHeaderEffectColor() {
    return this._headerEffectColor.r2();
  }
  setHeaderEffectColor(color) {
    this._headerEffectColor.vo(color);
  }
  getHeaderEffectProperty() {
    return this.headerEffect;
  }
  getHeaderEffect() {
    return this.headerEffect.r2();
  }
  setHeaderEffect(effect) {
    this.headerEffect.vo(effect);
  }
  getHeaderHorizontalAlignmentProperty() {
    return this.headerHorizontalAlignment;
  }
  getHeaderHorizontalAlignment() {
    return this.headerHorizontalAlignment.r2();
  }
  setHeaderHorizontalAlignment(alignment) {
    this.headerHorizontalAlignment.vo(alignment);
  }
  getHeaderVerticalAlignmentProperty() {
    return this.headerVerticalAlignment;
  }
  getHeaderVerticalAlignment() {
    return this.headerVerticalAlignment.r2();
  }
  setHeaderVerticalAlignment(alignment) {
    this.headerVerticalAlignment.vo(alignment);
  }
  getHeaderRenderingProperty() {
    return this.headerRendering;
  }
  getHeaderRendering() {
    return this.headerRendering.r2();
  }
  setHeaderRendering(rendering) {
    this.headerRendering.vo(rendering);
  }
  getHeaderMinimumCharactersToDisplayProperty() {
    return this.headerMinimumCharactersToDisplay;
  }
  getHeaderMinimumCharactersToDisplay() {
    return this.headerMinimumCharactersToDisplay.r2();
  }
  setHeaderMinimumCharactersToDisplay(minimumCharactersToDisplay) {
    this.headerMinimumCharactersToDisplay.vo(minimumCharactersToDisplay);
  }
  getHeaderEffectOpacityProperty() {
    return this.headerEffectOpacity;
  }
  getHeaderEffectOpacity() {
    return this.headerEffectOpacity.r2();
  }
  setHeaderEffectOpacity(opacity) {
    this.headerEffectOpacity.vo(opacity);
  }
  getHeaderInsetsProperty() {
    return this.headerInsets;
  }
  getHeaderInsets() {
    return this.headerInsets.r2();
  }
  setHeaderInsets(insets) {
    this.headerInsets.vo(insets);
  }
  getTooltipFontProperty() {
    return this.tooltipFont;
  }
  getTooltipFont() {
    return this.tooltipFont.r2();
  }
  setTooltipFont(font) {
    this.tooltipFont.vo(font);
  }
  getTooltipForegroundProperty() {
    return this.tooltipForeground;
  }
  getTooltipForeground() {
    return this.tooltipForeground.r2();
  }
  setTooltipForeground(color) {
    this.tooltipForeground.vo(color);
  }
  getTooltipRenderingProperty() {
    return this.tooltipRendering;
  }
  getTooltipRendering() {
    return this.tooltipRendering.r2();
  }
  setTooltipRendering(rendering) {
    this.tooltipRendering.vo(rendering);
  }
  getBorderColorProperty() {
    return this.borderColor;
  }
  getBorderColor() {
    return this.borderColor.r2();
  }
  setBorderColor(color) {
    this.borderColor.vo(color);
  }
  getBorderThicknessInterval() {
    return this.borderThickness;
  }
  getBorderThickness() {
    return this.borderThickness.start;
  }
  setBorderThickness(value) {
    this.borderThickness.start = value;
  }
  getFormatProperty() {
    return ensureNotNull(this.format);
  }
  getFormat() {
    return ensureNotNull(this.format).r2();
  }
  setFormat(format) {
    ensureNotNull(this.format).vo(format);
  }
  getShowLabelProperty() {
    return this.tooltipShowLabel;
  }
  getShowLabel() {
    return this.tooltipShowLabel.r2();
  }
  setShowLabel(show) {
    this.tooltipShowLabel.vo(show);
  }
  getColorMapProperty() {
    return this.colorMap;
  }
  getColorMap() {
    return ensureNotNull(this.colorMap).r2();
  }
  setColorMap(colorMap) {
    ensureNotNull(this.colorMap).vo(colorMap);
  }
  getProperty(key) {
    return ensureNotNull(this.t3h_1.az(key).r2());
  }
  isDefaults() {
    return true;
  }
  getOverrideDefaultsProperty() {
    return null;
  }
  isOverrideDefaults() {
    return false;
  }
  setOverrideDefaults(overrideDefaults) {
    if (overrideDefaults) {
      throw UnsupportedOperationException.t9('Default settings cannot be overridden');
    }
  }
  getPropertyOverride(key) {
    return this.getProperty(key);
  }
  reset() {
    this.setAlgorithm(Companion_getInstance_74().getInstance().getDefault());
    this.setAggregation(Companion_getInstance_73().y3c().a3d());
    this.setScale(Companion_getInstance_92().g3i_1.i3i());
    this.setNesting(Companion_getInstance_85().y3c().a3d());
    this.setOrdering(Companion_getInstance_87().y3c().a3d());
    this.setOrderingDirection(SortOrder_Descending_getInstance());
    this.setOrderingHorizontalVanishingPoint(4);
    this.setOrderingVerticalVanishingPoint(3);
    this.setLabeling(Companion_getInstance_83().y3c().a3d());
    this.setLabelingForeground(colorOf_1(32, 32, 32));
    this.setLabelingEffectColor(null);
    this.setLabelingEffect(null);
    this.setLabelingHorizontalAlignment(2);
    this.setLabelingVerticalAlignment(1);
    this.setLabelingRendering(Rendering_Clip_getInstance());
    this.setLabelingMinimumCharactersToDisplay(1);
    this.setLabelingEffectOpacity(null);
    this.setLabelingShrinkTextToFitShape(false);
    this.setLabelingResizeTextToFitShape(false);
    this.setLabelingFloat(false);
    this.setLabelingContrastEnhancement(Brightness_getInstance());
    this.setNestingAmount(1.0);
    this.setNestingBackground(colorOf_1(180, 180, 180));
    this.setHeaderForeground(colorOf_1(64, 64, 64));
    this.setHeaderEffectColor(colorOf_1(255, 255, 255));
    this.setHeaderBackground(colorOf_1(204, 204, 204));
    this.setHeaderEffect(null);
    this.setHeaderHorizontalAlignment(0);
    this.setHeaderVerticalAlignment(0);
    this.setHeaderRendering(Rendering_Clip_getInstance());
    this.setHeaderMinimumCharactersToDisplay(1);
    this.setHeaderEffectOpacity(null);
    this.setHeaderInsets(new Insets(1, 1, 0, 1));
    this.setTooltipForeground(colorOf_1(32, 32, 32));
    this.setShowLabel(false);
    this.setTooltipRendering(Rendering_Truncate_getInstance());
    this.setBorderThickness(0.5);
    this.setBorderColor(colorOf_1(96, 96, 96));
    this.setFormat(null);
    this.setHeaderFont(Companion_instance_78.getDefaultHeaderFont(this.v3h_1));
    this.setLabelingFont(Companion_instance_78.getDefaultLabelingFont(this.v3h_1));
    this.setTooltipFont(Companion_instance_78.getDefaultLabelingFont(this.v3h_1));
  }
  createDefaultColorMap(column) {
    return null;
  }
  get properties() {
    return this.f24();
  }
}
class DefaultTreeMapController extends AbstractTreeMapController {}
class Companion_79 {
  constructor() {
    Companion_instance_79 = this;
    this.l3m_1 = new Insets(0, 0, 0, 0);
  }
}
class DefaultTreeMapHeaderRenderer extends EnhancedLabel {
  static h3b() {
    Companion_getInstance_79();
    var $this = this.z23();
    $this.g3b_1 = null;
    $this.isOpaque = false;
    $this.setName('TreeMap.headerRenderer');
    $this.setInsets(Companion_getInstance_79().l3m_1.j22_1, Companion_getInstance_79().l3m_1.k22_1, Companion_getInstance_79().l3m_1.l22_1, Companion_getInstance_79().l3m_1.m22_1);
    $this.setEffect(Emphasize_getInstance());
    $this.setHorizontalAlignment(0);
    $this.setVerticalAlignment(1);
    $this.setRendering(Rendering_Clip_getInstance());
    return $this;
  }
  m3m(model, node, dimension) {
    var value = model.getLabelName(node);
    this.n3m(value);
    var settings = model.settings.getColumnSettings(model.getGroupByColumn(node));
    var effect = settings.getHeaderEffect();
    if (!(effect == null)) {
      this.setEffect(effect);
    }
    var horizontalAlignment = settings.getHeaderHorizontalAlignment();
    if (horizontalAlignment == null)
      null;
    else {
      // Inline function 'kotlin.let' call
      // Inline function 'com.treemap.DefaultTreeMapHeaderRenderer.getTreeMapHeaderRendererComponent.<anonymous>' call
      this.setHorizontalAlignment(horizontalAlignment);
    }
    var verticalAlignment = settings.getHeaderVerticalAlignment();
    if (verticalAlignment == null)
      null;
    else {
      // Inline function 'kotlin.let' call
      // Inline function 'com.treemap.DefaultTreeMapHeaderRenderer.getTreeMapHeaderRendererComponent.<anonymous>' call
      this.setVerticalAlignment(verticalAlignment);
    }
    var rendering = settings.getHeaderRendering();
    if (!(rendering == null)) {
      this.setRendering(rendering);
    }
    var minimumCharactersToDisplay = settings.getHeaderMinimumCharactersToDisplay();
    if (minimumCharactersToDisplay == null)
      null;
    else {
      // Inline function 'kotlin.let' call
      // Inline function 'com.treemap.DefaultTreeMapHeaderRenderer.getTreeMapHeaderRendererComponent.<anonymous>' call
      this.setMinimumCharactersToDisplay(minimumCharactersToDisplay);
    }
    var effectOpacity = settings.getHeaderEffectOpacity();
    if (effectOpacity == null)
      null;
    else {
      // Inline function 'kotlin.let' call
      // Inline function 'com.treemap.DefaultTreeMapHeaderRenderer.getTreeMapHeaderRendererComponent.<anonymous>' call
      this.setEffectOpacity(effectOpacity);
    }
    var insets = settings.getHeaderInsets();
    if (!(insets == null)) {
      this.setInsets(insets.j22_1, insets.k22_1, insets.l22_1, insets.m22_1);
    } else {
      this.setInsets(0, 0, 0, 0);
    }
    this.setDesiredWidth(dimension.yl_1);
    this.setDesiredHeight(dimension.zl_1);
    return this;
  }
  n3m(value) {
    var tmp1_elvis_lhs = value == null ? null : toString_1(value);
    this.setText(tmp1_elvis_lhs == null ? '' : tmp1_elvis_lhs);
  }
  setName(name) {
    this.g3b_1 = name;
  }
  getName() {
    return this.g3b_1;
  }
}
class Companion_80 {
  constructor() {
    Companion_instance_80 = this;
    this.o3m_1 = new Insets(0, 2, 0, 1);
  }
}
class DefaultTreeMapLabelRenderer extends EnhancedLabel {
  static i3a() {
    Companion_getInstance_80();
    var $this = this.z23();
    $this.isOpaque = false;
    $this.setName('TreeMap.labelRenderer');
    $this.setEffect(Plain_getInstance());
    $this.setHorizontalAlignment(2);
    $this.setRendering(Rendering_Clip_getInstance());
    return $this;
  }
  o2p(view, column, node, dimension) {
    var value = ensureNotNull(view.j2p()).getStringValue(node, column);
    this.setInsets(Companion_getInstance_80().o3m_1.j22_1, Companion_getInstance_80().o3m_1.k22_1, Companion_getInstance_80().o3m_1.l22_1, Companion_getInstance_80().o3m_1.m22_1);
    this.setText(value);
    this.isHTML = ensureNotNull(view.j2p()).getColumnClass(column) === getKClass(HtmlString);
    var settings = ensureNotNull(view.j2p()).settings.getColumnSettings(column);
    var effect = settings.getLabelingEffect();
    if (!(effect == null)) {
      this.setEffect(effect);
    }
    var horizontalAlignment = settings.getLabelingHorizontalAlignment();
    if (horizontalAlignment == null)
      null;
    else {
      // Inline function 'kotlin.let' call
      // Inline function 'com.treemap.DefaultTreeMapLabelRenderer.getTreeMapLabelRendererComponent.<anonymous>' call
      this.setHorizontalAlignment(horizontalAlignment);
    }
    var verticalAlignment = settings.getLabelingVerticalAlignment();
    if (verticalAlignment == null)
      null;
    else {
      // Inline function 'kotlin.let' call
      // Inline function 'com.treemap.DefaultTreeMapLabelRenderer.getTreeMapLabelRendererComponent.<anonymous>' call
      this.setVerticalAlignment(verticalAlignment);
    }
    var rendering = settings.getLabelingRendering();
    if (!(rendering == null)) {
      this.setRendering(rendering);
    }
    var minimumCharactersToDisplay = settings.getLabelingMinimumCharactersToDisplay();
    if (minimumCharactersToDisplay == null)
      null;
    else {
      // Inline function 'kotlin.let' call
      // Inline function 'com.treemap.DefaultTreeMapLabelRenderer.getTreeMapLabelRendererComponent.<anonymous>' call
      this.setMinimumCharactersToDisplay(minimumCharactersToDisplay);
    }
    var effectOpacity = settings.getLabelingEffectOpacity();
    if (effectOpacity == null)
      null;
    else {
      // Inline function 'kotlin.let' call
      // Inline function 'com.treemap.DefaultTreeMapLabelRenderer.getTreeMapLabelRendererComponent.<anonymous>' call
      this.setEffectOpacity(effectOpacity);
    }
    this.setDesiredWidth(dimension.yl_1);
    this.setDesiredHeight(dimension.zl_1);
    return this;
  }
}
class DefaultTreeMapModel$dataFrameListener$1 {
  constructor(this$0) {
    this.p3m_1 = this$0;
  }
  n2k(event) {
    var groupByTreeMapColumns = this.p3m_1.settings.groupByColumns;
    this.p3m_1.i3o_1.o5();
    this.p3m_1.h3o_1.o5();
    this.p3m_1.w2y();
    this.p3m_1.b32();
    var affectedColumns = event.f2l_1;
    if (affectedColumns == null) {
      this.p3m_1.f30();
      return Unit_instance;
    } else {
      if (!(groupByTreeMapColumns == null)) {
        var _iterator__ex2g4s = groupByTreeMapColumns.x();
        while (_iterator__ex2g4s.y()) {
          var column = _iterator__ex2g4s.z();
          if (!(column == null)) {
            var _iterator__ex2g4s_0 = affectedColumns.x();
            while (_iterator__ex2g4s_0.y()) {
              var column_0 = _iterator__ex2g4s_0.z();
              if (column_0 === column_0) {
                this.p3m_1.f30();
                return Unit_instance;
              }
            }
          }
        }
      }
    }
    this.p3m_1.d30();
  }
  h2g(event) {
    return this.n2k(event);
  }
}
class DefaultTreeMapModel extends AbstractTreeMapModel {
  constructor(dataFrame) {
    super();
    this.f3o_1 = null;
    this.g3o_1 = HashMap.d8();
    this.h3o_1 = HashMap.d8();
    this.i3o_1 = HashMap.d8();
    var tmp = this;
    tmp.dataFrameListener = new DefaultTreeMapModel$dataFrameListener$1(this);
    this.dataFrame = dataFrame;
    this.a32();
  }
  j3o(dataFrame) {
    if (!(this.f3o_1 === dataFrame)) {
      var tmp0_safe_receiver = this.f3o_1;
      if (tmp0_safe_receiver == null)
        null;
      else {
        tmp0_safe_receiver.j2k(this.dataFrameListener);
      }
      this.f3o_1 = dataFrame;
      var tmp1_safe_receiver = this.f3o_1;
      if (tmp1_safe_receiver == null)
        null;
      else {
        tmp1_safe_receiver.j2g(this.dataFrameListener);
      }
      this.b32();
      this.f30();
    }
  }
  k2g() {
    return this.f3o_1;
  }
  k3o() {
    return this.dataFrameListener;
  }
  getLabelName(node) {
    return node.e34();
  }
  getParent(node) {
    return node.v33();
  }
  isRoot(node) {
    return node.w33();
  }
  getChildCount(node) {
    return node.u33();
  }
  getChildren(parent) {
    return ensureNotNull(parent.x33());
  }
  getChildrenOfTypeParent(parent) {
    return ensureNotNull(parent.y33());
  }
  getCushionImage(node) {
    return node.h34();
  }
  getCushionColor(node) {
    return node.i34();
  }
  r2y(childrenGroupByColumn) {
    return new ParentTreeMapNode('root', this, null, childrenGroupByColumn);
  }
  createLeafNode(row) {
    var tmp;
    if (this.s2w_1.s2(row)) {
      tmp = ensureNotNull(this.s2w_1.u2(row));
    } else {
      var tmp_0 = new LeafTreeMapNode(row, this);
      var node = tmp_0 instanceof AbstractTreeMapNode ? tmp_0 : THROW_CCE();
      this.s2w_1.i7(row, node);
      tmp = node;
    }
    return tmp;
  }
  getNodeForRow(row) {
    return ensureNotNull(this.s2w_1.u2(row));
  }
  createParentNode(name, groupByColumn, childrenGroupByColumn) {
    return new ParentTreeMapNode(name, this, groupByColumn, childrenGroupByColumn);
  }
  findChild(parent, name) {
    return parent.b34(name);
  }
  addChildToParent(parent, child) {
    parent.z33(child);
  }
  s2y(parent, worker) {
    var groupByTreeMapColumns;
    if (!(this.settings.groupByColumns == null)) {
      var count = 0;
      var inductionVariable = 0;
      var last = this.settings.groupByColumns.a1();
      if (inductionVariable < last)
        do {
          var i = inductionVariable;
          inductionVariable = inductionVariable + 1 | 0;
          var column = this.settings.groupByColumns.b1(i);
          if (!(column == null)) {
            count = count + 1 | 0;
          }
        }
         while (inductionVariable < last);
      if (count === this.settings.groupByColumns.a1()) {
        groupByTreeMapColumns = toMutableList_0(this.settings.groupByColumns);
      } else {
        var filter1 = filterNotNull(this.settings.groupByColumns);
        groupByTreeMapColumns = toMutableList_0(filter1);
        var index = 0;
        var inductionVariable_0 = 0;
        var last_0 = this.settings.groupByColumns.a1();
        if (inductionVariable_0 < last_0)
          do {
            var i_0 = inductionVariable_0;
            inductionVariable_0 = inductionVariable_0 + 1 | 0;
            var column_0 = this.settings.groupByColumns.b1(i_0);
            if (!(column_0 == null)) {
              groupByTreeMapColumns.j5(index, column_0);
              index = index + 1 | 0;
            }
          }
           while (inductionVariable_0 < last_0);
      }
    } else {
      groupByTreeMapColumns = toMutableList_0(this.settings.groupByColumns);
    }
    if (!(this.f3o_1 == null)) {
      var _iterator__ex2g4s = ensureNotNull(this.f3o_1).p2h().x();
      while (_iterator__ex2g4s.y()) {
        var row = _iterator__ex2g4s.z();
        if (!ensureNotNull(worker).d17()) {
          var pathList;
          var groupByList;
          var childrenGroupByList;
          if (groupByTreeMapColumns == null || groupByTreeMapColumns.a1() === 0) {
            pathList = emptyList();
            groupByList = emptyList();
            childrenGroupByList = emptyList();
          } else {
            pathList = ArrayList.o7(groupByTreeMapColumns.a1());
            groupByList = ArrayList.o7(groupByTreeMapColumns.a1());
            childrenGroupByList = ArrayList.o7(groupByTreeMapColumns.a1());
            var inductionVariable_1 = 0;
            var last_1 = groupByTreeMapColumns.a1() - 1 | 0;
            if (inductionVariable_1 <= last_1)
              do {
                var i_1 = inductionVariable_1;
                inductionVariable_1 = inductionVariable_1 + 1 | 0;
                var column_1 = groupByTreeMapColumns.b1(i_1);
                var groupByColumn = i_1 < (groupByTreeMapColumns.a1() - 1 | 0) ? groupByTreeMapColumns.b1(i_1 + 1 | 0) : null;
                var index_0 = ensureNotNull(column_1);
                var value = ensureNotNull(this.f3o_1).y2j(row, index_0);
                if (!(value == null) && this.w2x_1.s17(getKClassFromExpression(value))) {
                  var objects = (!(value == null) ? isArray(value) : false) ? value : THROW_CCE();
                  addAll(pathList, requireNoNulls(objects));
                  var inductionVariable_2 = 0;
                  var last_2 = objects.length - 1 | 0;
                  if (inductionVariable_2 <= last_2)
                    do {
                      var j = inductionVariable_2;
                      inductionVariable_2 = inductionVariable_2 + 1 | 0;
                      if (!(column_1 == null) && !(groupByColumn == null)) {
                        groupByList.o(column_1);
                        childrenGroupByList.o(groupByColumn);
                      }
                    }
                     while (inductionVariable_2 <= last_2);
                } else {
                  if (!(value == null)) {
                    var settings = this.settings.getColumnSettings(column_1);
                    if (!(settings.getFormat() == null)) {
                      var s = ensureNotNull(ensureNotNull(settings.getFormat()).wl(value, false));
                      pathList.o(s);
                    } else {
                      pathList.o(value);
                    }
                    groupByList.o(column_1);
                    childrenGroupByList.o(groupByColumn);
                  }
                }
              }
               while (inductionVariable_1 <= last_1);
          }
          this.addChild(ensureNotNull(parent), pathList, groupByList, childrenGroupByList, row);
        } else {
          return true;
        }
      }
    }
    return false;
  }
  addChild(parent, path, groupBy, childrenGroupBy, row) {
    var parent_0 = parent;
    var groupByIterator = groupBy.x();
    var childrenGroupByIterator = childrenGroupBy.x();
    var _iterator__ex2g4s = path.x();
    while (_iterator__ex2g4s.y()) {
      var name = _iterator__ex2g4s.z();
      var g = groupByIterator.z();
      var c = childrenGroupByIterator.z();
      var node;
      if (this.c2y(parent_0) || this.findChild(parent_0, name) == null) {
        node = this.createParentNode(ensureNotNull(name), g, c);
        this.addChildToParent(parent_0, node);
      } else {
        var tmp = this.findChild(parent_0, name);
        node = tmp instanceof AbstractTreeMapNode ? tmp : THROW_CCE();
      }
      parent_0 = node;
    }
    this.addChildToParent(parent_0, this.createLeafNode(row));
  }
  getTreeMapColumn(columnIndex) {
    var tmp;
    if (columnIndex >= 0 && columnIndex <= ensureNotNull(this.f3o_1).z2i()) {
      tmp = ensureNotNull(this.f3o_1).a2j(columnIndex);
    } else {
      tmp = null;
    }
    return tmp;
  }
  getTreeMapColumnByName(columnName) {
    var _iterator__ex2g4s = ensureNotNull(this.f3o_1).b2k().x();
    while (_iterator__ex2g4s.y()) {
      var c = _iterator__ex2g4s.z();
      if (equals_0(ensureNotNull(this.f3o_1).i2k(c), columnName)) {
        return this.getTreeMapColumn(ensureNotNull(this.f3o_1).f2k(c));
      }
    }
    return null;
  }
  g2k() {
    var df = this.f3o_1;
    return !(df == null) ? df.g2k() : 0;
  }
  z2i() {
    var df = this.f3o_1;
    return !(df == null) ? df.z2i() : 0;
  }
  columns() {
    return ensureNotNull(this.f3o_1).b2k();
  }
  getColumnName(columnIndex) {
    return !(this.f3o_1 == null) ? ensureNotNull(this.f3o_1).i2k(columnIndex) : null;
  }
  getColumnClass(columnIndex) {
    return ensureNotNull(this.f3o_1).h2j(columnIndex);
  }
  getValueAt(node, columnIndex) {
    var row = node.d34();
    var tmp;
    if (!(row == null)) {
      tmp = ensureNotNull(this.f3o_1).y2j(row, columnIndex);
    } else {
      tmp = null;
    }
    return tmp;
  }
  isEveryValueUnique(column) {
    var isEveryValueUnique = this.getColumnClass(ensureNotNull(column)).equals(PrimitiveClasses_getInstance().ke()) || this.getColumnClass(column).equals(PrimitiveClasses_getInstance().le());
    if (!isEveryValueUnique) {
      isEveryValueUnique = true;
      var values = HashSet.x9();
      var series = ensureNotNull(this.f3o_1).a2k(column);
      var _iterator__ex2g4s = ensureNotNull(this.f3o_1).p2h().x();
      $l$loop: while (_iterator__ex2g4s.y()) {
        var row = _iterator__ex2g4s.z();
        var value = ensureNotNull(series).u2(row);
        if (values.j2(value)) {
          isEveryValueUnique = false;
          break $l$loop;
        } else {
          values.o(value);
        }
      }
    }
    return isEveryValueUnique;
  }
  getNumericMax(columnIndex) {
    var tmp;
    if (!(columnIndex == null)) {
      if (!this.h3o_1.s2(columnIndex)) {
        var max = DataFrameHelper_instance.h2l(ensureNotNull(this.f3o_1), columnIndex).b2l_1;
        if (!(max == null)) {
          var tmp0 = this.h3o_1;
          // Inline function 'kotlin.collections.set' call
          var value = numberToDouble(max);
          tmp0.i7(columnIndex, value);
        } else {
          // Inline function 'kotlin.collections.set' call
          this.h3o_1.i7(columnIndex, null);
        }
      }
      return this.h3o_1.u2(columnIndex);
    } else {
      tmp = null;
    }
    return tmp;
  }
  getNumericMin(columnIndex) {
    var tmp;
    if (!(columnIndex == null)) {
      if (!this.i3o_1.s2(columnIndex)) {
        var min = DataFrameHelper_instance.h2l(ensureNotNull(this.f3o_1), columnIndex).a2l_1;
        if (!(min == null)) {
          var tmp0 = this.i3o_1;
          // Inline function 'kotlin.collections.set' call
          var value = numberToDouble(min);
          tmp0.i7(columnIndex, value);
        } else {
          // Inline function 'kotlin.collections.set' call
          this.i3o_1.i7(columnIndex, null);
        }
      }
      return this.i3o_1.u2(columnIndex);
    } else {
      tmp = null;
    }
    return tmp;
  }
  setNumericMax(columnIndex, max) {
    this.h3o_1.i7(ensureNotNull(columnIndex), max);
    this.d30();
  }
  setNumericMin(columnIndex, min) {
    this.i3o_1.i7(ensureNotNull(columnIndex), min);
    this.d30();
  }
  createDefaultColorMap(column) {
    var stat = DataFrameHelper_instance.h2l(ensureNotNull(this.f3o_1), column);
    return DataFrameColorMapFactory_instance.l3o(this.p2w_1, this.f3o_1, column, stat.a2l_1, stat.b2l_1);
  }
  c33(column) {
    return DataFrameColorMapFactory_instance.m3o(this.p2w_1, this.f3o_1, ensureNotNull(column));
  }
  get dataFrame() {
    return this.k2g();
  }
  set dataFrame(value) {
    this.j3o(value);
  }
  get rowCount() {
    return this.g2k();
  }
  get columnCount() {
    return this.z2i();
  }
  get colorFactory() {
    return this.q30();
  }
  get settings() {
    return this.t30();
  }
  get properties() {
    return this.f24();
  }
  get probing() {
    return this.w30();
  }
  get highlighting() {
    return this.x30();
  }
  get selection() {
    return this.y30();
  }
  get filter() {
    return this.z30();
  }
  get search() {
    return this.a31();
  }
  get root() {
    return this.c31();
  }
  set root(value) {
    this.b31(value);
  }
  get worker() {
    return this.e31();
  }
  set worker(value) {
    this.d31(value);
  }
  get workerFuture() {
    return this.g31();
  }
  set workerFuture(value) {
    this.f31(value);
  }
  get isDirty() {
    return this.x2g();
  }
  get normalizedLightSourceX() {
    return this.i31();
  }
  set normalizedLightSourceX(value) {
    this.h31(value);
  }
  get normalizedLightSourceY() {
    return this.k31();
  }
  set normalizedLightSourceY(value) {
    this.j31(value);
  }
  get normalizedLightSourceZ() {
    return this.m31();
  }
  set normalizedLightSourceZ(value) {
    this.l31(value);
  }
  get maximumSize() {
    return this.o31();
  }
  set maximumSize(value) {
    this.n31(value);
  }
  get colorProvider() {
    return this.t31();
  }
  set colorProvider(value) {
    this.r31(value);
  }
  get groupByColumns() {
    return this.u31();
  }
  get sizeColumns() {
    return this.v31();
  }
  get colorColumns() {
    return this.w31();
  }
  get heightColumns() {
    return this.x31();
  }
  get labelsColumns() {
    return this.y31();
  }
  get tooltipColumns() {
    return this.z31();
  }
  get currentRoot() {
    return this.o33();
  }
  set currentRoot(value) {
    this.m33(value);
  }
}
class DefaultTreeMapPopup {
  constructor(view) {
    this.o3o_1 = null;
    this.p3o_1 = null;
    this.n3o_1 = view;
  }
  m37(x, y, owner) {
    this.o3o_1 = new Point(x, y);
    this.p3o_1 = owner;
  }
  n36() {
    this.o3o_1 = null;
    this.p3o_1 = null;
  }
  j37() {
    if (!(this.p3o_1 == null)) {
      this.n3o_1.j37();
    }
  }
  f37() {
    return this.o3o_1;
  }
}
class DefaultTreeMapSettings$propertyChangeListener$1 {
  constructor(this$0) {
    this.q3o_1 = this$0;
  }
  k30(name, event) {
    if (equals('depth', name) || equals('rendering', name) || equals('nestingBackground', name) || equals('headerBackground', name) || equals('headerForeground', name) || equals('headerEffectColor', name) || equals('labelingFont', name) || equals('labelingEffectColor', name) || equals('labelingForeground', name) || equals('labelingShrinkTextToFitShape', name) || equals('labelingResizeTextToFitShape', name) || equals('labelingFloat', name) || equals('tooltipFont', name) || equals('background', name) || equals('tooltipBackground', name) || equals('tooltipForeground', name) || equals('borderColor', name) || equals('showLabel', name)) {
      scheduleUpdate(this.q3o_1);
    } else if (equals('dimension', name) || equals('aggregation', name) || equals('algorithm', name) || equals('scale', name) || equals('labeling', name) || equals('nesting', name) || equals('nestingAmount', name) || equals('ordering', name) || equals('orderingDirection', name) || equals('orderingHorizontalVanishingPoint', name) || equals('orderingVerticalVanishingPoint', name) || equals('sizeField', name) || equals('heightField', name) || equals('backgroundField', name) || equals('headerFont', name) || equals('labelsField', name) || equals('hideFilterResults', name) || equals('hideSearchResults', name) || equals('format', name) || equals('borderThickness', name) || equals('headerFont', name) || equals('headerRendering', name)) {
      scheduleUpdateLayout(this.q3o_1);
    } else if (equals('colormap', name) || equals('colorField', name) || equals('lightSourceHeight', name) || equals('lightSourceAmbient', name) || equals('lightSourceX', name) || equals('lightSourceY', name) || equals('lightSourceZ', name)) {
      scheduleUpdateColors(this.q3o_1);
    } else if (equals('groupByField', name)) {
      scheduleUpdateGroupBy(this.q3o_1);
    } else {
      scheduleUpdate(this.q3o_1);
    }
  }
  zx(name, event) {
    return this.k30((name == null ? true : typeof name === 'string') ? name : THROW_CCE(), event);
  }
}
class DefaultTreeMapSettings$1 {
  constructor(this$0) {
    this.r3o_1 = this$0;
  }
  k30(name, event) {
    if (equals('groupByField', name)) {
      this.r3o_1.getGroupByColumnsSelection().j13(this.r3o_1.groupByColumns);
    }
  }
  zx(name, event) {
    return this.k30((name == null ? true : typeof name === 'string') ? name : THROW_CCE(), event);
  }
}
class DefaultTreeMapSettings$2 {
  constructor(this$0) {
    this.s3o_1 = this$0;
  }
  t3o(event) {
    var selected = this.s3o_1.getGroupByColumnsSelection().c13();
    this.s3o_1.groupByColumns = toList_0(selected);
  }
  x13(event) {
    return this.t3o(event);
  }
}
class SingleSelectionSettingsCoordinator {
  static w3o(settings, property, selection, $box) {
    var $this = createThis(this, $box);
    init_com_treemap_legacy_SingleSelectionSettingsCoordinator($this);
    var tmp = settings.properties;
    tmp.cy(new SingleSelectionSettingsCoordinator$1(property, selection, $this));
    selection.q13(new SingleSelectionSettingsCoordinator$2($this));
    selection.f13($this.xk());
    return $this;
  }
}
class DefaultTreeMapSettings$3 extends SingleSelectionSettingsCoordinator {
  static v3o(this$0, $box) {
    if ($box === VOID)
      $box = {};
    $box.u3o_1 = this$0;
    return this.w3o(isInterface(this$0, TreeMapSettings) ? this$0 : THROW_CCE(), 'sizeField', this$0.getSizeColumnSelection(), $box);
  }
  xk() {
    return this.u3o_1.sizeColumn;
  }
  x3o(value) {
    this.u3o_1.sizeColumn = value;
  }
  y3o(value) {
    return this.x3o((value == null ? true : !(value == null)) ? value : THROW_CCE());
  }
}
class DefaultTreeMapSettings$4 extends SingleSelectionSettingsCoordinator {
  static a3p(this$0, $box) {
    if ($box === VOID)
      $box = {};
    $box.z3o_1 = this$0;
    return this.w3o(this$0, 'progressive', this$0.getProgressiveSelection(), $box);
  }
  xk() {
    return this.z3o_1.getProgressive();
  }
  b3p(value) {
    this.z3o_1.setProgressive(value);
  }
  y3o(value) {
    return this.b3p((value == null ? true : value instanceof Progressive) ? value : THROW_CCE());
  }
}
class DefaultTreeMapSettings$5 extends SingleSelectionSettingsCoordinator {
  static d3p(this$0, $box) {
    if ($box === VOID)
      $box = {};
    $box.c3p_1 = this$0;
    return this.w3o(isInterface(this$0, TreeMapSettings) ? this$0 : THROW_CCE(), 'colorField', this$0.getColorColumnSelection(), $box);
  }
  xk() {
    var tmp = this.c3p_1.colorColumn;
    return (tmp == null ? true : !(tmp == null)) ? tmp : THROW_CCE();
  }
  x3o(value) {
    this.c3p_1.colorColumn = value;
  }
  y3o(value) {
    return this.x3o((value == null ? true : !(value == null)) ? value : THROW_CCE());
  }
}
class DefaultTreeMapSettings$6 extends SingleSelectionSettingsCoordinator {
  static f3p(this$0, $box) {
    if ($box === VOID)
      $box = {};
    $box.e3p_1 = this$0;
    return this.w3o(isInterface(this$0, TreeMapSettings) ? this$0 : THROW_CCE(), 'heightField', this$0.getHeightColumnSelection(), $box);
  }
  xk() {
    var tmp = this.e3p_1.heightColumn;
    return (tmp == null ? true : !(tmp == null)) ? tmp : THROW_CCE();
  }
  x3o(value) {
    this.e3p_1.heightColumn = value;
  }
  y3o(value) {
    return this.x3o((value == null ? true : !(value == null)) ? value : THROW_CCE());
  }
}
class DefaultTreeMapSettings$7 {
  constructor(this$0) {
    this.g3p_1 = this$0;
  }
  k30(name, event) {
    if (equals('labelsField', name)) {
      this.g3p_1.getLabelColumnsSelection().j13(this.g3p_1.labelsColumns);
    }
  }
  zx(name, event) {
    return this.k30((name == null ? true : typeof name === 'string') ? name : THROW_CCE(), event);
  }
}
class DefaultTreeMapSettings$8 {
  constructor(this$0) {
    this.h3p_1 = this$0;
  }
  t3o(event) {
    var selected = this.h3p_1.getLabelColumnsSelection().c13();
    this.h3p_1.labelsColumns = toList_0(selected);
  }
  x13(event) {
    return this.t3o(event);
  }
}
class DefaultTreeMapSettings$9 {
  constructor(this$0) {
    this.i3p_1 = this$0;
  }
  k30(name, event) {
    if (equals('toolTipField', name)) {
      this.i3p_1.getTooltipColumnsSelection().j13(this.i3p_1.toolTipColumns);
    }
  }
  zx(name, event) {
    return this.k30((name == null ? true : typeof name === 'string') ? name : THROW_CCE(), event);
  }
}
class DefaultTreeMapSettings$10 {
  constructor(this$0) {
    this.j3p_1 = this$0;
  }
  t3o(event) {
    var selected = this.j3p_1.getTooltipColumnsSelection().c13();
    this.j3p_1.toolTipColumns = toList_0(selected);
  }
  x13(event) {
    return this.t3o(event);
  }
}
class DefaultTreeMapSettings$11 extends SingleSelectionSettingsCoordinator {
  static l3p(this$0, $box) {
    if ($box === VOID)
      $box = {};
    $box.k3p_1 = this$0;
    return this.w3o(isInterface(this$0, TreeMapSettings) ? this$0 : THROW_CCE(), 'backgroundField', this$0.getBackgroundColumnSelection(), $box);
  }
  xk() {
    var tmp = this.k3p_1.backgroundColumn;
    return (tmp == null ? true : !(tmp == null)) ? tmp : THROW_CCE();
  }
  x3o(value) {
    this.k3p_1.backgroundColumn = value;
  }
  y3o(value) {
    return this.x3o((value == null ? true : !(value == null)) ? value : THROW_CCE());
  }
}
class DefaultTreeMapSettings$12 extends SingleSelectionSettingsCoordinator {
  static n3p(this$0, $box) {
    if ($box === VOID)
      $box = {};
    $box.m3p_1 = this$0;
    return this.w3o(this$0, 'depth', this$0.getDepthSelection(), $box);
  }
  xk() {
    return this.m3p_1.getDepth();
  }
  o3p(value) {
    this.m3p_1.setDepth(value);
  }
  y3o(value) {
    return this.o3p((value == null ? true : isInterface(value, Depth)) ? value : THROW_CCE());
  }
}
class DefaultTreeMapSettings$13 extends SingleSelectionSettingsCoordinator {
  static q3p(this$0, $box) {
    if ($box === VOID)
      $box = {};
    $box.p3p_1 = this$0;
    return this.w3o(this$0, 'rendering', this$0.renderingSelection, $box);
  }
  xk() {
    return this.p3p_1.rendering;
  }
  r3p(value) {
    this.p3p_1.rendering = value;
  }
  y3o(value) {
    return this.r3p((value == null ? true : isInterface(value, Rendering_0)) ? value : THROW_CCE());
  }
}
class DefaultTreeMapSettings extends AbstractTreeMapSettings {
  constructor(model, colorFactory, fontFactory, colorMapFactory) {
    super();
    this.t3p_1 = new SimpleProperties();
    this.groupByVariables = SimpleSelection.m14();
    this.sizeVariable = SimpleSingleSelection.x14(null);
    this.colorVariable = SimpleSingleSelection.x14(null);
    this.labelVariable = SimpleSelection.m14();
    this.toolTipVariable = SimpleSelection.m14();
    this.backgroundVariable = SimpleSingleSelection.x14(null);
    this.heightVariable = SimpleSingleSelection.x14(null);
    this.progressive = SimpleSingleSelection.x14(Progressive_Disabled_getInstance());
    this.depth = SimpleSingleSelection.x14(Companion_getInstance_82().d3r_1.i3i());
    this.u3p_1 = SimpleSingleSelection.x14(Companion_getInstance_91().instance.getDefault());
    this.v3p_1 = this.t3p_1.vy('dimensionFixed', false);
    this.w3p_1 = this.t3p_1.vy('dimension', null);
    this.x3p_1 = this.t3p_1.vy('progressive', null);
    this.groupByFields = this.t3p_1.vy('groupByField', emptyList());
    this.y3p_1 = PropertyDelegates_instance.j10(this.groupByFields);
    this.labelsFields = this.t3p_1.vy('labelsField', emptyList());
    this.z3p_1 = PropertyDelegates_instance.j10(this.labelsFields);
    this.toolTipFields = this.t3p_1.vy('toolTipField', emptyList());
    this.a3q_1 = PropertyDelegates_instance.j10(this.toolTipFields);
    this.sizeField = this.t3p_1.vy('sizeField', null);
    this.b3q_1 = PropertyDelegates_instance.j10(this.sizeField);
    this.c3q_1 = this.t3p_1.vy('colorField', null);
    this.d3q_1 = PropertyDelegates_instance.j10(this.c3q_1);
    this.backgroundField = this.t3p_1.vy('backgroundField', null);
    this.e3q_1 = PropertyDelegates_instance.j10(this.backgroundField);
    this.heightField = this.t3p_1.vy('heightField', null);
    this.f3q_1 = PropertyDelegates_instance.j10(this.heightField);
    this._depth = this.t3p_1.vy('depth', null);
    this._rendering = this.t3p_1.vy('rendering', null);
    this.g3q_1 = PropertyDelegates_instance.j10(this._rendering);
    this.h3q_1 = SimpleBoundedInterval.lp(0.03, 0.0, 0.5);
    this.maximumHeight = this.t3p_1.wy('maximumHeight', this.h3q_1.sm());
    this.i3q_1 = SimpleBoundedInterval.lp(0.25, 0.0, 2.0);
    this.lightSourceHeight = this.t3p_1.wy('lightSourceHeight', this.i3q_1.sm());
    this.j3q_1 = SimpleBoundedInterval.lp(0.5, 0.0, 1.0);
    this.lightSourceAmbient = this.t3p_1.wy('lightSourceAmbient', this.j3q_1.sm());
    this.k3q_1 = SimpleBoundedInterval.lp(-1.0, -4.0, 4.0);
    this.lightSourceX = this.t3p_1.wy('lightSourceX', this.k3q_1.sm());
    this.l3q_1 = SimpleBoundedInterval.lp(-1.0, -4.0, 4.0);
    this.lightSourceY = this.t3p_1.wy('lightSourceY', this.l3q_1.sm());
    this.m3q_1 = SimpleBoundedInterval.lp(10.0, 0.0, 100.0);
    this.lightSourceZ = this.t3p_1.wy('lightSourceZ', this.m3q_1.sm());
    this.hideSearchResults = this.t3p_1.vy('hideSearchResults', null);
    this.hideFilterResults = this.t3p_1.vy('hideFilterResults', null);
    this.o3q_1 = HashMap.d8();
    var tmp = this;
    tmp.s3q_1 = new DefaultTreeMapSettings$propertyChangeListener$1(this);
    this._model = model;
    this.p3q_1 = colorFactory;
    this.q3q_1 = fontFactory;
    this.r3q_1 = colorMapFactory;
    this._background = this.t3p_1.vy('background', null);
    this._tooltipBackground = this.t3p_1.vy('tooltipBackground', colorOf_0(_UByte___init__impl__g9hnc4(-24), _UByte___init__impl__g9hnc4(-24), _UByte___init__impl__g9hnc4(-24), _UByte___init__impl__g9hnc4(-56)));
    this._probingColor = this.t3p_1.vy('probingColor', colorOf_0(_UByte___init__impl__g9hnc4(0), _UByte___init__impl__g9hnc4(0), _UByte___init__impl__g9hnc4(0), _UByte___init__impl__g9hnc4(-16)));
    this._selectionColor = this.t3p_1.vy('selectionColor', colorOf_4(_UByte___init__impl__g9hnc4(-1), _UByte___init__impl__g9hnc4(102), _UByte___init__impl__g9hnc4(0)));
    this.resetToDefaults();
    this.t3p_1.cy(this.s3q_1);
    this.n3q_1 = this.createDefaultTreeMapColumnSettings();
    this.n3q_1.properties.cy(this.s3q_1);
    this.t3p_1.cy(new DefaultTreeMapSettings$1(this));
    var tmp_0 = this.getGroupByColumnsSelection();
    tmp_0.x12(new DefaultTreeMapSettings$2(this));
    this.getGroupByColumnsSelection().j13(this.groupByColumns);
    DefaultTreeMapSettings$3.v3o(this);
    DefaultTreeMapSettings$4.a3p(this);
    DefaultTreeMapSettings$5.d3p(this);
    DefaultTreeMapSettings$6.f3p(this);
    var tmp_1 = this.properties;
    tmp_1.cy(new DefaultTreeMapSettings$7(this));
    var tmp_2 = this.getLabelColumnsSelection();
    tmp_2.x12(new DefaultTreeMapSettings$8(this));
    this.getLabelColumnsSelection().j13(this.labelsColumns);
    var tmp_3 = this.properties;
    tmp_3.cy(new DefaultTreeMapSettings$9(this));
    var tmp_4 = this.getTooltipColumnsSelection();
    tmp_4.x12(new DefaultTreeMapSettings$10(this));
    this.getTooltipColumnsSelection().j13(this.toolTipColumns);
    DefaultTreeMapSettings$11.l3p(this);
    DefaultTreeMapSettings$12.n3p(this);
    DefaultTreeMapSettings$13.q3p(this);
  }
  f24() {
    return this.t3p_1;
  }
  f3r() {
    return this._model;
  }
  g3r() {
    return this.groupByVariables;
  }
  h3r() {
    return this.sizeVariable;
  }
  i3r() {
    return this.colorVariable;
  }
  j3r() {
    return this.labelVariable;
  }
  k3r() {
    return this.toolTipVariable;
  }
  l3r() {
    return this.backgroundVariable;
  }
  m3r() {
    return this.heightVariable;
  }
  n3r() {
    return this.progressive;
  }
  o3r() {
    return this.depth;
  }
  y35() {
    return this.u3p_1;
  }
  p3r(_set____db54di) {
    this.groupByFields = _set____db54di;
  }
  q3r() {
    return this.groupByFields;
  }
  k35(_set____db54di) {
    return this.y3p_1.vh(this, groupByColumns$factory(), _set____db54di);
  }
  u31() {
    return this.y3p_1.th(this, groupByColumns$factory_0());
  }
  r3r(_set____db54di) {
    this.labelsFields = _set____db54di;
  }
  s3r() {
    return this.labelsFields;
  }
  p35(_set____db54di) {
    return this.z3p_1.vh(this, labelsColumns$factory(), _set____db54di);
  }
  y31() {
    return this.z3p_1.th(this, labelsColumns$factory_0());
  }
  t3r(_set____db54di) {
    this.toolTipFields = _set____db54di;
  }
  u3r() {
    return this.toolTipFields;
  }
  q35(_set____db54di) {
    return this.a3q_1.vh(this, toolTipColumns$factory(), _set____db54di);
  }
  r35() {
    return this.a3q_1.th(this, toolTipColumns$factory_0());
  }
  v3r(_set____db54di) {
    this.sizeField = _set____db54di;
  }
  w3r() {
    return this.sizeField;
  }
  l35(_set____db54di) {
    return this.b3q_1.vh(this, sizeColumn$factory(), _set____db54di);
  }
  m35() {
    return this.b3q_1.th(this, sizeColumn$factory_0());
  }
  n35(_set____db54di) {
    return this.d3q_1.vh(this, colorColumn$factory(), _set____db54di);
  }
  o35() {
    return this.d3q_1.th(this, colorColumn$factory_0());
  }
  x3r(_set____db54di) {
    this.backgroundField = _set____db54di;
  }
  y3r() {
    return this.backgroundField;
  }
  s35(_set____db54di) {
    return this.e3q_1.vh(this, backgroundColumn$factory(), _set____db54di);
  }
  t35() {
    return this.e3q_1.th(this, backgroundColumn$factory_0());
  }
  z3r(_set____db54di) {
    this.heightField = _set____db54di;
  }
  a3s() {
    return this.heightField;
  }
  u35(_set____db54di) {
    return this.f3q_1.vh(this, heightColumn$factory(), _set____db54di);
  }
  v35() {
    return this.f3q_1.th(this, heightColumn$factory_0());
  }
  b3s(_set____db54di) {
    this._depth = _set____db54di;
  }
  c3s() {
    return this._depth;
  }
  d3s(_set____db54di) {
    this._rendering = _set____db54di;
  }
  e3s() {
    return this._rendering;
  }
  w35(_set____db54di) {
    return this.g3q_1.vh(this, rendering$factory(), _set____db54di);
  }
  x35() {
    return this.g3q_1.th(this, rendering$factory_0());
  }
  z35() {
    return this.h3q_1;
  }
  f3s() {
    return this.maximumHeight;
  }
  g3s(_set____db54di) {
    this.i3q_1 = _set____db54di;
  }
  a36() {
    return this.i3q_1;
  }
  h3s() {
    return this.lightSourceHeight;
  }
  b36() {
    return this.j3q_1;
  }
  i3s() {
    return this.lightSourceAmbient;
  }
  c36() {
    return this.k3q_1;
  }
  j3s() {
    return this.lightSourceX;
  }
  d36() {
    return this.l3q_1;
  }
  k3s() {
    return this.lightSourceY;
  }
  e36() {
    return this.m3q_1;
  }
  l3s() {
    return this.lightSourceZ;
  }
  m3s(_set____db54di) {
    this._background = _set____db54di;
  }
  n3s() {
    return this._background;
  }
  o3s(_set____db54di) {
    this._tooltipBackground = _set____db54di;
  }
  p3s() {
    return this._tooltipBackground;
  }
  q3s(_set____db54di) {
    this._probingColor = _set____db54di;
  }
  r3s() {
    return this._probingColor;
  }
  s3s(_set____db54di) {
    this._selectionColor = _set____db54di;
  }
  t3s() {
    return this._selectionColor;
  }
  u3s(_set____db54di) {
    this.hideSearchResults = _set____db54di;
  }
  v3s() {
    return this.hideSearchResults;
  }
  w3s(_set____db54di) {
    this.hideFilterResults = _set____db54di;
  }
  x3s() {
    return this.hideFilterResults;
  }
  getGroupByColumnsSelection() {
    return this.groupByVariables;
  }
  getSizeColumnSelection() {
    return this.sizeVariable;
  }
  getColorColumnSelection() {
    return this.colorVariable;
  }
  getLabelColumnsSelection() {
    return this.labelVariable;
  }
  getTooltipColumnsSelection() {
    return this.toolTipVariable;
  }
  getBackgroundColumnSelection() {
    return this.backgroundVariable;
  }
  getHeightColumnSelection() {
    return this.heightVariable;
  }
  getDepthSelection() {
    return this.depth;
  }
  getProgressiveSelection() {
    return this.progressive;
  }
  getHideFilterResultsSelection() {
    return this.hideFilterResults;
  }
  getHideSearchResultsSelection() {
    return this.hideSearchResults;
  }
  createDefaultTreeMapColumnSettings() {
    return new DefaultTreeMapColumnSettings(this.p3q_1, this.q3q_1, this.r3q_1);
  }
  createOverridingTreeMapColumnSettings(defaultSettings, model, field) {
    return new OverridingTreeMapColumnSettings(defaultSettings);
  }
  getDefaultColumnSettings() {
    return this.n3q_1;
  }
  getColumnSettings(field) {
    var tmp;
    if (!(field == null)) {
      if (!this.o3q_1.s2(field)) {
        var treeMapColumnSettings = this.createOverridingTreeMapColumnSettings(this.getDefaultColumnSettings(), this._model, field);
        treeMapColumnSettings.properties.cy(this.s3q_1);
        // Inline function 'kotlin.collections.set' call
        this.o3q_1.i7(field, treeMapColumnSettings);
      }
      tmp = ensureNotNull(this.o3q_1.u2(field));
    } else {
      tmp = this.getDefaultColumnSettings();
    }
    return tmp;
  }
  getDimensionFixed() {
    return this.v3p_1.r2();
  }
  setDimensionFixed(fixed) {
    this.v3p_1.vo(fixed);
  }
  getDimension() {
    return this.w3p_1.r2();
  }
  setDimension(dimension) {
    this.w3p_1.vo(dimension);
  }
  getProgressive() {
    return this.x3p_1.r2();
  }
  setProgressive(progressive) {
    this.x3p_1.vo(progressive);
  }
  getMaximumHeight() {
    return this.h3q_1.start;
  }
  setMaximumHeight(height) {
    this.h3q_1.start = height;
  }
  isHideFilterResults() {
    return this.hideFilterResults.r2();
  }
  isHideSearchResults() {
    return this.hideSearchResults.r2();
  }
  setGroupBy(columns) {
    var fields = this._model.getTreeMapColumnsByIndices(columns.slice());
    this.groupByColumns = fields;
  }
  setGroupByByNames(columnNames) {
    var fields = this._model.getTreeMapColumnsByNames(columnNames.slice());
    this.groupByColumns = fields;
  }
  setLabels(columns) {
    var fields = this._model.getTreeMapColumnsByIndices(columns.slice());
    this.labelsColumns = fields;
  }
  setLabelsByNames(columnNames) {
    var fields = this._model.getTreeMapColumnsByNames(columnNames.slice());
    this.labelsColumns = fields;
  }
  setToolTip(columns) {
    var fields = this._model.getTreeMapColumnsByIndices(columns.slice());
    this.toolTipColumns = fields;
  }
  setToolTipByNames(columns) {
    var fields = this._model.getTreeMapColumnsByNames(columns.slice());
    this.toolTipColumns = fields;
  }
  getShowPopup(field) {
    var tmp;
    if (!(this.toolTipFields == null)) {
      var inductionVariable = 0;
      var last = this.toolTipFields.r2().a1();
      if (inductionVariable < last)
        do {
          var i = inductionVariable;
          inductionVariable = inductionVariable + 1 | 0;
          var toolTipField = this.toolTipFields.r2().b1(i);
          if (toolTipField === field) {
            return true;
          }
        }
         while (inductionVariable < last);
      tmp = false;
    } else {
      tmp = false;
    }
    return tmp;
  }
  setShowPopup(field, show) {
    if (!(this.getShowPopup(field) === show)) {
      if (show) {
        if (!(field == null)) {
          var fields = toMutableList_0(this.toolTipFields.r2());
          fields.o(field);
          this.toolTipColumns = fields;
        }
      } else {
        var fields_0 = toMutableList_0(this.toolTipFields.r2());
        // Inline function 'kotlin.collections.remove' call
        (isInterface(fields_0, MutableCollection) ? fields_0 : THROW_CCE()).w2(field);
        this.toolTipColumns = fields_0;
      }
    }
  }
  setBackground(column) {
    var field = this._model.getTreeMapColumn(column);
    this.backgroundColumn = field;
  }
  setBackgroundByName(columnName) {
    var field = ensureNotNull(this._model.getTreeMapColumnByName(columnName));
    this.backgroundColumn = field;
  }
  setSize(column) {
    var field = this._model.getTreeMapColumn(column);
    this.sizeColumn = field;
  }
  setSizeByName(columnName) {
    var field = ensureNotNull(this._model.getTreeMapColumnByName(columnName));
    this.sizeColumn = field;
  }
  setColor(column) {
    var field = this._model.getTreeMapColumn(column);
    this.colorColumn = field;
  }
  setColorByName(columnName) {
    var field = ensureNotNull(this._model.getTreeMapColumnByName(columnName));
    this.colorColumn = field;
  }
  setHeight(column) {
    var field = this._model.getTreeMapColumn(column);
    this.heightColumn = field;
  }
  setHeightByName(columnName) {
    var field = ensureNotNull(this._model.getTreeMapColumnByName(columnName));
    this.heightColumn = field;
  }
  getDepth() {
    return this._depth.r2();
  }
  setDepth(depth) {
    this._depth.vo(depth);
  }
  setHideFilterResults(hideFilterResults) {
    this.hideFilterResults.vo(hideFilterResults);
  }
  setHideSearchResults(hideSearchResults) {
    this.hideSearchResults.vo(hideSearchResults);
  }
  getLightSourceHeight() {
    return this.i3q_1.start;
  }
  setLightSourceHeight(value) {
    this.i3q_1.start = value;
  }
  getLightSourceAmbient() {
    return this.j3q_1.start;
  }
  setLightSourceAmbient(value) {
    this.j3q_1.start = value;
  }
  getLightSourceX() {
    return this.k3q_1.start;
  }
  setLightSourceX(value) {
    this.k3q_1.start = value;
  }
  getLightSourceY() {
    return this.l3q_1.start;
  }
  setLightSourceY(value) {
    this.l3q_1.start = value;
  }
  getLightSourceZ() {
    return this.m3q_1.start;
  }
  setLightSourceZ(value) {
    this.m3q_1.start = value;
  }
  getBackgroundProperty() {
    return this._background;
  }
  getBackground() {
    return this._background.r2();
  }
  setBackgroundColor(color) {
    this._background.vo(color);
  }
  getTooltipBackgroundProperty() {
    return this._tooltipBackground;
  }
  getTooltipBackground() {
    return this._tooltipBackground.r2();
  }
  setTooltipBackground(color) {
    this._tooltipBackground.vo(color);
  }
  getProbingColorProperty() {
    return this._probingColor;
  }
  getProbingColor() {
    return this._probingColor.r2();
  }
  setProbingColor(color) {
    this._probingColor.vo(color);
  }
  getSelectionColorProperty() {
    return this._selectionColor;
  }
  getSelectionColor() {
    return this._selectionColor.r2();
  }
  setSelectionColor(color) {
    this._selectionColor.vo(color);
  }
  getValue(key) {
    return this.t3p_1.yy(key);
  }
  resetToDefaults() {
    this.setDimensionFixed(false);
    this.setProgressive(Progressive_Disabled_getInstance());
    this.setDepth(Companion_getInstance_82().d3r_1.i3i());
    this.rendering = Companion_getInstance_91().instance.getDefault();
    this.setMaximumHeight(0.03);
    this.setBackgroundColor(null);
    this.setTooltipBackground(colorOf_0(_UByte___init__impl__g9hnc4(-24), _UByte___init__impl__g9hnc4(-24), _UByte___init__impl__g9hnc4(-24), _UByte___init__impl__g9hnc4(-56)));
    this.setProbingColor(colorOf_0(_UByte___init__impl__g9hnc4(0), _UByte___init__impl__g9hnc4(0), _UByte___init__impl__g9hnc4(0), _UByte___init__impl__g9hnc4(-16)));
    this.setSelectionColor(colorOf_4(_UByte___init__impl__g9hnc4(-1), _UByte___init__impl__g9hnc4(102), _UByte___init__impl__g9hnc4(0)));
    this.setHideSearchResults(true);
    this.setHideFilterResults(true);
  }
  save(dataFrame, elementFactory, root) {
    var configuration = elementFactory.y3s('Configuration');
    var groupBy = elementFactory.y3s('GroupBy');
    var _iterator__ex2g4s = this.groupByVariables.x();
    while (_iterator__ex2g4s.y()) {
      var variable = _iterator__ex2g4s.z();
      if (!(variable == null)) {
        var v = elementFactory.y3s('Variable');
        v.a3t(elementFactory.z3s('name', ensureNotNull(this._model.getColumnName(variable))));
        v.a3t(elementFactory.z3s('index', dataFrame.f2k(variable).toString()));
        groupBy.b3t(v);
      }
    }
    configuration.b3t(groupBy);
    var size = elementFactory.y3s('Size');
    if (!(this.sizeVariable.v13() == null)) {
      size.a3t(elementFactory.z3s('variableName', ensureNotNull(this._model.getColumnName(ensureNotNull(this.sizeVariable.v13())))));
      size.a3t(elementFactory.z3s('variableIndex', dataFrame.f2k(ensureNotNull(this.sizeVariable.v13())).toString()));
    }
    configuration.b3t(size);
    var color = elementFactory.y3s('Color');
    if (!(this.colorVariable.v13() == null)) {
      color.a3t(elementFactory.z3s('variableName', ensureNotNull(this._model.getColumnName(ensureNotNull(this.colorVariable.v13())))));
      color.a3t(elementFactory.z3s('variableIndex', dataFrame.f2k(ensureNotNull(this.colorVariable.v13())).toString()));
    }
    configuration.b3t(color);
    var height = elementFactory.y3s('Height');
    if (!(this.heightVariable.v13() == null)) {
      height.a3t(elementFactory.z3s('variableName', ensureNotNull(this._model.getColumnName(ensureNotNull(this.heightVariable.v13())))));
      height.a3t(elementFactory.z3s('variableIndex', dataFrame.f2k(ensureNotNull(this.heightVariable.v13())).toString()));
    }
    configuration.b3t(height);
    var label = elementFactory.y3s('Label');
    var _iterator__ex2g4s_0 = this.labelVariable.x();
    while (_iterator__ex2g4s_0.y()) {
      var variable_0 = _iterator__ex2g4s_0.z();
      if (!(variable_0 == null)) {
        var v_0 = elementFactory.y3s('Variable');
        v_0.a3t(elementFactory.z3s('name', ensureNotNull(this._model.getColumnName(variable_0))));
        v_0.a3t(elementFactory.z3s('index', dataFrame.f2k(variable_0).toString()));
        label.b3t(v_0);
      }
    }
    configuration.b3t(label);
    var tooltip = elementFactory.y3s('Tooltip');
    var _iterator__ex2g4s_1 = this.toolTipVariable.x();
    while (_iterator__ex2g4s_1.y()) {
      var variable_1 = _iterator__ex2g4s_1.z();
      if (!(variable_1 == null)) {
        var v_1 = elementFactory.y3s('Variable');
        v_1.a3t(elementFactory.z3s('name', ensureNotNull(this._model.getColumnName(variable_1))));
        v_1.a3t(elementFactory.z3s('index', dataFrame.f2k(variable_1).toString()));
        tooltip.b3t(v_1);
      }
    }
    configuration.b3t(tooltip);
    var background = elementFactory.y3s('Background');
    if (!(this.backgroundVariable.v13() == null)) {
      background.a3t(elementFactory.z3s('variableName', ensureNotNull(this._model.getColumnName(ensureNotNull(this.backgroundVariable.v13())))));
      background.a3t(elementFactory.z3s('variableIndex', dataFrame.f2k(ensureNotNull(this.backgroundVariable.v13())).toString()));
    }
    configuration.b3t(background);
    root.b3t(configuration);
  }
  get properties() {
    return this.f24();
  }
  get renderingSelection() {
    return this.y35();
  }
  get groupByColumns() {
    return this.u31();
  }
  set groupByColumns(value) {
    this.k35(value);
  }
  get labelsColumns() {
    return this.y31();
  }
  set labelsColumns(value) {
    this.p35(value);
  }
  get toolTipColumns() {
    return this.r35();
  }
  set toolTipColumns(value) {
    this.q35(value);
  }
  get sizeColumn() {
    return this.m35();
  }
  set sizeColumn(value) {
    this.l35(value);
  }
  get colorColumn() {
    return this.o35();
  }
  set colorColumn(value) {
    this.n35(value);
  }
  get backgroundColumn() {
    return this.t35();
  }
  set backgroundColumn(value) {
    this.s35(value);
  }
  get heightColumn() {
    return this.v35();
  }
  set heightColumn(value) {
    this.u35(value);
  }
  get rendering() {
    return this.x35();
  }
  set rendering(value) {
    this.w35(value);
  }
  get maximumHeightInterval() {
    return this.z35();
  }
  get lightSourceHeightInterval() {
    return this.a36();
  }
  set lightSourceHeightInterval(value) {
    this.g3s(value);
  }
  get lightSourceAmbientInterval() {
    return this.b36();
  }
  get lightSourceXInterval() {
    return this.c36();
  }
  get lightSourceYInterval() {
    return this.d36();
  }
  get lightSourceZInterval() {
    return this.e36();
  }
}
class DefaultTreeMapToolTip extends AbstractTreeMapToolTip {
  constructor(view) {
    super(view);
    this.h3t_1 = 0;
    this.i3t_1 = 0;
  }
  cm() {
    return this.h3t_1;
  }
  dm() {
    return this.i3t_1;
  }
  n37(d) {
    this.h3t_1 = d.yl_1;
    this.i3t_1 = d.zl_1;
  }
  h37() {
    return this.k37(null);
  }
  h26() {
    return ToolTipType_Painted_getInstance();
  }
}
class Companion_81 {
  constructor() {
    Companion_instance_81 = this;
    this.j3t_1 = new Insets(0, 2, 0, 1);
  }
}
class DefaultTreeMapTooltipRenderer extends EnhancedLabel {
  static f3c() {
    Companion_getInstance_81();
    var $this = this.z23();
    $this.isOpaque = false;
    $this.setName('TreeMap.tooltipRenderer');
    $this.setInsets(Companion_getInstance_81().j3t_1.j22_1, Companion_getInstance_81().j3t_1.k22_1, Companion_getInstance_81().j3t_1.l22_1, Companion_getInstance_81().j3t_1.m22_1);
    $this.setEffect(Plain_getInstance());
    $this.setHorizontalAlignment(2);
    $this.setRendering(Rendering_WordWrap_getInstance());
    return $this;
  }
  k3t(view, column, node, dimension) {
    var model = ensureNotNull(view.j2p());
    var value = model.getStringValue(node, column);
    this.setText(value);
    this.isHTML = model.getColumnClass(column) === getKClass(HtmlString);
    var settings = model.settings.getColumnSettings(column);
    var rendering = settings.getTooltipRendering();
    if (!(rendering == null)) {
      this.setRendering(rendering);
    }
    if (model.isNumericType(column)) {
      this.setHorizontalAlignment(4);
    } else {
      this.setHorizontalAlignment(2);
    }
    this.setDesiredWidth(dimension.yl_1);
    this.setDesiredHeight(dimension.zl_1);
    return this;
  }
}
class DefaultTreeMapView$timer$2$1 {
  constructor(this$0) {
    this.l3t_1 = this$0;
  }
  y17() {
    this.l3t_1.r2r().s2a();
  }
}
class DefaultTreeMapView$1 {
  constructor(this$0) {
    this.p3u_1 = this$0;
  }
  h2b(width, height) {
    this.p3u_1.g39();
    this.p3u_1.h39();
  }
}
class DefaultTreeMapView$2 {
  q3u(view, tg, width, height) {
    var width_0 = numberToInt(width);
    var height_0 = numberToInt(height);
    if (width_0 > 0 && height_0 > 0) {
      var current = Companion_getInstance_28().h17_1.t17();
      var _iterator__ex2g4s = view.m3c().x();
      while (_iterator__ex2g4s.y()) {
        var renderer = _iterator__ex2g4s.z();
        renderer.r3d(tg, view, null);
      }
      var paintingForPrint = false;
      var _iterator__ex2g4s_0 = view.n3c().x();
      while (_iterator__ex2g4s_0.y()) {
        var renderer_0 = _iterator__ex2g4s_0.z();
        renderer_0.r3d(tg, view, null);
      }
      var _iterator__ex2g4s_1 = view.o3c().x();
      while (_iterator__ex2g4s_1.y()) {
        var renderer_1 = _iterator__ex2g4s_1.z();
        renderer_1.r3d(tg, view, null);
      }
      // Inline function 'kotlin.run' call
      // Inline function 'com.treemap.<no name provided>.draw.<anonymous>' call
      var toolTip = view.s38();
      if (!(toolTip == null) && (paintingForPrint || toolTip.h26() === ToolTipType_Painted_getInstance())) {
        var tooltipPosition = toolTip.e37();
        var tooltipDimension = toolTip.u36(tg);
        if (!(tooltipPosition == null) && !(tooltipDimension == null)) {
          toolTip.n37(tooltipDimension);
          tg.w2q();
          tg.e1o(tooltipPosition.w1l(), tooltipPosition.x1l());
          tg.x2q(Double_3.p1m(0.0, 0.0, tooltipDimension.cm(), tooltipDimension.dm()));
          toolTip.y36(tg);
          toolTip.b37(tg);
          tg.y2q();
        }
      }
      // Inline function 'kotlin.run' call
      // Inline function 'com.treemap.<no name provided>.draw.<anonymous>' call
      var toolTip_0 = view.v38();
      if (!(toolTip_0 == null) && (paintingForPrint || toolTip_0.h26() === ToolTipType_Painted_getInstance())) {
        var tooltipPosition_0 = toolTip_0.h37();
        var tooltipDimension_0 = toolTip_0.u36(tg);
        if (!(tooltipPosition_0 == null) && !(tooltipDimension_0 == null)) {
          toolTip_0.n37(tooltipDimension_0);
          tg.w2q();
          tg.e1o(tooltipPosition_0.w1l(), tooltipPosition_0.x1l());
          tg.x2q(Double_3.p1m(0.0, 0.0, tooltipDimension_0.cm(), tooltipDimension_0.dm()));
          toolTip_0.y36(tg);
          toolTip_0.b37(tg);
          tg.y2q();
        }
      }
      if (view.s28().s28().a13()) {
        tg.w2q();
        tg.a2r(Companion_getInstance_54().a1g_1.f2c());
        // Inline function 'kotlin.doubleArrayOf' call
        var dashPattern = new Float64Array([10.0, 2.0, 2.0, 2.0]);
        tg.z2q(1.0);
        tg.r3u(dashPattern);
        var r = ensureNotNull(view.s28().w28());
        tg.b2r(Double_3.p1m(r.w1l(), r.x1l(), r.cm(), r.dm()));
        tg.y2q();
      }
      if (view.s3c()) {
        tg.w2q();
        var duration = Companion_getInstance_28().h17_1.t17().i3(current);
        tg.s3u(colorOf_4(_UByte___init__impl__g9hnc4(-1), _UByte___init__impl__g9hnc4(0), _UByte___init__impl__g9hnc4(0)));
        tg.h3h(Companion_getInstance_55().a24_1.b24().w2d(Weight_BOLD_getInstance()));
        tg.i3h(duration.toString() + ' ms', 5.0, height_0 - 5.0);
        tg.y2q();
      }
    }
  }
}
class DefaultTreeMapView extends AbstractTreeMapView {
  constructor() {
    super(new Headless());
    var tmp = this;
    tmp.n3u_1 = lazy(DefaultTreeMapView$component$delegate$lambda(this));
    var tmp_0 = this;
    tmp_0.o3u_1 = lazy(DefaultTreeMapView$timer$delegate$lambda(this));
    var tmp_1 = this.r2r();
    tmp_1.r2a(new DefaultTreeMapView$1(this));
    var tmp_2 = this.r2r();
    tmp_2.a3v(new DefaultTreeMapView$2());
    this.g39();
    this.h39();
  }
  r2r() {
    var tmp0 = this.n3u_1;
    // Inline function 'kotlin.getValue' call
    component$factory();
    return tmp0.r2();
  }
  b3v() {
    var tmp0 = this.o3u_1;
    // Inline function 'kotlin.getValue' call
    timer$factory();
    return tmp0.r2();
  }
  i2r(model) {
    Companion_getInstance_83().v3i_1.t3g_1 = new Headless();
    Companion_getInstance_83().w3i_1.t3g_1 = new Headless();
    super.i2r(model);
  }
  j2p() {
    return super.j2p();
  }
  d39(delay) {
    this.b3v().g15();
  }
  h39() {
    var m = !(this.j2p() == null) && !(ensureNotNull(this.j2p()).settings.getDimension() == null) ? ensureNotNull(ensureNotNull(this.j2p()).settings.getDimension()) : Dimension.bm(0, 0);
    var width;
    var height;
    var w;
    var h;
    var v = Dimension.bm(numberToInt(this.r2r().p2a()), numberToInt(this.r2r().q2a()));
    var tmp0 = m.cm();
    // Inline function 'kotlin.math.max' call
    var b = v.cm();
    // Inline function 'kotlin.math.max' call
    var b_0 = Math.max(tmp0, b);
    width = Math.max(0.0, b_0);
    var tmp4 = m.dm();
    // Inline function 'kotlin.math.max' call
    var b_1 = v.dm();
    // Inline function 'kotlin.math.max' call
    var b_2 = Math.max(tmp4, b_1);
    height = Math.max(0.0, b_2);
    // Inline function 'kotlin.math.max' call
    var b_3 = v.yl_1;
    w = Math.max(0, b_3);
    // Inline function 'kotlin.math.max' call
    var b_4 = v.zl_1;
    h = Math.max(0, b_4);
    this.p37_1.mp(0.0, width);
    this.q37_1.mp(0.0, height);
    this.p37_1.jp(w);
    this.q37_1.jp(h);
    this.p37_1.lo(0.0, this.p37_1.kp());
    this.q37_1.lo(height - this.q37_1.kp(), this.q37_1.kp());
    this.r37_1.c29(w, h);
  }
  j2r(licenseModel) {
  }
  g39() {
    if (!(this.j2p() == null)) {
      if (this.r3c() && !ensureNotNull(ensureNotNull(this.j2p()).settings.getDimensionFixed())) {
        var dimension = Dimension.bm(numberToInt(this.r2r().p2a()), numberToInt(this.r2r().q2a()));
        ensureNotNull(this.j2p()).settings.setDimension(dimension);
      }
    }
  }
  m2q() {
    return null;
  }
  a1() {
    return Dimension.bm(numberToInt(this.r2r().p2a()), numberToInt(this.r2r().q2a()));
  }
  t2a(l) {
    this.r2r().t2a(l);
  }
  u2a(l) {
    this.r2r().u2a(l);
  }
  v2a(l) {
    this.r2r().v2a(l);
  }
  w2a(l) {
    this.r2r().w2a(l);
  }
  x2a(l) {
    this.r2r().x2a(l);
  }
}
class Depth {}
class Companion_82 {
  constructor() {
    Companion_instance_82 = this;
    this.t3q_1 = new InfiniteDepth();
    this.u3q_1 = new ThresholdDepth(1);
    this.v3q_1 = new ThresholdDepth(2);
    this.w3q_1 = new ThresholdDepth(3);
    this.x3q_1 = new ThresholdDepth(4);
    this.y3q_1 = new ThresholdDepth(5);
    this.z3q_1 = new ThresholdDepth(6);
    this.a3r_1 = new ThresholdDepth(7);
    this.b3r_1 = new ThresholdDepth(8);
    this.c3r_1 = new ThresholdDepth(9);
    this.d3r_1 = new DepthFactory([this.t3q_1, this.u3q_1, this.v3q_1, this.w3q_1, this.x3q_1, this.y3q_1, this.z3q_1, this.a3r_1, this.b3r_1, this.c3r_1]);
  }
}
class DepthFactory {
  constructor(entries) {
    Companion_getInstance_82();
    this.e3r_1 = ArrayList.e1();
    addAll(this.e3r_1, entries);
  }
  i3i() {
    return Companion_getInstance_82().t3q_1;
  }
}
class EqualCirclesInCircle {
  constructor() {
    EqualCirclesInCircle_instance = this;
    var tmp = this;
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_0 = new Float32Array([0.0, 0.0]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_1 = new Float32Array([-0.5, 0.0, 0.5, 0.0]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_2 = new Float32Array([-0.4641016, -0.2679492, 0.4641016, -0.2679492, 0.0, 0.5358984]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_3 = new Float32Array([-0.41421357, -0.41421357, 0.41421357, -0.41421357, -0.41421357, 0.41421357, 0.41421357, 0.41421357]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_4 = new Float32Array([-0.3701919, -0.5095255, 0.3701919, -0.5095255, -0.5989831, 0.1946214, 0.5989831, 0.1946214, 0.0, 0.62980807]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_5 = new Float32Array([-0.33333334, -0.57735026, 0.33333334, -0.57735026, -0.6666667, 0.0, 0.6666667, 0.0, -0.33333334, 0.57735026, 0.33333334, 0.57735026]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_6 = new Float32Array([-0.33333334, -0.57735026, 0.33333334, -0.57735026, -0.6666667, 0.0, 0.0, 0.0, 0.6666667, 0.0, -0.33333334, 0.57735026, 0.33333334, 0.57735026]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_7 = new Float32Array([-0.30259338, -0.6283417, 0.30259338, -0.6283417, -0.67992115, -0.15518758, 0.67992115, -0.15518758, 0.0, 0.0, -0.54525447, 0.4348259, 0.54525447, 0.4348259, 0.0, 0.6974066]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_8 = new Float32Array([-0.27676865, -0.6681786, 0.27676865, -0.6681786, -0.6681786, -0.27676865, 0.6681786, -0.27676865, 0.0, 0.0, -0.6681786, 0.27676865, 0.6681786, 0.27676865, -0.27676865, 0.6681786, 0.27676865, 0.6681786]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_9 = new Float32Array([-0.26225892, -0.6895521, 0.26225892, -0.6895521, -0.65420747, -0.3409904, 0.65420747, -0.3409904, 0.0, -0.23530635, -0.71546066, 0.1799386, 0.71546066, 0.1799386, 0.0, 0.28921148, -0.41505563, 0.6099104, 0.41505563, 0.6099104]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_10 = new Float32Array([-0.2548547, -0.70020753, 0.2548547, -0.70020753, -0.64531475, -0.37257266, 0.64531475, -0.37257266, -0.2548547, -0.04493776, 0.2548547, -0.04493776, -0.73382485, 0.12939313, 0.73382485, 0.12939313, 0.0, 0.39648354, -0.47897017, 0.57081443, 0.47897017, 0.57081443]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_11 = new Float32Array([0.0, -0.75183654, -0.4685099, -0.5880107, 0.4685099, -0.5880107, -0.24816348, -0.14327724, 0.24816348, -0.14327724, -0.7434872, -0.11173612, 0.7434872, -0.11173612, 0.0, 0.2865545, -0.6511095, 0.37591827, 0.6511095, 0.37591827, -0.27497727, 0.69974685, 0.27497727, 0.69974685]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_12 = new Float32Array([0.0, -0.76393205, -0.449028, -0.618034, 0.449028, -0.618034, 0.0, -0.29179606, -0.72654253, -0.23606798, 0.72654253, -0.23606798, -0.27751455, 0.090169944, 0.27751455, 0.090169944, -0.72654253, 0.23606798, 0.72654253, 0.23606798, 0.0, 0.47213596, -0.449028, 0.618034, 0.449028, 0.618034]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_13 = new Float32Array([-0.23103073, -0.73344296, 0.23103073, -0.73344296, -0.6096758, -0.46862474, 0.6096758, -0.46862474, 0.0, -0.333286, -0.76819026, -0.034604043, 0.76819026, -0.034604043, -0.30836722, 0.010822211, 0.30836722, 0.010822211, 0.0, 0.3549304, -0.64934057, 0.41191083, 0.64934057, 0.41191083, -0.29603884, 0.70970047, 0.29603884, 0.70970047]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_14 = new Float32Array([-0.22117254, -0.746763, 0.22117254, -0.746763, -0.6418677, -0.44111004, 0.6418677, -0.44111004, -0.22117254, -0.30441788, 0.22117254, -0.30441788, -0.77855986, -0.02041486, 0.77855986, -0.02041486, -0.35786468, 0.116277285, 0.35786468, 0.116277285, 0.0, 0.3762812, -0.6178686, 0.474142, 0.6178686, 0.474142, -0.26000392, 0.7341459, 0.26000392, 0.7341459]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_15 = new Float32Array([0.0, -0.78333527, -0.41642413, -0.6634795, 0.41642413, -0.6634795, -0.7054167, -0.34058985, 0.7054167, -0.34058985, -0.21666475, -0.27894002, 0.21666475, -0.27894002, -0.7785419, 0.08652506, 0.7785419, 0.08652506, -0.3478278, 0.13406205, 0.3478278, 0.13406205, 0.0, 0.3925002, -0.6134226, 0.48716208, 0.6134226, 0.48716208, -0.26058733, 0.7387208, 0.26058733, 0.7387208]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_16 = new Float32Array([-0.20867966, -0.763309, 0.20867966, -0.763309, -0.5679899, -0.55097675, 0.5679899, -0.55097675, 0.0, -0.40186524, -0.3593102, -0.18953298, 0.3593102, -0.18953298, -0.775452, -0.15767702, 0.775452, -0.15767702, 0.0, 0.022799296, -0.74781543, 0.25876626, 0.74781543, 0.25876626, -0.33086324, 0.27719727, 0.33086324, 0.27719727, -0.0, 0.53159523, -0.38574672, 0.6909322, 0.38574672, 0.6909322]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_17 = new Float32Array([-0.20560464, -0.767327, 0.20560464, -0.767327, -0.56172234, -0.56172234, 0.56172234, -0.56172234, -0.20560464, -0.3561177, 0.20560464, -0.3561177, -0.767327, -0.20560464, 0.767327, -0.20560464, -0.4112093, 0.0, 0.4112093, 0.0, -0.767327, 0.20560464, 0.767327, 0.20560464, -0.20560464, 0.3561177, 0.20560464, 0.3561177, -0.56172234, 0.56172234, 0.56172234, 0.56172234, -0.20560464, 0.767327, 0.20560464, 0.767327]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_18 = new Float32Array([-0.20560464, -0.767327, 0.20560464, -0.767327, -0.56172234, -0.56172234, 0.56172234, -0.56172234, -0.20560464, -0.3561177, 0.20560464, -0.3561177, -0.767327, -0.20560464, 0.767327, -0.20560464, -0.4112093, 0.0, 0.0, 0.0, 0.4112093, 0.0, -0.767327, 0.20560464, 0.767327, 0.20560464, -0.20560464, 0.3561177, 0.20560464, 0.3561177, -0.56172234, 0.56172234, 0.56172234, 0.56172234, -0.20560464, 0.767327, 0.20560464, 0.767327]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_19 = new Float32Array([-0.19522402, -0.7807381, 0.19522402, -0.7807381, -0.53971946, -0.5969651, 0.53971946, -0.5969651, -0.19522402, -0.39029008, 0.19522402, -0.39029008, -0.7571738, -0.27267614, 0.7571738, -0.27267614, -0.42198148, -0.0724368, 0.42198148, -0.0724368, 0.0, 0.0, -0.7964017, 0.115796275, 0.7964017, 0.115796275, -0.30080065, 0.2987301, 0.30080065, 0.2987301, -0.6481696, 0.47701216, 0.6481696, 0.47701216, 0.0, 0.54766506, -0.34736893, 0.72594714, 0.34736893, 0.72594714]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_20 = new Float32Array([-0.19039215, -0.7869026, 0.19039215, -0.7869026, -0.5290594, -0.61283034, 0.5290594, -0.61283034, 0.0, -0.45713374, -0.7506924, -0.30319265, 0.7506924, -0.30319265, -0.33866727, -0.28306144, 0.33866727, -0.28306144, 0.0, 0.0, -0.80626327, 0.07351488, 0.80626327, 0.07351488, -0.4257408, 0.08763368, 0.4257408, 0.08763368, -0.19039215, 0.3869791, 0.19039215, 0.3869791, -0.683479, 0.43396002, 0.683479, 0.43396002, -0.40950105, 0.698408, 0.40950105, 0.698408, 0.0, 0.7772235]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_21 = new Float32Array([-0.0861123, -0.8116115, 0.27884403, -0.76705575, -0.43359375, -0.69146585, 0.5872142, -0.5668404, -0.69308543, -0.4310001, 0.16102736, -0.41877776, -0.20627783, -0.40249214, 0.7764202, -0.2515954, 0.42072973, -0.15852211, -0.44657195, -0.12421697, -0.008521454, -0.09253932, -0.8119284, -0.083071, 0.80806625, 0.11470617, 0.40514088, 0.20881331, -0.40064925, 0.24056986, 0.042861454, 0.27151853, -0.7660057, 0.28171584, 0.67573035, 0.4577303, -0.19928, 0.54818773, -0.56463647, 0.5893337, 0.40626764, 0.7078666, 0.054360516, 0.81435466]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_22 = new Float32Array([-0.16034868, -0.8038267, 0.20021126, -0.79483616, -0.4898617, -0.65717924, 0.52200603, -0.63194835, -0.17509694, -0.44345635, 0.2200437, -0.43470982, -0.72452706, -0.38328788, 0.7427293, -0.34670192, -0.42458308, -0.18299334, 0.440767, -0.14946336, 0.015796514, -0.13744327, -0.8189085, -0.035183813, 0.81964433, 0.0056734183, -0.42321372, 0.17767608, 0.40858343, 0.20976989, 0.048111383, 0.22177817, -0.75473183, 0.3197326, 0.7378588, 0.35695025, -0.21290486, 0.47068545, 0.1603279, 0.5645489, -0.544423, 0.61274195, 0.513208, 0.6391139, -0.10068833, 0.8134562]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_23 = new Float32Array([0.11770021, -0.81460166, -0.23523109, -0.7887303, 0.4488734, -0.6898854, -0.5446775, -0.617054, 0.023343535, -0.47353473, 0.6970677, -0.43763667, -0.3093029, -0.35280293, 0.3545167, -0.34881848, -0.75343454, -0.33130884, 0.8164018, -0.10448625, 0.15598781, -0.055874646, -0.47331947, -0.039229352, -0.82291144, 0.0156822, 0.49536428, 0.044392135, -0.15438978, 0.11411233, 0.7848155, 0.24797954, 0.30718815, 0.35718057, -0.7402646, 0.35977423, -0.38701096, 0.38079044, -0.034352448, 0.4633757, 0.6081479, 0.55460376, -0.3717211, 0.7343382, 0.3190579, 0.75870365, -0.029013293, 0.82254934]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_24 = new Float32Array([0.119223475, -0.8175246, -0.22764783, -0.79418963, -0.5342085, -0.6302238, 0.5726889, -0.5954731, 0.24084036, -0.49183527, -0.10603095, -0.4685003, -0.74617434, -0.3546613, 0.7669519, -0.30715716, -0.40453178, -0.2902828, 0.10621345, -0.17130473, 0.4535601, -0.15665857, -0.63110644, -0.026600901, -0.20094946, -0.008469945, 0.8254072, 0.035548564, 0.09365106, 0.17612354, 0.44099772, 0.1907697, -0.42752415, 0.25521192, -0.7733724, 0.29061297, 0.73770374, 0.3719595, -0.14507905, 0.4579161, 0.1990334, 0.5074222, -0.5853469, 0.583035, 0.5193717, 0.6425059, -0.29367125, 0.77221626, 0.05163279, 0.8243523]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_25 = new Float32Array([-0.038242128, -0.8275366, 0.3004004, -0.77203554, -0.37032267, -0.7410401, 0.58749706, -0.5840604, -0.6388593, -0.527388, -0.05106595, -0.48461577, 0.28599226, -0.42018843, -0.3577257, -0.33060628, 0.77378464, -0.2958659, -0.7977736, -0.22324103, 0.16437186, -0.09930277, 0.5069913, -0.0800408, -0.17378387, -0.040908966, -0.51664, -0.026459323, 0.827298, 0.043096423, -0.816406, 0.14057206, 0.045864508, 0.22274558, 0.4128512, 0.25581527, -0.38962898, 0.29233107, 0.7388547, 0.3746638, -0.68939495, 0.45936248, 0.19935839, 0.52966374, -0.14379573, 0.5317578, 0.52363086, 0.6419423, -0.44331455, 0.69977933, 0.029594833, 0.82789093]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_26 = new Float32Array([-0.16930793, -0.81325525, 0.16930793, -0.81325525, -0.47979107, -0.6781223, 0.47979107, -0.6781223, -0.059421573, -0.49296525, 0.71055067, -0.43031043, 0.26954076, -0.41268772, -0.7279351, -0.4001997, -0.39293686, -0.35083488, 0.50030035, -0.16487586, -0.11405054, -0.1587851, -0.8271667, -0.07645011, 0.8271667, -0.07645011, -0.49216843, -0.027085287, 0.19453721, -0.01937811, -0.08048666, 0.17816322, 0.4566312, 0.19502205, -0.78895366, 0.26000267, 0.78895366, 0.26000267, -0.39720964, 0.29794323, 0.22262767, 0.43977302, -0.107363485, 0.5157108, -0.6196458, 0.5532526, 0.6196458, 0.5532526, -0.3473756, 0.7545724, 0.3473756, 0.7545724, 0.017384442, 0.83051014]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_27 = new Float32Array([0.10739565, -0.8262805, -0.44784173, -0.70325834, 0.44784173, -0.70325834, -0.13469408, -0.59146184, 0.18490662, -0.49972692, -0.6870604, -0.47231606, 0.6870604, -0.47231606, -0.37408397, -0.36004117, -0.05433852, -0.26881206, 0.4241253, -0.26878464, -0.81700337, -0.16625275, 0.81700337, -0.16625275, -0.5040269, -0.053977866, 0.18428145, -0.037251238, -0.18428145, 0.037251238, 0.5040269, 0.053977866, -0.81700337, 0.16625275, 0.81700337, 0.16625275, -0.4241253, 0.26878464, 0.05433852, 0.26881206, 0.37408397, 0.36004117, -0.6870604, 0.47231606, 0.6870604, 0.47231606, -0.18490662, 0.49972692, 0.13469408, 0.59146184, -0.44784173, 0.70325834, 0.44784173, 0.70325834, -0.107132696, 0.82663286]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_28 = new Float32Array([0.054795023, -0.83530104, -0.27204946, -0.791553, 0.36953768, -0.75111395, -0.6097868, -0.5734896, 0.64191437, -0.53728604, 0.020558335, -0.5112976, -0.30212387, -0.46627992, 0.33530098, -0.42711052, -0.7825411, -0.2972536, 0.79841375, -0.25152683, -0.4748782, -0.19004391, -0.14927362, -0.1785523, 0.17465979, -0.14365892, 0.5030025, -0.1135781, -0.8367519, 0.024012001, 0.8339652, 0.07233503, -0.529089, 0.1312217, -0.20348439, 0.14271331, 0.120449014, 0.17760667, 0.4550303, 0.20966442, 0.7431831, 0.38523915, -0.3762387, 0.41894934, -0.70822024, 0.42270303, 0.26074067, 0.4716622, -0.062978104, 0.5084937, 0.5398196, 0.63978523, -0.38229802, 0.7447003, 0.25468132, 0.7974132, -0.06903744, 0.83424467]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_29 = new Float32Array([-0.1613491, -0.82298344, 0.1613491, -0.82298344, -0.46015838, -0.7011345, 0.46015838, -0.7011345, -0.1729397, -0.50049347, 0.1729397, -0.50049347, -0.6908377, -0.47547725, 0.6908377, -0.47547725, -0.42261782, -0.2960553, 0.42261782, -0.2960553, 0.0, -0.22804898, -0.81923324, -0.17942198, 0.81923324, -0.17942198, -0.55101335, 0.0, -0.22831514, 0.0, 0.22831514, 0.0, 0.55101335, 0.0, -0.81923324, 0.17942198, 0.81923324, 0.17942198, 0.0, 0.22804898, -0.42261782, 0.2960553, 0.42261782, 0.2960553, -0.6908377, 0.47547725, 0.6908377, 0.47547725, -0.1729397, 0.50049347, 0.1729397, 0.50049347, -0.46015838, 0.7011345, 0.46015838, 0.7011345, -0.1613491, 0.82298344, 0.1613491, 0.82298344]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_30 = new Float32Array([-0.27530003, -0.79472274, 0.27530003, -0.79472274, -0.55060005, -0.6357782, 0.0, -0.6357782, 0.55060005, -0.6357782, -0.27530003, -0.4768336, 0.27530003, -0.4768336, -0.55060005, -0.3178891, 0.0, -0.3178891, 0.55060005, -0.3178891, -0.8259001, -0.15894455, -0.27530003, -0.15894455, 0.27530003, -0.15894455, 0.8259001, -0.15894455, -0.55060005, 0.0, 0.0, 0.0, 0.55060005, 0.0, 0.27530003, 0.15894455, -0.8259001, 0.15894455, -0.27530003, 0.15894455, 0.8259001, 0.15894455, -0.55060005, 0.3178891, 0.0, 0.3178891, 0.55060005, 0.3178891, -0.27530003, 0.4768336, 0.27530003, 0.4768336, -0.55060005, 0.6357782, 0.0, 0.6357782, 0.55060005, 0.6357782, -0.27530003, 0.79472274, 0.27530003, 0.79472274]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_31 = new Float32Array([0.0046014143, -0.84445345, -0.3014526, -0.7888277, 0.31003106, -0.78549576, -0.5756095, -0.6178969, 0.6011625, -0.5930653, 0.008168486, -0.53340596, -0.29788554, -0.4777802, 0.31359813, -0.47444823, -0.76027244, -0.36757135, 0.7751013, -0.33517277, -0.48254848, -0.22745466, 0.48753694, -0.21655568, -0.14493822, -0.20691049, 0.16606557, -0.20059167, -0.8417744, -0.06737022, 0.843867, -0.031800795, -0.5451871, 0.07724139, 0.5500945, 0.08815702, -0.23442392, 0.09100827, 0.23932268, 0.10172717, -0.8090564, 0.24197233, 0.79812884, 0.2758862, -0.0021098705, 0.2978741, -0.40268865, 0.35375085, 0.3824328, 0.37792054, -0.66655797, 0.5184818, 0.6440929, 0.5461384, -0.1697453, 0.55990773, 0.14100024, 0.5740675, -0.43361458, 0.7246387, 0.4026604, 0.7422853, -0.022259008, 0.8436182]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_32 = new Float32Array([0.00831911, -0.8457976, -0.29537773, -0.79258734, 0.31091055, -0.786624, -0.5598268, -0.6340636, 0.57219034, -0.62292933, 0.08753886, -0.5478256, -0.21615797, -0.49461535, 0.35848567, -0.40068305, -0.74988997, -0.3912899, 0.75744146, -0.37646404, -0.45536584, -0.30008337, -0.018195283, -0.25819927, 0.54373676, -0.15421778, -0.8403129, -0.09652424, 0.2416938, -0.092305444, 0.84230214, -0.07726453, -0.25742227, -0.063690804, -0.5544501, 0.018998705, 0.5154697, 0.15280676, 0.16586477, 0.20654745, -0.8190809, 0.21106687, -0.14205885, 0.22223641, 0.81403506, 0.22976, -0.44200656, 0.30608675, 0.3790392, 0.42930236, -0.68901503, 0.4906129, 0.6776046, 0.5062556, -0.22038914, 0.5204435, 0.08777215, 0.530429, -0.46739763, 0.70496964, 0.41841274, 0.73510104, -0.18101561, 0.82624215, 0.1271457, 0.83622766]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_33 = new Float32Array([0.037210736, -0.8479199, -0.26255155, -0.8071056, 0.33224526, -0.7810031, 0.58601767, -0.6133853, -0.03810108, -0.5500557, -0.37708646, -0.5270967, -0.67907995, -0.50912, 0.30957606, -0.47932556, 0.764711, -0.36819804, -0.21052143, -0.27455103, 0.09195874, -0.26916867, -0.5125149, -0.25657433, -0.8145084, -0.23859762, 0.49173498, -0.23778601, 0.84527284, -0.076593824, 0.27411765, -0.027629107, -0.3459499, -0.0040286607, -0.039849035, 0.0031361917, -0.6479434, 0.013948056, 0.5680459, 0.05495938, 0.8184399, 0.2247419, 0.14230986, 0.24467576, -0.1990054, 0.26041517, -0.8034862, 0.27342764, -0.50099885, 0.2783919, 0.4372275, 0.3277409, 0.6876214, 0.49752343, 0.21904442, 0.5373104, -0.6565417, 0.5378715, -0.08347157, 0.5400134, -0.3703694, 0.63599706, 0.46943834, 0.70709294, 0.15871978, 0.833763, -0.1437962, 0.836466]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_34 = new Float32Array([0.09608062, -0.8452399, -0.20195572, -0.826363, 0.3840532, -0.7590554, -0.47510362, -0.7056476, 0.62271893, -0.5795542, 0.16607827, -0.5549257, -0.13195807, -0.5360488, -0.6935851, -0.4925461, -0.40510598, -0.4153334, 0.404744, -0.37542453, 0.7846426, -0.32863048, 0.04112943, -0.2836882, -0.8210719, -0.22249225, -0.23497589, -0.16989957, -0.53259283, -0.1452795, 0.5637096, -0.12261644, 0.26704475, -0.088382624, 0.84986913, -0.037207253, -0.009060566, 0.025405992, -0.8473723, 0.07498093, -0.55784255, 0.1522847, 0.5242008, 0.1733921, -0.26107597, 0.18562531, 0.22753593, 0.20762591, 0.8103603, 0.25880128, -0.7692449, 0.3632137, -0.024479486, 0.36784524, -0.32154876, 0.47807476, 0.238936, 0.5089183, 0.67098504, 0.5229159, -0.59631807, 0.60668504, -0.073455215, 0.6624354, 0.4489195, 0.7225879, -0.3499027, 0.77539027, 0.17153043, 0.83321023]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_35 = new Float32Array([0.119019054, -0.8434243, -0.17724122, -0.8331361, 0.40086377, -0.7515573, -0.4520341, -0.7219386, 0.634156, -0.56866187, 0.07727307, -0.54993963, -0.21895532, -0.5387712, -0.6720767, -0.5233001, 0.35911778, -0.4580726, -0.43899795, -0.34013274, 0.7906394, -0.31689027, -0.06114985, -0.2877473, -0.81071764, -0.2612797, 0.5179602, -0.20060602, 0.22156566, -0.19547898, -0.28140208, -0.089056, -0.57763886, -0.078112334, 0.85136086, -0.02673703, 6.4628146E-4, 0.0021839316, -0.8509951, 0.036571395, 0.5786816, 0.089547224, 0.28228706, 0.09467427, -0.21724206, 0.2031831, -0.51356924, 0.21132001, 0.8034605, 0.28280988, 0.06439873, 0.29567343, -0.7869255, 0.32600373, 0.41833794, 0.3638902, -0.3517057, 0.46737155, 0.65788037, 0.54103935, 0.18919149, 0.5645652, -0.6275437, 0.5759506, -0.10092875, 0.62544405, 0.43261802, 0.73373824, -0.35973018, 0.7711782, 0.09685404, 0.84625614]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_36 = new Float32Array([-0.14795591, -0.83909965, 0.14795591, -0.83909965, -0.42602205, -0.73789185, 0.42602205, -0.73789185, -0.65270364, -0.54768336, -0.096571356, -0.54768336, 0.19934045, -0.54768336, 0.65270364, -0.54768336, -0.3746375, -0.4464756, 0.42602205, -0.35747495, -0.80065954, -0.29141626, 0.051384546, -0.29141626, 0.80065954, -0.29141626, -0.5225934, -0.19020845, -0.22668159, -0.19020845, 0.27806613, -0.1012078, 0.57397795, -0.1012078, -0.8520441, 0.0, 0.0, 0.0, 0.8520441, 0.0, -0.57397795, 0.1012078, -0.27806613, 0.1012078, 0.22668159, 0.19020845, 0.5225934, 0.19020845, -0.80065954, 0.29141626, -0.051384546, 0.29141626, 0.80065954, 0.29141626, -0.42602205, 0.35747495, 0.3746375, 0.4464756, -0.65270364, 0.54768336, -0.19934045, 0.54768336, 0.096571356, 0.54768336, 0.65270364, 0.54768336, -0.42602205, 0.73789185, 0.42602205, 0.73789185, -0.14795591, 0.83909965, 0.14795591, 0.83909965]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_37 = new Float32Array([0.09193262, -0.8514119, -0.19481204, -0.8339077, 0.36833152, -0.77310133, -0.4596333, -0.7225587, 0.60327977, -0.60778886, 0.0740497, -0.5646906, -0.21269497, -0.54718643, -0.67272913, -0.52989554, 0.3475722, -0.47685933, 0.77033716, -0.37407807, -0.43625593, -0.3667719, -0.04482107, -0.30315924, -0.8101185, -0.27760002, 0.5146296, -0.24314855, 0.22870146, -0.215328, -0.2738831, -0.12978253, -0.57364535, -0.11447634, 0.8507037, -0.098269954, -1.3082715E-12, -4.968819E-12, -0.8563402, 0.0059356242, 0.5938487, 0.03299134, 0.30792052, 0.060811903, -0.4112725, 0.12251303, 0.8353352, 0.18859711, -0.15986364, 0.26151836, 0.12656416, 0.2836095, -0.8061926, 0.28880328, 0.48024943, 0.3006898, -0.5344641, 0.38203707, 0.7259612, 0.45424014, 0.28865108, 0.5207945, -0.28305525, 0.5210424, 0.00382569, 0.5676192, 0.53489023, 0.6687647, -0.53420097, 0.6693154, 0.2836247, 0.808029, -0.28279212, 0.80832076, 4.411181E-4, 0.8563607]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_38 = new Float32Array([-0.0993953, -0.8525399, 0.18362486, -0.8384424, -0.37158158, -0.7737124, 0.4466303, -0.7329564, -0.60326624, -0.6105519, 0.08846039, -0.5715288, -0.19428179, -0.5526605, 0.660954, -0.54757977, 0.35146582, -0.46604282, -0.42596644, -0.3895, -0.76919615, -0.38084248, -0.017376093, -0.3086642, 0.80323505, -0.30251804, 0.526195, -0.24295345, 0.24562934, -0.20317824, -0.25896728, -0.16056676, -0.5702057, -0.14558569, -0.85128534, -0.10962205, 0.85796523, -0.024482522, 3.6580235E-12, -6.8038127E-12, 0.58092517, 0.035082083, 0.30035952, 0.07485729, -0.40320653, 0.08334753, -0.6842862, 0.11931117, -0.1709939, 0.24575579, 0.819179, 0.25622156, 0.10971478, 0.28450873, 0.49447846, 0.30494523, -0.4828739, 0.3552892, -0.7639535, 0.39125282, 0.2910746, 0.50224197, 0.691104, 0.50899804, -0.25066125, 0.51769745, 0.022570392, 0.5928215, -0.5949195, 0.61868775, 0.48770013, 0.7062948, -0.3610405, 0.77868706, 0.20883611, 0.81069607, -0.08780888, 0.8538111]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_39 = new Float32Array([-0.041784517, -0.8586103, 0.23709527, -0.82628286, -0.31620747, -0.7993562, 0.4906859, -0.7058221, -0.55690295, -0.65484095, -0.12768048, -0.591326, 0.15384805, -0.55295706, 0.69193876, -0.5100767, -0.73819786, -0.4404787, 0.41121155, -0.43655866, -0.37102538, -0.4357823, -0.07544393, -0.31548125, 0.8193878, -0.25992528, 0.19837128, -0.2534794, -0.5631451, -0.22098944, 0.5472411, -0.19096762, -0.84075475, -0.17913397, -0.29440382, -0.13976681, 0.32057163, -7.224559E-4, -1.1981002E-11, -1.1363408E-12, 0.85943896, 0.017950412, -0.5760251, 0.059462164, 0.58729225, 0.08690807, -0.8536347, 0.10131764, -0.28950062, 0.14093758, 0.20297909, 0.25421086, 0.80782026, 0.29391146, -0.07069297, 0.31684154, -0.49785435, 0.329107, 0.46969968, 0.34184137, -0.775464, 0.37096247, -0.28105956, 0.50748587, 0.26044914, 0.5290129, 0.6700375, 0.5385232, -0.013222925, 0.59164363, -0.6145804, 0.6010395, 0.46078694, 0.7256948, -0.38814414, 0.76700824, 0.17879316, 0.8312622, -0.1203075, 0.85116607]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_40 = new Float32Array([0.05568636, -0.86045915, -0.21853198, -0.8341071, 0.32422063, -0.7989818, -0.47044417, -0.72261554, 0.55966085, -0.6559502, -0.037009973, -0.6010415, 0.2315243, -0.53956413, -0.67433685, -0.5373646, -0.2966234, -0.508895, 0.73797494, -0.44596398, 0.4669645, -0.39653254, 0.012880751, -0.33011523, -0.5005161, -0.32364404, -0.8093981, -0.29726344, -0.24255823, -0.22695974, 0.26198542, -0.21248446, 0.840962, -0.19045703, 0.5664655, -0.1295489, -0.45677444, -0.051657304, -0.861842, -0.02681978, 0.07008105, -0.014841246, -0.19881655, 0.045027018, 0.33719727, 0.052531198, 0.8581097, 0.08449038, -0.64790493, 0.1467344, 0.5922461, 0.1566476, -0.38994703, 0.24341872, 0.15921082, 0.28654414, -0.116910815, 0.31267497, 0.7876679, 0.35081363, 0.44140488, 0.38716236, -0.7661905, 0.39552876, -0.31223458, 0.50771195, 0.22556104, 0.55833936, 0.6368267, 0.5813284, -0.04842153, 0.5870391, -0.6023429, 0.61698776, 0.42098284, 0.75250536, -0.37701255, 0.7754692, 0.16216815, 0.84687215, -0.11319949, 0.85479635]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_41 = new Float32Array([-0.1263724, -0.85459316, 0.14583738, -0.85148746, -0.38603336, -0.77283746, 0.40356547, -0.76382875, -0.6073611, -0.6143387, 0.62121934, -0.6003216, 0.19878675, -0.58445907, -0.09791589, -0.58069813, -0.35943323, -0.50191265, 0.41644064, -0.42095187, -0.7683776, -0.39483586, 0.7771859, -0.37720224, 0.08361508, -0.33779472, -0.18490095, -0.2929957, -0.5202019, -0.2819861, 0.5724072, -0.19783252, 0.30120698, -0.17420508, -0.8530939, -0.13612568, 0.83395475, -0.10652843, 0.050738245, -0.06755977, -0.33727247, -0.06740596, -0.6057554, -0.022409057, 0.5932305, 0.073597394, 0.32203028, 0.09722485, -0.85309774, 0.13610181, 0.8460909, 0.17444086, -0.06635371, 0.17819881, -0.33727628, 0.20482153, -0.6057592, 0.24981844, 0.16588984, 0.32022256, 0.49693877, 0.32822597, 0.7497992, 0.42906946, -0.16162671, 0.4332103, -0.4325493, 0.45983303, -0.7010322, 0.50482994, 0.32619172, 0.5402478, 0.05904872, 0.59261596, 0.57905215, 0.6410913, -0.19013768, 0.7039407, -0.46106026, 0.7305634, 0.29768077, 0.8109782, 0.030537749, 0.86334634]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_42 = new Float32Array([-0.0017293628, -0.8652264, 0.26460782, -0.82377326, -0.2678987, -0.8227089, 0.5052647, -0.7023726, -0.5080684, -0.70034724, -0.13043319, -0.59085315, 0.13905251, -0.5852576, 0.6968854, -0.5128064, -0.6989298, -0.5100165, 0.3797094, -0.46385697, -0.43781424, -0.44011998, -0.19244939, -0.32854068, 0.077036306, -0.32294512, 0.82087314, -0.27347213, 0.55186707, -0.25645494, -0.6747922, -0.24155568, -0.41176233, -0.17183815, 0.29736435, -0.16767308, -0.16581477, -0.060316075, -0.8638167, -0.049400594, 0.86519474, -0.0075972527, 0.59618866, 0.0094199125, 0.09445966, 0.009762945, -0.60289323, 0.018221907, 0.34541363, 0.10837548, -0.35664222, 0.13004869, -0.09636777, 0.2001277, -0.8371017, 0.21881603, 0.8255489, 0.25901493, 0.5565428, 0.2760321, -0.57617825, 0.28643852, 0.155274, 0.30134016, 0.36828053, 0.46893406, -0.10892891, 0.46937865, -0.37847257, 0.46964967, 0.7057831, 0.5004896, -0.67977726, 0.535278, 0.12979262, 0.5945421, 0.51752084, 0.69339156, -0.21252793, 0.71821815, -0.48207158, 0.71848917, 0.27903295, 0.8189996, 0.013464794, 0.86512333]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_43 = new Float32Array([0.034600705, -0.86594075, -0.23038705, -0.83544743, 0.3254817, -0.8031888, -0.47354984, -0.7258107, 0.5543298, -0.6661599, 0.13335586, -0.61815906, -0.13163191, -0.58766574, -0.6718524, -0.5474166, -0.3747947, -0.47802898, 0.73066527, -0.46602458, 0.39633387, -0.45125148, 0.14880264, -0.35187018, -0.116185114, -0.32137686, -0.8065092, -0.31716478, 0.5726693, -0.2511161, 0.83778346, -0.22174187, -0.3593479, -0.21174012, 0.3251381, -0.15173481, -0.6140401, -0.13249211, 0.062284376, -0.099555016, -0.8655336, -0.043613754, -0.18799768, -0.0073203044, 0.60042286, 0.014172598, 0.865537, 0.043546844, -0.44268987, 0.071927704, 0.3528916, 0.11355389, 0.01702095, 0.16331297, -0.72161156, 0.18096319, -0.24697497, 0.25315693, 0.5446214, 0.298994, 0.81129664, 0.30471027, -0.5017815, 0.3320364, 0.21510682, 0.34194764, -0.041716672, 0.42350185, -0.7425298, 0.44687817, -0.3217458, 0.5288497, 0.4135255, 0.5312917, 0.68020076, 0.537008, 0.15636918, 0.6021365, -0.5714552, 0.65152866, -0.10397158, 0.68287164, 0.35189274, 0.7918835, -0.34624556, 0.7944587, 0.09411428, 0.8615063]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_44 = new Float32Array([-0.022583244, -0.8642128, -0.2831912, -0.8204515, 0.2831912, -0.8204515, -0.5168216, -0.6973043, 0.10055345, -0.62968504, 0.6176784, -0.6097633, -0.16004406, -0.5868211, 0.3570809, -0.56689936, -0.70615435, -0.50449455, -0.39367446, -0.46367395, 0.17444316, -0.3761329, 0.52450097, -0.36264727, 0.7899837, -0.35929722, -0.08615436, -0.33326894, -0.5763122, -0.27290753, -0.8369097, -0.23004355, -0.31978476, -0.2101218, 0.3418632, -0.17188083, 0.08126567, -0.12901686, 0.59839064, -0.109095104, 0.8622941, -0.09892847, -0.6694897, -0.025791468, -0.15236472, -0.0058697094, -0.41296223, 0.036994252, 0.33169654, 0.09202261, 0.07109904, 0.13488656, 0.588224, 0.15480833, -0.85212743, 0.16497496, 0.85212743, 0.16497496, -0.5956, 0.22776069, -0.2455422, 0.24124633, 0.23851907, 0.33913866, -0.022078436, 0.38200262, 0.49504653, 0.40192437, 0.76043093, 0.41285095, -0.42817995, 0.43201277, -0.74360687, 0.44745678, -0.20471619, 0.57276905, 0.31240878, 0.5926908, 0.051811263, 0.6355548, -0.5689362, 0.6554765, 0.5689362, 0.6554765, -0.34547248, 0.7962328, 0.2192313, 0.83980685, -0.083822526, 0.8637954]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_45 = new Float32Array([-0.030625433, -0.8687445, 0.22905825, -0.83856255, -0.28753915, -0.82035124, 0.46802437, -0.73253536, -0.51844585, -0.6977598, -0.101975836, -0.6172376, 0.15770786, -0.58705574, 0.66465914, -0.5602527, -0.3392266, -0.50742584, 0.39667395, -0.48102856, -0.59436727, -0.44759485, -0.08598473, -0.3535011, 0.18536866, -0.32709143, 0.59330875, -0.30874586, -0.8138252, -0.30552167, -0.32655647, -0.24630128, 0.8402307, -0.22286153, -0.5810572, -0.18650213, 0.3838501, -0.15230536, -0.12573008, -0.07892349, 0.13556424, -0.07044754, -0.8678602, -0.049735073, 0.6167972, -0.0336369, -0.3640213, 0.028611874, 0.8684947, 0.037037898, -0.62187386, 0.07172367, 0.33356154, 0.1042441, -0.002423308, 0.151602, -0.84340006, 0.2105499, 0.56650865, 0.22291256, -0.26078528, 0.26879698, 0.8182062, 0.29358736, -0.52113086, 0.31296507, 0.20926887, 0.3342395, -0.040887672, 0.41018865, -0.74265707, 0.45179132, 0.44221598, 0.45290798, -0.35321695, 0.5133434, 0.6939135, 0.5235828, 0.14475991, 0.5945242, -0.5747431, 0.65216964, -0.13331933, 0.6547351, 0.5068586, 0.7062218, -0.3548455, 0.7935613, 0.2739599, 0.8249854, 0.016282445, 0.8691316]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_46 = new Float32Array([0.08836861, -0.86603945, -0.1702658, -0.853723, 0.33918527, -0.8017398, -0.41516805, -0.7645366, 0.5599952, -0.6665124, 0.08166319, -0.60719883, -0.6255285, -0.6054316, -0.17697121, -0.5948823, 0.33247986, -0.54289913, 0.73126376, -0.4723205, -0.4042896, -0.47090733, -0.77593285, -0.39466637, -0.037786726, -0.37654513, 0.50370055, -0.34804022, 0.21323802, -0.31306264, -0.55469394, -0.2601421, -0.2651051, -0.25257015, 0.8378395, -0.23634367, -0.85769254, -0.14898609, -0.044080425, -0.11769415, 0.38277242, -0.117354855, 0.6377067, -0.072056375, -0.37757215, -0.019343613, -0.6364536, -0.014461814, 0.16922948, 0.029078932, 0.8694522, 0.043431718, -0.8635745, 0.1098746, -0.062656574, 0.14428444, 0.39686763, 0.15246576, 0.6535638, 0.18638511, -0.307056, 0.22979675, -0.5659375, 0.23467855, 0.16189058, 0.3025816, -0.7930584, 0.35901496, 0.49584073, 0.39173084, -0.095154755, 0.4011644, 0.7615741, 0.4217088, -0.41961592, 0.46297848, 0.28469658, 0.5416028, -0.65238255, 0.57639426, 0.038810723, 0.6227422, 0.60385096, 0.6270545, -0.22006397, 0.6279708, -0.45284826, 0.74336535, 0.39270684, 0.77692646, 0.14682098, 0.85806584, -0.112053715, 0.8632945]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_47 = new Float32Array([0.11484223, -0.8640528, -0.14182386, -0.86003596, 0.3615483, -0.7931322, -0.38618988, -0.78143024, 0.57689816, -0.65342516, -0.5970625, -0.6350529, 0.02743304, -0.6226956, -0.22585034, -0.5809687, 0.27413914, -0.5517751, 0.7422149, -0.45704803, -0.75615335, -0.43359888, -0.4499277, -0.4247081, 0.48948896, -0.41206807, 0.03971346, -0.36629206, -0.21356992, -0.32456508, 0.2769171, -0.26816943, -0.6090185, -0.22325405, 0.8431611, -0.22103219, 0.59043515, -0.17605221, -0.8572413, -0.15783946, -0.37940902, -0.108479924, -0.1238769, -0.08404737, 0.1313627, -0.05672786, 0.38560772, -0.0213288, -0.6178216, 0.033292476, 0.8709819, 0.034153275, 0.61933297, 0.08481319, -0.86604434, 0.098707065, -0.33445054, 0.14424987, -0.019916486, 0.15065637, 0.2960494, 0.21923912, -0.5515146, 0.28127837, 0.8232644, 0.28637668, 0.52977467, 0.3253811, -0.7997374, 0.34669295, -0.18131447, 0.35026675, 0.095770776, 0.37980714, -0.39837852, 0.48729524, 0.34740198, 0.5082305, 0.7041471, 0.5137633, -0.664071, 0.56461096, -0.13574685, 0.60288745, 0.11887534, 0.63546276, 0.5239607, 0.69659245, -0.47081137, 0.7335616, 0.29833245, 0.8190077, -0.23671928, 0.83889204, 0.017902916, 0.87146735]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_48 = new Float32Array([-0.13746409, -0.862319, 0.12291223, -0.8588754, 0.37438133, -0.7888784, -0.37943745, -0.78645897, 0.5852626, -0.6480418, -0.58941036, -0.6442716, -0.016556535, -0.6394127, 0.23005944, -0.58036685, -0.25564137, -0.53804755, 0.7467848, -0.45255154, 0.4409407, -0.43953028, -0.7505061, -0.4366798, -0.49453214, -0.40910363, -0.04263847, -0.3871716, 0.20397751, -0.32812575, -0.2741408, -0.2836703, 0.5923232, -0.23608692, 0.8453257, -0.21889466, -0.6438788, -0.20416115, -0.06875489, -0.13493402, 0.36206463, -0.12984735, -0.8688484, -0.08713744, -0.40730858, -0.067864366, 0.14507541, 0.0013834721, 0.5980052, 0.017677499, 0.87257475, 0.03322307, -0.63227814, 0.04915935, -0.20192267, 0.0808719, 0.36721924, 0.12368625, -0.8572477, 0.16618307, -0.42689222, 0.19789562, 0.011907628, 0.2171894, 0.57286423, 0.27206415, 0.8262338, 0.28253886, -0.6518618, 0.31491932, -0.21306194, 0.3342131, 0.23369262, 0.34041885, -0.4380315, 0.45123684, 7.683578E-4, 0.47053063, 0.4568415, 0.4975516, 0.71021104, 0.5080263, -0.66300106, 0.56826055, -0.2242012, 0.58755434, 0.22229308, 0.5939513, -0.010370913, 0.7238718, -0.4685373, 0.7366649, 0.44570222, 0.7508928, -0.23534048, 0.84089553, 0.2111538, 0.8472925]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_49 = new Float32Array([-0.09866021, -0.8685892, 0.15286723, -0.8607048, -0.3424864, -0.80429107, 0.39172643, -0.7814931, -0.55741787, -0.67339915, 0.598123, -0.6375186, -0.16503987, -0.6258508, 0.08648756, -0.6179663, 0.3253468, -0.53875464, -0.3799713, -0.49495885, -0.7261557, -0.48670217, 0.7549527, -0.44071242, 0.023775022, -0.3742547, 0.5130961, -0.3711885, -0.54870915, -0.30826187, -0.21751073, -0.30277464, 0.26263425, -0.29504302, -0.8354277, -0.25489807, 0.6942339, -0.19649646, -0.026519433, -0.12768081, 0.45038354, -0.12747689, -0.38624856, -0.116077654, -0.63391525, -0.07147478, 0.21189767, -0.047148187, 0.8739381, -0.020329997, -0.87416786, 0.003404447, 0.63152134, 0.04721516, -0.20071302, 0.053936403, 0.39303547, 0.12754385, -0.44152755, 0.12942682, 0.037704077, 0.13446902, -0.68919426, 0.1740297, 0.83514994, 0.23896602, 0.5842898, 0.29439402, -0.25599203, 0.2994409, 0.21884188, 0.30916107, -0.5147822, 0.37253255, -0.020279778, 0.3875769, -0.7709884, 0.41201696, 0.40854564, 0.47451127, 0.7070405, 0.5140767, -0.2955503, 0.5479632, 0.18877265, 0.5971002, -0.6216689, 0.6145803, -0.059838064, 0.6360993, 0.5312964, 0.69419396, -0.4208312, 0.7662129, 0.31152335, 0.8167829, -0.18511897, 0.8543489, 0.065934196, 0.87168443]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_50 = new Float32Array([-0.10570153, -0.86902356, 0.14338292, -0.86360645, -0.3462247, -0.8040542, 0.3808541, -0.7882416, -0.55870545, -0.6739606, 0.58747804, -0.64903337, -0.16969803, -0.6282397, 0.10825184, -0.61658263, 0.34627923, -0.54150903, -0.38217878, -0.49814615, -0.72593397, -0.48927972, 0.7465193, -0.45725667, -0.039904997, -0.41557524, 0.51708657, -0.36013296, 0.19792499, -0.34135053, -0.5494073, -0.3134652, -0.25238574, -0.28548166, -0.83436555, -0.26496968, 0.84509635, -0.22844458, -0.033481028, -0.16651472, 0.36810607, -0.15938677, 0.6156636, -0.13132086, -0.40870637, -0.09148094, -0.6578388, -0.089155145, 0.16469577, -0.0155234365, 0.8745746, 0.027163815, -0.18980163, 0.027486002, -0.8747935, 0.03333189, 0.39099023, 0.088703394, 0.6385477, 0.1167693, -0.4022824, 0.15757959, -0.66023934, 0.15997665, 0.008375166, 0.17847729, 0.8311944, 0.2747556, 0.25554597, 0.29781404, -0.20643555, 0.3124799, 0.52637357, 0.3398797, -0.5292802, 0.37192503, -0.78650755, 0.382321, 0.041551225, 0.4254019, 0.72013456, 0.49777606, 0.3551263, 0.5261913, -0.33611044, 0.5292713, -0.6438348, 0.5931707, -0.10643912, 0.6258296, 0.14113154, 0.65377915, 0.5507475, 0.6804792, -0.45066506, 0.750517, 0.33675274, 0.808067, -0.22099376, 0.8470753, 0.026576905, 0.8750248]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_51 = new Float32Array([-0.04579474, -0.8751124, 0.20059901, -0.853041, -0.28853902, -0.8274444, 0.4310066, -0.762989, -0.50828904, -0.71383554, 0.100751, -0.6267063, -0.14662214, -0.62482, 0.62706643, -0.61213285, -0.6875324, -0.5433397, 0.3311586, -0.5366543, -0.36637214, -0.5112112, 0.773154, -0.41249457, 0.5272184, -0.38579816, -0.10399247, -0.38051644, 0.1433677, -0.37487042, -0.811985, -0.32954407, -0.56359756, -0.32924357, -0.32405216, -0.26747763, 0.3577307, -0.2056012, 0.8576274, -0.17998378, 0.6116918, -0.15328734, 0.12346052, -0.12613727, -0.12388707, -0.122112714, -0.87172884, -0.08948635, -0.62434846, -0.08943874, -0.3848031, -0.027672822, 0.38628, 0.040126223, 0.8737547, 0.0668703, 0.6278191, 0.093566746, 0.116203934, 0.121136606, -0.13114366, 0.12516116, -0.8620028, 0.1577027, -0.6146225, 0.15775032, -0.36024535, 0.21848555, 0.30964464, 0.27533686, 0.8202507, 0.30839536, 0.55118376, 0.3287774, -0.15339106, 0.3715391, -0.783582, 0.39232412, -0.53620166, 0.39237174, 0.092911944, 0.39460114, 0.36004362, 0.5175289, 0.70137924, 0.5253438, -0.33629906, 0.53809744, -0.10363561, 0.62214947, -0.6109959, 0.6281743, 0.14331092, 0.63679314, 0.5266135, 0.7004264, -0.4110933, 0.77390003, 0.30988076, 0.8196907, -0.17842984, 0.85795206, 0.06845304, 0.87363213]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_52 = new Float32Array([-0.0025203018, -0.8750278, 0.24006088, -0.8442784, -0.24582773, -0.8426173, 0.366858, -0.6352132, -0.122101024, -0.63172054, -0.6111176, -0.6300559, -0.36660635, -0.6300184, 0.12240371, -0.6299363, 0.61131084, -0.62986845, -0.7639875, -0.43133682, 0.7420223, -0.4232193, -0.48895833, -0.41824737, 6.4154374E-5, -0.4182318, -0.2444471, -0.41820988, 0.24457538, -0.41813487, 0.48908663, -0.41809735, -0.61124647, -0.20651318, -0.36673522, -0.20647566, -0.122223966, -0.20643815, 0.12228728, -0.20640066, 0.36679852, -0.20636316, 0.61130977, -0.20632565, -0.8555394, -0.19618253, 0.8555995, -0.19592008, -0.4890233, 0.005258534, -0.24451207, 0.0052960366, -8.182018E-7, 0.005333539, 0.24451043, 0.0053710416, 0.48902166, 0.005408544, -0.73331624, 0.015589171, 0.7333114, 0.01581412, -0.36680016, 0.21703024, -0.12228892, 0.21706773, 0.12222233, 0.21710524, 0.36673358, 0.21714275, -0.8464291, 0.23236376, 0.8463578, 0.23262338, -0.60511047, 0.2717472, 0.6050271, 0.2719328, -0.24457702, 0.42880192, -6.577444E-5, 0.42883945, 0.24444547, 0.42887694, 0.7277296, 0.4834304, -0.48288733, 0.4835189, 0.48273897, 0.483667, -0.73154175, 0.485055, -0.122353874, 0.6405736, 0.12215737, 0.6406111, -0.49048892, 0.72791195, 0.4902656, 0.7280624, -0.2706617, 0.8349715, 0.27040556, 0.8350545, 0.0041644815, 0.8547889]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_53 = new Float32Array([-0.21112317, -0.85235006, 0.21112317, -0.85235006, -0.44101226, -0.7579577, 0.4410039, -0.75795656, 0.0, -0.730458, -0.21112317, -0.60856605, 0.21112317, -0.60856605, -0.6338826, -0.607673, 0.6338826, -0.607673, -0.42224634, -0.48667398, 0.0, -0.48667398, 0.42224634, -0.48667398, -0.21112317, -0.36478198, 0.21112317, -0.36478198, -0.6338826, -0.36388895, 0.6338826, -0.36388895, -0.42224634, -0.24288996, 0.0, -0.24288996, 0.42224634, -0.24288996, -0.8444014, -0.24095613, 0.8444014, -0.24095613, -0.21112317, -0.12099793, 0.21112317, -0.12099793, -0.6327652, -0.11995712, 0.6327652, -0.11995712, 0.0, 8.940921E-4, -0.421642, 0.0019349055, 0.421642, 0.0019349055, -0.877555, 0.004107874, 0.8775665, 0.0041112485, -0.6327652, 0.12382693, -0.21051884, 0.12382693, 0.21051884, 0.12382693, 0.6327652, 0.12382693, -0.421642, 0.24571896, 0.421642, 0.24571896, 0.0, 0.24675976, -0.8421671, 0.24865282, 0.8421671, 0.24865282, -0.6310439, 0.37054485, 0.6310439, 0.37054485, -0.19307497, 0.39559764, 0.19307497, 0.39559764, -0.41805807, 0.48947665, 0.41805807, 0.48947665, 0.0, 0.5444355, -0.62745994, 0.6143025, 0.62745994, 0.6143025, -0.2249831, 0.63831455, 0.2249831, 0.63831455, -0.434385, 0.76314044, 0.434385, 0.76314044, -0.12250156, 0.8689237, 0.122465566, 0.8689288]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_54 = new Float32Array([-0.21094011, -0.85250425, 0.21094011, -0.85250425, -0.43884337, -0.760099, 0.43884337, -0.760099, 0.0, -0.73071796, -0.6328203, -0.6089316, -0.21094011, -0.6089316, 0.21094011, -0.6089316, 0.6328203, -0.6089316, -0.42188022, -0.4871453, 0.0, -0.4871453, 0.42188022, -0.4871453, -0.6328203, -0.36535898, -0.21094011, -0.36535898, 0.21094011, -0.36535898, 0.6328203, -0.36535898, -0.84376043, -0.24357265, -0.42188022, -0.24357265, 0.0, -0.24357265, 0.42188022, -0.24357265, 0.84376043, -0.24357265, -0.6328203, -0.121786326, -0.21094011, -0.121786326, 0.21094011, -0.121786326, 0.6328203, -0.121786326, 0.87768674, -1.1E-29, -0.87768674, -8.0E-30, -0.42188022, 0.0, 0.0, 0.0, 0.42188022, 0.0, -0.6328203, 0.121786326, -0.21094011, 0.121786326, 0.21094011, 0.121786326, 0.6328203, 0.121786326, -0.84376043, 0.24357265, -0.42188022, 0.24357265, 0.0, 0.24357265, 0.42188022, 0.24357265, 0.84376043, 0.24357265, -0.6328203, 0.36535898, -0.21094011, 0.36535898, 0.21094011, 0.36535898, 0.6328203, 0.36535898, -0.42188022, 0.4871453, 0.0, 0.4871453, 0.42188022, 0.4871453, -0.6328203, 0.6089316, -0.21094011, 0.6089316, 0.21094011, 0.6089316, 0.6328203, 0.6089316, 0.0, 0.73071796, 0.43884337, 0.760099, -0.43884337, 0.760099, -0.21094011, 0.85250425, 0.21094011, 0.85250425]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_55 = new Float32Array([-0.07408615, -0.8775969, 0.1641589, -0.8652843, -0.30689535, -0.82551825, 0.39035922, -0.78948385, -0.5171869, -0.7128694, 0.58791804, -0.6557572, -0.02663111, -0.64380145, 0.21161394, -0.63148886, -0.25944027, -0.5917227, -0.7025476, -0.5311233, 0.40917274, -0.49776217, -0.46973187, -0.47907394, 0.74233997, -0.4739161, -0.043662407, -0.40584716, 0.19458264, -0.39353457, -0.27379382, -0.34298357, -0.8193153, -0.32309058, 0.56359464, -0.3159211, -0.5864996, -0.27104124, 0.8422947, -0.25730276, 0.34900457, -0.21169351, 0.10271908, -0.17336784, -0.13461904, -0.14922422, -0.39056152, -0.13495086, 0.65335375, -0.09488806, -0.875968, -0.091352, -0.64304304, -0.03709617, 0.8804484, -0.021810506, 0.43876368, 0.009339535, 0.20262562, 0.04326777, -0.18235627, 0.08451379, -0.42029566, 0.10175188, -0.8683489, 0.14708929, 0.6212341, 0.16301723, 0.024985386, 0.20250423, -0.63638854, 0.20282695, 0.8540016, 0.21528202, 0.34566292, 0.2352559, -0.28853506, 0.30062732, -0.79331684, 0.3825095, 0.5321273, 0.38431403, 0.16738577, 0.39390546, -0.50462794, 0.4017024, -0.08010012, 0.4166755, 0.7648948, 0.43657884, 0.35379747, 0.54277784, -0.32432747, 0.55792034, -0.66155624, 0.58138496, 0.61966586, 0.62584287, 0.13144602, 0.6297457, -0.105897166, 0.65383965, -0.48125574, 0.7376029, 0.4289707, 0.7691874, -0.26564443, 0.8397012, 0.20680097, 0.8560949, -0.030542212, 0.88018876]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_56 = new Float32Array([0.09996409, -0.8759317, -0.1367487, -0.8709472, -0.36359873, -0.803147, 0.4770538, -0.74139655, 0.24602619, -0.68958884, -0.56422484, -0.6774212, -0.014075568, -0.66844016, -0.24546945, -0.5923801, 0.6586336, -0.5853053, 0.4064068, -0.5154169, -0.72872543, -0.49619395, 0.17537917, -0.46360922, -0.4963956, -0.4505799, -0.05978598, -0.43612924, 0.7917958, -0.3876965, -0.28111327, -0.35203388, 0.5607682, -0.3358888, -0.8344963, -0.2843678, 0.32974058, -0.2840811, 0.09691255, -0.24017063, -0.6021665, -0.23875377, -0.12971584, -0.16999923, 0.7211488, -0.16171686, -0.38700908, -0.13765542, 0.4901212, -0.10990916, 0.25909355, -0.05810146, -0.8800806, -0.052032113, -0.64775074, -0.006418078, 0.030664746, 0.004172705, 0.8815294, 0.012455071, -0.20036286, 0.055980407, 0.6505018, 0.06426277, -0.43386874, 0.09513137, 0.41947415, 0.11607047, 0.19104534, 0.17834464, -0.86208075, 0.18436643, -0.62875414, 0.22958387, -0.039982274, 0.23015234, 0.8438359, 0.25228596, -0.27983794, 0.2934679, 0.5927098, 0.29386652, 0.36168218, 0.34567422, 0.13325337, 0.4079484, -0.77922046, 0.4123889, -0.49090686, 0.42208305, -0.097774245, 0.45975608, 0.73996943, 0.47926447, 0.5089418, 0.5310722, -0.30680165, 0.57095563, 0.27425206, 0.5981513, -0.6413732, 0.6048881, 0.043224458, 0.649959, -0.45726797, 0.7537607, 0.44735342, 0.7596868, -0.24018306, 0.8482696, 0.22904892, 0.8513435, -0.005775334, 0.8815985]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_57 = new Float32Array([-0.0037970617, -0.88268363, 0.22887018, -0.85250413, -0.23619606, -0.8505035, 0.44536826, -0.76209706, -0.45190832, -0.75823724, 0.026157178, -0.6499873, 0.2588244, -0.6198078, 0.630402, -0.6178496, -0.20624182, -0.61780715, -0.6426813, -0.6050666, -0.42195407, -0.5255409, 0.4438582, -0.47556025, 0.77089936, -0.42995235, 0.12395599, -0.42783028, -0.77937734, -0.4143861, -0.10945566, -0.4040847, -0.5586501, -0.33486038, -0.32516792, -0.31181842, 0.58435553, -0.28766304, 0.31680042, -0.2583027, 0.8569343, -0.21167998, 0.086211346, -0.19626994, -0.86101204, -0.19443014, -0.14569438, -0.16070889, -0.64028484, -0.11490444, -0.39487916, -0.085781, 0.4776512, -0.0787156, 0.24878122, -0.027107637, 0.88242877, 0.021547122, 0.021443617, 0.030879112, -0.8818182, 0.039261866, -0.21071988, 0.06471634, 0.6541776, 0.07582654, -0.66109097, 0.118787564, 0.40791002, 0.14529559, -0.42874786, 0.15136878, 0.1805724, 0.20328234, 0.8455816, 0.25325197, -0.053337377, 0.25325865, -0.84032583, 0.2701801, 0.5844364, 0.29983774, -0.28812358, 0.33917096, -0.52062935, 0.37063622, 0.34536663, 0.37142205, 0.11802903, 0.4294088, 0.748996, 0.46706513, -0.73946637, 0.48201072, -0.10857659, 0.49019322, 0.521893, 0.5259642, -0.37550965, 0.5569059, 0.2847047, 0.5980605, 0.057367075, 0.6560472, -0.5863652, 0.65978837, -0.16923854, 0.7168317, 0.46123108, 0.75260264, -0.39183867, 0.7909534, 0.23979697, 0.84639, -0.003294871, 0.88268566]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_58 = new Float32Array([-0.058117796, -0.8817061, 0.17413238, -0.86629164, -0.28633523, -0.8359399, 0.39429966, -0.7907661, -0.49468416, -0.7321686, -0.042038236, -0.6446061, 0.19123892, -0.63416, 0.6381598, -0.61117536, -0.29816955, -0.60347974, -0.66870743, -0.57759297, 0.41140622, -0.55863446, -0.4736602, -0.45057204, -0.14003639, -0.43268266, 0.092538044, -0.42336178, 0.77561116, -0.42333272, -0.79632986, -0.38293874, 0.5484418, -0.3702726, 0.31270534, -0.3478363, -0.31552705, -0.27977496, -0.6012826, -0.25591782, 0.8592437, -0.20611544, -0.09535976, -0.20424944, 0.13721468, -0.19492856, -0.86869574, -0.1617128, 0.4492704, -0.15934826, -0.44314945, -0.08512072, 0.66647, -0.07566986, -0.6736485, -0.03469187, -0.21971908, -0.00749451, 0.012855341, 0.0018263682, 0.24922526, 0.009109119, 0.8832542, 0.025403978, -0.8806375, 0.07183667, 0.47328088, 0.07217115, -0.397228, 0.14306553, 0.6904805, 0.15584955, -0.6246041, 0.1928436, -0.11090372, 0.19895943, 0.12486593, 0.20586404, 0.35215136, 0.27093077, -0.8309097, 0.30061993, -0.2888188, 0.3490393, 0.56935096, 0.35460916, 0.8085327, 0.3564522, -0.5172773, 0.39938346, -0.04930867, 0.42342275, 0.18332367, 0.4311648, -0.7235829, 0.50715977, 0.40052328, 0.5148432, 0.6874032, 0.5552118, -0.35974187, 0.570732, -0.13720223, 0.6389511, 0.09543011, 0.64669317, -0.5660475, 0.67850834, 0.5185755, 0.7154459, -0.36799052, 0.80334693, 0.31376436, 0.82603586, -0.14545088, 0.87156606, 0.08718147, 0.8793081]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_59 = new Float32Array([0.04565883, -0.88316303, -0.18492542, -0.86479145, 0.2731192, -0.84111094, -0.40285754, -0.78725314, 0.4818935, -0.7415122, -0.05372304, -0.6742854, -0.5932272, -0.655853, 0.17373735, -0.6322333, -0.27165517, -0.5967471, 0.6576979, -0.59118116, 0.38251165, -0.5326346, -0.74300987, -0.47958112, -0.46202487, -0.46534696, -0.09451582, -0.44659582, 0.13294457, -0.4045437, 0.7908729, -0.3957042, 0.55999357, -0.38151363, -0.2854138, -0.3159644, 0.34171885, -0.30494496, -0.61180747, -0.28907508, -0.8422895, -0.2694626, -0.07644573, -0.21596214, 0.86643237, -0.1770781, 0.15107669, -0.1739405, 0.63555306, -0.16288751, -0.43519643, -0.13969252, 0.41727838, -0.08631887, -0.6528711, -0.061434146, -0.88335305, -0.041821655, -0.22652127, -0.039886285, 9.6092286E-4, 0.0020477604, 0.22794947, 0.0465765, 0.88271284, 0.053663217, 0.6518336, 0.06785381, -0.41429573, 0.095196515, 0.43527657, 0.14915372, -0.6334979, 0.16906811, -0.14584635, 0.18080524, -0.86397994, 0.1886806, 0.081142195, 0.22533397, 0.8386004, 0.28073305, 0.6083259, 0.30264813, -0.33581135, 0.31278974, 0.32547772, 0.35274848, -0.55501354, 0.38666135, -0.7854956, 0.40627384, -0.11055143, 0.4124709, 0.11739786, 0.45378995, 0.72974473, 0.4995341, 0.49852708, 0.5062429, -0.36518842, 0.5422317, -0.65326965, 0.5960709, 0.2932701, 0.6129021, -0.15567698, 0.64027023, 0.07209078, 0.6806244, 0.48826817, 0.73733026, -0.4763487, 0.7450863, -0.26683727, 0.84312487, 0.25726917, 0.84396666, -0.0390695, 0.88347906]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_60 = new Float32Array([-0.11545614, -0.8769765, 0.11545614, -0.8769765, -0.3385003, -0.817212, 0.3385003, -0.817212, -0.53847617, -0.7017558, 0.53847617, -0.7017558, -0.11545614, -0.64606416, 0.11545614, -0.64606416, -0.3385003, -0.58629966, 0.3385003, -0.58629966, -0.7017558, -0.53847617, 0.7017558, -0.53847617, 0.0, -0.44608828, -0.5017799, -0.42302004, 0.5017799, -0.42302004, -0.22304414, -0.38632378, 0.22304414, -0.38632378, -0.817212, -0.3385003, 0.817212, -0.3385003, -0.6172361, -0.22304414, -0.38632378, -0.22304414, -0.059764497, -0.22304414, 0.38632378, -0.22304414, 0.6172361, -0.22304414, 0.16327964, -0.16327964, -0.8769765, -0.11545614, 0.8769765, -0.11545614, -0.22304414, -0.059764497, -0.6770006, 0.0, -0.44608828, 0.0, 0.0, 0.0, 0.44608828, 0.0, 0.6770006, 0.0, 0.22304414, 0.059764497, -0.8769765, 0.11545614, 0.8769765, 0.11545614, -0.16327964, 0.16327964, -0.6172361, 0.22304414, -0.38632378, 0.22304414, 0.059764497, 0.22304414, 0.38632378, 0.22304414, 0.6172361, 0.22304414, -0.817212, 0.3385003, 0.817212, 0.3385003, -0.22304414, 0.38632378, 0.22304414, 0.38632378, -0.5017799, 0.42302004, 0.5017799, 0.42302004, 0.0, 0.44608828, -0.7017558, 0.53847617, 0.7017558, 0.53847617, -0.3385003, 0.58629966, 0.3385003, 0.58629966, -0.11545614, 0.64606416, 0.11545614, 0.64606416, -0.53847617, 0.7017558, 0.53847617, 0.7017558, -0.3385003, 0.817212, 0.3385003, 0.817212, -0.11545614, 0.8769765, 0.11545614, 0.8769765]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_61 = new Float32Array([0.06428452, -0.8844135, -0.16187319, -0.8718468, 0.28624785, -0.83927464, -0.37746912, -0.8023944, 0.48953426, -0.73937535, -0.5684362, -0.680588, 0.13129008, -0.6680446, -0.09486764, -0.6554779, 0.6608799, -0.59123385, -0.31046355, -0.58602554, 0.33657405, -0.5723173, -0.72231436, -0.51437503, 0.029094316, -0.46590292, -0.50143063, -0.46421912, 0.50791967, -0.42417577, 0.78910494, -0.40451595, -0.1883584, -0.39262348, 0.23453647, -0.36999902, -0.8290635, -0.31460053, -0.38179538, -0.2718844, -0.60817975, -0.2644446, -0.009314247, -0.24267656, 0.6361447, -0.23745787, 0.41032973, -0.2197707, 0.865843, -0.19140448, 0.1958995, -0.14679876, -0.20556797, -0.12958497, -0.88171846, -0.09429916, -0.43445036, -0.05158306, -0.6608347, -0.044143237, 0.010260011, -0.017017348, 0.66449517, -0.012732519, 0.43868023, 0.004954646, 0.8860871, 0.034195635, 0.22424999, 0.07792659, -0.21701041, 0.096632406, -0.87684363, 0.13215496, -0.42957556, 0.17487106, -0.65595996, 0.18231088, -0.019505775, 0.20752493, 0.6269246, 0.2106364, 0.4011096, 0.22832358, 0.84851646, 0.25756457, 0.18667935, 0.30129552, -0.8147572, 0.3499863, -0.31742474, 0.3716639, -0.5438091, 0.37910372, 0.5339905, 0.41719997, -0.09627328, 0.4206258, 0.75558245, 0.4641281, 0.10991185, 0.51439637, 0.33604988, 0.52731234, -0.69951004, 0.544982, -0.25246134, 0.58865464, -0.47884572, 0.5960945, 0.61334866, 0.6404086, -0.045024704, 0.6796232, 0.21213673, 0.7169192, 0.4310956, 0.7749041, -0.38136333, 0.8005509, -0.16610742, 0.87104994, 0.059986565, 0.8847154]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_62 = new Float32Array([0.022389863, -0.88726133, -0.20135774, -0.864401, 0.24469966, -0.8531448, -0.41217482, -0.7860318, 0.45129567, -0.76424223, 0.04617245, -0.6636099, -0.59652346, -0.65718627, -0.17757514, -0.6407496, 0.26848224, -0.62949336, 0.628911, -0.62626266, -0.38839224, -0.5623803, 0.44749057, -0.49332583, -0.7425654, -0.48613852, -0.04590369, -0.45840862, 0.76613986, -0.44806662, 0.1790332, -0.4198355, -0.5374233, -0.39393055, -0.25672078, -0.3800394, 0.59007436, -0.30811182, -0.8409223, -0.2838726, 0.36648855, -0.28350627, 0.019438192, -0.24319705, 0.85416985, -0.2410973, -0.40575185, -0.21158963, -0.63551843, -0.19111966, -0.18784241, -0.15590253, 0.20930736, -0.12263471, 0.67811, -0.10113833, 0.45454586, -0.07654857, -0.8852781, -0.06337737, 0.88734794, -0.018645514, -0.0050353287, -0.017572168, -0.45686653, 0.0074374634, -0.6806482, 0.02996172, -0.23895708, 0.06312457, 0.29736468, 0.084323, 0.5152741, 0.1400101, 0.73990804, 0.1511987, -0.8727844, 0.16118774, 0.10122853, 0.19439657, -0.39613825, 0.22399613, -0.61991996, 0.24652039, -0.116278954, 0.2516336, 0.35809296, 0.30088165, 0.5837412, 0.3577212, 0.8088957, 0.36526945, -0.8042434, 0.3754019, 0.1619568, 0.41095525, -0.27346012, 0.41250518, -0.4972418, 0.43502942, -0.055550676, 0.46819228, 0.4159991, 0.51821196, 0.69110656, 0.5568714, -0.68405664, 0.5655091, 0.21986295, 0.6282855, -0.21555397, 0.6298355, -0.47961035, 0.65924966, 0.0023554787, 0.68552256, 0.5289369, 0.71271294, 0.33280078, 0.8227865, -0.32748985, 0.8249148, 0.11529329, 0.88002354, -0.109617926, 0.8807485]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_63 = new Float32Array([0.09187021, -0.88365453, -0.13123931, -0.87867045, 0.30918288, -0.8328814, -0.34606785, -0.81824356, 0.50698656, -0.7295547, -0.53906, -0.7061868, 0.14904304, -0.6679372, -0.09668335, -0.65130126, -0.32006305, -0.5965987, 0.6728002, -0.5801943, 0.3500185, -0.5709239, -0.69803834, -0.5495707, 0.04527638, -0.47036397, -0.17383416, -0.4280169, 0.5158321, -0.42156348, 0.7961611, -0.39422444, -0.3929447, -0.38566986, 0.24625184, -0.3733507, -0.61211085, -0.34361157, -0.83339155, -0.30201328, -0.027605265, -0.25943515, 0.63919306, -0.23559366, 0.41243434, -0.22192766, -0.24671581, -0.21708809, 0.8692856, -0.18337967, -0.46582636, -0.17474103, 0.17337018, -0.16242188, -0.6849925, -0.13268274, -0.10048691, -0.04850632, -0.8875593, -0.039037723, 0.53905946, -0.036154546, -0.31989223, -0.0059040417, 0.3198934, 0.005904154, -0.5390584, 0.03615426, 0.8875594, 0.039036095, 0.100488536, 0.048506934, 0.6849933, 0.1326827, -0.1733693, 0.16242224, 0.46582723, 0.17474139, -0.8692859, 0.18337807, 0.24671684, 0.21708922, -0.41243434, 0.22192766, -0.63919324, 0.23559274, 0.027606146, 0.2594355, 0.83339155, 0.30201328, 0.6121124, 0.34361178, -0.24625169, 0.3733508, 0.39294633, 0.38567048, -0.7961619, 0.39422297, -0.5158326, 0.4215628, 0.17383444, 0.4280178, -0.045276243, 0.47036406, 0.6980373, 0.549572, -0.35001928, 0.57092357, -0.67280126, 0.58019304, 0.32006395, 0.59659904, 0.09668401, 0.651301, -0.14904383, 0.6679368, 0.53905874, 0.7061878, -0.5069879, 0.7295538, 0.34606636, 0.8182442, -0.3091844, 0.83288085, 0.1312377, 0.8786707, -0.091871835, 0.88365436]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_64 = new Float32Array([0.0882225, -0.88471544, -0.13349794, -0.87902385, 0.30445296, -0.835352, -0.34691092, -0.8186314, 0.5017376, -0.73400545, -0.538736, -0.7072964, 0.15358776, -0.67277265, -0.06813268, -0.66708106, -0.28154567, -0.6066887, 0.66779953, -0.5869824, 0.35366264, -0.56682897, -0.697036, -0.5519469, -0.47337073, -0.49535358, 0.15979625, -0.45106608, -0.06610664, -0.44293794, 0.52469903, -0.4175286, 0.792305, -0.40343204, -0.2810392, -0.38489574, -0.81196016, -0.36225033, -0.59623975, -0.31070375, 0.33080822, -0.30983132, 0.07537947, -0.24596573, 0.6492045, -0.23397821, -0.1436102, -0.21081066, -0.40403318, -0.19808544, 0.867506, -0.19477645, -0.8763568, -0.15001124, 0.45531365, -0.12628095, -0.66063637, -0.09846468, 0.23602486, -0.09304284, -0.25555968, -0.019343525, 0.66607994, -0.010855181, -1.6511754E-12, 2.094794E-12, -0.4736784, 0.020862935, 0.888723, 0.025999894, -0.88621855, 0.07156289, 0.44872323, 0.09541461, -0.67049813, 0.12310945, 0.22034998, 0.12819606, -0.17266396, 0.18637632, 0.6347402, 0.21620385, -0.3992552, 0.22979721, 0.8546356, 0.24515828, 0.038288824, 0.2548692, 0.36145267, 0.29931703, -0.8338675, 0.30455318, -0.59607494, 0.33204374, -0.25030774, 0.3941353, 0.5474696, 0.4201063, 0.17939149, 0.42599016, 0.76736504, 0.4490607, -0.03935495, 0.4626282, -0.44712746, 0.49638182, -0.7281111, 0.5102537, 0.37217414, 0.5573471, -0.2621392, 0.6187407, 0.63234204, 0.6250185, 0.16853464, 0.6475178, -0.5791636, 0.67459184, -0.050211802, 0.68415576, 0.45796904, 0.762082, -0.39417535, 0.7969507, 0.25509703, 0.8517218, -0.18465792, 0.86971605, 0.036350586, 0.88835984]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_65 = new Float32Array([0.11038514, -0.8831935, -0.2770902, -0.84583485, 0.32351926, -0.82918686, -0.073537394, -0.76271373, -0.47961032, -0.7442648, 0.5169115, -0.72458136, 0.1227624, -0.66367203, -0.2938113, -0.6266015, -0.6545635, -0.60312706, 0.33398074, -0.60260093, 0.6787605, -0.5757601, -0.08740955, -0.5432817, -0.46605912, -0.4899503, 0.4958298, -0.45377976, 0.10889024, -0.44423994, -0.2615918, -0.40910488, 0.79919004, -0.3918047, -0.65832525, -0.38328916, 0.304932, -0.3446885, -0.065292016, -0.31006318, -0.8476493, -0.271489, -0.46389937, -0.2700908, 0.6162593, -0.2698243, 0.13074975, -0.21051173, -0.25943205, -0.18924539, 0.87085104, -0.1839404, -0.6561655, -0.16342965, 0.42536148, -0.16073306, -0.063132256, -0.09020367, 0.68792033, -0.06196001, -0.8883381, -0.055416573, -0.46766117, -0.050252862, 0.25117925, -0.026556278, -0.24705479, 0.030276073, 0.8893707, 0.03514838, -0.68408406, 0.054660752, 0.45447087, 0.057201594, 0.064165734, 0.089067325, 0.6514596, 0.15486592, -0.87481844, 0.1640375, -0.42109996, 0.16463064, 0.26504323, 0.19299595, -0.13085073, 0.21692945, 0.8536188, 0.2520923, -0.61718094, 0.26410487, 0.46838543, 0.27663097, 0.06886567, 0.3088872, -0.30489588, 0.35128403, -0.8079153, 0.3734816, 0.6705753, 0.37390348, 0.26255736, 0.41293716, -0.10517949, 0.44324178, -0.50097686, 0.45075825, 0.4659344, 0.49648744, 0.0885122, 0.54729176, -0.69171125, 0.56013495, 0.6631716, 0.5936489, -0.34256294, 0.60323083, 0.29188925, 0.630842, -0.13059257, 0.6616383, -0.5332973, 0.7126076, 0.4969749, 0.7383317, 0.063099116, 0.76568824, -0.3386136, 0.82309407, 0.26647615, 0.8492385, -0.123856656, 0.8814052]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_66 = new Float32Array([-0.16300398, -0.8758982, 0.21429479, -0.86478066, -0.37095097, -0.81003904, 0.41824692, -0.78570074, 0.022424368, -0.7610256, -0.55666274, -0.69562525, -0.16977234, -0.65787625, 0.2082141, -0.64673847, 0.61574733, -0.6439124, -0.37283188, -0.5782132, 0.41144103, -0.56750345, 0.016343676, -0.5429834, -0.70900744, -0.5395149, 0.7537557, -0.47499505, -0.17585304, -0.43983403, 0.23650292, -0.4304537, -0.52517664, -0.4221028, 0.43972984, -0.35121867, 0.044632494, -0.32669863, -0.71877384, -0.32160667, -0.34390637, -0.30077487, 0.846583, -0.27760595, 0.63076717, -0.24593754, -0.14311455, -0.21551833, 0.24084544, -0.21236995, -0.5375036, -0.20027871, -0.8747391, -0.16911335, 0.44407237, -0.13313495, 0.04897502, -0.10861489, -0.3173467, -0.08427093, 0.8886652, -0.063576825, -0.69346887, -0.047785413, 0.6715901, -0.030365843, 0.27383938, 0.0032472394, -0.12637283, 0.021125253, -0.4948843, 0.04245618, 0.48415273, 0.08127807, -0.88649815, 0.08777783, 0.073790416, 0.10829563, -0.30391046, 0.14785236, 0.8774798, 0.15426315, -0.6723281, 0.16931465, 0.66494143, 0.20332244, 0.26130408, 0.22101372, -0.10539275, 0.23824091, -0.48215607, 0.27615082, 0.4651746, 0.29857787, -0.832479, 0.3174061, 0.08348607, 0.3473471, 0.81369716, 0.36285642, -0.28293037, 0.36496803, 0.281803, 0.43817532, -0.6763314, 0.4697127, -0.094051555, 0.4740742, -0.45946118, 0.49309394, 0.4856735, 0.5157395, 0.70114064, 0.54969966, 0.10385329, 0.56579685, -0.2792224, 0.615949, 0.3027755, 0.65529174, -0.588145, 0.6692184, -0.07453326, 0.6913262, 0.506646, 0.73285586, -0.40790623, 0.7920735, 0.22970495, 0.8608156, -0.2032171, 0.8674507, 0.013653119, 0.8908319]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_67 = new Float32Array([-0.00801405, -0.89161897, 0.20729832, -0.86722314, -0.22285312, -0.8633569, 0.53523755, -0.7131405, -0.54636365, -0.70465267, 0.32071283, -0.68258375, 0.101894, -0.67789674, -0.33158666, -0.67592263, -0.11478321, -0.67553926, 0.6914556, -0.56297225, -0.70020574, -0.55205125, 0.42893717, -0.49485505, 0.21227425, -0.4914275, -0.0044029607, -0.48907, -0.43776998, -0.487032, -0.22108017, -0.48671252, 0.60264564, -0.3653176, -0.6097136, -0.35516104, 0.8189638, -0.35262853, -0.82562006, -0.3367494, 0.32357654, -0.30550236, 0.10597729, -0.30260077, -0.11069992, -0.3002433, -0.3297274, -0.29919642, 0.6469266, -0.15320027, 0.87984115, -0.14466572, -0.6478677, -0.14185646, -0.8824705, -0.1276499, 0.43303475, -0.11848905, 0.21635754, -0.11613156, -3.1966926E-4, -0.11377407, -0.21699688, -0.111416586, -0.4336741, -0.109059095, 0.7566943, 0.033630177, -0.75416464, 0.046970244, 0.3267378, 0.07033766, 0.54342175, 0.07196269, 0.11006058, 0.07269515, -0.10661663, 0.07505264, -0.32329383, 0.07741013, -0.53997105, 0.07976762, 0.8635387, 0.2221477, -0.8598119, 0.23616125, 0.43367246, 0.25880396, 0.6503518, 0.26095417, 0.21699524, 0.26116148, -0.21291359, 0.26387936, -0.4295908, 0.26623684, -0.64619035, 0.27249867, 0.0022136471, 0.28985712, 0.3273755, 0.4476307, 0.77002746, 0.44880116, 0.54405487, 0.44978088, -0.31921056, 0.45270607, -0.76338136, 0.4579371, -0.5358101, 0.4589679, 0.1125939, 0.47632635, -0.104083315, 0.47868383, 0.24483585, 0.6479848, -0.23414433, 0.6520006, 0.60071343, 0.65893245, -0.589631, 0.6688676, 7.3942466E-4, 0.67134076, 0.4240275, 0.7843783, -0.41087583, 0.7913467, 0.22229904, 0.8634997, -0.20785479, 0.86709, 0.0074418793, 0.8916239]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_68 = new Float32Array([-0.19065687, -0.87151146, 0.19065687, -0.87151146, -0.39432627, -0.800226, 0.39518195, -0.79961383, 0.0, -0.7705149, 0.57730734, -0.680146, -0.58163553, -0.67644835, -0.18279402, -0.6558995, 0.18279402, -0.6558995, -0.38641888, -0.5845745, 0.38536075, -0.5816226, 0.0, -0.5412841, 0.72370714, -0.5216611, -0.62167877, -0.46444154, -0.22283721, -0.44389272, 0.19065687, -0.44028756, 0.5317605, -0.42313775, -0.42646208, -0.37256774, -0.81362534, -0.3659182, -0.040043194, -0.3292773, 0.7130576, -0.30616882, 0.35458714, -0.30001208, -0.63232833, -0.24894926, -0.23348677, -0.22840041, 0.15061367, -0.22828074, 0.53588414, -0.18304314, 0.87663925, -0.16548699, -0.8776774, -0.15988983, -0.43711165, -0.15707543, -0.050692752, -0.113785, 0.31454393, -0.08800527, -0.6963803, -0.042920902, 0.6994659, -0.042361308, -0.27300376, -0.016294891, 0.12388708, 0.012991291, 0.49584097, 0.02896367, -0.47662863, 0.05503009, -0.8900769, 0.057569306, 0.89017916, 0.058616426, -0.073194325, 0.10079371, 0.3051841, 0.12996022, -0.65942264, 0.1696455, 0.65942264, 0.1696455, -0.26514092, 0.19931707, 0.12239009, 0.24457563, -0.85007954, 0.27064204, -0.4687658, 0.27064204, 0.4687658, 0.27064204, 0.85007954, 0.27064204, -0.081057176, 0.31640568, -0.6672855, 0.38525745, 0.28597176, 0.38525745, 0.6672855, 0.38525745, -0.27300376, 0.41492903, 0.08252451, 0.45708752, -0.47662863, 0.486254, 0.47662863, 0.486254, -0.10942207, 0.5556109, -0.65942264, 0.6008694, 0.65942264, 0.6008694, 0.31101957, 0.6245435, -0.31304696, 0.62693584, 0.10056777, 0.672087, -0.4958529, 0.7416096, 0.49489492, 0.7420445, -0.09137881, 0.7706104, 0.30037, 0.8400358, -0.29500368, 0.84193534, 0.08991822, 0.8875793]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_69 = new Float32Array([0.055261098, -0.8912869, -0.15837993, -0.8788412, -0.3629252, -0.81592363, 0.41379124, -0.7913425, 0.20615378, -0.7395345, -0.54662764, -0.70614755, -0.04078116, -0.7000455, 0.59046775, -0.66817766, -0.24801, -0.63537186, 0.35483953, -0.58561915, -0.69893724, -0.5558173, 0.11803349, -0.5444576, -0.49259263, -0.49907845, 0.7412096, -0.49805063, -0.089356944, -0.4916282, 0.53012204, -0.4628453, -0.29229838, -0.42371535, 0.2670786, -0.39043874, -0.8111068, -0.37356648, 0.059604652, -0.3379798, -0.6047622, -0.31682763, 0.8384215, -0.30740112, 0.62733394, -0.2721958, -0.14333679, -0.27006695, -0.40446794, -0.2414645, 0.41624635, -0.23699047, 0.20877239, -0.18453154, -0.87669444, -0.16986167, 0.0058309524, -0.11661869, -0.67034984, -0.11312282, 0.76336646, -0.106991254, -0.25550637, -0.087816104, 0.5522789, -0.07178592, -0.4700556, -0.0377597, 0.3448049, -0.019326996, -0.89193344, 0.04359829, 0.14504154, 0.05743228, 0.890625, 0.06506292, -0.06724004, 0.08452308, 0.6795374, 0.10026825, -0.6855889, 0.10033715, -0.27736744, 0.1250676, 0.47206348, 0.15272717, -0.48529464, 0.17570026, 0.27230012, 0.22948645, -0.8559487, 0.2545544, 0.060018536, 0.25657725, 0.849571, 0.27509138, -0.15010887, 0.2971218, 0.6212312, 0.30617544, -0.35803607, 0.34775445, -0.5708995, 0.37353182, 0.42146787, 0.38293472, 0.20055528, 0.43110505, -0.7708067, 0.45089144, -0.011468584, 0.46014404, 0.75972605, 0.4693213, -0.21939577, 0.5107767, -0.44155174, 0.5447887, 0.5599627, 0.5460806, 0.34948793, 0.5847815, -0.6413973, 0.6213337, -0.05619293, 0.6694217, 0.15757413, 0.67947304, -0.26412013, 0.7200543, 0.48824129, 0.74770755, -0.4750568, 0.75615287, 0.2963275, 0.842399, -0.12655544, 0.8839852, 0.0873956, 0.8887115]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_70 = new Float32Array([-0.075178936, -0.89062816, 0.13710076, -0.8832179, -0.28321278, -0.8477387, 0.36540365, -0.8156902, -0.47525167, -0.7569718, 0.5475593, -0.70643413, -0.010923708, -0.68817115, 0.201356, -0.6807608, -0.272213, -0.6356147, -0.64044994, -0.6234535, 0.38351166, -0.5715047, 0.6987906, -0.55728096, -0.45284125, -0.52385145, -0.10895151, -0.49973512, 0.10332819, -0.4923248, 0.53474295, -0.42235154, -0.6354237, -0.411104, -0.28957975, -0.38797188, 0.81055653, -0.37665436, 0.2999816, -0.3733778, -0.83117783, -0.32865453, 0.09294658, -0.28016967, -0.47069755, -0.27700377, -0.11867062, -0.26184633, 0.45344728, -0.22611547, 0.6657996, -0.22120978, -0.6664517, -0.1945543, 0.87654483, -0.17475556, -0.2981965, -0.14832082, 0.2570231, -0.14527532, -0.8852576, -0.123245284, 0.058162924, -0.07062806, -0.4939506, -0.06587138, 0.47347835, -0.014653083, 0.68583065, -0.0097473925, -0.14321533, -0.0030678639, -0.6897047, 0.016578065, 0.8930288, 0.037012864, 0.27024657, 0.06672166, -0.33896944, 0.079381585, -0.8893409, 0.08912446, 0.015982643, 0.13755073, -0.5347236, 0.16183102, 0.43952695, 0.19502497, 0.6518793, 0.19993065, -0.17977147, 0.22000016, -0.73435974, 0.23437743, 0.8590774, 0.24669091, 0.1877773, 0.2624674, -0.3755256, 0.3024496, -0.010491098, 0.34830347, -0.57516176, 0.374996, 0.35705766, 0.39077073, 0.56941, 0.3956764, -0.20624521, 0.43075293, 0.7766081, 0.44243667, -0.77654004, 0.4425562, 0.16130355, 0.47322017, -0.4488059, 0.54573494, -0.03329477, 0.55948484, 0.334254, 0.60195214, 0.65027857, 0.61319506, -0.65018415, 0.61329514, -0.25700668, 0.6370073, 0.13849989, 0.6844016, 0.48722342, 0.7493222, -0.47609293, 0.756401, -0.08740534, 0.764886, 0.2947684, 0.8433882, -0.28295225, 0.8478257, 0.084389314, 0.8898027]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_71 = new Float32Array([-0.086609535, -0.89024365, 0.12444907, -0.88574684, -0.29284355, -0.84514946, 0.32857525, -0.8319094, -0.48276472, -0.75297624, 0.5143981, -0.7317305, -0.031170994, -0.6865465, 0.17988761, -0.6820497, -0.23740502, -0.6414523, -0.6457935, -0.61885846, 0.6715664, -0.59079057, -0.42732617, -0.5492791, 0.4263782, -0.53984916, 0.01414343, -0.48036078, 0.22520204, -0.47586393, -0.7728483, -0.45026714, -0.19209059, -0.43526658, 0.79132515, -0.4169406, 0.5812241, -0.39636156, -0.56957495, -0.39329433, 0.38004795, -0.3323763, -0.37064323, -0.3226393, -0.034197554, -0.27486357, 0.17686105, -0.2703667, -0.8568516, -0.25659367, 0.7471775, -0.2105019, -0.6535782, -0.19962089, 0.536212, -0.17997761, -0.22003438, -0.17471051, 0.33170697, -0.12687908, -0.4498709, -0.12580411, 0.115414076, -0.06840081, 0.8925985, -0.05747031, -0.893124, -0.048626687, -0.087553665, -0.010348651, 0.6848861, -0.008794825, -0.6898506, 0.008346114, -0.29613557, 0.022202076, 0.47675243, 0.02650857, 0.27025998, 0.07508683, -0.49566355, 0.09115521, 0.06420485, 0.13640049, 0.88120675, 0.15332861, -0.8796449, 0.16204906, 0.6758152, 0.20211671, -0.18813564, 0.2035911, -0.66447186, 0.21792158, 0.42442492, 0.231027, -0.38766363, 0.2725442, 0.21905075, 0.27988812, -0.019282028, 0.3302971, 0.82069504, 0.3556608, -0.81716514, 0.36369786, 0.56942695, 0.38445568, -0.55647194, 0.3993106, -0.23945151, 0.4236073, 0.3640528, 0.4333168, 0.14190978, 0.4763957, -0.0601896, 0.5374022, 0.71448046, 0.53810096, -0.7091652, 0.54508686, -0.40896797, 0.5503355, 0.5090549, 0.5867455, 0.28691185, 0.6298244, -0.23017663, 0.66258353, 0.08481246, 0.6908309, -0.56166124, 0.6961118, 0.4319139, 0.7832531, -0.3828699, 0.80835986, 0.23631307, 0.8626651, -0.18275079, 0.87557817, 0.027548434, 0.8940224]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_72 = new Float32Array([0.0104987, -0.89512044, -0.19796881, -0.87301725, 0.21839045, -0.8681339, -0.39557943, -0.8030366, 0.41430533, -0.79353756, -0.04951946, -0.6942596, -0.59213144, -0.6713604, 0.15650156, -0.65369904, 0.56660247, -0.6491344, -0.39752147, -0.5934096, 0.36412832, -0.58999515, -0.19415776, -0.5425131, 0.7301241, -0.51793796, -0.74052536, -0.50296426, 0.011724857, -0.49376923, 0.21502782, -0.44263068, -0.5405291, -0.44012526, -0.33716536, -0.38922873, 0.42322552, -0.38886145, -0.13291344, -0.3420227, 0.6253972, -0.33341888, 0.8347859, -0.32323888, -0.8371948, -0.3169474, 0.070389524, -0.2908841, 0.27412504, -0.24149695, -0.4874579, -0.23731819, -0.2840942, -0.18642168, 0.4762967, -0.18605438, -0.6864246, -0.17129163, -0.0798423, -0.13921563, 0.6775581, -0.12739362, 0.8870716, -0.120227925, -0.8879513, -0.113548696, 0.12346067, -0.08807705, 0.32719618, -0.03868988, -0.53229237, -0.029198349, -0.32816193, 0.018530235, 0.52845764, 0.01997087, -0.12391003, 0.06573628, 0.8907091, 0.08937652, -0.89001125, 0.09607719, 0.07939294, 0.11687486, -0.6815278, 0.11802952, 0.690826, 0.15257466, 0.28312844, 0.16626203, -0.47607765, 0.17275995, -0.2719472, 0.22048853, 0.49406195, 0.22676592, -0.06769531, 0.2676946, 0.84549874, 0.29407942, -0.84326166, 0.30043405, 0.13560766, 0.31883317, -0.62531304, 0.31998783, 0.3393432, 0.36822033, -0.41871348, 0.37439477, -0.21458304, 0.42212337, 0.5514261, 0.42840073, -0.01033113, 0.46932942, 0.75392, 0.48265457, -0.7502664, 0.48831466, 0.19297184, 0.520468, -0.5471265, 0.54009736, 0.39670736, 0.56985515, -0.34299606, 0.58782595, 0.6209952, 0.64476025, 0.04703305, 0.67096424, -0.16147389, 0.69269234, 0.24970399, 0.72455287, -0.49797466, 0.7438898, 0.45401412, 0.7715063, -0.31131217, 0.8393066, 0.117701404, 0.8874104, -0.091912545, 0.89045095]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_73 = new Float32Array([0.005234809, -0.89308643, -0.20338301, -0.8723206, 0.23038347, -0.86558145, -0.54321164, -0.71220005, -0.33465356, -0.71024543, 0.35712656, -0.6999418, -0.093438655, -0.69508475, 0.5656237, -0.6945341, 0.115102254, -0.69176966, -0.69319326, -0.56726617, 0.71091217, -0.544896, -0.22470921, -0.5330096, -0.44062534, -0.53060615, 0.24184534, -0.52613, 0.45669192, -0.51667416, 0.007960866, -0.5128255, -0.8055906, -0.39157575, -0.5906069, -0.38567227, 0.6019804, -0.36703604, 0.81765574, -0.36571422, -0.330681, -0.3533703, -0.122144066, -0.34981316, 0.13286406, -0.34579405, 0.3414107, -0.34286234, -0.8743097, -0.19465446, -0.6657724, -0.19112033, -0.45723507, -0.1875862, 0.0027591193, -0.18278176, 0.4629866, -0.17339376, -0.2293317, -0.17089668, 0.67153245, -0.17040744, 0.8800669, -0.16670379, 0.23421648, -0.1635086, -0.7731017, -0.012288784, -0.56456435, -0.008754655, -0.35602707, -0.005220526, -0.10442851, -0.0038652539, 0.10411154, -4.9629546E-4, 0.35612744, 0.0057191243, 0.5646733, 0.008705434, 0.77320766, 0.012409078, -0.23112388, 0.16181089, -0.88005465, 0.16676809, 0.2260225, 0.16873142, -0.6715174, 0.17030221, -0.46298003, 0.17383634, -0.0030760877, 0.1784202, 0.45718393, 0.1881688, 0.6657298, 0.1911551, 0.8742642, 0.19485876, -0.3383164, 0.34104663, -0.12977146, 0.34409636, 0.118834876, 0.3476479, 0.32736817, 0.35141146, -0.81762904, 0.36577398, -0.6021125, 0.36698282, 0.59248775, 0.38643926, 0.8033385, 0.39507467, -0.00786049, 0.5133241, -0.45445678, 0.51428556, -0.2409063, 0.5254689, 0.43896198, 0.5276134, 0.2198422, 0.53012484, -0.71087235, 0.544948, 0.6904988, 0.5705429, -0.11538647, 0.6920374, -0.565573, 0.6945754, 0.09314683, 0.69580096, -0.35704663, 0.6987078, 0.331436, 0.7063268, 0.53983253, 0.7147648, -0.23152682, 0.86527634, 0.20474064, 0.8720029, -0.014560036, 0.87817633]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_74 = new Float32Array([0.10338878, -0.8906282, -0.103393055, -0.89062774, 0.3046715, -0.8432574, -0.30467555, -0.843256, 0.4897492, -0.75103503, -0.4897528, -0.75103265, 0.11403695, -0.6841207, -0.1140439, -0.68412036, 0.3153197, -0.63675, -0.3153264, -0.6367486, 0.6487778, -0.6188661, -0.64878076, -0.618863, -3.205394E-6, -0.5116285, 0.4755159, -0.50599873, -0.4755199, -0.505994, 0.20127952, -0.46425772, -0.2012857, -0.46425676, 0.7732988, -0.45378053, -0.773301, -0.4537768, 0.6000369, -0.34091315, -0.60004014, -0.34090787, 0.36147577, -0.33350646, -0.3614792, -0.33350214, 0.103382185, -0.2821181, -0.10339964, -0.2821111, 0.8566892, -0.26455903, -0.85669047, -0.26455492, 0.47654063, -0.15995829, -0.47031802, -0.15630217, 0.6834273, -0.15169166, -0.6834296, -0.15168598, 0.26357841, -0.15136686, -0.26359314, -0.15135649, -2.6436999E-6, -0.10303629, 0.8945134, -0.06126602, -0.8945137, -0.061261725, 0.57371616, 0.02358581, -0.5737185, 0.023591505, 0.36697543, 0.027707944, 0.16019359, 0.027714971, -0.16019614, 0.027718322, -0.36697796, 0.02772535, 0.88475984, 0.14528565, -0.8847591, 0.1452899, 9.213632E-8, 0.15846959, 0.6771132, 0.20266062, -0.67710334, 0.20267333, 0.47037244, 0.20678274, 0.2635906, 0.20678978, -0.26358098, 0.20680015, -0.4703628, 0.20680718, 0.10339709, 0.33754438, -0.10338474, 0.33755141, 0.827947, 0.34410977, -0.8279454, 0.34411377, 0.3669876, 0.3858646, -0.57377696, 0.38587907, -0.3669658, 0.385882, 0.5737707, 0.3858856, 0.2067737, 0.51663095, -0.20676957, 0.5166333, 2.0733512E-6, 0.51868606, 0.7270969, 0.5246312, -0.7270944, 0.5246347, 0.4001107, 0.5899763, -0.4001016, 0.5899916, 0.5875736, 0.67724824, -0.5875703, 0.67725104, 0.103457786, 0.69772696, -0.10332403, 0.69780177, 0.41184354, 0.796425, -0.41181132, 0.7964416, 0.2184394, 0.8695931, -0.21840423, 0.8696019, 0.0022355954, 0.88002634]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_75 = new Float32Array([-0.030815199, -0.8966915, 0.17407827, -0.88017154, -0.23409119, -0.8661446, -0.42507988, -0.7901344, 0.512045, -0.7367599, 0.3069271, -0.72331035, 0.07518961, -0.69996256, -0.13006815, -0.6888498, -0.5937564, -0.6726504, 0.66629124, -0.60088366, -0.40767404, -0.5853142, 0.42113367, -0.5523978, 0.20803845, -0.54310143, -0.731267, -0.51985943, -0.013815009, -0.51467246, -0.21907277, -0.5035597, 0.78556424, -0.43346745, -0.5451846, -0.43252328, 0.5753799, -0.4165216, 0.32415885, -0.37115178, 0.11903383, -0.3578113, -0.356883, -0.34921765, -0.8303938, -0.33978134, -0.11952169, -0.32371584, -0.6443114, -0.2524452, 0.8636034, -0.24329878, 0.65857476, -0.22855127, 0.45371953, -0.21156396, 0.23314953, -0.18683806, 0.023319656, -0.17589639, -0.25461257, -0.16878136, -0.4600368, -0.16135678, -0.88593376, -0.14186835, 0.77588725, -0.057395276, -0.6998514, -0.05453219, 0.5708586, -0.042647768, 0.3627102, -0.027250253, -0.11052323, -0.019882534, 0.13743535, -0.004923146, -0.3101525, 0.029131647, -0.5155767, 0.03655622, -0.89497155, 0.06349124, 0.89000297, 0.11357796, 0.6849743, 0.12832548, 0.47984928, 0.14166595, -0.68659896, 0.15059854, 0.003592463, 0.15109071, 0.26699603, 0.15466467, -0.22010797, 0.21391861, -0.4265305, 0.2268632, -0.85703284, 0.26551822, 0.84079504, 0.31315958, 0.1439578, 0.32134724, 0.3841351, 0.32358086, 0.6357664, 0.3279071, -0.6036751, 0.3386886, -0.062404487, 0.34576645, -0.30043277, 0.4031332, -0.774109, 0.45360827, 0.5071566, 0.48826224, 0.2660582, 0.49184284, -0.48011872, 0.5029691, 0.73892933, 0.5071395, 0.061297767, 0.50993705, -0.14272928, 0.5349811, -0.65055263, 0.61788875, -0.32241526, 0.6348169, 0.3841085, 0.66012347, 0.58898675, 0.67683065, 0.17934805, 0.6782177, -0.024679001, 0.7032617, -0.49284914, 0.74973655, -0.3092763, 0.84223115, 0.29739833, 0.8464983, -0.109469734, 0.8905176, 0.096549444, 0.891997]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_76 = new Float32Array([-0.053816576, -0.8963337, 0.149991, -0.88533217, -0.25484368, -0.8610256, 0.3460492, -0.8285893, -0.4427041, -0.781232, 0.5242285, -0.7290369, -0.08317808, -0.6943524, 0.15286572, -0.6812481, -0.60769194, -0.66107553, -0.28322446, -0.6538554, 0.34892392, -0.6245053, -0.4482123, -0.5336989, 0.5679068, -0.52966094, 0.02562055, -0.52166355, -0.741283, -0.5067641, -0.17442584, -0.48116657, 0.76375884, -0.47221056, 0.22167875, -0.46492073, 0.413754, -0.395887, -0.5818033, -0.37938753, -0.33716482, -0.35015237, 0.61607933, -0.3313229, -0.83657515, -0.32627046, 0.061447352, -0.32072824, 0.8507723, -0.2872044, -0.13859904, -0.28023124, 0.25750554, -0.26398543, -0.47997895, -0.2024967, 0.4619265, -0.19754896, -0.68375766, -0.19097304, 0.6975571, -0.14418678, -0.28598937, -0.13904113, -0.88665086, -0.12695903, 0.11002641, -0.12248941, 0.8936636, -0.08761122, -0.09001997, -0.08199241, 0.3060846, -0.06574658, -0.4991317, 7.069661E-4, 0.49814975, 0.0033152758, -0.7029104, 0.012230631, 0.6942563, 0.05989083, -0.30514213, 0.064162545, 0.15903547, 0.07579888, -0.89402026, 0.083893724, -0.041040797, 0.11614795, 0.8903628, 0.11646638, 0.35110062, 0.14486073, -0.45709106, 0.20043465, 0.5472072, 0.20143628, -0.6608698, 0.21195832, -0.20272687, 0.24071191, 0.74331367, 0.25801185, 0.18646456, 0.27821937, -0.8519796, 0.2836214, -0.014008283, 0.31845418, 0.37882793, 0.3470729, -0.3546758, 0.376984, -0.57481104, 0.3970325, 0.5749345, 0.40364844, -0.16357094, 0.45861077, 0.771041, 0.460224, -0.7659209, 0.4686956, 0.2420108, 0.49853125, 0.038626097, 0.51565504, 0.43811733, 0.5551068, -0.4491805, 0.55789125, 0.6471913, 0.62245786, -0.6402903, 0.62955433, -0.2652169, 0.6462991, 0.14666736, 0.69055015, -0.066040605, 0.69087905, 0.48990405, 0.75253195, -0.47840837, 0.759892, 0.30730557, 0.84372604, -0.29444474, 0.84829986, 0.108829945, 0.89132845, -0.09526846, 0.8928798]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_77 = new Float32Array([0.028559715, -0.8981026, 0.22931963, -0.8688017, -0.32055017, -0.8394352, 0.41838837, -0.79520756, -0.12956157, -0.7709777, -0.500705, -0.74612224, 0.05959248, -0.69760305, 0.5861268, -0.6810721, 0.26031202, -0.6680268, -0.3239224, -0.63657635, -0.6553329, -0.6147704, -0.108982444, -0.5690504, 0.42802513, -0.5538541, -0.48197493, -0.509366, 0.08021386, -0.49576688, 0.6172188, -0.4805818, -0.77655065, -0.45207635, -0.26703238, -0.44182882, 0.27065492, -0.42580056, 0.8039706, -0.40129197, -0.077838674, -0.3685565, 0.4598486, -0.35252824, -0.4250849, -0.3146184, -0.6279706, -0.31392044, 0.11135502, -0.29528418, -0.8581782, -0.2663345, 0.6685404, -0.25022325, -0.23589121, -0.2413461, 0.30179608, -0.22531787, 0.8735058, -0.21069308, -0.046697512, -0.16807379, 0.49098977, -0.15204555, -0.5067125, -0.1288766, -0.7095981, -0.12817861, 0.14249618, -0.09480148, -0.31751877, -0.05560428, -0.8971231, -0.050735176, 0.6996816, -0.049740538, 0.33293724, -0.024835158, 0.8985079, -0.009352626, -0.11406944, 0.023300475, 0.52213097, 0.048437156, -0.49522626, 0.073684886, -0.69811195, 0.07438287, 0.07512426, 0.09657279, -0.27764514, 0.1433258, -0.88563687, 0.1518263, 0.2673846, 0.16716988, 0.67510027, 0.18171684, 0.87770224, 0.19246465, -0.08309859, 0.22542986, 0.45657828, 0.24044219, -0.43858847, 0.26850596, -0.6414741, 0.26920393, 0.11088301, 0.29628357, -0.2504223, 0.34437805, -0.8289991, 0.34664738, 0.6095476, 0.37372187, 0.31306586, 0.3840262, 0.8121496, 0.3844697, -0.045851562, 0.4251143, -0.5425723, 0.4463522, 0.14408642, 0.49643508, 0.4694578, 0.52048, -0.73009723, 0.52379566, -0.21072955, 0.5433443, 0.7051919, 0.5568737, -0.40644866, 0.59679633, 0.29788172, 0.62876076, -0.5939736, 0.67423975, 0.10638664, 0.69578856, 0.5622821, 0.70088714, -0.09595547, 0.7106464, -0.4098238, 0.79965514, 0.390706, 0.8091679, -0.21997558, 0.87121445, 0.19921093, 0.87619567, -0.018768152, 0.898355]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_78 = new Float32Array([0.0, -0.89904153, 0.23828673, -0.86688817, -0.25331548, -0.86261636, 0.42574108, -0.7918461, -0.4728883, -0.7646256, -0.10442667, -0.7262251, 0.097450085, -0.7221972, -0.29698935, -0.66547924, 0.62038994, -0.6506858, -0.63160384, -0.63980645, 0.42782724, -0.58993995, 0.2263038, -0.56534874, 0.025265016, -0.53362423, -0.17459625, -0.5048854, -0.37656376, -0.47883013, 0.57671607, -0.4535487, -0.7785928, -0.44952077, 0.7785928, -0.44952077, -0.57671607, -0.44549283, 0.34994546, -0.40364748, 0.1500842, -0.3749087, -0.04977708, -0.34616986, -0.24963835, -0.31743106, -0.4494996, -0.28869227, 0.67416614, -0.27670434, -0.68114275, -0.2726764, 0.47476465, -0.24493197, 0.8698906, -0.22708173, 0.27490336, -0.21619315, -0.8737054, -0.21193054, 0.0750421, -0.18745434, -0.124819174, -0.15871553, -0.32468045, -0.12997672, -0.52454174, -0.10123791, 0.60266876, -0.0867002, -0.7248166, -0.0755393, 0.39972255, -0.05747762, 0.19986127, -0.02873881, 0.89862937, -0.02722046, 0.0, 0.0, -0.89862937, 0.02722046, -0.19986127, 0.02873881, -0.39972255, 0.05747762, 0.7248166, 0.0755393, -0.6026776, 0.08668601, 0.52454174, 0.10123791, 0.32468045, 0.12997672, 0.124819174, 0.15871553, -0.0750421, 0.18745434, 0.8737054, 0.21193054, -0.27490336, 0.21619315, -0.8698906, 0.22708173, -0.47476465, 0.24493197, 0.68114275, 0.2726764, -0.67416614, 0.27670434, 0.4494996, 0.28869227, 0.24963835, 0.31743106, 0.04977708, 0.34616986, -0.1500842, 0.3749087, -0.34994546, 0.40364748, 0.57671607, 0.44549283, -0.7785928, 0.44952077, 0.7785928, 0.44952077, -0.57671607, 0.4535487, 0.37656346, 0.47883108, 0.17459625, 0.5048854, -0.025265016, 0.53362423, -0.2262972, 0.56535685, -0.42782724, 0.58993995, 0.63160384, 0.63980645, -0.62038994, 0.6506858, 0.29698935, 0.66547924, -0.097450085, 0.7221972, 0.10442667, 0.7262251, 0.4728883, 0.7646256, -0.42574108, 0.7918461, 0.25331548, 0.86261636, -0.23828673, 0.86688817, 0.0, 0.89904153]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_79 = new Float32Array([0.042689875, -0.8986671, -0.15753488, -0.8857809, 0.24662426, -0.86521757, -0.34992477, -0.82884115, 0.43224153, -0.78904516, -0.5249115, -0.73067975, 0.116819814, -0.7122247, -0.08335158, -0.6967088, 0.6312176, -0.6410751, -0.31059253, -0.63209516, -0.67379224, -0.5961787, 0.43688884, -0.58845997, 0.23934679, -0.55334383, -0.4839854, -0.5311451, 0.039813712, -0.5269518, -0.15908235, -0.50056314, 0.7800045, -0.44835034, 0.57936877, -0.44719616, -0.7891625, -0.43202722, 0.36852932, -0.39982548, 0.16234069, -0.36807087, -0.03651771, -0.34139985, -0.43488726, -0.33660617, -0.23541377, -0.31501117, -0.6331565, -0.30586016, 0.6806862, -0.27401766, -0.86528456, -0.24638928, 0.48376375, -0.2355786, 0.87308866, -0.21712033, 0.28486767, -0.20918994, 0.08600927, -0.18251891, -0.11284913, -0.1558479, -0.51168716, -0.14616919, -0.3117452, -0.12945925, -0.7104491, -0.11878839, 0.6118859, -0.07862373, 0.40716895, -0.050135218, -0.8983724, -0.048497394, 0.20831056, -0.0234642, 0.89949584, -0.01822673, 0.009452151, 0.0032068205, -0.18944392, 0.029595478, -0.5883761, 0.040441606, -0.38834, 0.055984136, 0.72896034, 0.08747875, 0.52947026, 0.1089195, 0.33061182, 0.13559052, -0.88678056, 0.15180647, 0.13175343, 0.16226155, -0.067142636, 0.1886502, -0.26603872, 0.21503885, -0.6713846, 0.22310412, 0.8696436, 0.23053198, -0.4713485, 0.23864664, 0.67541426, 0.28084064, 0.45313883, 0.29447144, 0.25428042, 0.32114246, -0.8310855, 0.34456038, 0.055158645, 0.34770492, -0.14373742, 0.37409356, -0.3490472, 0.39770138, -0.55052537, 0.42576346, 0.57449275, 0.45425016, 0.7754771, 0.45595303, 0.37797177, 0.4946917, 0.17768563, 0.50658584, -0.7340572, 0.5201779, -0.0192535, 0.5449393, -0.21933039, 0.5599476, -0.41826794, 0.5860216, 0.6231914, 0.6488894, -0.6005212, 0.66992486, 0.28812933, 0.67409164, -0.106294386, 0.7257151, 0.09434427, 0.7260855, 0.46388718, 0.77086556, -0.43711886, 0.7863537, -0.2519768, 0.863674, 0.23631242, 0.86805874, -0.006295819, 0.8996585]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_80 = new Float32Array([-0.058984082, -0.8981738, 0.14059092, -0.88906103, -0.28504312, -0.8537832, 0.3586518, -0.82556903, -0.5165101, -0.73712295, 0.53192425, -0.7261212, -0.1405607, -0.71580476, 0.20367028, -0.6994978, -0.33229476, -0.6596685, 0.026770413, -0.60665566, -0.6671923, -0.60419357, 0.3772504, -0.5981774, 0.67899215, -0.59090185, -0.48252237, -0.5279685, -0.15142104, -0.5163172, 0.2021155, -0.4997209, 0.7926104, -0.42657253, 0.57251287, -0.4218593, -0.32089922, -0.41053262, 0.025215644, -0.40687874, -0.672206, -0.4044735, 0.37414348, -0.39813545, -0.4949121, -0.31238607, -0.14889535, -0.30890638, -0.846317, -0.30650112, 0.19990659, -0.29995015, 0.66745764, -0.24607898, 0.8671817, -0.24122867, -0.32290822, -0.21075979, 0.023006724, -0.207108, -0.6744149, -0.20470278, 0.37193456, -0.19836472, -0.497121, -0.11261532, -0.89307964, -0.112268075, -0.15100613, -0.10896143, 0.19186032, -0.10032931, 0.5407882, -0.09158602, 0.8990324, -0.044000994, -0.32511714, -0.010989044, -0.7211776, -0.010469722, 0.017847458, -0.002182733, 0.3638883, 0.0012561295, 0.7086892, 0.016684283, -0.5063549, 0.086954124, -0.89581877, 0.087530315, -0.15626355, 0.095789656, 0.19289319, 0.10541924, 0.53178936, 0.10952643, 0.88659346, 0.15539435, -0.6803678, 0.1851007, -0.3343511, 0.1885804, 0.015638536, 0.19758801, 0.36237818, 0.21541825, 0.6977845, 0.22069676, -0.85438067, 0.2832473, -0.50836396, 0.28672698, -0.15847246, 0.2955604, 0.18393056, 0.30524963, 0.53430223, 0.33553043, 0.8147023, 0.3826951, -0.6823768, 0.38487354, -0.3363601, 0.38835326, 0.010387938, 0.40422532, 0.35095063, 0.4148741, -0.51037294, 0.48649982, -0.16751082, 0.4951388, 0.18280679, 0.522767, 0.51134, 0.5339894, 0.71021855, 0.5529783, -0.68438584, 0.5846464, 1.7194457E-4, 0.6037469, -0.36455205, 0.62306297, 0.3431962, 0.64188236, -0.1780331, 0.69464445, -0.5385649, 0.7212095, 0.16056137, 0.7228622, 0.5216906, 0.7335062, -0.35732752, 0.8240317, 0.3220094, 0.8405387, -0.13551039, 0.8898496, 0.06411342, 0.89782226]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_81 = new Float32Array([-0.08883093, -0.8961136, 0.254314, -0.86384887, -0.2834679, -0.85472596, 0.4378247, -0.78690535, 0.07342751, -0.7809238, -0.46426323, -0.77160233, -0.10745897, -0.69799876, 0.5999566, -0.67153746, 0.23568596, -0.66573405, -0.3020423, -0.6563597, -0.6223887, -0.6508016, 0.4190971, -0.5885535, 0.054799475, -0.582809, -0.46016783, -0.535559, 0.73279274, -0.5233787, -0.12608701, -0.49988392, 0.21705791, -0.46761924, -0.64177877, -0.45275992, 0.5519333, -0.4403947, -0.3044525, -0.411667, 0.036171436, -0.38469416, -0.82184714, -0.36807302, 0.37585315, -0.34770024, -0.4856401, -0.3294019, 0.714927, -0.32519364, -0.14219408, -0.29647723, 0.19496666, -0.2647752, -0.67448497, -0.2343536, 0.53853047, -0.23310277, -0.32308057, -0.21355216, 0.8760533, -0.20842542, -0.8826186, -0.17859133, 0.016601147, -0.17655823, 0.3572251, -0.14958543, -0.50426817, -0.13128708, 0.706348, -0.10451863, -0.16428533, -0.093633175, 0.17885959, -0.06136847, -0.7352565, -0.0448719, 0.5199024, -0.034987953, 0.90043926, -0.010936662, -0.34549916, -0.010860763, -0.00202689, 0.021556586, 0.341464, 0.053709183, -0.53361595, 0.0655255, -0.8977478, 0.06999373, 0.73073405, 0.092970125, -0.18291338, 0.104481645, 0.16023156, 0.13674635, -0.7124422, 0.1528046, 0.51204914, 0.16384567, -0.36379987, 0.1874067, -0.020654928, 0.2196714, 0.86888033, 0.23639911, 0.32249, 0.2519361, -0.54744315, 0.26403317, 0.67147183, 0.28292927, -0.8503929, 0.29621348, -0.20154141, 0.30259645, 0.14160351, 0.33486116, 0.48863107, 0.36145154, -0.3822367, 0.38593733, -0.039282966, 0.4177862, 0.78027225, 0.44953945, 0.30359438, 0.45042694, -0.5660522, 0.46214977, -0.76457584, 0.47574598, -0.21997824, 0.50112706, 0.12193185, 0.5344321, 0.46998388, 0.55956453, -0.40086472, 0.58405215, 0.66249347, 0.60992855, 0.28495264, 0.64854044, -0.6190906, 0.6539398, -0.16579607, 0.69259715, 0.0322385, 0.7120598, 0.48634234, 0.7578797, -0.46035644, 0.77393955, 0.30802172, 0.84618735, -0.27914318, 0.85614806, 0.114660546, 0.893176, -0.08429948, 0.8965512]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_82 = new Float32Array([0.07039221, -0.8984016, 0.26459494, -0.86143434, -0.26916477, -0.8600179, 0.44607833, -0.78300357, -0.45021504, -0.7806324, -0.08821673, -0.78039956, 0.09328049, -0.7020412, 0.6060787, -0.66689515, 0.28746942, -0.6650016, -0.25191292, -0.6630823, -0.6173288, -0.65522915, -0.43296322, -0.5836967, -0.07096489, -0.5834639, 0.44746974, -0.5488931, 0.11053233, -0.50510556, -0.75400513, -0.4935147, 0.6289669, -0.47053477, -0.23039624, -0.46656185, -0.5647604, -0.43635094, 0.29202956, -0.4267472, 0.8108771, -0.39313975, -0.048076607, -0.38710356, 0.47352678, -0.34838885, -0.38818276, -0.34745988, 0.13342062, -0.30874518, -0.7325898, -0.29698822, 0.6554369, -0.27099386, -0.20668554, -0.26910153, 0.31491783, -0.23038684, -0.5467917, -0.22945786, 0.87708956, -0.206868, -0.025188325, -0.19074316, -0.88481057, -0.17085297, 0.49744666, -0.1521513, -0.3652945, -0.1510995, 0.15630889, -0.11238481, 0.7216494, -0.08472209, -0.18379726, -0.07274114, -0.719375, -0.062629394, 0.3378061, -0.03402645, -0.5239034, -0.033097476, -0.002300043, 0.0056172134, 0.8964532, 0.011452028, -0.90077436, 0.026191259, 0.5193033, 0.044331905, -0.34240618, 0.04526088, 0.17919718, 0.08397557, 0.70495576, 0.11226166, -0.16233821, 0.12685005, -0.6964867, 0.133731, 0.36069438, 0.16233392, -0.5010151, 0.1632629, 0.020516569, 0.20198594, 0.876021, 0.21134718, -0.8733885, 0.22197504, 0.5421916, 0.24069229, -0.32094714, 0.24485208, 0.20201379, 0.28034428, -0.6270692, 0.31883225, -0.13944994, 0.32321042, 0.7182927, 0.3305237, 0.383511, 0.35870266, 0.04340485, 0.3983463, -0.803971, 0.4070763, -0.29805887, 0.44121245, 0.22490206, 0.47670466, 0.5381027, 0.48192066, -0.5189606, 0.48434302, -0.114294, 0.51929784, 0.7303847, 0.52784336, -0.6958625, 0.5725871, 0.37949377, 0.5999227, -0.37736374, 0.62229806, 0.5919649, 0.6721452, 0.19677494, 0.6753886, -0.19546515, 0.6997201, 0.001997422, 0.70919675, -0.5542656, 0.71054214, 0.4332897, 0.7901522, -0.3474067, 0.8269501, 0.2505709, 0.8656181, -0.1416692, 0.8899496, 0.055793375, 0.8994262]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_83 = new Float32Array([-0.16175698, -0.886842, 0.17978399, -0.8833639, -0.35058632, -0.8305079, 0.36742693, -0.82319593, 0.00801243, -0.78679997, -0.5244966, -0.7327805, 0.5408295, -0.7208578, -0.1638763, -0.68979996, 0.17766468, -0.68632185, -0.35270566, -0.6334658, 0.36530763, -0.6261539, -0.6760053, -0.59638155, 0.0058931145, -0.5897579, 0.6888708, -0.58147323, -0.50168836, -0.5044921, 0.51200634, -0.4945881, -0.16583037, -0.49275622, 0.1757106, -0.4892781, -0.6777404, -0.3993357, -0.337354, -0.3957526, 0.003939044, -0.3927142, 0.34548002, -0.3892361, 0.6860685, -0.38443974, -0.849264, -0.3023321, -0.5085925, -0.29824644, -0.1675846, -0.29571056, 0.17395638, -0.29223248, 0.5143786, -0.28773072, 0.8555811, -0.28396314, -0.6801161, -0.20124283, -0.33882305, -0.19820441, 0.0021848185, -0.19566855, 0.34285495, -0.19072713, 0.6838912, -0.18725416, -0.89466536, -0.110580236, -0.5103467, -0.101200804, -0.16905364, -0.0981624, 0.17108338, -0.09416321, 0.8968403, -0.091277555, 0.51236755, -0.090250544, -0.72551745, -0.009490961, -0.34057727, -0.001158786, -1.5507634E-4, 0.0033429465, 0.72515035, 0.0054314355, 0.34059596, 0.006313369, -0.89626575, 0.09402839, -0.51210093, 0.09584483, -0.1716787, 0.10034656, 0.16935751, 0.10381953, 0.51010853, 0.10678995, 0.8940178, 0.11404146, -0.68832535, 0.18402082, -0.34320235, 0.19735017, 0.68463784, 0.1982754, -0.002166129, 0.20082314, 0.3388701, 0.2042961, -0.5155578, 0.29286796, -0.8525585, 0.29291317, -0.17368977, 0.29782674, 0.16734646, 0.30129972, 0.5089321, 0.3038399, 0.845977, 0.31141132, -0.6840445, 0.39505562, -0.0041771815, 0.39830333, 0.6751625, 0.40965828, -0.3259975, 0.4228564, 0.31679806, 0.42972976, -0.511304, 0.48987547, 0.50053126, 0.50094897, -0.15648493, 0.52333295, 0.14527443, 0.52673334, -0.6797906, 0.5920631, 0.66690695, 0.6065387, -0.36641917, 0.6234361, 0.35280895, 0.6313644, -0.0070333094, 0.651763, -0.1929828, 0.7169769, 0.1773994, 0.7211506, -0.5349058, 0.7256238, 0.51918465, 0.73695415, -0.35894573, 0.8266779, 0.34302497, 0.83274794, -0.10836354, 0.89493656, 0.08867801, 0.89710104]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_84 = new Float32Array([-0.17055643, -0.8853259, 0.17055643, -0.8853259, -0.35857654, -0.82723296, 0.36271286, -0.82480764, 0.0, -0.7871584, -0.53285205, -0.7267043, 0.53711647, -0.72415286, 0.17963165, -0.68874514, -0.17134441, -0.68853736, -0.35936454, -0.6304444, 0.3662986, -0.626441, -7.879889E-4, -0.5903699, -0.68143654, -0.59036916, 0.68143654, -0.59036916, -0.506655, -0.49993816, 0.5106186, -0.4926573, 0.16976844, -0.49220234, -0.17108175, -0.4917474, 0.34032488, -0.39403486, -5.253259E-4, -0.3935799, -0.68169916, -0.3935792, 0.68169916, -0.3935792, -0.34137553, -0.39312497, 0.5108813, -0.29586735, 0.1700311, -0.2954124, -0.17081909, -0.29495746, -0.85199296, -0.29495674, 0.85199296, -0.29495674, -0.5116693, -0.2945025, 0.34058753, -0.1972449, -2.6266294E-4, -0.19678995, -0.34111285, -0.196335, -0.681963, -0.19588006, 0.6862866, -0.18880701, -0.895693, -0.10308008, 0.511144, -0.099077396, 0.17029376, -0.09862245, 0.8957445, -0.09834743, -0.17055643, -0.0981675, -0.5114066, -0.097712554, -0.7256631, -0.004003385, 0.3408502, -4.5494558E-4, 0.0, 0.0, -0.3408502, 4.5494558E-4, 0.7256631, 0.004003385, 0.5114066, 0.097712554, 0.17055643, 0.0981675, -0.8957442, 0.09835026, -0.17029376, 0.09862245, -0.511144, 0.099077396, 0.895693, 0.10308008, -0.6862866, 0.18880701, 0.681963, 0.19588006, 0.34111285, 0.196335, 2.6266294E-4, 0.19678995, -0.34058753, 0.1972449, 0.5116693, 0.2945025, -0.85199296, 0.29495674, 0.85199296, 0.29495674, 0.17081909, 0.29495746, -0.1700311, 0.2954124, -0.5108813, 0.29586735, 0.34137553, 0.39312497, -0.68169916, 0.3935792, 0.68169916, 0.3935792, 5.253259E-4, 0.3935799, -0.34032488, 0.39403486, 0.17108175, 0.4917474, -0.16976844, 0.49220234, -0.5106186, 0.4926573, 0.506655, 0.49993816, -0.68143654, 0.59036916, 0.68143654, 0.59036916, 7.879889E-4, 0.5903699, -0.3662986, 0.626441, 0.35936454, 0.6304444, 0.17134441, 0.68853736, -0.17963165, 0.68874514, -0.53711647, 0.72415286, 0.5328435, 0.7267106, 0.0, 0.7871584, -0.36269534, 0.8247773, 0.35857654, 0.82723296, -0.17055643, 0.8853259, 0.17055643, 0.8853259]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_85 = new Float32Array([0.1251658, -0.8941826, -0.2108705, -0.87793094, 0.31347948, -0.8467347, -0.3937266, -0.8125321, -0.038164575, -0.7891277, 0.48729128, -0.760116, -0.55836844, -0.7095448, 0.13882709, -0.7004645, -0.2027614, -0.6839011, 0.32662797, -0.6510259, 0.6385605, -0.6383335, -0.38561746, -0.61850226, -0.0295092, -0.59512144, -0.6971796, -0.5737331, 0.47789717, -0.52924335, 0.14319475, -0.5063144, -0.19277035, -0.489959, -0.5252163, -0.48350033, 0.6527036, -0.4446499, 0.31723386, -0.42015326, -0.020066407, -0.40115193, -0.35704383, -0.38638502, -0.68934184, -0.37969208, 0.8277689, -0.3605935, 0.4920403, -0.33555982, 0.1563877, -0.31108564, -0.18493254, -0.29591796, -0.8575324, -0.28260812, -0.52116936, -0.28257677, 0.66684675, -0.25096637, 0.331377, -0.22646973, -0.012228601, -0.2071109, -0.34920603, -0.192344, -0.6893599, -0.18549283, 0.88573027, -0.17524563, 0.50618345, -0.14187627, 0.17071368, -0.11737962, -0.17548975, -0.10194843, -0.8981291, -0.09269959, -0.5211875, -0.08837752, 0.7253225, -0.06578013, 0.34552014, -0.032786164, 0.006436971, -0.01381076, -0.34922415, 0.0018552478, -0.7288513, 0.00464864, 0.90271676, 0.018209288, 0.523829, 0.051519662, 0.18607855, 0.0808643, -0.17734167, 0.09224198, -0.89717746, 0.10149733, -0.51352346, 0.10567044, 0.70271754, 0.127099, 0.36316568, 0.16060975, -0.004152756, 0.18009955, -0.68639535, 0.19415018, -0.3415601, 0.19590321, 0.8779426, 0.21082182, 0.5379721, 0.24520321, 0.21570589, 0.2869781, -0.8547214, 0.29099888, -0.52333367, 0.29962173, -0.15944487, 0.3141897, 0.717824, 0.32070982, 0.0397994, 0.3692597, -0.35137033, 0.38985452, -0.6916598, 0.39647043, 0.3719671, 0.40228543, 0.5628919, 0.43779695, 0.20137025, 0.5042035, -0.19516008, 0.50523084, -0.5048212, 0.5131617, 0.7428031, 0.5132959, -0.008114742, 0.5574553, 0.4366756, 0.58538693, -0.6830547, 0.59047896, -0.3483061, 0.62817997, 0.6158603, 0.66026145, -0.14686507, 0.6933291, 0.27825016, 0.69770217, -0.5409894, 0.7228828, 0.086298056, 0.7271596, 0.45402122, 0.78042555, -0.3738973, 0.8218454, 0.207785, 0.8786663, -0.18950838, 0.8827886, 0.0036474087, 0.902893]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_86 = new Float32Array([-0.02399154, -0.9031862, 0.16837472, -0.88767725, -0.21526316, -0.8774866, -0.39671323, -0.8117509, 0.4795969, -0.7657073, 0.28877613, -0.73685014, -0.0944109, -0.723502, 0.09795536, -0.70799303, -0.2768317, -0.6605103, 0.631277, -0.6463824, -0.4730324, -0.6344921, -0.6647026, -0.611957, 0.41195464, -0.5849593, 0.22113387, -0.5561022, 0.030313103, -0.52724504, -0.16148064, -0.50578654, 0.7541547, -0.49756575, -0.35315084, -0.48325145, 0.5636348, -0.46563444, -0.5493515, -0.45723325, -0.7795064, -0.45682675, 0.3415353, -0.40527514, 0.15071452, -0.37641796, -0.04010625, -0.34756082, -0.2377998, -0.32852772, 0.84262335, -0.32604724, -0.42947, -0.30599263, -0.6641553, -0.302103, 0.65093136, -0.2935164, -0.85874456, -0.28085342, 0.4619367, -0.2544481, 0.27111593, -0.22559091, 0.08029517, -0.19673376, -0.12309451, -0.17332461, -0.31476474, -0.15078953, 0.7746709, -0.14541566, -0.51500756, -0.1329937, -0.7070552, -0.1139411, 0.58567625, -0.106347345, -0.89880186, -0.09206592, 0.39151737, -0.07476386, 0.20069659, -0.0459067, -0.0026930878, -0.022497563, 0.9035031, -0.0017230894, -0.20331575, 0.014726553, -0.40030226, 0.022209408, 0.7147759, 0.038631175, -0.5911938, 0.052908983, -0.78398407, 0.063053966, 0.5152569, 0.07333688, 0.31899393, 0.12696019, 0.11770833, 0.1283295, -0.07311244, 0.15718666, 0.88325757, 0.19020247, -0.30659413, 0.19092245, -0.6791052, 0.2250593, 0.6925142, 0.2303347, -0.8725345, 0.23453027, -0.4885086, 0.2553618, 0.4872728, 0.26428765, 0.21436082, 0.2953732, -0.16800937, 0.3252339, 0.024864778, 0.3319321, 0.82271266, 0.3734499, -0.61004966, 0.40527204, -0.80281985, 0.41448906, 0.36616126, 0.41454506, -0.37592408, 0.41629866, 0.55684376, 0.44430205, 0.18777923, 0.4882082, -0.195149, 0.5163065, -0.0022748495, 0.5230047, 0.7246308, 0.53965837, -0.50023633, 0.5639741, -0.6926642, 0.5800776, 0.4182595, 0.60037047, -0.32981798, 0.6545439, 0.24000444, 0.67433286, 0.5934871, 0.68124443, -0.1427664, 0.70205194, 0.050107744, 0.7087501, -0.4934629, 0.7568456, 0.43340984, 0.7927653, -0.3146676, 0.8469387, 0.2551548, 0.8667277, -0.12761605, 0.8944468, 0.0652581, 0.901145]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_87 = new Float32Array([-0.024015637, -0.9038252, 0.1670881, -0.88857096, -0.21403965, -0.87844396, 0.35067964, -0.833367, -0.39444053, -0.8135683, 0.5185048, -0.7406953, 0.020348873, -0.7173175, -0.5571076, -0.71211505, 0.21141617, -0.70161337, -0.16967514, -0.69193625, -0.35007602, -0.6270606, 0.6630183, -0.6147223, 0.39408898, -0.5948391, -0.69472736, -0.57864547, 0.030638602, -0.5235996, -0.5112112, -0.5231915, 0.22207369, -0.51019824, -0.16027036, -0.5004555, 0.7777228, -0.46111172, 0.58632827, -0.43843058, -0.34067127, -0.43557987, -0.8011126, -0.4191603, 0.38138244, -0.40354905, -0.6175964, -0.36370635, 0.1197331, -0.348088, -0.071188115, -0.33069777, 0.8574613, -0.2867698, -0.4470703, -0.2761039, -0.251589, -0.2658221, 0.6644551, -0.2631934, -0.87148017, -0.24082991, 0.46636868, -0.23170415, 0.27363497, -0.2311503, -0.687964, -0.18537594, 0.08026813, -0.16048242, -0.10995289, -0.1366225, 0.78115684, -0.11089779, -0.51743793, -0.097773515, -0.32592228, -0.08910795, 0.5910582, -0.086081825, 0.39684612, -0.053042617, -0.90266645, -0.05167192, 0.20838873, -0.017869506, -0.7191503, 0.0037820586, 0.016500244, 0.020313017, 0.9033955, 0.03678785, -0.17372078, 0.044172924, 0.7116343, 0.067763746, -0.5486242, 0.09138448, 0.52153563, 0.09257971, -0.35710856, 0.10005005, 0.33307824, 0.12775283, -0.89326936, 0.13980922, 0.14462085, 0.16292593, -0.70975316, 0.19526319, -0.047267642, 0.20110846, 0.875331, 0.22643414, -0.23350485, 0.2465951, 0.6861995, 0.25778058, -0.46746546, 0.26621225, 0.45776772, 0.27337515, 0.26931036, 0.30854824, -0.83907866, 0.33678436, 0.08085296, 0.34372136, -0.651855, 0.37802297, -0.10538424, 0.38920802, 0.80791205, 0.40590006, 0.58245724, 0.41899747, -0.29295096, 0.42885727, 0.39399984, 0.45417058, -0.48116562, 0.46530682, 0.20554246, 0.48934367, 0.019305255, 0.53483033, -0.7090494, 0.5610042, 0.7041698, 0.5671169, -0.16826145, 0.5744796, 0.51571244, 0.60229003, -0.35850686, 0.6126437, 0.32725504, 0.63746315, -0.5444547, 0.65929925, 0.15198852, 0.71514827, -0.03971174, 0.71723187, -0.23086193, 0.7556825, 0.45194456, 0.78308547, -0.41680977, 0.80233806, 0.27667803, 0.8607706, -0.102733776, 0.89828867, 0.088972196, 0.8997559]);
    // Inline function 'kotlin.floatArrayOf' call
    var tmp_88 = new Float32Array([-0.007576515, -0.9047347, 0.18199395, -0.8862733, -0.19681121, -0.8831011, 0.36349902, -0.82853526, -0.37732387, -0.82233137, 0.528895, -0.7340792, 0.06960423, -0.7306056, -0.54111475, -0.7251186, -0.11963046, -0.7089721, 0.25159264, -0.6744095, -0.30014312, -0.64820236, 0.6708521, -0.6070911, -0.68092525, -0.59577096, 0.4169886, -0.57995343, -0.46393403, -0.55098957, 0.10548125, -0.5435478, -0.08960896, -0.5208857, -0.27012163, -0.46011597, 0.27378395, -0.45437396, 0.7830792, -0.45319876, 0.5589457, -0.4529654, -0.7905593, -0.44002065, 0.026767263, -0.37010652, -0.43391252, -0.3629032, -0.62379587, -0.34800032, 0.41574106, -0.3273859, -0.15543555, -0.3080473, 0.6711728, -0.29907304, 0.19506997, -0.28093266, 0.8606028, -0.27922213, -0.8651584, -0.2647701, -0.31922644, -0.21083452, -0.5085116, -0.18765263, -0.011340555, -0.18349041, 0.52796817, -0.17349355, -0.69839495, -0.17274976, 0.33799887, -0.15350683, 0.7105573, -0.11272218, 0.15696216, -0.094316535, 0.8999873, -0.092871256, -0.17558247, -0.08575777, -0.9014164, -0.07778577, -0.3557241, -0.023896819, -0.54476964, -6.68313E-4, -0.009208556, 0.0069649317, -0.734653, 0.01423455, 0.52954715, 0.01696717, 0.34013087, 0.036948502, 0.71005726, 0.07774443, 0.15909415, 0.0961388, 0.89948726, 0.09759536, -0.1709087, 0.10761701, -0.89772666, 0.11264575, -0.35203433, 0.1665347, -0.5410799, 0.18976322, -0.0022840353, 0.19730629, 0.48918477, 0.20310867, -0.73096323, 0.20466608, 0.29991025, 0.22439092, 0.6696949, 0.26388595, 0.8591249, 0.28373685, -0.2104473, 0.29393524, 0.13961647, 0.32726797, -0.4438955, 0.35357097, -0.6339131, 0.36961544, -0.82569563, 0.36990395, 0.40941378, 0.38023302, -0.04235769, 0.38351017, 0.59110475, 0.4373834, 0.78053623, 0.45755374, -0.29065737, 0.46668977, 0.24912001, 0.48311007, -0.72996163, 0.53456354, 0.067147665, 0.53935814, -0.46524018, 0.54283845, -0.12256778, 0.5562647, 0.4164059, 0.58042866, 0.66585237, 0.61257064, -0.30649146, 0.65806705, 0.25019908, 0.67357427, -0.60187817, 0.67553306, 0.06822672, 0.72982234, 0.5228589, 0.7383906, -0.12148873, 0.7467289, -0.44712135, 0.7865651, 0.3566941, 0.83148754, -0.27254963, 0.86273915, 0.17472175, 0.8877356, -0.014993695, 0.9046421]);
    // Inline function 'kotlin.floatArrayOf' call
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp.g3g_1 = [tmp_0, tmp_1, tmp_2, tmp_3, tmp_4, tmp_5, tmp_6, tmp_7, tmp_8, tmp_9, tmp_10, tmp_11, tmp_12, tmp_13, tmp_14, tmp_15, tmp_16, tmp_17, tmp_18, tmp_19, tmp_20, tmp_21, tmp_22, tmp_23, tmp_24, tmp_25, tmp_26, tmp_27, tmp_28, tmp_29, tmp_30, tmp_31, tmp_32, tmp_33, tmp_34, tmp_35, tmp_36, tmp_37, tmp_38, tmp_39, tmp_40, tmp_41, tmp_42, tmp_43, tmp_44, tmp_45, tmp_46, tmp_47, tmp_48, tmp_49, tmp_50, tmp_51, tmp_52, tmp_53, tmp_54, tmp_55, tmp_56, tmp_57, tmp_58, tmp_59, tmp_60, tmp_61, tmp_62, tmp_63, tmp_64, tmp_65, tmp_66, tmp_67, tmp_68, tmp_69, tmp_70, tmp_71, tmp_72, tmp_73, tmp_74, tmp_75, tmp_76, tmp_77, tmp_78, tmp_79, tmp_80, tmp_81, tmp_82, tmp_83, tmp_84, tmp_85, tmp_86, tmp_87, tmp_88, new Float32Array([0.0540326, -0.9035638, -0.13541766, -0.89499116, 0.24111113, -0.87247497, -0.31892383, -0.8471332, 0.41760617, -0.80308914, -0.4890081, -0.76172054, 0.042606458, -0.7142642, -0.1468438, -0.7056916, 0.57577056, -0.6984521, 0.22968498, -0.6831753, -0.33034995, -0.65783364, -0.63698596, -0.64311427, 0.40613303, -0.6136701, 0.7086618, -0.5631568, -0.47832784, -0.53922737, 0.07133355, -0.5268085, -0.11811671, -0.51823586, -0.7570036, -0.49627882, 0.25827622, -0.49491295, 0.53902423, -0.47837478, -0.30162287, -0.47037792, 0.81044656, -0.40314198, -0.59834546, -0.3923919, 0.39116743, -0.35961762, 0.02060998, -0.3440737, -0.1688169, -0.33499894, -0.84379286, -0.3276594, -0.42164052, -0.32354245, 0.640809, -0.31835994, 0.20755266, -0.31217813, 0.8766572, -0.22543138, -0.68513477, -0.22377247, 0.49295223, -0.1996028, -0.29060474, -0.18644933, 0.086489126, -0.1661552, -0.10325349, -0.15704858, -0.5084298, -0.154923, 0.30933747, -0.1521633, -0.89354426, -0.1446575, 0.7070196, -0.14064938, -0.7348861, -0.040770575, 0.9043873, -0.037825588, 0.5591628, -0.021892222, -0.37739402, -0.017829908, 0.18885009, -0.005713005, -6.194301E-4, 0.0024228594, -0.19004278, 0.011570845, 0.37576142, 0.026365679, -0.5601307, 0.03288697, -0.9040622, 0.0449285, 0.73537785, 0.048201736, 0.89171183, 0.15555431, -0.30746323, 0.16075748, -0.69850427, 0.16256982, 0.09975947, 0.16332336, 0.5056053, 0.16458818, -0.089663886, 0.17247133, 0.28692025, 0.19391309, -0.4925262, 0.21007197, 0.6833962, 0.23058267, -0.87485933, 0.23231068, -0.20571391, 0.3224623, 0.41676414, 0.3321356, 0.83973026, 0.33793524, -0.6308998, 0.33975482, 0.16169846, 0.34256747, -0.38948762, 0.36928234, -0.024598287, 0.38192335, 0.5945551, 0.3981301, -0.80725485, 0.40949568, 0.294963, 0.47749507, -0.5278612, 0.4989652, 0.75088906, 0.5054827, -0.25320584, 0.5060635, 0.11148, 0.5254417, 0.47275394, 0.5434896, -0.07358002, 0.56688666, -0.70421624, 0.56870604, -0.39391133, 0.63321245, 0.6290879, 0.65084213, 0.31988397, 0.6654946, -0.21428552, 0.6940356, -0.57026637, 0.7029533, 0.13640097, 0.7134413, 0.47967324, 0.7676332, -0.042897888, 0.77522165, -0.3785267, 0.82223153, 0.2902093, 0.85726815, -0.19890086, 0.8830547, 0.10025489, 0.89960885])];
    var tmp_89 = this;
    // Inline function 'kotlin.floatArrayOf' call
    tmp_89.h3g_1 = new Float32Array([1.0, 0.5, 0.4641016, 0.41421357, 0.3701919, 0.33333334, 0.33333334, 0.30259338, 0.27676865, 0.26225892, 0.2548547, 0.24816348, 0.23606798, 0.23103073, 0.22117254, 0.21666475, 0.20867966, 0.20560464, 0.20560464, 0.19522402, 0.19039215, 0.18383303, 0.18033601, 0.17693913, 0.17382766, 0.17158026, 0.16930793, 0.16625275, 0.16290365, 0.1613491, 0.15894455, 0.15553398, 0.15416151, 0.15126403, 0.14931677, 0.14821944, 0.14795591, 0.14363922, 0.14168552, 0.1403736, 0.1377408, 0.13611375, 0.1347719, 0.13336824, 0.13204959, 0.13071588, 0.12946375, 0.12834875, 0.126793, 0.1258255, 0.12457167, 0.123690166, 0.12225562, 0.12189202, 0.121786326, 0.1192815, 0.11838264, 0.11730819, 0.116380565, 0.11565748, 0.11545614, 0.113253295, 0.112456195, 0.11158259, 0.110896744, 0.10993506, 0.109063484, 0.10834502, 0.10787764, 0.10700162, 0.1062045, 0.105553254, 0.104818, 0.10428363, 0.10339092, 0.10277918, 0.102052145, 0.10144344, 0.10095847, 0.1003195, 0.09989148, 0.09949433, 0.098844916, 0.09852672, 0.098395064, 0.097099625, 0.09649521, 0.095855795, 0.095233634, 0.09482206, 0.09463628]);
  }
}
class Exp10Scale {
  o2o(value, min, max) {
    // Inline function 'kotlin.math.pow' call
    return Math.pow(value, 10.0);
  }
  toString() {
    return 'Exp10';
  }
}
class ExpScale {
  o2o(value, min, max) {
    // Inline function 'kotlin.math.exp' call
    return Math.exp(value);
  }
  toString() {
    return 'Exp';
  }
}
class ExpandLabeling extends AbstractLabeling {
  x2p(g, bounds, node, view, pass, passes) {
    if (pass === (passes - 1 | 0)) {
      if (bounds.cm() > 20 && bounds.dm() > 16) {
        var model = ensureNotNull(view.j2p());
        g.w2q();
        g.c3v(0.5);
        var elabel = ensureNotNull(view.p3c()).m3m(model, node, Dimension.bm(bounds.s20_1, bounds.t20_1));
        var pf = g.q2p(elabel, bounds.s20_1, bounds.t20_1);
        var column = model.getGroupByColumn(node);
        var headerFont = model.settings.getColumnSettings(column).getHeaderFont();
        elabel.setFont(ensureNotNull(headerFont));
        var size = pf.s2p();
        var scalex = bounds.cm() / size.cm();
        var scaley = bounds.dm() / size.dm();
        // Inline function 'kotlin.math.min' call
        var scale = Math.min(scalex, scaley);
        var tmp2 = getFontSize(headerFont);
        // Inline function 'kotlin.math.max' call
        var b = getFontSize(headerFont) * scale;
        var fontSize = Math.max(tmp2, b);
        var foreground = model.settings.getColumnSettings(column).getHeaderForeground();
        var background = model.settings.getColumnSettings(column).getHeaderEffectColor();
        var derivedFont = headerFont.u2d(fontSize);
        elabel.setFont(derivedFont);
        elabel.setForeground(ensureNotNull(foreground));
        elabel.setBackground(ensureNotNull(background));
        size = pf.s2p();
        var position;
        var shape = model.getShape(node);
        if (!(shape == null) ? isInterface(shape, Arc2D) : false) {
          position = Companion_instance_65.d2p(shape);
        } else {
          position = null;
        }
        var rect;
        if (!(position == null)) {
          var w = size.yl_1;
          if (!(shape == null) ? isInterface(shape, Arc2D) : false) {
            var arc = shape;
            var startPoint = arc.q1p();
            var endPoint = arc.r1p();
            var s = Double_2.s1p(view.v3c(startPoint.w1l()), view.w3c(startPoint.x1l()));
            var e = Double_2.s1p(view.v3c(endPoint.w1l()), view.w3c(endPoint.x1l()));
            var tmp4 = numberToInt(s.j20(e));
            // Inline function 'kotlin.math.min' call
            var b_0 = w;
            w = Math.min(tmp4, b_0);
          }
          var h = size.zl_1;
          var x = view.v3c(position.w1l()) - (w / 2 | 0) | 0;
          var y = view.w3c(position.x1l()) - (h / 2 | 0) | 0;
          rect = Rectangle.from(x, y, w, h).u20(bounds);
        } else {
          rect = bounds;
        }
        g.w2p(elabel, rect.q20_1, rect.r20_1, rect.s20_1, rect.t20_1);
        g.y2q();
      }
    }
  }
  toString() {
    return 'Expand';
  }
}
class FixedNesting extends AbstractNesting {
  z2p(model, shape, node, amount) {
    var tmp;
    var tmp_0;
    if (!model.isRoot(node)) {
      tmp_0 = isInterface(shape, Rectangle2D);
    } else {
      tmp_0 = false;
    }
    if (tmp_0) {
      var rectangle = shape;
      var tmp_1;
      if (rectangle.cm() > amount * 2 + 1 && rectangle.dm() >= amount * 2 + 1) {
        tmp_1 = Double_3.p1m(rectangle.w1l() + amount, rectangle.x1l() + amount, rectangle.cm() - amount * 2, rectangle.dm() - amount * 2);
      } else {
        tmp_1 = shape;
      }
      tmp = tmp_1;
    } else {
      tmp = shape;
    }
    return tmp;
  }
  toString() {
    return 'Fixed';
  }
}
class FlatRendering extends AbstractRendering {
  constructor() {
    super();
    this.drawBorder = true;
  }
  d3v(_set____db54di) {
    this.drawBorder = _set____db54di;
  }
  e3v() {
    return this.drawBorder;
  }
  paintNode(g, view, node, pass, bounds, shape) {
    var model = ensureNotNull(view.j2p());
    if (pass === 0) {
      var color;
      var tmp;
      if (!model.filter.ol(node) && !model.search.ol(node)) {
        tmp = model.getColor(node);
      } else {
        tmp = view.m2q();
      }
      color = tmp;
      if (!(color == null)) {
        g.n2q(color);
        if (shape instanceof TextShape) {
          var textShape = shape;
          if (textShape.c22()) {
            g.o2q(shape);
          } else {
            var bounds2D = textShape.y1l();
            g.i3h(textShape.z21_1, bounds2D.w1l(), bounds2D.j1m());
          }
        } else {
          g.o2q(shape);
        }
      }
    } else if (pass === 1)
      if (!model.filter.ol(node) && !model.search.ol(node)) {
        var color_0 = ensureNotNull(model.getColor(node));
        if (isInterface(shape, Rectangle2D)) {
          var bottom = shape;
          var tmp_0 = this.getRenderedShape(view, model, node, shape);
          var top = isInterface(tmp_0, Rectangle2D) ? tmp_0 : THROW_CCE();
          g.n2q(color_0);
          g.s3d(top.w1l(), top.x1l(), top.cm(), top.dm());
          if (bounds.cm() > 1 && bounds.dm() > 1) {
            var g2 = g.e3h();
            g2.h22();
            g2.c20(top.f1m(), top.j1m());
            g2.d20(bottom.w1l(), bottom.j1m());
            g2.d20(bottom.i1m(), bottom.j1m());
            g2.d20(top.i1m(), top.j1m());
            g2.g20();
            g2.g22(darker(color_0));
            g2.i22();
            g2.h22();
            g2.c20(top.i1m(), top.j1m());
            g2.d20(bottom.i1m(), bottom.j1m());
            g2.d20(bottom.i1m(), bottom.h1m());
            g2.d20(top.i1m(), top.h1m());
            g2.g20();
            g2.g22(darker(color_0));
            g2.i22();
            if (this.drawBorder) {
              g.a2r(g.q30().e2c());
              g.f3h(top.w1l(), top.x1l(), top.cm(), top.dm());
              g.g3h(numberToInt(top.f1m()), numberToInt(top.j1m()), numberToInt(bottom.w1l()), numberToInt(bottom.j1m()));
              g.g3h(numberToInt(top.i1m()), numberToInt(top.j1m()), numberToInt(bottom.i1m()), numberToInt(bottom.j1m()));
              g.g3h(numberToInt(top.i1m()), numberToInt(top.h1m()), numberToInt(bottom.i1m()), numberToInt(bottom.h1m()));
            }
          }
        }
      }
    return true;
  }
  paintBorder(g2, view, node, pass, bounds, shape) {
    if (this.drawBorder && pass === 0 && bounds.cm() > 1 && bounds.dm() > 1) {
      var model = ensureNotNull(view.j2p());
      if (model.hasNoChildren(node)) {
        if (!model.filter.ol(node) && !model.search.ol(node)) {
          var columnSettings = model.settings.getColumnSettings(model.getGroupByColumn(node));
          var borderThickness = columnSettings.getBorderThickness();
          var tmp;
          if (borderThickness > 0) {
            tmp = !(shape instanceof TextShape);
          } else {
            tmp = false;
          }
          if (tmp) {
            g2.w2q();
            g2.z2q(borderThickness);
            g2.a2r(columnSettings.getBorderColor());
            g2.b2r(shape);
            g2.y2q();
          }
        }
      }
    }
  }
  toString() {
    return 'Flat';
  }
}
class FlatNoBorderRendering extends FlatRendering {
  constructor() {
    super();
    this.drawBorder = false;
  }
  toString() {
    return 'Flat (No Border)';
  }
}
class AscendingTreeMapNodeComparator_0 {
  constructor(model, universal) {
    this.f3v_1 = model;
    this.g3v_1 = universal;
  }
  k2q(a, b) {
    var column = this.f3v_1.settings.heightColumn;
    return this.g3v_1.compare(this.f3v_1.getAggregateValue(a, column), this.f3v_1.getAggregateValue(b, column));
  }
  compare(a, b) {
    var tmp = (a == null ? true : !(a == null)) ? a : THROW_CCE();
    return this.k2q(tmp, (b == null ? true : !(b == null)) ? b : THROW_CCE());
  }
}
class DescendingTreeMapNodeComparator_0 {
  constructor(model, universal) {
    this.h3v_1 = model;
    this.i3v_1 = universal;
  }
  k2q(a, b) {
    var column = this.h3v_1.settings.heightColumn;
    return this.i3v_1.compare(this.h3v_1.getAggregateValue(b, column), this.h3v_1.getAggregateValue(a, column));
  }
  compare(a, b) {
    var tmp = (a == null ? true : !(a == null)) ? a : THROW_CCE();
    return this.k2q(tmp, (b == null ? true : !(b == null)) ? b : THROW_CCE());
  }
}
class HeightOrdering {
  y32(model, nodes, sortOrder) {
    // Inline function 'kotlin.collections.copyOf' call
    // Inline function 'kotlin.js.asDynamic' call
    var copy = nodes.slice();
    var universal = new UniversalComparator();
    var comparator;
    var tmp;
    switch (sortOrder.z2_1) {
      case 0:
        tmp = new AscendingTreeMapNodeComparator_0(model, universal);
        break;
      case 1:
        tmp = new DescendingTreeMapNodeComparator_0(model, universal);
        break;
      default:
        throw IllegalArgumentException.qc();
    }
    comparator = tmp;
    sortWith(copy, comparator);
    return copy;
  }
  toString() {
    return 'By height';
  }
}
class HighlightParentNodeRenderer extends AbstractNodeRenderer {
  c2q(view) {
    var model = ensureNotNull(view.j2p());
    return model.highlighting.a13();
  }
  b2q(view, root, pass) {
    var model = ensureNotNull(view.j2p());
    return model.highlighting;
  }
  e2q(view, node) {
    return !ensureNotNull(view.j2p()).hasNoChildren(node);
  }
  d2q(model) {
    return ensureNotNull(model.settings.rendering).getPasses(model);
  }
  f2q(g, view, node, pass, passes, bounds, shape) {
    var model = ensureNotNull(view.j2p());
    if (bounds.cm() > 0 && bounds.dm() > 0) {
      var rendering = ensureNotNull(model.settings.rendering);
      rendering.paintParentHighlight(g, view, node, pass, bounds, shape);
    }
    return true;
  }
}
class IcicleRectangle2D extends Double_3 {
  static o3v(x, y, w, h, fullWidth) {
    var $this = this.p1m(x, y, w, h);
    $this.n3v_1 = fullWidth;
    return $this;
  }
}
class IcicleAlgorithm extends AbstractAlgorithm {
  constructor() {
    super();
    this.p3v_1 = 0;
  }
  q2o(bounds, model, root, worker) {
    super.q2o(bounds, model, root, worker);
    this.p3v_1 = getMaxDepthToLeaf(this, model, root) - model.getLevel(root) | 0;
  }
  x2o(shape, parent, children, sumSizes, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    if (shape instanceof IcicleRectangle2D) {
      var bounds = shape.y1l();
      var width = bounds.cm();
      var sumShares = 0.0;
      var inductionVariable = 0;
      var last = children.length;
      while (inductionVariable < last) {
        var child = children[inductionVariable];
        inductionVariable = inductionVariable + 1 | 0;
        var r;
        var share = accessor.getSize(child) / sumSizes;
        r = IcicleRectangle2D.o3v(bounds.w1l() + width, bounds.x1l() + bounds.dm() * sumShares, width, bounds.dm() * share, bounds.cm());
        accessor.setShape(child, r);
        sumShares = sumShares + share;
      }
    } else {
      var bounds_0 = shape.y1l();
      var width_0 = bounds_0.cm() / this.p3v_1;
      var sumShares_0 = 0.0;
      var inductionVariable_0 = 0;
      var last_0 = children.length;
      while (inductionVariable_0 < last_0) {
        var child_0 = children[inductionVariable_0];
        inductionVariable_0 = inductionVariable_0 + 1 | 0;
        var r_0;
        var share_0 = accessor.getSize(child_0) / sumSizes;
        r_0 = IcicleRectangle2D.o3v(bounds_0.w1l(), bounds_0.x1l() + bounds_0.dm() * sumShares_0, width_0, bounds_0.dm() * share_0, width_0);
        accessor.setShape(child_0, r_0);
        sumShares_0 = sumShares_0 + share_0;
      }
    }
    return false;
  }
  s2o() {
    return true;
  }
  t2o() {
    return true;
  }
  u2o() {
    return true;
  }
  v2o() {
    return false;
  }
  y2o(shape) {
    return !(shape == null) ? isInterface(shape, Rectangle2D) : false;
  }
  toString() {
    return 'Icicle';
  }
}
class InfiniteDepth {
  p2q(depth) {
    return true;
  }
  toString() {
    return 'Infinite';
  }
}
class InverseScale {
  o2o(value, min, max) {
    return 1.0 / value;
  }
  toString() {
    return 'Inverse';
  }
}
class Itertools$combinations$1$iterator$1 {
  constructor($list, $r) {
    this.t3v_1 = $list;
    this.u3v_1 = $r;
    this.q3v_1 = -1;
    this.r3v_1 = CombinationGenerator_instance.x3g($list.a1(), $r);
    this.s3v_1 = new Int32Array($r);
  }
  y() {
    this.q3v_1 = this.q3v_1 + 1 | 0;
    return this.q3v_1 < this.r3v_1;
  }
  z() {
    if (this.q3v_1 === 0) {
      var inductionVariable = 0;
      var last = this.s3v_1.length - 1 | 0;
      if (inductionVariable <= last)
        do {
          var i = inductionVariable;
          inductionVariable = inductionVariable + 1 | 0;
          this.s3v_1[i] = i + 1 | 0;
        }
         while (inductionVariable <= last);
    } else
      this.s3v_1 = CombinationGenerator_instance.y3g(this.s3v_1, this.t3v_1.a1(), this.u3v_1);
    var result = ArrayList.e1();
    var indexedObject = this.s3v_1;
    var inductionVariable_0 = 0;
    var last_0 = indexedObject.length;
    while (inductionVariable_0 < last_0) {
      var aCurrCombination = indexedObject[inductionVariable_0];
      inductionVariable_0 = inductionVariable_0 + 1 | 0;
      result.o(this.t3v_1.b1(aCurrCombination - 1 | 0));
    }
    return result;
  }
  n5() {
    // Inline function 'kotlin.TODO' call
    var reason = 'Not yet implemented';
    throw NotImplementedError.bk('An operation is not implemented: ' + reason);
  }
}
class Itertools$combinations$1 {
  constructor($list, $r) {
    this.v3v_1 = $list;
    this.w3v_1 = $r;
  }
  x() {
    return new Itertools$combinations$1$iterator$1(this.v3v_1, this.w3v_1);
  }
}
class Itertools {
  d3f(list, r) {
    return new Itertools$combinations$1(list, r);
  }
}
class Companion_83 {
  constructor() {
    Companion_instance_83 = this;
    this.u3i_1 = new OverlayLabeling();
    this.v3i_1 = new SurroundLabeling();
    this.w3i_1 = new ColoredSurroundLabeling();
    this.x3i_1 = new NoneLabeling();
    this.y3i_1 = new ExpandLabeling();
    this.z3i_1 = new LabelingFactory([this.u3i_1, this.v3i_1, this.w3i_1, this.x3i_1, this.y3i_1]);
  }
  y3c() {
    return this.z3i_1;
  }
}
class LabelingFactory {
  constructor(entries) {
    Companion_getInstance_83();
    this.a3j_1 = ArrayList.e1();
    addAll(this.a3j_1, entries);
  }
  a3d() {
    return Companion_getInstance_83().v3i_1;
  }
}
class LeafNodeRenderer extends AbstractNodeRenderer {
  constructor(drawText) {
    super();
    this.x3v_1 = drawText;
  }
  c2q(view) {
    return true;
  }
  b2q(view, root, pass) {
    return ensureNotNull(ensureNotNull(view.j2p()).settings.rendering).getOrder(view, root, pass);
  }
  e2q(view, node) {
    return ensureNotNull(view.j2p()).hasNoChildren(node);
  }
  d2q(model) {
    return ensureNotNull(model.settings.rendering).getPasses(model);
  }
  f2q(g, view, node, pass, passes, bounds, shape) {
    var completed = true;
    var model = ensureNotNull(view.j2p());
    if (bounds.cm() > 0 && bounds.dm() > 0) {
      var settings = model.settings;
      var rendering = ensureNotNull(settings.rendering);
      completed = rendering.paintNode(g, view, node, pass, bounds, shape);
      if (this.x3v_1 && bounds.cm() > 4 && bounds.dm() > 4) {
        if (!(settings.backgroundColumn == null)) {
          rendering.paintBackground(g, view, node, pass, passes, bounds, shape);
        }
        // Inline function 'kotlin.collections.isNotEmpty' call
        if (!settings.labelsColumns.c1()) {
          rendering.paintLabel(g, view, node, pass, passes, bounds, shape);
        }
      }
      rendering.paintBorder(g, view, node, pass, bounds, shape);
    }
    return completed;
  }
}
class LeafTreeMapNode extends AbstractTreeMapNode {
  constructor(row, model) {
    super(model);
    this.g3w_1 = row;
  }
  x32(value) {
    throw IllegalStateException.lc();
  }
  b33() {
    return this.a1();
  }
  d34() {
    return this.g3w_1;
  }
  u33() {
    return 0;
  }
  j33() {
    return null;
  }
  k33() {
    return null;
  }
  x33() {
    return emptyList();
  }
  y33() {
    return emptyList();
  }
  z33(newChild) {
    throw UnsupportedOperationException.h4();
  }
  b34(name) {
    return null;
  }
  l32() {
    return true;
  }
  w32() {
    return true;
  }
  c34() {
    return this.g3w_1;
  }
  equals(other) {
    if (this === other)
      return true;
    if (other == null || !getKClassFromExpression(this).equals(getKClassFromExpression(other)))
      return false;
    var that = other instanceof LeafTreeMapNode ? other : THROW_CCE();
    return !(this.f2y_1 === that.f2y_1) ? false : this.g3w_1 === that.g3w_1 || equals(this.g3w_1, that.g3w_1);
  }
  hashCode() {
    // Inline function 'kotlin.hashCode' call
    var tmp0_safe_receiver = this.g3w_1;
    var tmp1_elvis_lhs = tmp0_safe_receiver == null ? null : hashCode(tmp0_safe_receiver);
    return tmp1_elvis_lhs == null ? 0 : tmp1_elvis_lhs;
  }
  h3w(other) {
    var tmp;
    if (other instanceof AbstractTreeMapNode) {
      var tmp_0 = this.g3w_1;
      tmp = compareTo((!(tmp_0 == null) ? isComparable(tmp_0) : false) ? tmp_0 : THROW_CCE(), ensureNotNull(other.d34()));
    } else {
      tmp = compareTo(this.hashCode(), hashCode(other));
    }
    return tmp;
  }
  d(other) {
    return this.h3w(other instanceof AbstractTreeMapNode ? other : THROW_CCE());
  }
}
class Log1pScale {
  o2o(value, min, max) {
    // Inline function 'kotlin.math.ln' call
    var x = 1 + value;
    return Math.log(x);
  }
  toString() {
    return 'Ln(1+x)';
  }
}
class LogScale {
  o2o(value, min, max) {
    // Inline function 'kotlin.math.ln' call
    return Math.log(value);
  }
  toString() {
    return 'Log';
  }
}
class Companion_84 {}
class MatrixAlgorithm extends AbstractAlgorithm {
  x2o(shape, parent, children, sumSize, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    if (children.length === 0) {
      return true;
    }
    if (children.length === 1) {
      accessor.setShape(children[0], shape);
      return true;
    }
    var bounds = shape.y1l();
    var size = this.i3w(bounds.cm(), bounds.dm(), children.length);
    var x = bounds.w1l();
    var y = bounds.x1l();
    var col = 0;
    var row = 0;
    var inductionVariable = 0;
    var last = children.length;
    while (inductionVariable < last) {
      var child = children[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      accessor.setShape(child, Double_3.p1m(x, y, size, size));
      col = col + 1 | 0;
      x = bounds.w1l() + size * col;
      if (size * (col + 1 | 0) > bounds.cm()) {
        x = bounds.w1l();
        row = row + 1 | 0;
        y = bounds.x1l() + size * row;
        col = 0;
      }
    }
    return false;
  }
  i3w(width, height, count) {
    // Inline function 'kotlin.math.sqrt' call
    var x = width * count / height;
    // Inline function 'kotlin.math.ceil' call
    var x_0 = Math.sqrt(x);
    var cols = Math.ceil(x_0);
    // Inline function 'kotlin.math.ceil' call
    var x_1 = count / cols;
    var rows = Math.ceil(x_1);
    var p1 = width / cols;
    var p2 = height / rows;
    // Inline function 'kotlin.math.min' call
    return Math.min(p1, p2);
  }
  y2o(shape) {
    return !(shape == null) ? isInterface(shape, Rectangle2D) : false;
  }
  toString() {
    return getName(Companion_instance_84);
  }
}
class MaxAggregation {
  m32(values) {
    var max = -1.7976931348623157E308;
    var inductionVariable = 0;
    var last = values.length;
    while (inductionVariable < last) {
      var value = values[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      if (!isInfinite(value) && !isNaN_0(value)) {
        if (value > max) {
          max = value;
        }
      }
    }
    return max;
  }
  l33() {
    return false;
  }
  toString() {
    return 'Max';
  }
}
class MaxScale {
  o2o(value, min, max) {
    return max - value;
  }
  toString() {
    return 'Max - x';
  }
}
class MinAggregation {
  m32(values) {
    var min = 1.7976931348623157E308;
    var inductionVariable = 0;
    var last = values.length;
    while (inductionVariable < last) {
      var value = values[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      if (!isInfinite(value) && !isNaN_0(value)) {
        if (value < min) {
          min = value;
        }
      }
    }
    return min;
  }
  l33() {
    return false;
  }
  toString() {
    return 'Min';
  }
}
class MinScale {
  o2o(value, min, max) {
    return value - min;
  }
  toString() {
    return 'x - Min';
  }
}
class MutableAlgorithmOverrideProperty extends OverrideProperty {
  constructor(overrideDefaults, defaultProperty) {
    super(overrideDefaults, defaultProperty);
    this.p3w_1 = defaultProperty;
  }
  d10() {
    return this.p3w_1;
  }
  f10() {
    var overrideProperty = new MutableAlgorithmProperty(this.p3w_1.r2());
    return this.g10(overrideProperty);
  }
}
class MutableAlgorithmProperty$propertiesListener$1 {
  constructor(this$0, $algorithm) {
    this.q3w_1 = this$0;
    this.r3w_1 = $algorithm;
  }
  k30(name, event) {
    this.q3w_1.vx(new PropertyEvent(null, this.r3w_1));
  }
  zx(name, event) {
    return this.k30((name == null ? true : typeof name === 'string') ? name : THROW_CCE(), event);
  }
}
class MutableAlgorithmProperty extends AbstractMutableProperty {
  constructor(algorithm) {
    super();
    var tmp = this;
    tmp.u3w_1 = new MutableAlgorithmProperty$propertiesListener$1(this, algorithm);
    this.v3w_1 = algorithm;
  }
  w3w(value) {
    if (!(this.v3w_1 == null)) {
      if (!(ensureNotNull(this.v3w_1).f24() == null)) {
        ensureNotNull(ensureNotNull(this.v3w_1).f24()).by(this.u3w_1);
      }
    }
    var old = this.v3w_1;
    this.v3w_1 = value;
    if (!(this.v3w_1 == null)) {
      if (!(ensureNotNull(this.v3w_1).f24() == null)) {
        ensureNotNull(ensureNotNull(this.v3w_1).f24()).dy(this.u3w_1);
      }
    }
    this.vx(new PropertyEvent(old, this.v3w_1));
  }
  vo(_set____db54di) {
    return this.w3w((_set____db54di == null ? true : isInterface(_set____db54di, Algorithm)) ? _set____db54di : THROW_CCE());
  }
  r2() {
    return this.v3w_1;
  }
}
class Companion_85 {
  constructor() {
    Companion_instance_85 = this;
    this.j3i_1 = new NoneNesting();
    this.k3i_1 = new FixedNesting();
    this.l3i_1 = new ProportionalNesting();
    this.m3i_1 = new NestingFactory([this.j3i_1, this.k3i_1, this.l3i_1]);
  }
  y3c() {
    return this.m3i_1;
  }
}
class NestingFactory {
  constructor(entries) {
    Companion_getInstance_85();
    this.n3i_1 = ArrayList.e1();
    addAll(this.n3i_1, entries);
  }
  a3d() {
    return Companion_getInstance_85().l3i_1;
  }
}
class Companion_86 {
  constructor() {
    this.z3w_1 = true;
  }
}
class NodesTreeMapRenderer {
  static i3c(nodeRenderer, selectedPass) {
    var $this = createThis(this);
    $this.g3c_1 = nodeRenderer;
    $this.h3c_1 = selectedPass;
    return $this;
  }
  static j3c(nodeRenderer) {
    return this.i3c(nodeRenderer, -1);
  }
  r3d(g2, view, progress) {
    if (progress == null || !progress.d17()) {
      var model = view.j2p();
      if (!(model == null)) {
        var root = model.currentRoot;
        if (!(root == null)) {
          if (this.g3c_1.c2q(view)) {
            var passes = this.g3c_1.d2q(model);
            if (this.h3c_1 >= 0) {
              if (this.h3c_1 < passes) {
                paint(this, g2, view, model, root, this.h3c_1, passes, progress);
              }
            } else {
              var inductionVariable = 0;
              if (inductionVariable < passes)
                do {
                  var pass = inductionVariable;
                  inductionVariable = inductionVariable + 1 | 0;
                  paint(this, g2, view, model, root, pass, passes, progress);
                }
                 while (inductionVariable < passes);
            }
          }
        }
      }
    }
  }
}
class NoneAggregation {
  m32(values) {
    return null;
  }
  l33() {
    return false;
  }
  toString() {
    return 'None';
  }
}
class NoneLabeling extends AbstractLabeling {
  x2p(g2, bounds, node, view, pass, passes) {
  }
  toString() {
    return 'None';
  }
}
class NoneNesting extends AbstractNesting {
  z2p(model, shape, node, amount) {
    return shape;
  }
  toString() {
    return 'None';
  }
}
class NumericTransformScale {
  constructor(transform) {
    this.a3x_1 = transform;
  }
  o2o(value, min, max) {
    return this.a3x_1.l12_1(value);
  }
  hashCode() {
    return this.a3x_1.hashCode();
  }
  equals(obj) {
    var tmp;
    if (obj instanceof NumericTransformScale) {
      tmp = obj.a3x_1.equals(this.a3x_1);
    } else {
      tmp = false;
    }
    return tmp;
  }
  toString() {
    // Inline function 'kotlin.text.substring' call
    // Inline function 'kotlin.js.asDynamic' call
    // Inline function 'kotlin.text.uppercase' call
    // Inline function 'kotlin.js.asDynamic' call
    var tmp = this.a3x_1.k12_1.substring(0, 1).toUpperCase();
    // Inline function 'kotlin.text.substring' call
    // Inline function 'kotlin.js.asDynamic' call
    var tmp$ret$5 = this.a3x_1.k12_1.substring(1);
    return tmp + replace(tmp$ret$5, '_', ' ');
  }
}
class SortOrder extends Enum {}
class Companion_87 {
  constructor() {
    Companion_instance_87 = this;
    this.o3i_1 = new SizeOrdering();
    this.p3i_1 = new OriginalOrdering();
    this.q3i_1 = new ColorOrdering();
    this.r3i_1 = new HeightOrdering();
    this.s3i_1 = new OrderingFactory([this.p3i_1, this.o3i_1, this.q3i_1, this.r3i_1]);
  }
  y3c() {
    return this.s3i_1;
  }
}
class OrderingFactory {
  constructor(entries) {
    Companion_getInstance_87();
    this.t3i_1 = ArrayList.e1();
    addAll(this.t3i_1, entries);
  }
  a3d() {
    return Companion_getInstance_87().o3i_1;
  }
}
class Companion_88 {
  b3x(data) {
    var left = 0;
    var right = data.length - 1 | 0;
    while (left < right) {
      var temp = data[left];
      data[left] = data[right];
      data[right] = temp;
      left = left + 1 | 0;
      right = right - 1 | 0;
    }
  }
}
class OriginalOrdering {
  y32(model, nodes, sortOrder) {
    var tmp;
    switch (sortOrder.z2_1) {
      case 0:
        // Inline function 'kotlin.collections.copyOf' call

        // Inline function 'kotlin.js.asDynamic' call

        var copy = nodes.slice();
        Companion_instance_88.b3x(copy);
        tmp = copy;
        break;
      case 1:
        tmp = nodes;
        break;
      default:
        throw IllegalArgumentException.qc();
    }
    return tmp;
  }
  toString() {
    return 'Original';
  }
}
class OriginalScale {
  o2o(value, min, max) {
    return value;
  }
  toString() {
    return 'Original';
  }
}
class OverlayLabeling extends AbstractLabeling {
  x2p(g2, bounds, node, view, pass, passes) {
    if (pass === (passes - 1 | 0)) {
      var model = ensureNotNull(view.j2p());
      var columnSettings = model.settings.getColumnSettings(model.getGroupByColumn(node));
      var headerFont = columnSettings.getHeaderFont();
      var fontSize = getFontSize(ensureNotNull(headerFont)) * (1.0 + (view.u2p() - 1.0) * 0.15);
      var label = ensureNotNull(view.p3c()).m3m(model, node, Dimension.bm(bounds.s20_1, bounds.t20_1));
      var foreground = columnSettings.getHeaderForeground();
      var background = columnSettings.getHeaderEffectColor();
      var derivedFont;
      var tmp;
      if (!(fontSize === getFontSize(headerFont))) {
        tmp = headerFont.u2d(fontSize);
      } else {
        tmp = headerFont;
      }
      derivedFont = tmp;
      label.setFont(derivedFont);
      label.setForeground(ensureNotNull(foreground));
      if (!(background == null)) {
        label.setBackground(brighter(background));
      }
      var position;
      var shape = model.getShape(node);
      if (!(shape == null) ? isInterface(shape, Arc2D) : false) {
        position = Companion_instance_65.d2p(shape);
      } else {
        position = null;
      }
      var rect;
      if (!(position == null)) {
        var size = g2.q2p(label, bounds.s20_1, bounds.t20_1).s2p();
        var w = size.yl_1;
        if (!(shape == null) ? isInterface(shape, Arc2D) : false) {
          var arc = shape;
          var startPoint = arc.q1p();
          var endPoint = arc.r1p();
          var s = Double_2.s1p(view.v3c(startPoint.w1l()), view.w3c(startPoint.x1l()));
          var e = Double_2.s1p(view.v3c(endPoint.w1l()), view.w3c(endPoint.x1l()));
          var tmp0 = numberToInt(s.j20(e));
          // Inline function 'kotlin.math.min' call
          var b = w;
          w = Math.min(tmp0, b);
        }
        var h = size.zl_1;
        var x = view.v3c(position.w1l()) - (w / 2 | 0) | 0;
        var y = view.w3c(position.x1l()) - (h / 2 | 0) | 0;
        rect = Rectangle.from(x, y, w, h).u20(bounds);
      } else {
        var rectangle = ensureNotNull(model.getNestedShape(node));
        rect = view.x3c(rectangle.y1l());
      }
      g2.w2p(label, rect.q20_1, rect.r20_1, rect.s20_1, rect.t20_1);
    }
  }
  k2p(parent, node, view, model) {
    if (!model.isRoot(parent)) {
      var parentColumnSettings = model.settings.getColumnSettings(model.getGroupByColumn(parent));
      var headerVerticalAlignment = parentColumnSettings.getHeaderVerticalAlignment();
      if (headerVerticalAlignment === 1 && ensureNotNull(model.getNestedShape(parent)).y1l().x1l() === model.getBounds(node).x1l()) {
        var headerFont = ensureNotNull(parentColumnSettings.getHeaderFont());
        var headerZoomedSize = getFontSize(headerFont) * (1.0 + (view.u2p() - 1.0) * 0.15);
        if (!(getFontSize(headerFont) === headerZoomedSize)) {
          headerFont = headerFont.u2d(headerZoomedSize);
        }
        return getFontSize(headerFont);
      }
    }
    return 0.0;
  }
  toString() {
    return 'Overlay';
  }
}
class OverridingTreeMapColumnSettings$1 extends OverrideProperties {
  constructor(this$0) {
    super(this$0.c3x_1.properties, this$0.e3x_1);
  }
  uz(name, overrideDefaults, defaultProperty) {
    var property;
    if (equals('colormap', name)) {
      var tmp = new MutableColorMapOverrideProperty(overrideDefaults, isInterface(defaultProperty, MutableProperty) ? defaultProperty : THROW_CCE());
      property = tmp instanceof OverrideProperty ? tmp : THROW_CCE();
    } else {
      var tmp_0;
      var tmp_1 = defaultProperty.r2();
      if (!(tmp_1 == null) ? isInterface(tmp_1, Algorithm) : false) {
        tmp_0 = true;
      } else {
        tmp_0 = equals('algorithm', name);
      }
      if (tmp_0) {
        var tmp_2 = new MutableAlgorithmOverrideProperty(overrideDefaults, isInterface(defaultProperty, MutableProperty) ? defaultProperty : THROW_CCE());
        property = tmp_2 instanceof OverrideProperty ? tmp_2 : THROW_CCE();
      } else {
        property = protoOf(OverrideProperties).uz.call(this, name, overrideDefaults, defaultProperty);
      }
    }
    return property;
  }
}
class OverridingTreeMapColumnSettings extends AbstractTreeMapColumnSettings {
  constructor(defaultSettings) {
    super();
    this.c3x_1 = defaultSettings;
    this.e3x_1 = new SimpleProperty(true);
    var tmp = this;
    tmp.d3x_1 = new OverridingTreeMapColumnSettings$1(this);
  }
  f24() {
    return this.d3x_1;
  }
  isDefaults() {
    return false;
  }
  isOverrideDefaults() {
    return this.e3x_1.r2();
  }
  getOverrideDefaultsProperty() {
    return this.e3x_1;
  }
  setOverrideDefaults(overrideDefaults) {
    this.e3x_1.vo(overrideDefaults);
  }
  getAlgorithmProperty() {
    var tmp = this.d3x_1.tz('algorithm');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getAlgorithm() {
    return ensureNotNull(this.getAlgorithmProperty().r2());
  }
  setAlgorithm(algorithm) {
    this.setProperty('algorithm', algorithm);
  }
  getAggregationProperty() {
    var tmp = this.d3x_1.tz('aggregation');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getAggregation() {
    return this.getAggregationProperty().r2();
  }
  setAggregation(aggregation) {
    this.setProperty('aggregation', aggregation);
  }
  getScaleProperty() {
    var tmp = this.d3x_1.tz('scale');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getScale() {
    return this.getScaleProperty().r2();
  }
  setScale(scale) {
    this.setProperty('scale', scale);
  }
  getNestingProperty() {
    var tmp = this.d3x_1.tz('nesting');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getNesting() {
    return this.getNestingProperty().r2();
  }
  setNesting(nesting) {
    this.setProperty('nesting', nesting);
  }
  getOrderingProperty() {
    var tmp = this.d3x_1.tz('ordering');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getOrdering() {
    return ensureNotNull(this.getOrderingProperty().r2());
  }
  setOrdering(ordering) {
    this.setProperty('ordering', ordering);
  }
  getOrderingDirectionProperty() {
    var tmp = this.d3x_1.tz('orderingDirection');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getOrderingDirection() {
    return this.getOrderingDirectionProperty().r2();
  }
  setOrderingDirection(ordering) {
    this.setProperty('orderingDirection', ordering);
  }
  getOrderingVerticalVanishingPointProperty() {
    var tmp = this.d3x_1.tz('orderingVerticalVanishingPoint');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getOrderingVerticalVanishingPoint() {
    return this.getOrderingVerticalVanishingPointProperty().r2();
  }
  setOrderingVerticalVanishingPoint(verticalVanishingPoint) {
    this.setProperty('orderingVerticalVanishingPoint', verticalVanishingPoint);
  }
  getOrderingHorizontalVanishingPointProperty() {
    var tmp = this.d3x_1.tz('orderingHorizontalVanishingPoint');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getOrderingHorizontalVanishingPoint() {
    return this.getOrderingHorizontalVanishingPointProperty().r2();
  }
  setOrderingHorizontalVanishingPoint(horizontalVanishingPoint) {
    this.setProperty('orderingHorizontalVanishingPoint', horizontalVanishingPoint);
  }
  getLabelingProperty() {
    var tmp = this.d3x_1.tz('labeling');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getLabeling() {
    return this.getLabelingProperty().r2();
  }
  setLabeling(labeling) {
    this.setProperty('labeling', labeling);
  }
  getLabelingFontProperty() {
    var tmp = this.d3x_1.tz('labelingFont');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getLabelingFont() {
    return ensureNotNull(this.getLabelingFontProperty().r2());
  }
  setLabelingFont(font) {
    this.setProperty('labelingFont', font);
  }
  getLabelingForegroundProperty() {
    var tmp = this.d3x_1.tz('labelingForeground');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getLabelingForeground() {
    return ensureNotNull(this.getLabelingForegroundProperty().r2());
  }
  setLabelingForeground(color) {
    this.setProperty('labelingForeground', color);
  }
  getLabelingEffectColorProperty() {
    var tmp = this.d3x_1.tz('labelingEffectColor');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getLabelingEffectColor() {
    return this.getLabelingEffectColorProperty().r2();
  }
  setLabelingEffectColor(color) {
    this.setProperty('labelingEffectColor', color);
  }
  getLabelingEffectProperty() {
    var tmp = this.d3x_1.tz('labelingEffect');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getLabelingEffect() {
    return this.getLabelingEffectProperty().r2();
  }
  setLabelingEffect(effect) {
    this.setProperty('labelingEffect', effect);
  }
  getLabelingHorizontalAlignmentProperty() {
    var tmp = this.d3x_1.tz('labelingHorizontalAlignment');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getLabelingHorizontalAlignment() {
    return ensureNotNull(this.getLabelingHorizontalAlignmentProperty().r2());
  }
  setLabelingHorizontalAlignment(alignment) {
    this.setProperty('labelingHorizontalAlignment', alignment);
  }
  getLabelingVerticalAlignmentProperty() {
    var tmp = this.d3x_1.tz('labelingVerticalAlignment');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getLabelingVerticalAlignment() {
    return this.getLabelingVerticalAlignmentProperty().r2();
  }
  setLabelingVerticalAlignment(alignment) {
    this.setProperty('labelingVerticalAlignment', alignment);
  }
  getLabelingRenderingProperty() {
    var tmp = this.d3x_1.tz('labelingRendering');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getLabelingRendering() {
    return ensureNotNull(this.getLabelingRenderingProperty().r2());
  }
  setLabelingRendering(rendering) {
    this.setProperty('labelingRendering', rendering);
  }
  getLabelingMinimumCharactersToDisplayProperty() {
    var tmp = this.d3x_1.tz('labelingMinimumCharactersToDisplay');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getLabelingMinimumCharactersToDisplay() {
    return ensureNotNull(this.getLabelingMinimumCharactersToDisplayProperty().r2());
  }
  setLabelingMinimumCharactersToDisplay(minimumCharactersToDisplay) {
    this.setProperty('labelingMinimumCharactersToDisplay', minimumCharactersToDisplay);
  }
  getLabelingEffectOpacityProperty() {
    var tmp = this.d3x_1.tz('labelingEffectOpacity');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getLabelingEffectOpacity() {
    return this.getLabelingEffectOpacityProperty().r2();
  }
  setLabelingEffectOpacity(opacity) {
    this.setProperty('labelingEffectOpacity', opacity);
  }
  getLabelingShrinkTextToFitShapeProperty() {
    var tmp = this.d3x_1.tz('labelingShrinkTextToFitShape');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getLabelingShrinkTextToFitShape() {
    return ensureNotNull(this.getLabelingShrinkTextToFitShapeProperty().r2());
  }
  setLabelingShrinkTextToFitShape(labelingShrinkTextToFitShape) {
    this.setProperty('labelingShrinkTextToFitShape', labelingShrinkTextToFitShape);
  }
  getLabelingResizeTextToFitShapeProperty() {
    var tmp = this.d3x_1.tz('labelingResizeTextToFitShape');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getLabelingResizeTextToFitShape() {
    return ensureNotNull(this.getLabelingResizeTextToFitShapeProperty().r2());
  }
  setLabelingResizeTextToFitShape(labelingResizeTextToFitShape) {
    this.setProperty('labelingResizeTextToFitShape', labelingResizeTextToFitShape);
  }
  getLabelingFloatProperty() {
    var tmp = this.d3x_1.tz('labelingFloat');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getLabelingFloat() {
    return ensureNotNull(this.getLabelingFloatProperty().r2());
  }
  setLabelingFloat(labelingFloat) {
    this.setProperty('labelingFloat', labelingFloat);
  }
  getLabelingContrastEnhancementProperty() {
    var tmp = this.d3x_1.tz('labelingContrastEnhancement');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getLabelingContrastEnhancement() {
    return ensureNotNull(this.getLabelingContrastEnhancementProperty().r2());
  }
  setLabelingContrastEnhancement(contrastEnhancement) {
    this.setProperty('labelingContrastEnhancement', contrastEnhancement);
  }
  getNestingAmountProperty() {
    var tmp = this.d3x_1.tz('nestingAmount');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getNestingAmount() {
    return ensureNotNull(this.getNestingAmountProperty().r2());
  }
  setNestingAmount(amount) {
    this.setProperty('nestingAmount', amount);
  }
  getNestingBackgroundProperty() {
    var tmp = this.d3x_1.tz('nestingBackground');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getNestingBackground() {
    return ensureNotNull(this.getNestingBackgroundProperty().r2());
  }
  setNestingBackground(color) {
    this.setProperty('nestingBackground', color);
  }
  getHeaderFontProperty() {
    var tmp = this.d3x_1.tz('headerFont');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getHeaderFont() {
    return ensureNotNull(this.getHeaderFontProperty().r2());
  }
  setHeaderFont(font) {
    this.setProperty('headerFont', font);
  }
  getHeaderForegroundProperty() {
    var tmp = this.d3x_1.tz('headerForeground');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getHeaderForeground() {
    return ensureNotNull(this.getHeaderForegroundProperty().r2());
  }
  setHeaderForeground(color) {
    this.setProperty('headerForeground', color);
  }
  getHeaderBackgroundProperty() {
    var tmp = this.d3x_1.tz('headerBackground');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getHeaderBackground() {
    return ensureNotNull(this.getHeaderBackgroundProperty().r2());
  }
  setHeaderBackground(color) {
    this.setProperty('headerBackground', color);
  }
  getHeaderEffectColorProperty() {
    var tmp = this.d3x_1.tz('headerEffectColor');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getHeaderEffectColor() {
    return ensureNotNull(this.getHeaderEffectColorProperty().r2());
  }
  setHeaderEffectColor(color) {
    this.setProperty('headerEffectColor', color);
  }
  getHeaderEffectProperty() {
    var tmp = this.d3x_1.tz('headerEffect');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getHeaderEffect() {
    return this.getHeaderEffectProperty().r2();
  }
  setHeaderEffect(effect) {
    this.setProperty('headerEffect', effect);
  }
  getHeaderHorizontalAlignmentProperty() {
    var tmp = this.d3x_1.tz('headerHorizontalAlignment');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getHeaderHorizontalAlignment() {
    return this.getHeaderHorizontalAlignmentProperty().r2();
  }
  setHeaderHorizontalAlignment(alignment) {
    this.setProperty('headerHorizontalAlignment', alignment);
  }
  getHeaderVerticalAlignmentProperty() {
    var tmp = this.d3x_1.tz('headerVerticalAlignment');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getHeaderVerticalAlignment() {
    return this.getHeaderVerticalAlignmentProperty().r2();
  }
  setHeaderVerticalAlignment(alignment) {
    this.setProperty('headerVerticalAlignment', alignment);
  }
  getHeaderRenderingProperty() {
    var tmp = this.d3x_1.tz('headerRendering');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getHeaderRendering() {
    return this.getHeaderRenderingProperty().r2();
  }
  setHeaderRendering(rendering) {
    this.setProperty('headerRendering', rendering);
  }
  getHeaderMinimumCharactersToDisplayProperty() {
    var tmp = this.d3x_1.tz('headerMinimumCharactersToDisplay');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getHeaderMinimumCharactersToDisplay() {
    return this.getHeaderMinimumCharactersToDisplayProperty().r2();
  }
  setHeaderMinimumCharactersToDisplay(minimumCharactersToDisplay) {
    this.setProperty('headerMinimumCharactersToDisplay', minimumCharactersToDisplay);
  }
  getHeaderEffectOpacityProperty() {
    var tmp = this.d3x_1.tz('headerEffectOpacity');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getHeaderEffectOpacity() {
    return this.getHeaderEffectOpacityProperty().r2();
  }
  setHeaderEffectOpacity(opacity) {
    this.setProperty('headerEffectOpacity', opacity);
  }
  getHeaderInsetsProperty() {
    var tmp = this.d3x_1.tz('headerInsets');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getHeaderInsets() {
    return this.getHeaderInsetsProperty().r2();
  }
  setHeaderInsets(insets) {
    this.setProperty('headerInsets', insets);
  }
  getTooltipFontProperty() {
    var tmp = this.d3x_1.tz('tooltipFont');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getTooltipFont() {
    return ensureNotNull(this.getTooltipFontProperty().r2());
  }
  setTooltipFont(font) {
    this.setProperty('tooltipFont', font);
  }
  getTooltipForegroundProperty() {
    var tmp = this.d3x_1.tz('tooltipForeground');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getTooltipForeground() {
    return this.getTooltipForegroundProperty().r2();
  }
  setTooltipForeground(color) {
    this.setProperty('tooltipForeground', color);
  }
  getTooltipRenderingProperty() {
    var tmp = this.d3x_1.tz('tooltipRendering');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getTooltipRendering() {
    return this.getTooltipRenderingProperty().r2();
  }
  setTooltipRendering(rendering) {
    this.setProperty('tooltipRendering', rendering);
  }
  getBorderColorProperty() {
    var tmp = this.d3x_1.tz('borderColor');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getBorderColor() {
    return this.getBorderColorProperty().r2();
  }
  setBorderColor(color) {
    this.setProperty('borderColor', color);
  }
  getBorderThicknessInterval() {
    return null;
  }
  getBorderThicknessProperty() {
    var tmp = this.d3x_1.tz('borderThickness');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getBorderThickness() {
    return this.getBorderThicknessProperty().r2();
  }
  setBorderThickness(value) {
    this.setProperty('borderThickness', value);
  }
  getShowLabelProperty() {
    var tmp = this.d3x_1.tz('showLabel');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  getShowLabel() {
    return this.getShowLabelProperty().r2();
  }
  getFormatProperty() {
    var tmp = this.d3x_1.tz('format');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  setShowLabel(show) {
    this.setPropertyOverride('showLabel', show);
  }
  getFormat() {
    return this.getFormatProperty().r2();
  }
  getColorMapProperty() {
    var tmp = this.d3x_1.tz('colormap');
    return isInterface(tmp, MutableProperty) ? tmp : THROW_CCE();
  }
  setFormat(format) {
    this.setPropertyOverride('format', format);
  }
  getColorMap() {
    return this.getColorMapProperty().r2();
  }
  setColorMap(colorMap) {
    this.setPropertyOverride('colormap', colorMap);
  }
  getProperty(key) {
    return this.d3x_1.tz(key).r2();
  }
  getPropertyOverride(key) {
    return this.d3x_1.tz(key).i10();
  }
  setProperty(key, value) {
    this.d3x_1.tz(key).vo(value);
  }
  setPropertyOverride(key, value) {
    this.d3x_1.tz(key).vo(value);
  }
  reset() {
    var keys = ArrayList.e1();
    if (!this.e3x_1.r2()) {
      this.c3x_1.reset();
    } else {
      this.d3x_1.ix();
    }
  }
  get properties() {
    return this.f24();
  }
}
class ParentPreorderIterator {
  constructor(hierarchy, rootNode) {
    this.k3x_1 = hierarchy;
    var v = ArrayList.o7(1);
    v.o(rootNode);
    this.l3x_1 = ArrayList.e1();
    var tmp0 = this.l3x_1;
    // Inline function 'com.macrofocus.common.collection.push' call
    var item = v.x();
    tmp0.o(item);
  }
  y() {
    return !empty(this.l3x_1) && ensureNotNull(peek(this.l3x_1)).y();
  }
  z() {
    var enumer = ensureNotNull(peek(this.l3x_1));
    var node = enumer.z();
    var children = this.k3x_1.getChildrenOfTypeParent(node).x();
    if (!enumer.y()) {
      pop(this.l3x_1);
    }
    if (children.y()) {
      // Inline function 'com.macrofocus.common.collection.push' call
      this.l3x_1.o(children);
    }
    return node;
  }
  n5() {
    throw UnsupportedOperationException.h4();
  }
}
class ParentTreeMapNode extends AbstractTreeMapNode {
  constructor(name, model, groupByColumn, childrenGroupByColumn) {
    super(model);
    this.u3x_1 = name;
    this.v3x_1 = 1.0;
    this.w3x_1 = null;
    this.x3x_1 = null;
    this.y3x_1 = null;
    this.b3y_1 = null;
    this.c3y_1 = null;
    this.d3y_1 = null;
    this.z3x_1 = groupByColumn;
    this.a3y_1 = childrenGroupByColumn;
  }
  x32(_set____db54di) {
    this.v3x_1 = _set____db54di;
  }
  b33() {
    return this.v3x_1;
  }
  j33() {
    return this.z3x_1;
  }
  k33() {
    return !(this.a3y_1 == null) ? this.a3y_1 : this.f2y_1.settings.sizeColumn;
  }
  a33(value) {
    this.b3y_1 = value;
    super.a33(value);
  }
  f33() {
    return !(this.b3y_1 == null) ? this.b3y_1 : this.e33();
  }
  d34() {
    throw IllegalStateException.lc();
  }
  u33() {
    return !(this.w3x_1 == null) ? ensureNotNull(this.w3x_1).a1() : 0;
  }
  l32() {
    return this.w3x_1 == null;
  }
  w32() {
    return false;
  }
  x33() {
    return ensureNotNull(!(this.w3x_1 == null) ? this.w3x_1 : emptyList());
  }
  y33() {
    return ensureNotNull(!(this.x3x_1 == null) ? this.x3x_1 : emptyList());
  }
  z33(child) {
    if (this.w3x_1 == null) {
      this.w3x_1 = LinkedHashSet.d1();
    }
    var tmp;
    if (!(child instanceof LeafTreeMapNode)) {
      tmp = true;
    } else {
      tmp = !ensureNotNull(this.w3x_1).j2(child);
    }
    if (tmp) {
      ensureNotNull(this.w3x_1).o(child);
    }
    child.a34(this.k34());
    if (child instanceof ParentTreeMapNode) {
      if (this.x3x_1 == null) {
        this.x3x_1 = ArrayList.e1();
      }
      ensureNotNull(this.x3x_1).o(child);
      if (!(this.y3x_1 == null)) {
        var index = ensureNotNull(this.y3x_1).xk();
        if (!(index == null)) {
          // Inline function 'kotlin.collections.set' call
          var key = child.c34();
          index.i7(key, child);
        }
      }
    }
  }
  e3y() {
    var tmp;
    if (this.y3x_1 == null) {
      var index = this.m2m();
      this.y3x_1 = new SoftReference(index);
      tmp = index;
    } else {
      var index_0 = ensureNotNull(this.y3x_1).xk();
      if (index_0 == null) {
        index_0 = this.m2m();
        this.y3x_1 = new SoftReference(index_0);
      }
      tmp = index_0;
    }
    return tmp;
  }
  m2m() {
    var index = HashMap.d8();
    var _iterator__ex2g4s = ensureNotNull(this.w3x_1).x();
    while (_iterator__ex2g4s.y()) {
      var child = _iterator__ex2g4s.z();
      if (child instanceof ParentTreeMapNode) {
        // Inline function 'kotlin.collections.set' call
        var key = child.c34();
        index.i7(key, child);
      }
    }
    return index;
  }
  b34(name) {
    // Inline function 'kotlin.collections.get' call
    var this_0 = this.e3y();
    return (isInterface(this_0, KtMap) ? this_0 : THROW_CCE()).u2(name);
  }
  c34() {
    return this.u3x_1;
  }
}
class PieAlgorithm extends AbstractAlgorithm {
  x2o(shape, parent, children, sumSizes, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    var bounds = shape.y1l();
    var tmp0 = bounds.cm();
    // Inline function 'kotlin.math.min' call
    var b = bounds.dm();
    var size = Math.min(tmp0, b);
    var shiftX = (bounds.cm() - size) / 2;
    var shiftY = (bounds.dm() - size) / 2;
    bounds = Double_3.p1m(bounds.w1l() + shiftX, bounds.x1l() + shiftY, size, size);
    var startAngle = 90.0;
    var inductionVariable = 0;
    var last = children.length;
    while (inductionVariable < last) {
      var child = children[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      var arcAngle = accessor.getSize(child) * 360 / sumSizes;
      accessor.setShape(child, Double.j1p(bounds, startAngle, -arcAngle, 2));
      startAngle = startAngle - arcAngle;
    }
    return false;
  }
  y2o(shape) {
    var tmp;
    if (!(shape == null) ? isInterface(shape, Rectangle2D) : false) {
      tmp = true;
    } else {
      tmp = !(shape == null) ? isInterface(shape, Ellipse2D) : false;
    }
    return tmp;
  }
  toString() {
    return 'Pie';
  }
}
class SplitSize {
  f3y(children, accessor) {
    var index = 0;
    var ratio;
    var bestRatio = 0.0;
    var first = true;
    var leftSize = 0.0;
    var rightSize = this.g3y(children, 0, children.length - 1 | 0, accessor);
    var inductionVariable = 0;
    var last = children.length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var tmp0 = leftSize / rightSize;
        // Inline function 'kotlin.math.max' call
        var b = rightSize / leftSize;
        ratio = Math.max(tmp0, b);
        if (first || ratio < bestRatio) {
          first = false;
          bestRatio = ratio;
          index = i;
        }
        leftSize = leftSize + accessor.getSize(ensureNotNull(children[i]));
        rightSize = rightSize - accessor.getSize(ensureNotNull(children[i]));
      }
       while (inductionVariable <= last);
    return index;
  }
  g3y(children, start, end, accessor) {
    var sum = 0.0;
    var inductionVariable = start;
    if (inductionVariable <= end)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        sum = sum + accessor.getSize(ensureNotNull(children[i]));
      }
       while (!(i === end));
    return sum;
  }
  toString() {
    return 'Split Size';
  }
}
class PivotByAlgorithm extends AbstractAlgorithm {
  constructor(type) {
    type = type === VOID ? new SplitSize() : type;
    super();
    this.h3y_1 = type;
  }
  x2o(shape, parent, children, sumSizes, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    var bounds = shape.y1l();
    var area = bounds.cm() * bounds.dm();
    // Inline function 'kotlin.math.sqrt' call
    var x = area / sumSizes;
    var scaleFactor = Math.sqrt(x);
    var scaledBounds = Double_3.p1m(0.0, 0.0, bounds.cm() / scaleFactor, bounds.dm() / scaleFactor);
    var results = this.i3y(children, scaledBounds, accessor);
    var inductionVariable = 0;
    var last = children.length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var r = ensureNotNull(results[i]);
        accessor.setShape(children[i], Double_3.p1m(r.w1l() * scaleFactor + bounds.w1l(), r.x1l() * scaleFactor + bounds.x1l(), r.cm() * scaleFactor, r.dm() * scaleFactor));
      }
       while (inductionVariable <= last);
    return false;
  }
  i3y(children, bounds, accessor) {
    var aspectRatio = ensureNotNull(bounds).cm() / bounds.dm();
    var tmp;
    if (children.length === 1) {
      // Inline function 'kotlin.arrayOfNulls' call
      var rectangles = fillArrayVal(Array(1), null);
      rectangles[0] = bounds;
      tmp = rectangles;
    } else if (children.length === 2) {
      // Inline function 'kotlin.arrayOfNulls' call
      var rectangles_0 = fillArrayVal(Array(2), null);
      var ratio = accessor.getSize(ensureNotNull(children[0])) / (accessor.getSize(ensureNotNull(children[0])) + accessor.getSize(ensureNotNull(children[1])));
      if (aspectRatio >= 1) {
        var w = ratio * bounds.cm();
        rectangles_0[0] = Double_3.p1m(bounds.w1l(), bounds.x1l(), w, bounds.dm());
        rectangles_0[1] = Double_3.p1m(bounds.w1l() + w, bounds.x1l(), bounds.cm() - w, bounds.dm());
      } else {
        var h = ratio * bounds.dm();
        rectangles_0[0] = Double_3.p1m(bounds.w1l(), bounds.x1l(), bounds.cm(), h);
        rectangles_0[1] = Double_3.p1m(bounds.w1l(), bounds.x1l() + h, bounds.cm(), bounds.dm() - h);
      }
      tmp = rectangles_0;
    } else {
      var rp;
      var pivotIndex = this.h3y_1.f3y(children, accessor);
      var pivotSize = children[pivotIndex];
      var d = (children.length - pivotIndex | 0) - 1 | 0;
      var l1 = copyFromSize(children, 0, pivotIndex);
      var l1Size = this.w2o(l1, 0, l1.length - 1 | 0, accessor);
      var box2;
      var r1;
      if (aspectRatio >= 1) {
        var h_0 = bounds.dm();
        var w_0 = l1Size / h_0;
        r1 = Double_3.p1m(bounds.w1l(), bounds.x1l(), w_0, h_0);
        box2 = Double_3.p1m(r1.w1l() + r1.cm(), bounds.x1l(), bounds.cm() - r1.cm(), bounds.dm());
      } else {
        var w_1 = bounds.cm();
        var h_1 = l1Size / w_1;
        r1 = Double_3.p1m(bounds.w1l(), bounds.x1l(), w_1, h_1);
        box2 = Double_3.p1m(r1.w1l(), r1.x1l() + r1.dm(), bounds.cm(), bounds.dm() - r1.dm());
      }
      var l2 = null;
      var l3 = null;
      var r2 = null;
      var r3 = null;
      if (d >= 3) {
        var first = true;
        var bestAspectRatio = 0.0;
        var bestWidth = 0.0;
        var bestHeight = 0.0;
        var bestIndex = 0;
        var inductionVariable = pivotIndex + 1 | 0;
        var last = children.length;
        if (inductionVariable < last)
          do {
            var i = inductionVariable;
            inductionVariable = inductionVariable + 1 | 0;
            var l2Size = this.w2o(children, pivotIndex + 1 | 0, i, accessor);
            var l3Size = this.w2o(children, i + 1 | 0, children.length - 1 | 0, accessor);
            var ratio_0 = (accessor.getSize(ensureNotNull(pivotSize)) + l2Size) / (accessor.getSize(pivotSize) + l2Size + l3Size);
            var w_2;
            var h_2;
            if (aspectRatio >= 1) {
              w_2 = ratio_0 * box2.cm();
              ratio_0 = accessor.getSize(pivotSize) / (accessor.getSize(pivotSize) + l2Size);
              h_2 = ratio_0 * box2.dm();
            } else {
              h_2 = ratio_0 * box2.dm();
              ratio_0 = accessor.getSize(pivotSize) / (accessor.getSize(pivotSize) + l2Size);
              w_2 = ratio_0 * box2.cm();
            }
            var pivotAspectRatio = w_2 / h_2;
            if (first) {
              first = false;
              bestAspectRatio = pivotAspectRatio;
              bestWidth = w_2;
              bestHeight = h_2;
              bestIndex = i;
            } else {
              // Inline function 'kotlin.math.abs' call
              var x = pivotAspectRatio - 1;
              var tmp_0 = Math.abs(x);
              // Inline function 'kotlin.math.abs' call
              var x_0 = bestAspectRatio - 1;
              if (tmp_0 < Math.abs(x_0)) {
                bestAspectRatio = pivotAspectRatio;
                bestWidth = w_2;
                bestHeight = h_2;
                bestIndex = i;
              }
            }
          }
           while (inductionVariable < last);
        l2 = copyFromSize(children, pivotIndex + 1 | 0, bestIndex - pivotIndex | 0);
        if (((children.length - 1 | 0) - bestIndex | 0) > 0) {
          l3 = copyFromSize(children, bestIndex + 1 | 0, (children.length - 1 | 0) - bestIndex | 0);
        } else {
          l3 = null;
        }
        if (aspectRatio >= 1) {
          rp = Double_3.p1m(box2.w1l(), box2.x1l(), bestWidth, bestHeight);
          r2 = Double_3.p1m(box2.w1l(), box2.x1l() + bestHeight, bestWidth, box2.dm() - bestHeight);
          if (!(l3 == null)) {
            r3 = Double_3.p1m(box2.w1l() + bestWidth, box2.x1l(), box2.cm() - bestWidth, box2.dm());
          }
        } else {
          rp = Double_3.p1m(box2.w1l(), box2.x1l(), bestWidth, bestHeight);
          r2 = Double_3.p1m(box2.w1l() + bestWidth, box2.x1l(), box2.cm() - bestWidth, bestHeight);
          if (!(l3 == null)) {
            r3 = Double_3.p1m(box2.w1l(), box2.x1l() + bestHeight, box2.cm(), box2.dm() - bestHeight);
          }
        }
      } else if (d > 0) {
        l2 = copyFromSize(children, pivotIndex + 1 | 0, d);
        var ratio_1 = accessor.getSize(ensureNotNull(pivotSize)) / (accessor.getSize(pivotSize) + this.w2o(l2, 0, l2.length - 1 | 0, accessor));
        if (aspectRatio >= 1) {
          var h_3 = ratio_1 * box2.dm();
          rp = Double_3.p1m(box2.w1l(), box2.x1l(), box2.cm(), h_3);
          r2 = Double_3.p1m(box2.w1l(), box2.x1l() + h_3, box2.cm(), box2.dm() - h_3);
        } else {
          var w_3 = ratio_1 * box2.cm();
          rp = Double_3.p1m(box2.w1l(), box2.x1l(), w_3, box2.dm());
          r2 = Double_3.p1m(box2.w1l() + w_3, box2.x1l(), box2.cm() - w_3, box2.dm());
        }
      } else {
        rp = box2;
      }
      var l1rectangles;
      var l2rectangles;
      var l3rectangles;
      if (l1.length > 1) {
        l1rectangles = this.i3y(l1, r1, accessor);
      } else if (l1.length === 1) {
        // Inline function 'kotlin.arrayOfNulls' call
        l1rectangles = fillArrayVal(Array(1), null);
        l1rectangles[0] = r1;
      } else {
        l1rectangles = null;
      }
      if (!(l2 == null)) {
        if (l2.length > 1) {
          l2rectangles = this.i3y(l2, r2, accessor);
        } else if (l2.length === 1) {
          // Inline function 'kotlin.arrayOfNulls' call
          l2rectangles = fillArrayVal(Array(1), null);
          l2rectangles[0] = r2;
        } else {
          l2rectangles = null;
        }
      } else {
        l2rectangles = null;
      }
      if (!(l3 == null)) {
        if (l3.length > 1) {
          l3rectangles = this.i3y(l3, r3, accessor);
        } else if (l3.length === 1) {
          // Inline function 'kotlin.arrayOfNulls' call
          l3rectangles = fillArrayVal(Array(1), null);
          l3rectangles[0] = r3;
        } else {
          l3rectangles = null;
        }
      } else {
        l3rectangles = null;
      }
      var count = l1.length + 1 | 0;
      if (!(l2 == null)) {
        count = count + l2.length | 0;
      }
      if (!(l3 == null)) {
        count = count + l3.length | 0;
      }
      // Inline function 'kotlin.arrayOfNulls' call
      var size = count;
      var rectangles_1 = fillArrayVal(Array(size), null);
      var i_0 = 0;
      if (!(l1rectangles == null)) {
        arraycopy(l1rectangles, 0, rectangles_1, 0, l1rectangles.length);
        i_0 = l1rectangles.length;
      }
      rectangles_1[i_0] = rp;
      i_0 = i_0 + 1 | 0;
      if (!(l2rectangles == null)) {
        arraycopy(l2rectangles, 0, rectangles_1, i_0, l2rectangles.length);
        i_0 = i_0 + l2rectangles.length | 0;
      }
      if (!(l3rectangles == null)) {
        arraycopy(l3rectangles, 0, rectangles_1, i_0, l3rectangles.length);
      }
      var tmp_1;
      if (rectangles_1.length >= 3 && rectangles_1.length <= 5) {
        tmp_1 = this.j3y(children, bounds, rectangles_1, accessor);
      } else {
        tmp_1 = rectangles_1;
      }
      tmp = tmp_1;
    }
    return tmp;
  }
  j3y(children, bounds, rectangles, accessor) {
    var bestRectangles = rectangles;
    switch (children.length) {
      case 3:
        var newRectangles = tryLayout3(this, children, bounds, accessor);
        if (this.k3y(newRectangles) < this.k3y(bestRectangles)) {
          bestRectangles = newRectangles;
        }

        break;
      case 4:
        var newRectangles_0 = tryLayout4Quad(this, children, bounds, accessor);
        if (this.k3y(newRectangles_0) < this.k3y(bestRectangles)) {
          bestRectangles = newRectangles_0;
        }

        newRectangles_0 = tryLayout4Snake(this, children, bounds, accessor);
        if (this.k3y(newRectangles_0) < this.k3y(bestRectangles)) {
          bestRectangles = newRectangles_0;
        }

        break;
      case 5:
        var newRectangles_1 = tryLayout5(this, children, bounds, accessor);
        if (this.k3y(newRectangles_1) < this.k3y(bestRectangles)) {
          bestRectangles = newRectangles_1;
        }

        break;
    }
    return bestRectangles;
  }
  k3y(rectangles) {
    var sum = 0.0;
    var count = 0;
    var inductionVariable = 0;
    var last = rectangles.length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var width = ensureNotNull(rectangles[i]).cm();
        var height = ensureNotNull(rectangles[i]).dm();
        if (!(width === 0.0) && !(height === 0.0)) {
          var tmp0 = width / height;
          // Inline function 'kotlin.math.max' call
          var b = height / width;
          var aspectRatio = Math.max(tmp0, b);
          sum = sum + aspectRatio;
          count = count + 1 | 0;
        }
      }
       while (inductionVariable <= last);
    return sum / count;
  }
  y2o(shape) {
    return !(shape == null) ? isInterface(shape, Rectangle2D) : false;
  }
  x3d() {
    return 'Pivot by ' + toString_1(this.h3y_1);
  }
  toString() {
    return this.x3d();
  }
}
class PostorderIterator {
  constructor(hierarchy, rootNode) {
    this.m3y_1 = null;
    this.o3y_1 = hierarchy;
    this.l3y_1 = rootNode;
    var iterable = hierarchy.getChildren(ensureNotNull(this.l3y_1));
    this.m3y_1 = iterable.x();
    this.n3y_1 = emptyList().x();
  }
  y() {
    return !(this.l3y_1 == null);
  }
  z() {
    var retval;
    if (this.n3y_1.y()) {
      retval = this.n3y_1.z();
    } else if (ensureNotNull(this.m3y_1).y()) {
      this.n3y_1 = new PostorderIterator(this.o3y_1, ensureNotNull(this.m3y_1).z());
      retval = this.n3y_1.z();
    } else {
      retval = ensureNotNull(this.l3y_1);
      this.l3y_1 = null;
    }
    return retval;
  }
  n5() {
    throw UnsupportedOperationException.h4();
  }
}
class PreorderIterator {
  constructor(hierarchy, rootNode) {
    this.p3y_1 = hierarchy;
    var v = ArrayList.o7(1);
    v.o(rootNode);
    this.q3y_1 = ArrayList.e1();
    var tmp0 = this.q3y_1;
    // Inline function 'com.macrofocus.common.collection.push' call
    var item = v.x();
    tmp0.o(item);
  }
  y() {
    return !empty(this.q3y_1) && ensureNotNull(peek(this.q3y_1)).y();
  }
  z() {
    var enumer = ensureNotNull(peek(this.q3y_1));
    var node = enumer.z();
    var children = this.p3y_1.getChildren(node).x();
    if (!enumer.y()) {
      pop(this.q3y_1);
    }
    if (children.y()) {
      // Inline function 'com.macrofocus.common.collection.push' call
      this.q3y_1.o(children);
    }
    return node;
  }
  n5() {
    throw UnsupportedOperationException.h4();
  }
}
class Progressive extends Enum {}
class Type extends Enum {}
class Companion_89 {
  constructor() {
    Companion_instance_89 = this;
    this.r3y_1 = Type_EqualBorderWidth_getInstance();
  }
}
class ProportionalNesting extends AbstractNesting {
  constructor() {
    Companion_getInstance_89();
    super();
  }
  z2p(model, shape, node, amount) {
    var tmp;
    var tmp_0;
    if (!model.isRoot(node)) {
      tmp_0 = isInterface(shape, Rectangle2D);
    } else {
      tmp_0 = false;
    }
    if (tmp_0) {
      var rectangle = shape;
      var proportion = amount / 100;
      var tmp_1;
      switch (Companion_getInstance_89().r3y_1.z2_1) {
        case 0:
          var x = rectangle.w1l() + rectangle.cm() * proportion;
          var y = rectangle.x1l() + rectangle.dm() * proportion;
          var width = rectangle.cm() * (1.0 - 2 * proportion);
          var height = rectangle.dm() * (1.0 - 2 * proportion);
          tmp_1 = Double_3.p1m(x, y, width, height);
          break;
        case 1:
          var a = rectangle.cm() * rectangle.dm();
          var b = (1.0 - proportion) * a;
          var tmp_2 = rectangle.cm();
          // Inline function 'kotlin.math.sqrt' call

          var x_0 = b / a;
          var width_0 = tmp_2 * Math.sqrt(x_0);
          var tmp_3 = rectangle.dm();
          // Inline function 'kotlin.math.sqrt' call

          var x_1 = b / a;
          var height_0 = tmp_3 * Math.sqrt(x_1);
          var x_2 = rectangle.w1l() + (rectangle.cm() - width_0) / 2.0;
          var y_0 = rectangle.x1l() + (rectangle.dm() - height_0) / 2.0;
          var scaled = Double_3.p1m(x_2, y_0, width_0, height_0);
          tmp_1 = scaled;
          break;
        case 2:
          var a_0 = rectangle.cm() * rectangle.dm();
          var b_0 = (1.0 - proportion) * a_0;
          var w = rectangle.cm();
          var h = rectangle.dm();
          // Inline function 'kotlin.math.sqrt' call

          var x_3 = 4 * b_0 + h * h - 2 * h * w + w * w;
          var x_4 = (-Math.sqrt(x_3) + h + w) / 4;
          var scaled_0 = Double_3.p1m(rectangle.w1l() + x_4, rectangle.x1l() + x_4, rectangle.cm() - 2 * x_4, rectangle.dm() - 2 * x_4);
          tmp_1 = scaled_0;
          break;
        default:
          tmp_1 = shape;
          break;
      }
      tmp = tmp_1;
    } else {
      tmp = shape;
    }
    return tmp;
  }
  toString() {
    return 'Proportional';
  }
}
class Companion_90 {}
class RectangularTransform {
  static u2q() {
    var $this = createThis(this);
    init_com_treemap_RectangularTransform($this);
    return $this;
  }
  v2q(src) {
    return Double_3.p1m(src.w1l() * this.s2q_1 + this.q2q_1, src.x1l() * this.t2q_1 + this.r2q_1, src.cm() * this.s2q_1, src.dm() * this.t2q_1);
  }
  e1o(tx, ty) {
    this.q2q_1 = tx * this.s2q_1 + this.q2q_1;
    this.r2q_1 = ty * this.t2q_1 + this.r2q_1;
  }
}
class Companion_91 {
  constructor() {
    Companion_instance_91 = this;
    this.CUSHION = new CushionRendering();
    this.FLAT = new FlatRendering();
    this.FLAT_NO_BORDER = new FlatNoBorderRendering();
    this.instance = new RenderingFactory([this.FLAT, this.CUSHION, this.FLAT_NO_BORDER]);
  }
  s3y() {
    return this.CUSHION;
  }
  t3y() {
    return this.FLAT;
  }
  u3y() {
    return this.FLAT_NO_BORDER;
  }
  i26() {
    return this.instance;
  }
}
class RenderingFactory {
  constructor(entries) {
    Companion_getInstance_91();
    this.v3y_1 = ArrayList.e1();
    addAll(this.v3y_1, entries);
  }
  add(entry) {
    this.v3y_1.o(entry);
  }
  getDefault() {
    return Companion_getInstance_91().CUSHION;
  }
  getRenderings() {
    return this.v3y_1;
  }
  get(name) {
    var _iterator__ex2g4s = this.v3y_1.x();
    while (_iterator__ex2g4s.y()) {
      var rendering = _iterator__ex2g4s.z();
      if (equals(toString_1(rendering), name)) {
        return rendering;
      }
    }
    return this.getDefault();
  }
}
class Companion_92 {
  constructor() {
    Companion_instance_92 = this;
    this.w3h_1 = new OriginalScale();
    this.x3h_1 = new AbsScale();
    this.y3h_1 = new Exp10Scale();
    this.z3h_1 = new ExpScale();
    this.a3i_1 = new InverseScale();
    this.b3i_1 = new LogScale();
    this.c3i_1 = new Log1pScale();
    this.d3i_1 = new MinScale();
    this.e3i_1 = new MaxScale();
    this.f3i_1 = new XPlus1Scale();
    this.g3i_1 = new ScaleFactory([this.w3h_1, this.x3h_1, this.f3i_1, this.y3h_1, this.z3h_1, this.a3i_1, this.b3i_1, this.c3i_1, new NumericTransformScale(NumericTransform_PSEUDO_LOG_getInstance()), this.d3i_1, this.e3i_1, new NumericTransformScale(NumericTransform_SQRT_getInstance())]);
  }
}
class ScaleFactory {
  constructor(entries) {
    Companion_getInstance_92();
    this.h3i_1 = ArrayList.e1();
    addAll(this.h3i_1, entries);
  }
  i3i() {
    return Companion_getInstance_92().x3h_1;
  }
}
class SelectionNodeRenderer extends AbstractNodeRenderer {
  c2q(view) {
    var model = ensureNotNull(view.j2p());
    return model.highlighting.a13() || model.selection.a13();
  }
  b2q(view, root, pass) {
    var model = ensureNotNull(view.j2p());
    return Iterables_instance.qk([model.highlighting, model.selection]);
  }
  d2q(model) {
    return 1;
  }
  e2q(view, node) {
    var model = ensureNotNull(view.j2p());
    return model.hasNoChildren(node) && (model.highlighting.a13() && model.highlighting.b13(node) || (model.selection.a13() && model.selection.b13(node)));
  }
  f2q(g, view, node, pass, passes, bounds, shape) {
    var model = ensureNotNull(view.j2p());
    if (model.hasNoChildren(node)) {
      if (bounds.cm() > 0 && bounds.dm() > 0) {
        if (model.highlighting.a13() && model.highlighting.b13(node)) {
          g.w2q();
          g.a2r(model.settings.getProbingColor());
          g.z2q(2.0);
          g.b2r(view.l37(node));
          g.y2q();
        }
        if (model.selection.a13() && model.selection.b13(node)) {
          g.w2q();
          g.a2r(model.settings.getSelectionColor());
          g.z2q(1.0);
          g.b2r(view.l37(node));
          g.y2q();
        }
      }
    }
    return true;
  }
}
class DescendingTreeMapNodeComparator_1 {
  constructor(model) {
    this.w3y_1 = model;
  }
  k2q(a, b) {
    return compareTo(this.w3y_1.getSize(b), this.w3y_1.getSize(a));
  }
  compare(a, b) {
    var tmp = (a == null ? true : !(a == null)) ? a : THROW_CCE();
    return this.k2q(tmp, (b == null ? true : !(b == null)) ? b : THROW_CCE());
  }
}
class AscendingTreeMapNodeComparator_1 {
  constructor(model) {
    this.x3y_1 = model;
  }
  k2q(a, b) {
    return compareTo(this.x3y_1.getSize(a), this.x3y_1.getSize(b));
  }
  compare(a, b) {
    var tmp = (a == null ? true : !(a == null)) ? a : THROW_CCE();
    return this.k2q(tmp, (b == null ? true : !(b == null)) ? b : THROW_CCE());
  }
}
class SizeOrdering {
  y32(model, nodes, sortOrder) {
    // Inline function 'kotlin.collections.copyOf' call
    // Inline function 'kotlin.js.asDynamic' call
    var copy = nodes.slice();
    var comparator;
    var tmp;
    switch (sortOrder.z2_1) {
      case 0:
        tmp = new AscendingTreeMapNodeComparator_1(model);
        break;
      case 1:
        tmp = new DescendingTreeMapNodeComparator_1(model);
        break;
      default:
        noWhenBranchMatchedException();
        break;
    }
    comparator = tmp;
    sortWith(copy, comparator);
    return copy;
  }
  toString() {
    return 'By size';
  }
}
class SumAggregation_0 {
  m32(values) {
    var sum = null;
    var inductionVariable = 0;
    var last = values.length;
    while (inductionVariable < last) {
      var value = values[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      if (!isInfinite(value) && !isNaN_0(value)) {
        if (!(sum == null)) {
          sum = sum + value;
        } else {
          sum = value;
        }
      }
    }
    return sum;
  }
  l33() {
    return false;
  }
  toString() {
    return 'Sum';
  }
}
class SizeWeightedAggregation extends SumAggregation_0 {
  l33() {
    return true;
  }
  toString() {
    return 'Size-Weighted';
  }
}
class AlternateOrientationStrategy {
  y3y(bounds, parent, accessor) {
    return ((accessor.getLevel(parent) + 1 | 0) % 2 | 0) === 0;
  }
}
class SliceAndDiceAlgorithm extends AbstractAlgorithm {
  constructor(orientationStrategy) {
    orientationStrategy = orientationStrategy === VOID ? new AlternateOrientationStrategy() : orientationStrategy;
    super();
    this.z3y_1 = orientationStrategy;
  }
  x2o(shape, parent, children, sumSizes, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    var bounds = shape.y1l();
    var sumShares = 0.0;
    var inductionVariable = 0;
    var last = children.length;
    while (inductionVariable < last) {
      var child = children[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      var r;
      var share = accessor.getSize(child) / sumSizes;
      var tmp;
      if (this.z3y_1.y3y(bounds, parent, accessor)) {
        tmp = Double_3.p1m(bounds.w1l(), bounds.x1l() + bounds.dm() * sumShares, bounds.cm(), bounds.dm() * share);
      } else {
        tmp = Double_3.p1m(bounds.w1l() + bounds.cm() * sumShares, bounds.x1l(), bounds.cm() * share, bounds.dm());
      }
      r = tmp;
      accessor.setShape(child, r);
      sumShares = sumShares + share;
    }
    return false;
  }
  y2o(shape) {
    return !(shape == null) ? isInterface(shape, Rectangle2D) : false;
  }
  x3d() {
    return 'Slice-and-dice';
  }
  toString() {
    return this.x3d();
  }
}
class Companion_93 {}
class SplitAlgorithm extends AbstractAlgorithm {
  x2o(shape, parent, children, sumSizes, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    var bounds = shape.y1l();
    var items = ArrayList.e1();
    var inductionVariable = 0;
    var last = children.length;
    while (inductionVariable < last) {
      var child = children[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      items.o(child);
    }
    splitLayout(this, items, bounds, accessor);
    return false;
  }
  y2o(shape) {
    return !(shape == null) ? isInterface(shape, Rectangle2D) : false;
  }
  toString() {
    return getName_0(Companion_instance_93);
  }
}
class Companion_94 {
  constructor() {
    this.c3z_1 = 'desiredAspectRatio';
  }
}
class SquarifiedAlgorithm extends AbstractAlgorithm {
  constructor() {
    super();
    this.a3z_1 = new SimpleProperties();
    this.b3z_1 = this.a3z_1.vy('desiredAspectRatio', 1.0);
  }
  f24() {
    return this.a3z_1;
  }
  x2o(shape, parent, children, sumSize, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    var bounds = shape.y1l();
    var hvp = horizontalVanishingPoint === 0 ? 4 : horizontalVanishingPoint;
    var vvp = verticalVanishingPoint === 0 ? 3 : verticalVanishingPoint;
    var sizeFactor = bounds.cm() * bounds.dm() / sumSize;
    var current = 0;
    while (current < children.length) {
      var last = current;
      var totalArea = 0.0;
      var previousWorstAspectRatio = Infinity;
      var desiredSize = 0.0;
      var horizontalSplit = bounds.cm() > bounds.dm() * this.b3z_1.r2();
      var shortestSide = horizontalSplit ? bounds.dm() : bounds.cm();
      $l$loop: while (last < children.length) {
        var lastArea = accessor.getSize(children[last]) * sizeFactor;
        totalArea = totalArea + lastArea;
        desiredSize = totalArea / shortestSide;
        var currentArea = accessor.getSize(children[current]) * sizeFactor;
        var lastWorstAspectRatio = computeAspectRatio(this, lastArea, desiredSize);
        var currentWorstAspectRatio = computeAspectRatio(this, currentArea, desiredSize);
        var worstAspectRatio;
        var tmp;
        if (!isInfinite(currentWorstAspectRatio)) {
          // Inline function 'kotlin.math.max' call
          tmp = Math.max(currentWorstAspectRatio, lastWorstAspectRatio);
        } else {
          tmp = lastWorstAspectRatio;
        }
        worstAspectRatio = tmp;
        if (worstAspectRatio > previousWorstAspectRatio) {
          totalArea = totalArea - lastArea;
          desiredSize = totalArea / shortestSide;
          last = last - 1 | 0;
          break $l$loop;
        }
        if (!isNaN_0(worstAspectRatio)) {
          previousWorstAspectRatio = worstAspectRatio;
        }
        last = last + 1 | 0;
      }
      if (last === children.length) {
        last = last - 1 | 0;
      }
      // Inline function 'kotlin.run' call
      // Inline function 'com.treemap.SquarifiedAlgorithm.breadthFirstLayout.<anonymous>' call
      var x = bounds.w1l();
      var y = bounds.x1l();
      var inductionVariable = current;
      var last_0 = last;
      if (inductionVariable <= last_0)
        do {
          var i = inductionVariable;
          inductionVariable = inductionVariable + 1 | 0;
          var size = accessor.getSize(children[i]) * sizeFactor / desiredSize;
          if (accessor.getSize(children[i]) === 1.0) {
            println(toString_0(children[i]) + ': ' + size + ', ' + accessor.getSize(children[i]) + ', ' + sizeFactor + ', ' + desiredSize);
          }
          if (horizontalSplit) {
            switch (hvp) {
              case 2:
                accessor.setShape(children[i], Double_3.p1m(x + bounds.cm() - desiredSize, y, desiredSize, size));
                break;
              case 4:
                accessor.setShape(children[i], Double_3.p1m(x, y, desiredSize, size));
                break;
              default:
                throw IllegalArgumentException.qc();
            }
            y = y + size;
          } else {
            switch (vvp) {
              case 1:
                switch (hvp) {
                  case 2:
                    accessor.setShape(children[i], Double_3.p1m(x + bounds.cm() - size, y + bounds.dm() - desiredSize, size, desiredSize));
                    x = x - size;
                    break;
                  case 4:
                    accessor.setShape(children[i], Double_3.p1m(x, y + bounds.dm() - desiredSize, size, desiredSize));
                    x = x + size;
                    break;
                  default:
                    throw IllegalArgumentException.qc();
                }

                break;
              case 3:
                switch (hvp) {
                  case 2:
                    accessor.setShape(children[i], Double_3.p1m(x + bounds.cm() - size, y, size, desiredSize));
                    x = x - size;
                    break;
                  case 4:
                    accessor.setShape(children[i], Double_3.p1m(x, y, size, desiredSize));
                    x = x + size;
                    break;
                  default:
                    throw IllegalArgumentException.qc();
                }

                break;
              default:
                throw IllegalArgumentException.qc();
            }
          }
        }
         while (!(i === last_0));
      current = last + 1 | 0;
      if (horizontalSplit) {
        var tmp_0;
        switch (hvp) {
          case 2:
            var tmp_1 = bounds.w1l();
            var tmp_2 = bounds.x1l();
            // Inline function 'kotlin.math.max' call

            var b = bounds.cm() - desiredSize;
            var tmp$ret$2 = Math.max(0.0, b);
            tmp_0 = Double_3.p1m(tmp_1, tmp_2, tmp$ret$2, bounds.dm());
            break;
          case 4:
            var tmp_3 = bounds.w1l() + desiredSize;
            var tmp_4 = bounds.x1l();
            // Inline function 'kotlin.math.max' call

            var b_0 = bounds.cm() - desiredSize;
            var tmp$ret$3 = Math.max(0.0, b_0);
            tmp_0 = Double_3.p1m(tmp_3, tmp_4, tmp$ret$3, bounds.dm());
            break;
          default:
            throw IllegalArgumentException.qc();
        }
        bounds = tmp_0;
        if (horizontalVanishingPoint === 0) {
          hvp = hvp === 2 ? 4 : 2;
        }
      } else {
        var tmp_5;
        switch (vvp) {
          case 1:
            var tmp_6 = bounds.w1l();
            var tmp_7 = bounds.x1l();
            var tmp_8 = bounds.cm();
            // Inline function 'kotlin.math.max' call

            var b_1 = bounds.dm() - desiredSize;
            var tmp$ret$4 = Math.max(0.0, b_1);
            tmp_5 = Double_3.p1m(tmp_6, tmp_7, tmp_8, tmp$ret$4);
            break;
          case 3:
            var tmp_9 = bounds.w1l();
            var tmp_10 = bounds.x1l() + desiredSize;
            var tmp_11 = bounds.cm();
            // Inline function 'kotlin.math.max' call

            var b_2 = bounds.dm() - desiredSize;
            var tmp$ret$5 = Math.max(0.0, b_2);
            tmp_5 = Double_3.p1m(tmp_9, tmp_10, tmp_11, tmp$ret$5);
            break;
          default:
            throw IllegalArgumentException.qc();
        }
        bounds = tmp_5;
        if (verticalVanishingPoint === 0) {
          vvp = vvp === 3 ? 1 : 3;
        }
      }
    }
    return false;
  }
  y2o(shape) {
    return !(shape == null) ? isInterface(shape, Rectangle2D) : false;
  }
  toString() {
    return getName_1(Companion_instance_94);
  }
}
class Companion_95 {}
class SquarifiedPlusAlgorithm extends AbstractAlgorithm {
  constructor() {
    super();
    this.d3z_1 = new SimpleProperties();
    this.e3z_1 = this.d3z_1.vy('desiredAspectRatio', 1.0);
  }
  f24() {
    return this.d3z_1;
  }
  x2o(shape, parent, children, sumSize, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    var bounds = shape.y1l();
    var hvp = horizontalVanishingPoint === 0 ? 4 : horizontalVanishingPoint;
    var vvp = verticalVanishingPoint === 0 ? 3 : verticalVanishingPoint;
    var sizeFactor = bounds.cm() * bounds.dm() / sumSize;
    var current = 0;
    while (current < children.length) {
      var last = current;
      var totalArea = 0.0;
      var previousWorstAspectRatio = Infinity;
      var desiredSize = 0.0;
      var horizontalSplit = bounds.cm() > bounds.dm() * this.e3z_1.r2();
      var shortestSide = horizontalSplit ? bounds.dm() : bounds.cm();
      var longestSide = horizontalSplit ? bounds.cm() : bounds.dm();
      $l$loop: while (last < children.length) {
        var lastArea = accessor.getSize(children[last]) * sizeFactor;
        totalArea = totalArea + lastArea;
        desiredSize = totalArea / shortestSide;
        var currentArea = accessor.getSize(children[current]) * sizeFactor;
        var lastWorstAspectRatio = computeAspectRatio_0(this, lastArea, desiredSize);
        var currentWorstAspectRatio = computeAspectRatio_0(this, currentArea, desiredSize);
        var worstAspectRatio;
        var tmp;
        if (!isInfinite(currentWorstAspectRatio)) {
          // Inline function 'kotlin.math.max' call
          tmp = Math.max(currentWorstAspectRatio, lastWorstAspectRatio);
        } else {
          tmp = lastWorstAspectRatio;
        }
        worstAspectRatio = tmp;
        if (worstAspectRatio > previousWorstAspectRatio) {
          totalArea = totalArea - lastArea;
          desiredSize = totalArea / shortestSide;
          last = last - 1 | 0;
          // Inline function 'kotlin.run' call
          // Inline function 'com.treemap.SquarifiedPlusAlgorithm.breadthFirstLayout.<anonymous>' call
          var alternativeDesiredSize = totalArea / longestSide;
          var actualAR = bestAspectRatio(this, children, current, last, desiredSize, sizeFactor, accessor);
          var alternativeAR = bestAspectRatio(this, children, current, last, alternativeDesiredSize, sizeFactor, accessor);
          if (willImprove(this, actualAR, alternativeAR)) {
            desiredSize = alternativeDesiredSize;
            horizontalSplit = !horizontalSplit;
          }
          break $l$loop;
        }
        if (!isNaN_0(worstAspectRatio)) {
          previousWorstAspectRatio = worstAspectRatio;
        }
        last = last + 1 | 0;
      }
      if (last === children.length) {
        last = last - 1 | 0;
      }
      // Inline function 'kotlin.run' call
      // Inline function 'com.treemap.SquarifiedPlusAlgorithm.breadthFirstLayout.<anonymous>' call
      var x = bounds.w1l();
      var y = bounds.x1l();
      var inductionVariable = current;
      var last_0 = last;
      if (inductionVariable <= last_0)
        do {
          var i = inductionVariable;
          inductionVariable = inductionVariable + 1 | 0;
          var size = accessor.getSize(children[i]) * sizeFactor / desiredSize;
          if (horizontalSplit) {
            var tmp0_subject = hvp;
            if (tmp0_subject === 2) {
              accessor.setShape(children[i], Double_3.p1m(x + bounds.cm() - desiredSize, y, desiredSize, size));
            } else if (tmp0_subject === 4) {
              accessor.setShape(children[i], Double_3.p1m(x, y, desiredSize, size));
            }
            y = y + size;
          } else {
            switch (vvp) {
              case 1:
                switch (hvp) {
                  case 2:
                    accessor.setShape(children[i], Double_3.p1m(x + bounds.cm() - size, y + bounds.dm() - desiredSize, size, desiredSize));
                    x = x - size;
                    break;
                  case 4:
                    accessor.setShape(children[i], Double_3.p1m(x, y + bounds.dm() - desiredSize, size, desiredSize));
                    x = x + size;
                    break;
                  default:
                    throw IllegalArgumentException.qc();
                }

                break;
              case 3:
                switch (hvp) {
                  case 2:
                    accessor.setShape(children[i], Double_3.p1m(x + bounds.cm() - size, y, size, desiredSize));
                    x = x - size;
                    break;
                  case 4:
                    accessor.setShape(children[i], Double_3.p1m(x, y, size, desiredSize));
                    x = x + size;
                    break;
                  default:
                    throw IllegalArgumentException.qc();
                }

                break;
              default:
                throw IllegalArgumentException.qc();
            }
          }
        }
         while (!(i === last_0));
      current = last + 1 | 0;
      if (horizontalSplit) {
        var tmp_0;
        switch (hvp) {
          case 2:
            var tmp_1 = bounds.w1l();
            var tmp_2 = bounds.x1l();
            // Inline function 'kotlin.math.max' call

            var b = bounds.cm() - desiredSize;
            var tmp$ret$3 = Math.max(0.0, b);
            tmp_0 = Double_3.p1m(tmp_1, tmp_2, tmp$ret$3, bounds.dm());
            break;
          case 4:
            var tmp_3 = bounds.w1l() + desiredSize;
            var tmp_4 = bounds.x1l();
            // Inline function 'kotlin.math.max' call

            var b_0 = bounds.cm() - desiredSize;
            var tmp$ret$4 = Math.max(0.0, b_0);
            tmp_0 = Double_3.p1m(tmp_3, tmp_4, tmp$ret$4, bounds.dm());
            break;
          default:
            throw IllegalArgumentException.qc();
        }
        bounds = tmp_0;
        if (horizontalVanishingPoint === 0) {
          hvp = hvp === 2 ? 4 : 2;
        }
      } else {
        var tmp_5;
        switch (vvp) {
          case 1:
            var tmp_6 = bounds.w1l();
            var tmp_7 = bounds.x1l();
            var tmp_8 = bounds.cm();
            // Inline function 'kotlin.math.max' call

            var b_1 = bounds.dm() - desiredSize;
            var tmp$ret$5 = Math.max(0.0, b_1);
            tmp_5 = Double_3.p1m(tmp_6, tmp_7, tmp_8, tmp$ret$5);
            break;
          case 3:
            var tmp_9 = bounds.w1l();
            var tmp_10 = bounds.x1l() + desiredSize;
            var tmp_11 = bounds.cm();
            // Inline function 'kotlin.math.max' call

            var b_2 = bounds.dm() - desiredSize;
            var tmp$ret$6 = Math.max(0.0, b_2);
            tmp_5 = Double_3.p1m(tmp_9, tmp_10, tmp_11, tmp$ret$6);
            break;
          default:
            throw IllegalArgumentException.qc();
        }
        bounds = tmp_5;
        if (verticalVanishingPoint === 0) {
          vvp = vvp === 3 ? 1 : 3;
        }
      }
    }
    return false;
  }
  y2o(shape) {
    return !(shape == null) ? isInterface(shape, Rectangle2D) : false;
  }
  toString() {
    return getName_2(Companion_instance_95);
  }
}
class StdDevAggregation {
  m32(values) {
    var count = 0;
    var sum = 0.0;
    var inductionVariable = 0;
    var last = values.length;
    while (inductionVariable < last) {
      var value = values[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      if (!isInfinite(value) && !isNaN_0(value)) {
        count = count + 1 | 0;
        sum = sum + value;
      }
    }
    var tmp;
    if (count < 2) {
      tmp = 0.0;
    } else {
      var average = sum / count;
      var stddev = 0.0;
      var inductionVariable_0 = 0;
      var last_0 = values.length;
      while (inductionVariable_0 < last_0) {
        var value_0 = values[inductionVariable_0];
        inductionVariable_0 = inductionVariable_0 + 1 | 0;
        if (!isInfinite(value_0) && !isNaN_0(value_0)) {
          var tmp_0 = stddev;
          // Inline function 'kotlin.math.pow' call
          var this_0 = value_0 - average;
          stddev = tmp_0 + Math.pow(this_0, 2.0);
        }
      }
      // Inline function 'kotlin.math.sqrt' call
      var x = stddev / count;
      tmp = Math.sqrt(x);
    }
    return tmp;
  }
  l33() {
    return false;
  }
  toString() {
    return 'StdDev';
  }
}
class StripAlgorithm extends AbstractAlgorithm {
  constructor(lookAhead) {
    lookAhead = lookAhead === VOID ? true : lookAhead;
    super();
    this.f3z_1 = lookAhead;
  }
  x2o(shape, parent, children, sumSizes, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    var bounds = shape.y1l();
    var area = bounds.cm() * bounds.dm();
    // Inline function 'kotlin.math.sqrt' call
    var x = area / sumSizes;
    var scaleFactor = Math.sqrt(x);
    var scaledBounds = Double_3.p1m(bounds.w1l() / scaleFactor, bounds.x1l() / scaleFactor, bounds.cm() / scaleFactor, bounds.dm() / scaleFactor);
    var finishedIndex = 0;
    var count;
    var yOffset = 0.0;
    while (finishedIndex < children.length) {
      count = this.g3z(children, scaledBounds, finishedIndex, accessor);
      if (this.f3z_1) {
        if ((finishedIndex + count | 0) < children.length) {
          var countSecondStrip = this.g3z(children, scaledBounds, finishedIndex + count | 0, accessor);
          var aspectRatioFirstPlusSecond = this.h3z(children, finishedIndex, count + countSecondStrip | 0, accessor);
          this.i3z(children, scaledBounds, finishedIndex, count + countSecondStrip | 0, accessor);
          var aspectRatioTogether = this.h3z(children, finishedIndex, count + countSecondStrip | 0, accessor);
          if (aspectRatioTogether < aspectRatioFirstPlusSecond) {
            count = count + countSecondStrip | 0;
          } else {
            this.i3z(children, scaledBounds, finishedIndex, count, accessor);
          }
        }
      }
      var inductionVariable = finishedIndex;
      var last = finishedIndex + count | 0;
      if (inductionVariable < last)
        do {
          var i = inductionVariable;
          inductionVariable = inductionVariable + 1 | 0;
          var child = children[i];
          var rectangle = accessor.getBounds(child);
          accessor.setShape(child, Double_3.p1m(rectangle.w1l(), rectangle.x1l() + yOffset, rectangle.cm(), rectangle.dm()));
        }
         while (inductionVariable < last);
      var height = accessor.getBounds(children[finishedIndex]).dm();
      yOffset = yOffset + height;
      scaledBounds = Double_3.p1m(scaledBounds.w1l(), scaledBounds.x1l() + height, scaledBounds.cm(), scaledBounds.dm() - height);
      finishedIndex = finishedIndex + count | 0;
    }
    var inductionVariable_0 = 0;
    var last_0 = children.length;
    while (inductionVariable_0 < last_0) {
      var child_0 = children[inductionVariable_0];
      inductionVariable_0 = inductionVariable_0 + 1 | 0;
      var childBounds = accessor.getBounds(child_0);
      accessor.setShape(child_0, Double_3.p1m(childBounds.w1l() * scaleFactor + bounds.w1l(), childBounds.x1l() * scaleFactor + bounds.x1l(), childBounds.cm() * scaleFactor, childBounds.dm() * scaleFactor));
    }
    return false;
  }
  g3z(children, box, index, accessor) {
    var count = 0;
    var previousAspectRatio;
    var aspectRatio = 1.7976931348623157E308;
    do {
      previousAspectRatio = aspectRatio;
      count = count + 1 | 0;
      this.i3z(children, box, index, count, accessor);
      aspectRatio = this.h3z(children, index, count, accessor);
    }
     while (aspectRatio < previousAspectRatio && (index + count | 0) < children.length);
    if (aspectRatio >= previousAspectRatio) {
      count = count - 1 | 0;
      this.i3z(children, box, index, count, accessor);
    }
    return count;
  }
  i3z(children, box, index, numItems, accessor) {
    var totalSize = this.w2o(children, index, (index + numItems | 0) - 1 | 0, accessor);
    var height = totalSize / box.cm();
    var x = 0.0;
    var inductionVariable = 0;
    if (inductionVariable < numItems)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var child = children[i + index | 0];
        var width = accessor.getSize(child) / height;
        accessor.setShape(child, Double_3.p1m(x, 0.0, width, height));
        x = x + width;
      }
       while (inductionVariable < numItems);
  }
  h3z(children, index, count, accessor) {
    var sum = 0.0;
    var inductionVariable = 0;
    if (inductionVariable < count)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var child = children[i + index | 0];
        var width = accessor.getBounds(child).cm();
        var height = accessor.getBounds(child).dm();
        var tmp0 = width / height;
        // Inline function 'kotlin.math.max' call
        var b = height / width;
        var aspectRatio = Math.max(tmp0, b);
        sum = sum + aspectRatio;
      }
       while (inductionVariable < count);
    return sum / count;
  }
  y2o(shape) {
    return !(shape == null) ? isInterface(shape, Rectangle2D) : false;
  }
  x3d() {
    return 'Strip';
  }
  toString() {
    return this.x3d();
  }
}
class Arc extends Double_1 {
  static v3z(x, y, startAngle, arcAngle, outerRadius, innerRadius, stripRadius) {
    var $this = this.j1z(1, 20);
    $this.o3z_1 = x;
    $this.p3z_1 = y;
    $this.q3z_1 = startAngle;
    $this.r3z_1 = arcAngle;
    $this.s3z_1 = outerRadius;
    $this.t3z_1 = innerRadius;
    $this.u3z_1 = stripRadius;
    var segAngle_a;
    var segAngle_b;
    var theta_a;
    var theta_b;
    var angle;
    var angleMid;
    var segs;
    var ax;
    var ay;
    var bx;
    var _by;
    var cx;
    var cy;
    var dx;
    var dy;
    _by = 0.0;
    bx = _by;
    // Inline function 'kotlin.math.abs' call
    var x_0 = $this.r3z_1;
    if (Math.abs(x_0) > 360) {
      $this.r3z_1 = 360.0;
    }
    // Inline function 'kotlin.math.abs' call
    var x_1 = $this.r3z_1;
    // Inline function 'kotlin.math.ceil' call
    var x_2 = Math.abs(x_1) / 45;
    segs = Math.ceil(x_2);
    segAngle_a = $this.r3z_1 / segs;
    segAngle_b = -$this.r3z_1 / segs;
    theta_a = -(segAngle_a / 180) * 3.141592653589793;
    theta_b = -(segAngle_b / 180) * 3.141592653589793;
    angle = -($this.q3z_1 / 180) * 3.141592653589793;
    if (segs > 0) {
      // Inline function 'kotlin.math.sin' call
      var x_3 = -$this.q3z_1 / 180 * 3.141592653589793;
      var tmp$ret$3 = Math.sin(x_3);
      ax = $this.o3z_1 + tmp$ret$3 * $this.s3z_1;
      // Inline function 'kotlin.math.cos' call
      var x_4 = $this.q3z_1 / 180 * 3.141592653589793;
      var tmp$ret$4 = Math.cos(x_4);
      ay = $this.p3z_1 + tmp$ret$4 * $this.s3z_1;
      $this.c20(ax, ay);
      var i = 0;
      while (i < segs) {
        angle = angle + theta_a;
        angleMid = angle - theta_a / 2;
        // Inline function 'kotlin.math.sin' call
        var x_5 = angle;
        var tmp$ret$5 = Math.sin(x_5);
        bx = $this.o3z_1 + tmp$ret$5 * $this.s3z_1;
        // Inline function 'kotlin.math.cos' call
        var x_6 = angle;
        var tmp$ret$6 = Math.cos(x_6);
        _by = $this.p3z_1 + tmp$ret$6 * $this.s3z_1;
        // Inline function 'kotlin.math.sin' call
        var x_7 = angleMid;
        var tmp = Math.sin(x_7);
        // Inline function 'kotlin.math.cos' call
        var x_8 = theta_a / 2;
        var tmp$ret$8 = Math.cos(x_8);
        cx = $this.o3z_1 + tmp * ($this.s3z_1 / tmp$ret$8);
        // Inline function 'kotlin.math.cos' call
        var x_9 = angleMid;
        var tmp_0 = Math.cos(x_9);
        // Inline function 'kotlin.math.cos' call
        var x_10 = theta_a / 2;
        var tmp$ret$10 = Math.cos(x_10);
        cy = $this.p3z_1 + tmp_0 * ($this.s3z_1 / tmp$ret$10);
        $this.e20(cx, cy, bx, _by);
        i = i + 1 | 0;
      }
      $this.q3z_1 = $this.q3z_1 + $this.r3z_1;
      angle = -($this.q3z_1 / 180) * 3.141592653589793;
      // Inline function 'kotlin.math.sin' call
      var x_11 = -$this.q3z_1 / 180 * 3.141592653589793;
      var tmp$ret$11 = Math.sin(x_11);
      dx = $this.o3z_1 + tmp$ret$11 * $this.t3z_1;
      // Inline function 'kotlin.math.cos' call
      var x_12 = $this.q3z_1 / 180 * 3.141592653589793;
      var tmp$ret$12 = Math.cos(x_12);
      dy = $this.p3z_1 + tmp$ret$12 * $this.t3z_1;
      if ($this.r3z_1 < 360) {
        $this.d20(dx, dy);
      } else {
        $this.c20(dx, dy);
      }
      if ($this.t3z_1 > 0) {
        var i_0 = 0;
        while (i_0 < segs) {
          angle = angle + theta_b;
          angleMid = angle - theta_b / 2;
          // Inline function 'kotlin.math.sin' call
          var x_13 = angle;
          var tmp$ret$13 = Math.sin(x_13);
          bx = $this.o3z_1 + tmp$ret$13 * $this.t3z_1;
          // Inline function 'kotlin.math.cos' call
          var x_14 = angle;
          var tmp$ret$14 = Math.cos(x_14);
          _by = $this.p3z_1 + tmp$ret$14 * $this.t3z_1;
          // Inline function 'kotlin.math.sin' call
          var x_15 = angleMid;
          var tmp_1 = Math.sin(x_15);
          // Inline function 'kotlin.math.cos' call
          var x_16 = theta_b / 2;
          var tmp$ret$16 = Math.cos(x_16);
          cx = $this.o3z_1 + tmp_1 * ($this.t3z_1 / tmp$ret$16);
          // Inline function 'kotlin.math.cos' call
          var x_17 = angleMid;
          var tmp_2 = Math.cos(x_17);
          // Inline function 'kotlin.math.cos' call
          var x_18 = theta_b / 2;
          var tmp$ret$18 = Math.cos(x_18);
          cy = $this.p3z_1 + tmp_2 * ($this.t3z_1 / tmp$ret$18);
          $this.e20(cx, cy, bx, _by);
          i_0 = i_0 + 1 | 0;
        }
      }
      if ($this.r3z_1 < 360) {
        $this.d20(ax, ay);
      }
    }
    return $this;
  }
}
class SunburstAlgorithm extends AbstractAlgorithm {
  constructor() {
    super();
    this.w3z_1 = 0;
  }
  q2o(bounds, model, root, worker) {
    super.q2o(bounds, model, root, worker);
    this.w3z_1 = getMaxDepthToLeaf_0(this, model, root) - model.getLevel(root) | 0;
  }
  x2o(shape, parent, children, sumSizes, horizontalVanishingPoint, verticalVanishingPoint, accessor, worker) {
    var centerX;
    var centerY;
    var startAngle;
    var arcAngle;
    var outerRadius;
    var innerRadius;
    var stripeRadius;
    if (shape instanceof Arc) {
      var arc = shape;
      centerX = arc.o3z_1;
      centerY = arc.p3z_1;
      startAngle = arc.q3z_1;
      arcAngle = arc.r3z_1;
      outerRadius = arc.s3z_1;
      innerRadius = arc.t3z_1 + arc.u3z_1;
      stripeRadius = arc.u3z_1;
    } else {
      var bounds = shape.y1l();
      var tmp0 = bounds.cm();
      // Inline function 'kotlin.math.min' call
      var b = bounds.dm();
      var size = Math.min(tmp0, b);
      var shiftX = (bounds.cm() - size) / 2;
      var shiftY = (bounds.dm() - size) / 2;
      bounds = Double_3.p1m(bounds.w1l() + shiftX, bounds.x1l() + shiftY, size, size);
      centerX = bounds.a1m();
      centerY = bounds.c1m();
      startAngle = 180.0;
      arcAngle = 360.0;
      stripeRadius = size / this.w3z_1 / 2;
      outerRadius = size / 2;
      innerRadius = 0.0;
    }
    var currentSize = 0.0;
    var inductionVariable = 0;
    var last = children.length;
    while (inductionVariable < last) {
      var child = children[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      var s = startAngle + currentSize * arcAngle / sumSizes;
      var a = accessor.getSize(child) * arcAngle / sumSizes;
      accessor.setShape(child, Arc.v3z(centerX, centerY, s, a, outerRadius, innerRadius, stripeRadius));
      currentSize = currentSize + accessor.getSize(child);
    }
    return false;
  }
  s2o() {
    return false;
  }
  t2o() {
    return false;
  }
  u2o() {
    return true;
  }
  v2o() {
    return false;
  }
  y2o(shape) {
    var tmp;
    var tmp_0;
    if (!(shape == null) ? isInterface(shape, Rectangle2D) : false) {
      tmp_0 = true;
    } else {
      tmp_0 = !(shape == null) ? isInterface(shape, Ellipse2D) : false;
    }
    if (tmp_0) {
      tmp = true;
    } else {
      tmp = shape instanceof Arc;
    }
    return tmp;
  }
  toString() {
    return 'Sunburst';
  }
}
class Companion_96 {
  constructor() {
    this.x3z_1 = 5.0;
  }
}
class TextParentNodeRenderer extends AbstractNodeRenderer {
  c2q(view) {
    return true;
  }
  d2q(model) {
    var heightColumn = model.settings.heightColumn;
    var tmp;
    if (!(heightColumn == null) && (model.isNumericType(heightColumn) || model.isTemporalType(heightColumn))) {
      tmp = 2;
    } else {
      tmp = 1;
    }
    return tmp;
  }
  e2q(view, node) {
    var model = ensureNotNull(view.j2p());
    return !model.isRoot(node) && !model.hasNoChildren(node);
  }
  f2q(g, view, node, pass, passes, bounds, shape) {
    if (bounds.cm() > 0 && bounds.dm() > 0) {
      g.w2q();
      g.x2q(bounds);
      var model = ensureNotNull(view.j2p());
      var algorithm = model.settings.getColumnSettings(model.getGroupByColumn(ensureNotNull(model.getParent(node)))).getAlgorithm();
      if (algorithm.t2o()) {
        ensureNotNull(model.settings.getColumnSettings(model.getGroupByColumn(node)).getLabeling()).x2p(g, bounds, node, view, pass, passes);
      }
      g.y2q();
    }
    return true;
  }
}
class ThresholdDepth {
  constructor(_max) {
    this.z3z_1 = _max;
  }
  p2q(depth) {
    return depth <= this.z3z_1;
  }
  toString() {
    return this.z3z_1.toString();
  }
}
class Companion_97 {
  constructor() {
    this.a40_1 = 2;
    this.b40_1 = 1;
  }
}
class ToolTipTreeMapRenderer {
  constructor() {
    this.v36_1 = EnhancedLabel.z23();
    this.v36_1.setInsets(Companion_getInstance_81().j3t_1.j22_1, Companion_getInstance_81().j3t_1.k22_1, Companion_getInstance_81().j3t_1.l22_1, Companion_getInstance_81().j3t_1.m22_1);
  }
  d37(g, view, node, width, leftShift, topShift, progress) {
    var model = ensureNotNull(view.j2p());
    if (!(node == null)) {
      var shape = view.l37(ensureNotNull(model.currentRoot));
      if (!(shape == null)) {
        this.w36(g, view, model, node, width, leftShift, topShift, true);
      }
    }
  }
  w36(g, view, model, node, width, leftShift, topShift, paint) {
    var labelColumn = model.settings.toolTipColumns;
    var tmp;
    if (!(labelColumn == null) && labelColumn.a1() >= 0) {
      var height = 0;
      var _iterator__ex2g4s = labelColumn.x();
      while (_iterator__ex2g4s.y()) {
        var column = _iterator__ex2g4s.z();
        if (!(column == null)) {
          var valueLabel = ensureNotNull(view.q3c()).k3t(view, column, node, Dimension.bm(width, 1000));
          if (!(valueLabel == null)) {
            var font = ensureNotNull(model.settings.getColumnSettings(column).getTooltipFont());
            var boldFont = font.w2d(Weight_BOLD_getInstance());
            valueLabel.setFont(boldFont);
            valueLabel.setForeground(ensureNotNull(model.settings.getColumnSettings(column).getTooltipForeground()));
            valueLabel.setBackground(null);
            var valueWidth = (width - 2 | 0) - 1 | 0;
            var labelSize;
            if (ensureNotNull(model.settings.getColumnSettings(column).getShowLabel()) && model.settings.getColumnSettings(column).getTooltipRendering() === Rendering_WordWrap_getInstance()) {
              this.v36_1.setFont(font);
              this.v36_1.setForeground(ensureNotNull(model.settings.getColumnSettings(column).getTooltipForeground()));
              this.v36_1.setBackground(null);
              this.v36_1.setText(plus(model.getColumnName(column), ': '));
              labelSize = view.l3c().y3z(this.v36_1, g, valueWidth, 1000).s2p();
            } else {
              labelSize = Dimension.bm(0, 0);
            }
            var pf = view.l3c().y3z(valueLabel, g, valueWidth - labelSize.yl_1 | 0, 1000);
            height = height + numberToInt(pf.v2p()) | 0;
          }
        }
      }
      var bounds = Rectangle.from(0, 0, width, height);
      if (height <= 0) {
        return null;
      }
      var top = bounds.r20_1;
      var _iterator__ex2g4s_0 = labelColumn.x();
      $l$loop: while (_iterator__ex2g4s_0.y()) {
        var column_0 = _iterator__ex2g4s_0.z();
        if (!(column_0 == null)) {
          var valueLabel_0 = ensureNotNull(view.q3c()).k3t(view, column_0, node, Dimension.bm(width, 1000));
          if (!(valueLabel_0 == null)) {
            var font_0 = ensureNotNull(model.settings.getColumnSettings(column_0).getTooltipFont());
            var boldFont_0 = font_0.w2d(Weight_BOLD_getInstance());
            valueLabel_0.setFont(boldFont_0);
            valueLabel_0.setForeground(ensureNotNull(model.settings.getColumnSettings(column_0).getTooltipForeground()));
            valueLabel_0.setBackground(null);
            var valueWidth_0 = (bounds.s20_1 - 2 | 0) - 1 | 0;
            var labelSize_0;
            if (ensureNotNull(model.settings.getColumnSettings(column_0).getShowLabel())) {
              this.v36_1.setFont(font_0);
              this.v36_1.setForeground(ensureNotNull(model.settings.getColumnSettings(column_0).getTooltipForeground()));
              this.v36_1.setBackground(null);
              this.v36_1.setText(toString_0(model.getColumnName(column_0)) + ': ');
              labelSize_0 = view.l3c().y3z(this.v36_1, g, valueWidth_0, 1000).s2p();
            } else {
              labelSize_0 = Dimension.bm(0, 0);
            }
            var pf_0 = view.l3c().y3z(valueLabel_0, g, valueWidth_0 - labelSize_0.yl_1 | 0, 1000);
            var valueSize = pf_0.s2p();
            if (top + valueSize.dm() <= bounds.x1l() + bounds.dm()) {
              var x = bounds.q20_1 + 2 | 0;
              if (ensureNotNull(model.settings.getColumnSettings(column_0).getShowLabel())) {
                var rect = Rectangle.from(x, top, labelSize_0.yl_1, labelSize_0.zl_1);
                if (paint && !(g == null)) {
                  g.w2p(this.v36_1, rect.q20_1, rect.r20_1, rect.s20_1, rect.t20_1);
                }
                if (model.isNumericType(column_0)) {
                  x = x + labelSize_0.yl_1 | 0;
                  valueWidth_0 = valueWidth_0 - labelSize_0.yl_1 | 0;
                } else {
                  x = x + labelSize_0.yl_1 | 0;
                  valueWidth_0 = valueWidth_0 - labelSize_0.yl_1 | 0;
                }
              }
              var rect_0 = Rectangle.from(x, top, valueWidth_0, valueSize.zl_1);
              if (paint && !(g == null)) {
                g.w2p(valueLabel_0, rect_0.q20_1, rect_0.r20_1, rect_0.s20_1, rect_0.t20_1);
              }
              top = top + valueSize.zl_1 | 0;
            } else {
              break $l$loop;
            }
          }
        }
      }
      tmp = bounds;
    } else {
      tmp = null;
    }
    return tmp;
  }
}
class TreeMapEvent {
  constructor(isGroupByChanged, isLayoutChanged, isColorsChanged) {
    this.z38_1 = isGroupByChanged;
    this.a39_1 = isLayoutChanged;
    this.b39_1 = isColorsChanged;
  }
  toString() {
    return 'TreeMapEvent{groupByChanged=' + this.z38_1 + ', layoutChanged=' + this.a39_1 + ', colorsChanged=' + this.b39_1 + toString(_Char___init__impl__6a9atx(125));
  }
}
class TreeMapSettingsEvent {
  constructor(updateGroupBy, updateLayout, updateColors) {
    this.z2z_1 = updateGroupBy;
    this.a30_1 = updateLayout;
    this.b30_1 = updateColors;
  }
  g30() {
    return this.z2z_1;
  }
  e30() {
    return this.a30_1;
  }
  c30() {
    return this.b30_1;
  }
  toString() {
    return 'TreeMapSettingsEvent{updateGroupBy=' + this.z2z_1 + ', updateLayout=' + this.a30_1 + ', updateColors=' + this.b30_1 + toString(_Char___init__impl__6a9atx(125));
  }
}
class ToolTipType extends Enum {}
class XPlus1Scale {
  o2o(value, min, max) {
    return value + 1;
  }
  toString() {
    return 'x + 1';
  }
}
class DataFrameColorMapFactory {
  l3o(factory, dataFrame, column, min, max) {
    var tmp;
    if (!(min == null) && !(max == null)) {
      tmp = factory.g1g(min, max);
    } else {
      tmp = this.m3o(factory, dataFrame, column);
    }
    return tmp;
  }
  m3o(factory, dataFrame, column) {
    var tmp;
    if (!(dataFrame == null) && !(column == null)) {
      var values = SortedSet.uk(new UniversalComparator());
      var valueCount = 0;
      var _iterator__ex2g4s = dataFrame.p2h().x();
      while (_iterator__ex2g4s.y()) {
        var row = _iterator__ex2g4s.z();
        var value = dataFrame.y2j(row, column);
        var tmp_0;
        if (!(value == null)) {
          tmp_0 = !(value == null) ? isComparable(value) : false;
        } else {
          tmp_0 = false;
        }
        if (tmp_0) {
          values.o(value);
          valueCount = valueCount + 1 | 0;
        }
      }
      if (valueCount === 0) {
        values = LinkedHashSet.d1();
        var _iterator__ex2g4s_0 = dataFrame.p2h().x();
        while (_iterator__ex2g4s_0.y()) {
          var row_0 = _iterator__ex2g4s_0.z();
          var value_0 = dataFrame.y2j(row_0, column);
          if (!(value_0 == null)) {
            values.o(value_0);
            valueCount = valueCount + 1 | 0;
          }
        }
      }
      tmp = factory.e1g(values);
    } else {
      tmp = factory.e1g(emptySet());
    }
    return tmp;
  }
}
class Companion_98 {
  constructor() {
    this.c40_1 = 5.0;
    this.d40_1 = 5;
  }
}
class AbstractTGraphics {
  constructor() {
    this.e40_1 = null;
  }
  r2p(elabel, pf, font, bounds, scaleFactor, expand) {
    var height;
    var size;
    var maxFontSize = this.f40(elabel, font, ensureNotNull(elabel).getDesiredWidth()) * scaleFactor;
    var fontSize = maxFontSize;
    var scaledFont = ensureNotNull(elabel.getFont()).u2d(fontSize);
    elabel.setFont(scaledFont);
    size = ensureNotNull(pf).s2p();
    height = size.dm() - elabel.getInsetTop() - elabel.getInsetBottom();
    var i = 0;
    $l$loop_1: while (height > elabel.getDesiredHeight() && i < 5) {
      i = i + 1 | 0;
      // Inline function 'kotlin.math.sqrt' call
      var x = elabel.getDesiredHeight() / height;
      var scale = Math.sqrt(x);
      var newFontSize = getFontSize(ensureNotNull(elabel.getFont())) * scale;
      if (newFontSize > maxFontSize) {
        newFontSize = maxFontSize;
      }
      fontSize = newFontSize;
      var oldFontSize = getFontSize(ensureNotNull(elabel.getFont()));
      scaledFont = ensureNotNull(elabel.getFont()).u2d(fontSize);
      if (getFontSize(scaledFont) === oldFontSize) {
        break $l$loop_1;
      }
      elabel.setFont(scaledFont);
      if (fontSize < 5.0) {
        break $l$loop_1;
      }
      var newSize = pf.s2p();
      size = newSize;
      height = size.dm() - elabel.getInsetTop() - elabel.getInsetBottom();
    }
    return fontSize;
  }
  f40(elabel, font, maxWidth) {
    this.h3h(ensureNotNull(font));
    var words = split(ensureNotNull(ensureNotNull(elabel).getText()), [' ']);
    var width = 0.0;
    var longest = null;
    var _iterator__ex2g4s = words.x();
    while (_iterator__ex2g4s.y()) {
      var word = _iterator__ex2g4s.z();
      var preferredWidth = this.g40(word);
      if (preferredWidth > width) {
        longest = word;
        width = preferredWidth;
      }
    }
    var maxFontSize;
    var fontSize = getFontSize(font) * maxWidth / width;
    maxFontSize = fontSize;
    return maxFontSize;
  }
  z3g(img, x, y, w, h, width, height, bounds, shape) {
    this.w2q();
    this.x2q(shape);
    var b = this.c3h(img, x, y, w, h);
    this.y2q();
    return b;
  }
  x3w(shape) {
    if (!(shape == null) ? isInterface(shape, Rectangle2D) : false) {
      this.e40_1 = shape.v1l();
    }
  }
  y3w(bounds) {
    return this.e40_1 == null || ensureNotNull(this.e40_1).b1m(ensureNotNull(bounds));
  }
}
class SingleSelectionSettingsCoordinator$1 {
  constructor($property, $selection, this$0) {
    this.h40_1 = $property;
    this.i40_1 = $selection;
    this.j40_1 = this$0;
  }
  k30(name, event) {
    if (this.h40_1 === name) {
      this.i40_1.f13(this.j40_1.xk());
    }
  }
  zx(name, event) {
    return this.k30((name == null ? true : typeof name === 'string') ? name : THROW_CCE(), event);
  }
}
class SingleSelectionSettingsCoordinator$2 {
  constructor(this$0) {
    this.k40_1 = this$0;
  }
  l40(event) {
    this.k40_1.y3o(event.y14_1.v13());
  }
  t13(event) {
    return this.l40(event);
  }
}
class JsTreeMap extends DefaultTreeMap {
  constructor(elementId, model) {
    return new.target.p40(elementId, model);
  }
  static p40(elementId, model) {
    var $this = this.p3h(model);
    var root = createRoot(ensureNotNull(document.getElementById(elementId)));
    var tmp = get_TreeMapComponent();
    root.render(create(tmp, JsTreeMap$lambda(model)));
    return $this;
  }
  get component() {
    return this.r2r();
  }
  get view() {
    return this.l2r();
  }
  set view(value) {
    this.h2r(value);
  }
  get controller() {
    return this.p2r();
  }
  set controller(value) {
    this.m2r(value);
  }
  get model() {
    return this.j2p();
  }
  set model(value) {
    this.q2r(value);
  }
}
class CanvasRenderingContext2DIGraphics extends AbstractIGraphics {
  constructor(gc) {
    super();
    this.s40_1 = gc;
  }
  g22(color) {
    var javaScriptColor = color.m1e();
    this.s40_1.fillStyle = javaScriptColor;
    this.s40_1.strokeStyle = javaScriptColor;
  }
  h22() {
    this.s40_1.beginPath();
  }
  c20(x, y) {
    this.s40_1.moveTo(x, y);
  }
  d20(x, y) {
    this.s40_1.lineTo(x, y);
  }
  g20() {
    this.s40_1.closePath();
  }
  i22() {
    this.s40_1.fill();
  }
}
class CanvasRenderingContext2DTGraphics$sizeLabel$1 {
  constructor(this$0, $label, $width) {
    this.e41_1 = this$0;
    this.f41_1 = $label;
    this.g41_1 = $width;
  }
  v2p() {
    var tmp;
    if (this.f41_1.getRendering().z2_1 === 2) {
      this.e41_1.u40_1.font = ensureNotNull(this.f41_1.getFont()).toString();
      tmp = paintWordWrapText(this.e41_1, this.e41_1, this.f41_1, this.f41_1.getText(), this.g41_1, 0, 0, ensureNotNull(this.f41_1.getForeground()), ensureNotNull(this.f41_1.getBackground()), false).dm();
    } else {
      tmp = this.e41_1.d41(this.f41_1);
    }
    return tmp;
  }
  s2p() {
    this.e41_1.u40_1.font = ensureNotNull(this.f41_1.getFont()).toString();
    return this.f41_1.getRendering().z2_1 === 2 ? paintWordWrapText(this.e41_1, this.e41_1, this.f41_1, this.f41_1.getText(), this.g41_1, 0, 0, ensureNotNull(this.f41_1.getForeground()), ensureNotNull(this.f41_1.getBackground()), false) : Dimension.bm(numberToInt(this.e41_1.u40_1.measureText(ensureNotNull(this.f41_1.getText())).width), this.e41_1.d41(this.f41_1));
  }
}
class CanvasRenderingContext2DTGraphics extends AbstractTGraphics {
  constructor(gc) {
    super();
    this.u40_1 = gc;
    this.v40_1 = Companion_getInstance_54().a1g_1;
    this.y40_1 = new CPFont('SansSerif', 12.0);
    this.z40_1 = AffineTransform.z1n();
    this.a41_1 = this.v40_1.f2c();
    this.w40_1 = this.v40_1.f2c();
    this.b41_1 = new Float64Array(6);
    this.x40_1 = 0.5;
  }
  q30() {
    return this.v40_1;
  }
  h3h(_set____db54di) {
    this.y40_1 = _set____db54di;
  }
  w2p(label, x, y, w, h) {
    var y_0 = y;
    if (label.isOpaque) {
      this.u40_1.fillStyle = ensureNotNull(label.getBackground()).m1e();
      this.u40_1.fillRect(x, y_0, w, h);
    }
    var text = label.getText();
    if (!(text == null)) {
      // Inline function 'web.canvas.CanvasTextBaseline.Companion.alphabetic' call
      var tmp$ret$0 = 'alphabetic';
      this.u40_1.textBaseline = tmp$ret$0;
      this.u40_1.font = ensureNotNull(label.getFont()).toString();
      var javaScriptColor = ensureNotNull(label.getForeground()).m1e();
      this.u40_1.fillStyle = javaScriptColor;
      if (label.getRendering().z2_1 === 2) {
        if (!(label.getVerticalAlignment() === 1)) {
          var d = this.q2p(label, w, h).s2p();
          switch (label.getVerticalAlignment()) {
            case 0:
              y_0 = y_0 + numberToInt((h - d.dm()) / 2) | 0;
              break;
            case 3:
              y_0 = y_0 + numberToInt(h - d.dm()) | 0;
              break;
            default:
              break;
          }
        }
        paintWordWrapText(this, this, label, label.getText(), w, x, y_0, ensureNotNull(label.getForeground()), ensureNotNull(label.getBackground()), true);
      } else {
        if (!(label.getMinimumCharactersToDisplay() == null)) {
          var minimumCharactersToDisplay = ensureNotNull(label.getMinimumCharactersToDisplay());
          if (text.length > minimumCharactersToDisplay) {
            // Inline function 'kotlin.text.substring' call
            // Inline function 'kotlin.js.asDynamic' call
            var s = text.substring(0, minimumCharactersToDisplay);
            var textMetrics = this.u40_1.measureText(s);
            if (!(textMetrics == null)) {
              var width = textMetrics.width;
              if (width > ((w - label.getInsetLeft() | 0) - label.getInsetRight() | 0)) {
                return Unit_instance;
              }
            }
          }
        }
        this.c41(label, x, y_0, w, text);
      }
    }
  }
  c41(label, x, y, w, text) {
    switch (label.getHorizontalAlignment()) {
      case 10:
      case 2:
        // Inline function 'web.canvas.CanvasTextAlign.Companion.left' call

        this.u40_1.textAlign = 'left';
        this.u40_1.fillText(text, x + label.getInsetLeft() | 0, (y + label.getInsetTop() | 0) + this.h41(label) | 0);
        break;
      case 11:
      case 4:
        // Inline function 'web.canvas.CanvasTextAlign.Companion.right' call

        this.u40_1.textAlign = 'right';
        this.u40_1.fillText(text, (x + w | 0) - label.getInsetRight() | 0, (y + label.getInsetTop() | 0) + this.h41(label) | 0);
        break;
      case 0:
        // Inline function 'web.canvas.CanvasTextAlign.Companion.left' call

        this.u40_1.textAlign = 'left';
        // Inline function 'kotlin.math.max' call

        var b = (((w - label.getInsetLeft() | 0) - label.getInsetRight() | 0) - this.u40_1.measureText(text).width) / 2;
        var width = Math.max(0.0, b);
        this.u40_1.fillText(text, x + width + label.getInsetLeft(), (y + label.getInsetTop() | 0) + this.h41(label) | 0);
        break;
    }
  }
  q2p(label, width, height) {
    return new CanvasRenderingContext2DTGraphics$sizeLabel$1(this, label, width);
  }
  h41(label) {
    return imul_0(3, this.d41(label)) / 4 | 0;
  }
  d41(label) {
    return numberToInt(ensureNotNull(label.getFont()).v2d() * 100 / 96 * 130 / 100);
  }
  w2q() {
    this.u40_1.save();
  }
  y2q() {
    this.u40_1.restore();
  }
  c3v(alpha) {
    this.u40_1.globalAlpha = alpha;
  }
  n2q(c) {
    this.u40_1.fillStyle = ensureNotNull(c).m1e();
  }
  a2r(c) {
    this.u40_1.strokeStyle = ensureNotNull(c).m1e();
  }
  s3u(c) {
    this.w40_1 = ensureNotNull(c);
    var javaScriptColor = this.w40_1.m1e();
    this.u40_1.fillStyle = javaScriptColor;
    this.u40_1.strokeStyle = javaScriptColor;
  }
  z2q(lw) {
    this.u40_1.lineWidth = lw;
  }
  r3u(dashPattern) {
    this.u40_1.setLineDash(toTypedArray(ensureNotNull(dashPattern)));
  }
  b3h(bilinear) {
  }
  a3h() {
    return false;
  }
  c37(antialias) {
  }
  b2r(s) {
    if (s instanceof Rectangle) {
      this.u40_1.strokeRect(s.w1l(), s.x1l(), s.cm(), s.dm());
    } else {
      if (!(s == null) ? isInterface(s, Rectangle2D) : false) {
        this.u40_1.strokeRect(s.w1l(), s.x1l(), s.cm(), s.dm());
      } else {
        this.i41(ensureNotNull(s));
        this.u40_1.stroke();
      }
    }
  }
  i41(s) {
    this.u40_1.beginPath();
    var iterator = s.e1m(null);
    while (!iterator.b17()) {
      var segType = iterator.i1q(this.b41_1);
      switch (segType) {
        case 0:
          this.u40_1.moveTo(this.b41_1[0], this.b41_1[1]);
          break;
        case 1:
          this.u40_1.lineTo(this.b41_1[0], this.b41_1[1]);
          break;
        case 2:
          this.u40_1.quadraticCurveTo(this.b41_1[0], this.b41_1[1], this.b41_1[2], this.b41_1[3]);
          break;
        case 3:
          this.u40_1.bezierCurveTo(this.b41_1[0], this.b41_1[1], this.b41_1[2], this.b41_1[3], this.b41_1[4], this.b41_1[5]);
          break;
        case 4:
          this.u40_1.closePath();
          break;
        default:
          throw RuntimeException.ja('Unrecognised segment type ' + segType);
      }
      iterator.h1q();
    }
  }
  o2q(s) {
    if (s instanceof Rectangle) {
      this.u40_1.fillRect(s.w1l(), s.x1l(), s.cm(), s.dm());
    } else {
      if (!(s == null) ? isInterface(s, Rectangle2D) : false) {
        this.u40_1.fillRect(s.w1l(), s.x1l(), s.cm(), s.dm());
      } else {
        this.i41(ensureNotNull(s));
        this.u40_1.fill();
      }
    }
  }
  g40(text) {
    return this.u40_1.measureText(ensureNotNull(text)).width;
  }
  i3h(str, x, y) {
    if (str == null) {
      throw NullPointerException.rd("Null 'str' argument.");
    } else {
      this.u40_1.fillText(str, x, y);
    }
  }
  e1o(tx, ty) {
    ensureNotNull(this.z40_1).e1o(tx, ty);
    this.u40_1.translate(tx, ty);
  }
  j41(t) {
    var tx = ensureNotNull(this.z40_1);
    tx.h1o(ensureNotNull(t));
    this.k41(tx);
  }
  applyTransform(t) {
    return this.j41(t);
  }
  k41(t) {
    var t_0 = t;
    if (t_0 == null) {
      this.z40_1 = AffineTransform.z1n();
      t_0 = this.z40_1;
    } else {
      this.z40_1 = AffineTransform.a1o(t_0);
    }
    this.u40_1.setTransform(ensureNotNull(t_0).w1m_1, t_0.x1m_1, t_0.y1m_1, t_0.z1m_1, t_0.a1n_1, t_0.b1n_1);
  }
  x2q(s) {
    if (!(s == null) ? isInterface(s, Rectangle2D) : false) {
      var r = s;
      this.u40_1.beginPath();
      // Inline function 'kotlin.math.floor' call
      var x = r.w1l();
      var tmp = Math.floor(x);
      // Inline function 'kotlin.math.floor' call
      var x_0 = r.x1l();
      var tmp_0 = Math.floor(x_0);
      // Inline function 'kotlin.math.ceil' call
      var x_1 = r.cm();
      var tmp_1 = Math.ceil(x_1);
      // Inline function 'kotlin.math.ceil' call
      var x_2 = r.dm();
      var tmp$ret$3 = Math.ceil(x_2);
      this.u40_1.rect(tmp, tmp_0, tmp_1, tmp$ret$3);
    } else {
      this.i41(ensureNotNull(s));
    }
    this.u40_1.clip();
  }
  g3h(x1, y1, x2, y2) {
    this.u40_1.beginPath();
    this.u40_1.moveTo(x1, y1);
    this.u40_1.lineTo(x2, y2);
    this.u40_1.closePath();
    this.u40_1.stroke();
  }
  f3h(x, y, width, height) {
    this.u40_1.strokeRect(x, y, width, height);
  }
  s3d(x, y, width, height) {
    this.u40_1.fillRect(x, y, width, height);
  }
  a37(x, y, width, height, arcWidth, arcHeight) {
    this.b2r(Double_4.w21(x, y, width, height, arcWidth, arcHeight));
  }
  z36(x, y, width, height, arcWidth, arcHeight) {
    this.o2q(Double_4.w21(x, y, width, height, arcWidth, arcHeight));
  }
  l41(img, x, y) {
    var completed;
    var nativeImage = ensureNotNull(img).f2e();
    if (nativeImage instanceof ImageData) {
      this.u40_1.putImageData(nativeImage, x, y);
      completed = true;
    } else {
      completed = img.i2e();
      var tmp = img.f2e();
      this.u40_1.drawImage(!(tmp == null) ? tmp : THROW_CCE(), x, y);
    }
    return completed;
  }
  c3h(img, x, y, w, h) {
    var tmp;
    if (ensureNotNull(img).x2d_1 === w && img.y2d_1 === h) {
      tmp = this.l41(img, x, y);
    } else {
      var completed = img.i2e();
      var tmp_0 = img.f2e();
      this.u40_1.drawImage(!(tmp_0 == null) ? tmp_0 : THROW_CCE(), x, y, w, h);
      tmp = completed;
    }
    return tmp;
  }
  e3h() {
    var tmp = this.u40_1;
    return new CanvasRenderingContext2DIGraphics(tmp instanceof CanvasRenderingContext2D ? tmp : THROW_CCE());
  }
}
class Headless$sizeLabel$1 {
  constructor($l) {
    this.m41_1 = $l;
  }
  v2p() {
    return numberToInt(ensureNotNull(this.m41_1.getFont()).v2d() * 100 / 96 * 130 / 100);
  }
  s2p() {
    return Dimension.bm(0, numberToInt(ensureNotNull(this.m41_1.getFont()).v2d() * 100 / 96 * 130 / 100));
  }
}
class Headless {
  y3z(l, g, width, height) {
    var tmp;
    if (!(g == null)) {
      tmp = g.q2p(l, width, height);
    } else {
      tmp = new Headless$sizeLabel$1(l);
    }
    return tmp;
  }
}
class TreeMapCanvas$addLayer$1 {
  constructor($d, this$0) {
    this.p41_1 = $d;
    this.q41_1 = this$0;
    this.n41_1 = 0;
    this.o41_1 = 0;
  }
  y2a(width, height) {
    this.n41_1 = width;
    this.o41_1 = height;
  }
  b2b(g) {
    this.p41_1.q3u(this.q41_1.z3u_1, new CanvasRenderingContext2DTGraphics(g), this.n41_1, this.o41_1);
  }
}
class TreeMapCanvas extends CPCanvas {
  constructor(view) {
    super();
    this.z3u_1 = view;
  }
  a3v(d) {
    this.o2a(new TreeMapCanvas$addLayer$1(d, this));
  }
}
//endregion
function toList(_this__u8e3s4) {
  switch (_this__u8e3s4.length) {
    case 0:
      return emptyList();
    case 1:
      return listOf(_this__u8e3s4[0]);
    default:
      return toMutableList(_this__u8e3s4);
  }
}
function requireNoNulls(_this__u8e3s4) {
  var inductionVariable = 0;
  var last = _this__u8e3s4.length;
  while (inductionVariable < last) {
    var element = _this__u8e3s4[inductionVariable];
    inductionVariable = inductionVariable + 1 | 0;
    if (element == null) {
      throw IllegalArgumentException.h('null element found in ' + toString_1(_this__u8e3s4) + '.');
    }
  }
  return isArray(_this__u8e3s4) ? _this__u8e3s4 : THROW_CCE();
}
function indexOf(_this__u8e3s4, element) {
  if (element == null) {
    var inductionVariable = 0;
    var last = _this__u8e3s4.length - 1 | 0;
    if (inductionVariable <= last)
      do {
        var index = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        if (_this__u8e3s4[index] == null) {
          return index;
        }
      }
       while (inductionVariable <= last);
  } else {
    var inductionVariable_0 = 0;
    var last_0 = _this__u8e3s4.length - 1 | 0;
    if (inductionVariable_0 <= last_0)
      do {
        var index_0 = inductionVariable_0;
        inductionVariable_0 = inductionVariable_0 + 1 | 0;
        if (equals(element, _this__u8e3s4[index_0])) {
          return index_0;
        }
      }
       while (inductionVariable_0 <= last_0);
  }
  return -1;
}
function contains_0(_this__u8e3s4, element) {
  return indexOf(_this__u8e3s4, element) >= 0;
}
function toMutableList(_this__u8e3s4) {
  return ArrayList.l(asCollection(_this__u8e3s4));
}
function toSet(_this__u8e3s4) {
  switch (_this__u8e3s4.length) {
    case 0:
      return emptySet();
    case 1:
      return setOf(_this__u8e3s4[0]);
    default:
      return toCollection(_this__u8e3s4, LinkedHashSet.n(mapCapacity(_this__u8e3s4.length)));
  }
}
function sortedWith(_this__u8e3s4, comparator) {
  return asList(sortedArrayWith(_this__u8e3s4, comparator));
}
function lastIndexOf(_this__u8e3s4, element) {
  if (element == null) {
    var inductionVariable = _this__u8e3s4.length - 1 | 0;
    if (0 <= inductionVariable)
      do {
        var index = inductionVariable;
        inductionVariable = inductionVariable + -1 | 0;
        if (_this__u8e3s4[index] == null) {
          return index;
        }
      }
       while (0 <= inductionVariable);
  } else {
    var inductionVariable_0 = _this__u8e3s4.length - 1 | 0;
    if (0 <= inductionVariable_0)
      do {
        var index_0 = inductionVariable_0;
        inductionVariable_0 = inductionVariable_0 + -1 | 0;
        if (equals(element, _this__u8e3s4[index_0])) {
          return index_0;
        }
      }
       while (0 <= inductionVariable_0);
  }
  return -1;
}
function get_lastIndex(_this__u8e3s4) {
  return _this__u8e3s4.length - 1 | 0;
}
function toCollection(_this__u8e3s4, destination) {
  var inductionVariable = 0;
  var last = _this__u8e3s4.length;
  while (inductionVariable < last) {
    var item = _this__u8e3s4[inductionVariable];
    inductionVariable = inductionVariable + 1 | 0;
    destination.o(item);
  }
  return destination;
}
function sortedArrayWith(_this__u8e3s4, comparator) {
  // Inline function 'kotlin.collections.isEmpty' call
  if (_this__u8e3s4.length === 0)
    return _this__u8e3s4;
  // Inline function 'kotlin.collections.copyOf' call
  // Inline function 'kotlin.collections.copyOf' call
  // Inline function 'kotlin.js.asDynamic' call
  // Inline function 'kotlin.apply' call
  var this_0 = _this__u8e3s4.slice();
  // Inline function 'kotlin.collections.sortedArrayWith.<anonymous>' call
  sortWith(this_0, comparator);
  return this_0;
}
function single(_this__u8e3s4) {
  var tmp;
  switch (_this__u8e3s4.length) {
    case 0:
      throw NoSuchElementException.s('Array is empty.');
    case 1:
      tmp = _this__u8e3s4[0];
      break;
    default:
      throw IllegalArgumentException.h('Array has more than one element.');
  }
  return tmp;
}
function joinToString(_this__u8e3s4, separator, prefix, postfix, limit, truncated, transform) {
  separator = separator === VOID ? ', ' : separator;
  prefix = prefix === VOID ? '' : prefix;
  postfix = postfix === VOID ? '' : postfix;
  limit = limit === VOID ? -1 : limit;
  truncated = truncated === VOID ? '...' : truncated;
  transform = transform === VOID ? null : transform;
  return joinTo(_this__u8e3s4, StringBuilder.u(), separator, prefix, postfix, limit, truncated, transform).toString();
}
function joinToString_0(_this__u8e3s4, separator, prefix, postfix, limit, truncated, transform) {
  separator = separator === VOID ? ', ' : separator;
  prefix = prefix === VOID ? '' : prefix;
  postfix = postfix === VOID ? '' : postfix;
  limit = limit === VOID ? -1 : limit;
  truncated = truncated === VOID ? '...' : truncated;
  transform = transform === VOID ? null : transform;
  return joinTo_0(_this__u8e3s4, StringBuilder.u(), separator, prefix, postfix, limit, truncated, transform).toString();
}
function joinTo(_this__u8e3s4, buffer, separator, prefix, postfix, limit, truncated, transform) {
  separator = separator === VOID ? ', ' : separator;
  prefix = prefix === VOID ? '' : prefix;
  postfix = postfix === VOID ? '' : postfix;
  limit = limit === VOID ? -1 : limit;
  truncated = truncated === VOID ? '...' : truncated;
  transform = transform === VOID ? null : transform;
  buffer.v(prefix);
  var count = 0;
  var inductionVariable = 0;
  var last = _this__u8e3s4.length;
  $l$loop: while (inductionVariable < last) {
    var element = _this__u8e3s4[inductionVariable];
    inductionVariable = inductionVariable + 1 | 0;
    count = count + 1 | 0;
    if (count > 1) {
      buffer.v(separator);
    }
    if (limit < 0 || count <= limit) {
      appendElement(buffer, element, transform);
    } else
      break $l$loop;
  }
  if (limit >= 0 && count > limit) {
    buffer.v(truncated);
  }
  buffer.v(postfix);
  return buffer;
}
function joinTo_0(_this__u8e3s4, buffer, separator, prefix, postfix, limit, truncated, transform) {
  separator = separator === VOID ? ', ' : separator;
  prefix = prefix === VOID ? '' : prefix;
  postfix = postfix === VOID ? '' : postfix;
  limit = limit === VOID ? -1 : limit;
  truncated = truncated === VOID ? '...' : truncated;
  transform = transform === VOID ? null : transform;
  buffer.v(prefix);
  var count = 0;
  var inductionVariable = 0;
  var last = _this__u8e3s4.length;
  $l$loop: while (inductionVariable < last) {
    var element = _this__u8e3s4[inductionVariable];
    inductionVariable = inductionVariable + 1 | 0;
    count = count + 1 | 0;
    if (count > 1) {
      buffer.v(separator);
    }
    if (limit < 0 || count <= limit) {
      if (!(transform == null))
        buffer.v(transform(element));
      else
        buffer.v(element.toString());
    } else
      break $l$loop;
  }
  if (limit >= 0 && count > limit) {
    buffer.v(truncated);
  }
  buffer.v(postfix);
  return buffer;
}
function asSequence(_this__u8e3s4) {
  // Inline function 'kotlin.collections.isEmpty' call
  if (_this__u8e3s4.length === 0)
    return emptySequence();
  // Inline function 'kotlin.sequences.Sequence' call
  return new asSequence$$inlined$Sequence$1(_this__u8e3s4);
}
function getOrNull(_this__u8e3s4, index) {
  return (0 <= index ? index <= (_this__u8e3s4.length - 1 | 0) : false) ? _this__u8e3s4[index] : null;
}
function joinToString_1(_this__u8e3s4, separator, prefix, postfix, limit, truncated, transform) {
  separator = separator === VOID ? ', ' : separator;
  prefix = prefix === VOID ? '' : prefix;
  postfix = postfix === VOID ? '' : postfix;
  limit = limit === VOID ? -1 : limit;
  truncated = truncated === VOID ? '...' : truncated;
  transform = transform === VOID ? null : transform;
  return joinTo_1(_this__u8e3s4, StringBuilder.u(), separator, prefix, postfix, limit, truncated, transform).toString();
}
function joinTo_1(_this__u8e3s4, buffer, separator, prefix, postfix, limit, truncated, transform) {
  separator = separator === VOID ? ', ' : separator;
  prefix = prefix === VOID ? '' : prefix;
  postfix = postfix === VOID ? '' : postfix;
  limit = limit === VOID ? -1 : limit;
  truncated = truncated === VOID ? '...' : truncated;
  transform = transform === VOID ? null : transform;
  buffer.v(prefix);
  var count = 0;
  var _iterator__ex2g4s = _this__u8e3s4.x();
  $l$loop: while (_iterator__ex2g4s.y()) {
    var element = _iterator__ex2g4s.z();
    count = count + 1 | 0;
    if (count > 1) {
      buffer.v(separator);
    }
    if (limit < 0 || count <= limit) {
      appendElement(buffer, element, transform);
    } else
      break $l$loop;
  }
  if (limit >= 0 && count > limit) {
    buffer.v(truncated);
  }
  buffer.v(postfix);
  return buffer;
}
function toList_0(_this__u8e3s4) {
  if (isInterface(_this__u8e3s4, Collection)) {
    var tmp;
    switch (_this__u8e3s4.a1()) {
      case 0:
        tmp = emptyList();
        break;
      case 1:
        var tmp_0;
        if (isInterface(_this__u8e3s4, KtList_0)) {
          tmp_0 = _this__u8e3s4.b1(0);
        } else {
          tmp_0 = _this__u8e3s4.x().z();
        }

        tmp = listOf(tmp_0);
        break;
      default:
        tmp = toMutableList_0(_this__u8e3s4);
        break;
    }
    return tmp;
  }
  return optimizeReadOnlyList(toMutableList_1(_this__u8e3s4));
}
function first(_this__u8e3s4) {
  if (_this__u8e3s4.c1())
    throw NoSuchElementException.s('List is empty.');
  return _this__u8e3s4.b1(0);
}
function last(_this__u8e3s4) {
  if (_this__u8e3s4.c1())
    throw NoSuchElementException.s('List is empty.');
  return _this__u8e3s4.b1(get_lastIndex_0(_this__u8e3s4));
}
function first_0(_this__u8e3s4) {
  if (isInterface(_this__u8e3s4, KtList_0))
    return first(_this__u8e3s4);
  else {
    var iterator = _this__u8e3s4.x();
    if (!iterator.y())
      throw NoSuchElementException.s('Collection is empty.');
    return iterator.z();
  }
}
function last_0(_this__u8e3s4) {
  if (isInterface(_this__u8e3s4, KtList_0))
    return last(_this__u8e3s4);
  else {
    var iterator = _this__u8e3s4.x();
    if (!iterator.y())
      throw NoSuchElementException.s('Collection is empty.');
    var last_0 = iterator.z();
    while (iterator.y())
      last_0 = iterator.z();
    return last_0;
  }
}
function toSet_0(_this__u8e3s4) {
  if (isInterface(_this__u8e3s4, Collection)) {
    var tmp;
    switch (_this__u8e3s4.a1()) {
      case 0:
        tmp = emptySet();
        break;
      case 1:
        var tmp_0;
        if (isInterface(_this__u8e3s4, KtList_0)) {
          tmp_0 = _this__u8e3s4.b1(0);
        } else {
          tmp_0 = _this__u8e3s4.x().z();
        }

        tmp = setOf(tmp_0);
        break;
      default:
        tmp = toCollection_0(_this__u8e3s4, LinkedHashSet.n(mapCapacity(_this__u8e3s4.a1())));
        break;
    }
    return tmp;
  }
  return optimizeReadOnlySet(toCollection_0(_this__u8e3s4, LinkedHashSet.d1()));
}
function single_0(_this__u8e3s4) {
  var tmp;
  switch (_this__u8e3s4.a1()) {
    case 0:
      throw NoSuchElementException.s('List is empty.');
    case 1:
      tmp = _this__u8e3s4.b1(0);
      break;
    default:
      throw IllegalArgumentException.h('List has more than one element.');
  }
  return tmp;
}
function toMutableList_0(_this__u8e3s4) {
  return ArrayList.l(_this__u8e3s4);
}
function sortedWith_0(_this__u8e3s4, comparator) {
  if (isInterface(_this__u8e3s4, Collection)) {
    if (_this__u8e3s4.a1() <= 1)
      return toList_0(_this__u8e3s4);
    // Inline function 'kotlin.collections.toTypedArray' call
    var tmp = copyToArray(_this__u8e3s4);
    // Inline function 'kotlin.apply' call
    var this_0 = isArray(tmp) ? tmp : THROW_CCE();
    // Inline function 'kotlin.collections.sortedWith.<anonymous>' call
    sortWith(this_0, comparator);
    return asList(this_0);
  }
  // Inline function 'kotlin.apply' call
  var this_1 = toMutableList_1(_this__u8e3s4);
  // Inline function 'kotlin.collections.sortedWith.<anonymous>' call
  sortWith_0(this_1, comparator);
  return this_1;
}
function filterNotNull(_this__u8e3s4) {
  return filterNotNullTo(_this__u8e3s4, ArrayList.e1());
}
function single_1(_this__u8e3s4) {
  if (isInterface(_this__u8e3s4, KtList_0))
    return single_0(_this__u8e3s4);
  else {
    var iterator = _this__u8e3s4.x();
    if (!iterator.y())
      throw NoSuchElementException.s('Collection is empty.');
    var single = iterator.z();
    if (iterator.y())
      throw IllegalArgumentException.h('Collection has more than one element.');
    return single;
  }
}
function toMutableList_1(_this__u8e3s4) {
  if (isInterface(_this__u8e3s4, Collection))
    return toMutableList_0(_this__u8e3s4);
  return toCollection_0(_this__u8e3s4, ArrayList.e1());
}
function toCollection_0(_this__u8e3s4, destination) {
  var _iterator__ex2g4s = _this__u8e3s4.x();
  while (_iterator__ex2g4s.y()) {
    var item = _iterator__ex2g4s.z();
    destination.o(item);
  }
  return destination;
}
function toMutableSet(_this__u8e3s4) {
  var tmp;
  if (isInterface(_this__u8e3s4, Collection)) {
    tmp = LinkedHashSet.f1(_this__u8e3s4);
  } else {
    tmp = toCollection_0(_this__u8e3s4, LinkedHashSet.d1());
  }
  return tmp;
}
function filterNotNullTo(_this__u8e3s4, destination) {
  var _iterator__ex2g4s = _this__u8e3s4.x();
  while (_iterator__ex2g4s.y()) {
    var element = _iterator__ex2g4s.z();
    if (!(element == null)) {
      destination.o(element);
    }
  }
  return destination;
}
function until(_this__u8e3s4, to) {
  if (to <= -2147483648)
    return Companion_getInstance_12().g1_1;
  return numberRangeToNumber(_this__u8e3s4, to - 1 | 0);
}
function downTo(_this__u8e3s4, to) {
  return Companion_instance_13.h1(_this__u8e3s4, to, -1);
}
function coerceAtMost(_this__u8e3s4, maximumValue) {
  return _this__u8e3s4 > maximumValue ? maximumValue : _this__u8e3s4;
}
function coerceAtLeast(_this__u8e3s4, minimumValue) {
  return _this__u8e3s4 < minimumValue ? minimumValue : _this__u8e3s4;
}
function coerceIn(_this__u8e3s4, minimumValue, maximumValue) {
  if (minimumValue > maximumValue)
    throw IllegalArgumentException.h('Cannot coerce value to an empty range: maximum ' + maximumValue + ' is less than minimum ' + minimumValue + '.');
  if (_this__u8e3s4 < minimumValue)
    return minimumValue;
  if (_this__u8e3s4 > maximumValue)
    return maximumValue;
  return _this__u8e3s4;
}
function contains_1(_this__u8e3s4, value) {
  // Inline function 'kotlin.let' call
  // Inline function 'kotlin.ranges.contains.<anonymous>' call
  var it = toIntExactOrNull(value);
  return !(it == null) ? _this__u8e3s4.i1(it) : false;
}
function toIntExactOrNull(_this__u8e3s4) {
  return ((new Long(-2147483648, -1)).m1(_this__u8e3s4) <= 0 ? _this__u8e3s4.m1(new Long(2147483647, 0)) <= 0 : false) ? _this__u8e3s4.l1() : null;
}
function asIterable(_this__u8e3s4) {
  // Inline function 'kotlin.collections.Iterable' call
  return new asIterable$$inlined$Iterable$1(_this__u8e3s4);
}
function map(_this__u8e3s4, transform) {
  return new TransformingSequence(_this__u8e3s4, transform);
}
function dropLast(_this__u8e3s4, n) {
  // Inline function 'kotlin.require' call
  if (!(n >= 0)) {
    // Inline function 'kotlin.text.dropLast.<anonymous>' call
    var message = 'Requested character count ' + n + ' is less than zero.';
    throw IllegalArgumentException.h(toString_1(message));
  }
  return take(_this__u8e3s4, coerceAtLeast(_this__u8e3s4.length - n | 0, 0));
}
function take(_this__u8e3s4, n) {
  // Inline function 'kotlin.require' call
  if (!(n >= 0)) {
    // Inline function 'kotlin.text.take.<anonymous>' call
    var message = 'Requested character count ' + n + ' is less than zero.';
    throw IllegalArgumentException.h(toString_1(message));
  }
  // Inline function 'kotlin.text.substring' call
  var endIndex = coerceAtMost(n, _this__u8e3s4.length);
  // Inline function 'kotlin.js.asDynamic' call
  return _this__u8e3s4.substring(0, endIndex);
}
function init_kotlin_KotlinNothingValueException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.q1_1);
}
function _Char___init__impl__6a9atx(value) {
  return value;
}
function _get_value__a43j40($this) {
  return $this;
}
function _Char___init__impl__6a9atx_0(code) {
  // Inline function 'kotlin.UShort.toInt' call
  var tmp$ret$0 = _UShort___get_data__impl__g0245(code) & 65535;
  return _Char___init__impl__6a9atx(tmp$ret$0);
}
function Char__compareTo_impl_ypi4mb($this, other) {
  return _get_value__a43j40($this) - _get_value__a43j40(other) | 0;
}
function Char__compareTo_impl_ypi4mb_0($this, other) {
  return Char__compareTo_impl_ypi4mb($this.x1_1, other instanceof Char ? other.x1_1 : THROW_CCE());
}
function Char__plus_impl_qi7pgj($this, other) {
  return numberToChar(_get_value__a43j40($this) + other | 0);
}
function Char__minus_impl_a2frrh($this, other) {
  return _get_value__a43j40($this) - _get_value__a43j40(other) | 0;
}
function Char__toInt_impl_vasixd($this) {
  return _get_value__a43j40($this);
}
function toString($this) {
  // Inline function 'kotlin.js.unsafeCast' call
  return String.fromCharCode(_get_value__a43j40($this));
}
function Char__equals_impl_x6719k($this, other) {
  if (!(other instanceof Char))
    return false;
  return _get_value__a43j40($this) === _get_value__a43j40(other.x1_1);
}
function Char__hashCode_impl_otmys($this) {
  return _get_value__a43j40($this);
}
var Companion_instance;
function Companion_getInstance() {
  if (Companion_instance === VOID)
    new Companion();
  return Companion_instance;
}
var Companion_instance_0;
function Companion_getInstance_0() {
  return Companion_instance_0;
}
var Companion_instance_1;
function Companion_getInstance_1() {
  return Companion_instance_1;
}
var Companion_instance_2;
function Companion_getInstance_2() {
  return Companion_instance_2;
}
function toString_0(_this__u8e3s4) {
  var tmp1_elvis_lhs = _this__u8e3s4 == null ? null : toString_1(_this__u8e3s4);
  return tmp1_elvis_lhs == null ? 'null' : tmp1_elvis_lhs;
}
function plus(_this__u8e3s4, other) {
  var tmp1_elvis_lhs = _this__u8e3s4 == null ? null : toString_1(_this__u8e3s4);
  var tmp = tmp1_elvis_lhs == null ? 'null' : tmp1_elvis_lhs;
  var tmp3_elvis_lhs = other == null ? null : toString_1(other);
  return tmp + (tmp3_elvis_lhs == null ? 'null' : tmp3_elvis_lhs);
}
var Companion_instance_3;
function Companion_getInstance_3() {
  if (Companion_instance_3 === VOID)
    new Companion_3();
  return Companion_instance_3;
}
function implement(interfaces) {
  var maxSize = 1;
  var masks = [];
  var inductionVariable = 0;
  var last = interfaces.length;
  while (inductionVariable < last) {
    var i = interfaces[inductionVariable];
    inductionVariable = inductionVariable + 1 | 0;
    var currentSize = maxSize;
    var tmp0_elvis_lhs = i.prototype.$imask$;
    var imask = tmp0_elvis_lhs == null ? i.$imask$ : tmp0_elvis_lhs;
    if (!(imask == null)) {
      masks.push(imask);
      currentSize = imask.length;
    }
    var iid = i.$metadata$.iid;
    var tmp;
    if (iid == null) {
      tmp = null;
    } else {
      // Inline function 'kotlin.let' call
      // Inline function 'kotlin.js.implement.<anonymous>' call
      tmp = bitMaskWith(iid);
    }
    var iidImask = tmp;
    if (!(iidImask == null)) {
      masks.push(iidImask);
      currentSize = Math.max(currentSize, iidImask.length);
    }
    if (currentSize > maxSize) {
      maxSize = currentSize;
    }
  }
  return compositeBitMask(maxSize, masks);
}
function bitMaskWith(activeBit) {
  var numberIndex = activeBit >> 5;
  var intArray = new Int32Array(numberIndex + 1 | 0);
  var positionInNumber = activeBit & 31;
  var numberWithSettledBit = 1 << positionInNumber;
  intArray[numberIndex] = intArray[numberIndex] | numberWithSettledBit;
  return intArray;
}
function compositeBitMask(capacity, masks) {
  var tmp = 0;
  var tmp_0 = new Int32Array(capacity);
  while (tmp < capacity) {
    var tmp_1 = tmp;
    var result = 0;
    var inductionVariable = 0;
    var last = masks.length;
    while (inductionVariable < last) {
      var mask = masks[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      if (tmp_1 < mask.length) {
        result = result | mask[tmp_1];
      }
    }
    tmp_0[tmp_1] = result;
    tmp = tmp + 1 | 0;
  }
  return tmp_0;
}
function isBitSet(_this__u8e3s4, possibleActiveBit) {
  var numberIndex = possibleActiveBit >> 5;
  if (numberIndex > _this__u8e3s4.length)
    return false;
  var positionInNumber = possibleActiveBit & 31;
  var numberWithSettledBit = 1 << positionInNumber;
  return !((_this__u8e3s4[numberIndex] & numberWithSettledBit) === 0);
}
function fillArrayVal(array, initValue) {
  var inductionVariable = 0;
  var last = array.length - 1 | 0;
  if (inductionVariable <= last)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      array[i] = initValue;
    }
     while (!(i === last));
  return array;
}
function arrayIterator(array) {
  return new arrayIterator$1(array);
}
function booleanArray(size) {
  var tmp0 = 'BooleanArray';
  // Inline function 'withType' call
  var array = fillArrayVal(Array(size), false);
  array.$type$ = tmp0;
  // Inline function 'kotlin.js.unsafeCast' call
  return array;
}
function charArray(size) {
  var tmp0 = 'CharArray';
  // Inline function 'withType' call
  var array = new Uint16Array(size);
  array.$type$ = tmp0;
  // Inline function 'kotlin.js.unsafeCast' call
  return array;
}
function longArray(size) {
  var tmp0 = 'LongArray';
  // Inline function 'withType' call
  var array = fillArrayVal(Array(size), new Long(0, 0));
  array.$type$ = tmp0;
  // Inline function 'kotlin.js.unsafeCast' call
  return array;
}
function booleanArrayOf(arr) {
  var tmp1 = 'BooleanArray';
  // Inline function 'kotlin.js.asDynamic' call
  // Inline function 'withType' call
  var array = arr.slice();
  array.$type$ = tmp1;
  // Inline function 'kotlin.js.unsafeCast' call
  return array;
}
function charArrayOf(arr) {
  var tmp0 = 'CharArray';
  // Inline function 'withType' call
  var array = new Uint16Array(arr);
  array.$type$ = tmp0;
  // Inline function 'kotlin.js.unsafeCast' call
  return array;
}
function longArrayOf(arr) {
  var tmp1 = 'LongArray';
  // Inline function 'kotlin.js.asDynamic' call
  // Inline function 'withType' call
  var array = arr.slice();
  array.$type$ = tmp1;
  // Inline function 'kotlin.js.unsafeCast' call
  return array;
}
function get_buf() {
  _init_properties_bitUtils_kt__nfcg4k();
  return buf;
}
var buf;
function get_bufFloat64() {
  _init_properties_bitUtils_kt__nfcg4k();
  return bufFloat64;
}
var bufFloat64;
var bufFloat32;
function get_bufInt32() {
  _init_properties_bitUtils_kt__nfcg4k();
  return bufInt32;
}
var bufInt32;
function get_lowIndex() {
  _init_properties_bitUtils_kt__nfcg4k();
  return lowIndex;
}
var lowIndex;
function get_highIndex() {
  _init_properties_bitUtils_kt__nfcg4k();
  return highIndex;
}
var highIndex;
function doubleToRawBits(value) {
  _init_properties_bitUtils_kt__nfcg4k();
  get_bufFloat64()[0] = value;
  return new Long(get_bufInt32()[get_lowIndex()], get_bufInt32()[get_highIndex()]);
}
function getNumberHashCode(obj) {
  _init_properties_bitUtils_kt__nfcg4k();
  // Inline function 'kotlin.js.jsBitwiseOr' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  if ((obj | 0) === obj) {
    return numberToInt(obj);
  }
  get_bufFloat64()[0] = obj;
  return imul_0(get_bufInt32()[get_highIndex()], 31) + get_bufInt32()[get_lowIndex()] | 0;
}
var properties_initialized_bitUtils_kt_i2bo3e;
function _init_properties_bitUtils_kt__nfcg4k() {
  if (!properties_initialized_bitUtils_kt_i2bo3e) {
    properties_initialized_bitUtils_kt_i2bo3e = true;
    buf = new ArrayBuffer(8);
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    bufFloat64 = new Float64Array(get_buf());
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    bufFloat32 = new Float32Array(get_buf());
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    bufInt32 = new Int32Array(get_buf());
    // Inline function 'kotlin.run' call
    // Inline function 'kotlin.js.lowIndex.<anonymous>' call
    get_bufFloat64()[0] = -1.0;
    lowIndex = !(get_bufInt32()[0] === 0) ? 1 : 0;
    highIndex = 1 - get_lowIndex() | 0;
  }
}
function charSequenceGet(a, index) {
  var tmp;
  if (isString(a)) {
    // Inline function 'kotlin.js.asDynamic' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.Char' call
    var code = a.charCodeAt(index);
    var tmp_0;
    // Inline function 'kotlin.code' call
    var this_0 = _Char___init__impl__6a9atx(0);
    if (code < Char__toInt_impl_vasixd(this_0)) {
      tmp_0 = true;
    } else {
      // Inline function 'kotlin.code' call
      var this_1 = _Char___init__impl__6a9atx(65535);
      tmp_0 = code > Char__toInt_impl_vasixd(this_1);
    }
    if (tmp_0) {
      throw IllegalArgumentException.h('Invalid Char code: ' + code);
    }
    tmp = numberToChar(code);
  } else {
    tmp = a.b(index);
  }
  return tmp;
}
function isString(a) {
  return typeof a === 'string';
}
function charSequenceLength(a) {
  var tmp;
  if (isString(a)) {
    // Inline function 'kotlin.js.asDynamic' call
    // Inline function 'kotlin.js.unsafeCast' call
    tmp = a.length;
  } else {
    tmp = a.a();
  }
  return tmp;
}
function charSequenceSubSequence(a, startIndex, endIndex) {
  var tmp;
  if (isString(a)) {
    // Inline function 'kotlin.js.asDynamic' call
    // Inline function 'kotlin.js.unsafeCast' call
    tmp = a.substring(startIndex, endIndex);
  } else {
    tmp = a.c(startIndex, endIndex);
  }
  return tmp;
}
function arrayToString(array) {
  return joinToString(array, ', ', '[', ']', VOID, VOID, arrayToString$lambda);
}
function contentEqualsInternal(_this__u8e3s4, other) {
  // Inline function 'kotlin.js.asDynamic' call
  var a = _this__u8e3s4;
  // Inline function 'kotlin.js.asDynamic' call
  var b = other;
  if (a === b)
    return true;
  if (a == null || b == null || !isArrayish(b) || a.length != b.length)
    return false;
  var inductionVariable = 0;
  var last = a.length;
  if (inductionVariable < last)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      if (!equals(a[i], b[i])) {
        return false;
      }
    }
     while (inductionVariable < last);
  return true;
}
function contentHashCodeInternal(_this__u8e3s4) {
  // Inline function 'kotlin.js.asDynamic' call
  var a = _this__u8e3s4;
  if (a == null)
    return 0;
  var result = 1;
  var inductionVariable = 0;
  var last = a.length;
  if (inductionVariable < last)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      result = imul_0(result, 31) + hashCode(a[i]) | 0;
    }
     while (inductionVariable < last);
  return result;
}
function arrayToString$lambda(it) {
  return toString_1(it);
}
function createJsReadonlyArrayViewFrom(list) {
  var tmp = createJsReadonlyArrayViewFrom$lambda(list);
  var tmp_0 = createJsReadonlyArrayViewFrom$lambda_0(list);
  // Inline function 'kotlin.js.asDynamic' call
  var tmp_1 = UNSUPPORTED_OPERATION$ref();
  // Inline function 'kotlin.js.asDynamic' call
  var tmp_2 = UNSUPPORTED_OPERATION$ref_0();
  // Inline function 'kotlin.js.asDynamic' call
  var tmp$ret$2 = UNSUPPORTED_OPERATION$ref_1();
  return createJsArrayViewWith(tmp, tmp_0, tmp_1, tmp_2, tmp$ret$2);
}
function createJsArrayViewWith(listSize, listGet, listSet, listDecreaseSize, listIncreaseSize) {
  var arrayView = new Array();
  var tmp = Object;
  // Inline function 'kotlin.js.asDynamic' call
  var tmp$ret$0 = JsArrayView;
  tmp.setPrototypeOf(arrayView, tmp$ret$0.prototype);
  return new Proxy(arrayView, {get: function (target, prop, receiver) {
    if (prop === 'length')
      return listSize();
    var type = typeof prop;
    var index = type === 'string' || type === 'number' ? +prop : undefined;
    if (!isNaN(index))
      return listGet(index);
    return target[prop];
  }, has: function (target, key) {
    return !isNaN(key) && key < listSize();
  }, set: function (obj, prop, value) {
    if (prop === 'length') {
      var size = listSize();
      var newSize = type === 'string' || type === 'number' ? +prop : undefined;
      if (isNaN(newSize))
        throw new RangeError('invalid array length');
      if (newSize < size)
        listDecreaseSize(size - newSize);
      else
        listIncreaseSize(newSize - size);
      return true;
    }
    var type = typeof prop;
    var index = type === 'string' || type === 'number' ? +prop : undefined;
    if (isNaN(index))
      return false;
    listSet(index, value);
    return true;
  }});
}
function UNSUPPORTED_OPERATION() {
  throw UnsupportedOperationException.h4();
}
function createJsReadonlySetViewFrom(set) {
  var tmp = createJsReadonlySetViewFrom$lambda(set);
  // Inline function 'kotlin.js.asDynamic' call
  var tmp_0 = UNSUPPORTED_OPERATION$ref_2();
  // Inline function 'kotlin.js.asDynamic' call
  var tmp_1 = UNSUPPORTED_OPERATION$ref_3();
  // Inline function 'kotlin.js.asDynamic' call
  var tmp_2 = UNSUPPORTED_OPERATION$ref_4();
  var tmp_3 = createJsReadonlySetViewFrom$lambda_0(set);
  var tmp_4 = createJsReadonlySetViewFrom$lambda_1(set);
  var tmp_5 = createJsReadonlySetViewFrom$lambda_2(set);
  return createJsSetViewWith(tmp, tmp_0, tmp_1, tmp_2, tmp_3, tmp_4, tmp_5, createJsReadonlySetViewFrom$lambda_3);
}
function createJsSetViewWith(setSize, setAdd, setRemove, setClear, setContains, valuesIterator, entriesIterator, forEach) {
  // Inline function 'kotlin.also' call
  var this_0 = objectCreate(protoOf(JsSetView));
  // Inline function 'kotlin.collections.createJsSetViewWith.<anonymous>' call
  this_0[Symbol.iterator] = valuesIterator;
  defineProp(this_0, 'size', setSize, VOID);
  var setView = this_0;
  return Object.assign(setView, {add: function (value) {
    setAdd(value);
    return this;
  }, 'delete': setRemove, clear: setClear, has: setContains, keys: valuesIterator, values: valuesIterator, entries: entriesIterator, forEach: function (cb, thisArg) {
    forEach(cb, setView, thisArg);
  }});
}
function createJsIteratorFrom(iterator, transform) {
  var tmp;
  if (transform === VOID) {
    tmp = createJsIteratorFrom$lambda;
  } else {
    tmp = transform;
  }
  transform = tmp;
  var iteratorNext = createJsIteratorFrom$lambda_0(iterator);
  var iteratorHasNext = createJsIteratorFrom$lambda_1(iterator);
  var jsIterator = {next: function () {
    var result = {done: !iteratorHasNext()};
    if (!result.done)
      result.value = transform(iteratorNext());
    return result;
  }};
  jsIterator[Symbol.iterator] = function () {
    return this;
  };
  return jsIterator;
}
function forEach(cb, collection, thisArg) {
  thisArg = thisArg === VOID ? undefined : thisArg;
  var iterator = collection.entries();
  var result = iterator.next();
  while (!result.done) {
    var value = result.value;
    // Inline function 'kotlin.js.asDynamic' call
    cb.call(thisArg, value[1], value[0], collection);
    result = iterator.next();
  }
}
function createListFrom(array) {
  // Inline function 'kotlin.js.asDynamic' call
  // Inline function 'kotlin.js.unsafeCast' call
  var tmp$ret$1 = array.slice();
  return ArrayList.i4(tmp$ret$1).j4();
}
function createSetFrom(set) {
  // Inline function 'kotlin.collections.buildSetInternal' call
  // Inline function 'kotlin.apply' call
  var this_0 = LinkedHashSet.d1();
  // Inline function 'kotlin.collections.createSetFrom.<anonymous>' call
  forEach(createSetFrom$lambda(this_0), set);
  return this_0.j4();
}
function createJsReadonlyArrayViewFrom$lambda($list) {
  return () => $list.a1();
}
function createJsReadonlyArrayViewFrom$lambda_0($list) {
  return (i) => $list.b1(i);
}
function UNSUPPORTED_OPERATION$ref() {
  var l = () => {
    UNSUPPORTED_OPERATION();
    return Unit_instance;
  };
  l.callableName = 'UNSUPPORTED_OPERATION';
  return l;
}
function UNSUPPORTED_OPERATION$ref_0() {
  var l = () => {
    UNSUPPORTED_OPERATION();
    return Unit_instance;
  };
  l.callableName = 'UNSUPPORTED_OPERATION';
  return l;
}
function UNSUPPORTED_OPERATION$ref_1() {
  var l = () => {
    UNSUPPORTED_OPERATION();
    return Unit_instance;
  };
  l.callableName = 'UNSUPPORTED_OPERATION';
  return l;
}
function createJsReadonlySetViewFrom$lambda($set) {
  return () => $set.a1();
}
function UNSUPPORTED_OPERATION$ref_2() {
  var l = () => {
    UNSUPPORTED_OPERATION();
    return Unit_instance;
  };
  l.callableName = 'UNSUPPORTED_OPERATION';
  return l;
}
function UNSUPPORTED_OPERATION$ref_3() {
  var l = () => {
    UNSUPPORTED_OPERATION();
    return Unit_instance;
  };
  l.callableName = 'UNSUPPORTED_OPERATION';
  return l;
}
function UNSUPPORTED_OPERATION$ref_4() {
  var l = () => {
    UNSUPPORTED_OPERATION();
    return Unit_instance;
  };
  l.callableName = 'UNSUPPORTED_OPERATION';
  return l;
}
function createJsReadonlySetViewFrom$lambda_0($set) {
  return (v) => $set.j2(v);
}
function createJsReadonlySetViewFrom$lambda_1($set) {
  return () => createJsIteratorFrom($set.x());
}
function createJsReadonlySetViewFrom$lambda$lambda(it) {
  // Inline function 'kotlin.arrayOf' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return [it, it];
}
function createJsReadonlySetViewFrom$lambda_2($set) {
  return () => {
    var tmp = $set.x();
    return createJsIteratorFrom(tmp, createJsReadonlySetViewFrom$lambda$lambda);
  };
}
function createJsReadonlySetViewFrom$lambda_3(callback, set, thisArg) {
  forEach(callback, set, thisArg);
  return Unit_instance;
}
function createJsIteratorFrom$lambda(it) {
  return it;
}
function createJsIteratorFrom$lambda_0($iterator) {
  return () => $iterator.z();
}
function createJsIteratorFrom$lambda_1($iterator) {
  return () => $iterator.y();
}
function createSetFrom$lambda($$this$buildSetInternal) {
  return (_unused_var__etf5q3, value, _unused_var__etf5q3_0) => {
    $$this$buildSetInternal.o(value);
    return Unit_instance;
  };
}
function compareTo(a, b) {
  var tmp;
  switch (typeof a) {
    case 'number':
      var tmp_0;
      if (typeof b === 'number') {
        tmp_0 = doubleCompareTo(a, b);
      } else {
        if (b instanceof Long) {
          tmp_0 = doubleCompareTo(a, b.a4());
        } else {
          tmp_0 = primitiveCompareTo(a, b);
        }
      }

      tmp = tmp_0;
      break;
    case 'string':
    case 'boolean':
      tmp = primitiveCompareTo(a, b);
      break;
    default:
      tmp = compareToDoNotIntrinsicify(a, b);
      break;
  }
  return tmp;
}
function doubleCompareTo(a, b) {
  var tmp;
  if (a < b) {
    tmp = -1;
  } else if (a > b) {
    tmp = 1;
  } else if (a === b) {
    var tmp_0;
    if (a !== 0) {
      tmp_0 = 0;
    } else {
      // Inline function 'kotlin.js.asDynamic' call
      var ia = 1 / a;
      var tmp_1;
      // Inline function 'kotlin.js.asDynamic' call
      if (ia === 1 / b) {
        tmp_1 = 0;
      } else {
        if (ia < 0) {
          tmp_1 = -1;
        } else {
          tmp_1 = 1;
        }
      }
      tmp_0 = tmp_1;
    }
    tmp = tmp_0;
  } else if (a !== a) {
    tmp = b !== b ? 0 : 1;
  } else {
    tmp = -1;
  }
  return tmp;
}
function primitiveCompareTo(a, b) {
  return a < b ? -1 : a > b ? 1 : 0;
}
function compareToDoNotIntrinsicify(a, b) {
  return a.d(b);
}
function identityHashCode(obj) {
  return getObjectHashCode(obj);
}
function getObjectHashCode(obj) {
  // Inline function 'kotlin.js.jsIn' call
  if (!('kotlinHashCodeValue$' in obj)) {
    var hash = calculateRandomHash();
    var descriptor = new Object();
    descriptor.value = hash;
    descriptor.enumerable = false;
    Object.defineProperty(obj, 'kotlinHashCodeValue$', descriptor);
  }
  // Inline function 'kotlin.js.unsafeCast' call
  return obj['kotlinHashCodeValue$'];
}
function calculateRandomHash() {
  // Inline function 'kotlin.js.jsBitwiseOr' call
  return Math.random() * 4.294967296E9 | 0;
}
function defineProp(obj, name, getter, setter) {
  return Object.defineProperty(obj, name, {configurable: true, get: getter, set: setter});
}
function objectCreate(proto) {
  proto = proto === VOID ? null : proto;
  return Object.create(proto);
}
function toString_1(o) {
  var tmp;
  if (o == null) {
    tmp = 'null';
  } else if (isArrayish(o)) {
    tmp = '[...]';
  } else if (!(typeof o.toString === 'function')) {
    tmp = anyToString(o);
  } else {
    // Inline function 'kotlin.js.unsafeCast' call
    tmp = o.toString();
  }
  return tmp;
}
function equals(obj1, obj2) {
  if (obj1 == null) {
    return obj2 == null;
  }
  if (obj2 == null) {
    return false;
  }
  if (typeof obj1 === 'object' && typeof obj1.equals === 'function') {
    return obj1.equals(obj2);
  }
  if (obj1 !== obj1) {
    return obj2 !== obj2;
  }
  if (typeof obj1 === 'number' && typeof obj2 === 'number') {
    var tmp;
    if (obj1 === obj2) {
      var tmp_0;
      if (obj1 !== 0) {
        tmp_0 = true;
      } else {
        // Inline function 'kotlin.js.asDynamic' call
        var tmp_1 = 1 / obj1;
        // Inline function 'kotlin.js.asDynamic' call
        tmp_0 = tmp_1 === 1 / obj2;
      }
      tmp = tmp_0;
    } else {
      tmp = false;
    }
    return tmp;
  }
  return obj1 === obj2;
}
function hashCode(obj) {
  if (obj == null)
    return 0;
  var typeOf = typeof obj;
  var tmp;
  switch (typeOf) {
    case 'object':
      tmp = 'function' === typeof obj.hashCode ? obj.hashCode() : getObjectHashCode(obj);
      break;
    case 'function':
      tmp = getObjectHashCode(obj);
      break;
    case 'number':
      tmp = getNumberHashCode(obj);
      break;
    case 'boolean':
      // Inline function 'kotlin.js.unsafeCast' call

      tmp = getBooleanHashCode(obj);
      break;
    case 'string':
      tmp = getStringHashCode(String(obj));
      break;
    case 'bigint':
      tmp = getBigIntHashCode(obj);
      break;
    case 'symbol':
      tmp = getSymbolHashCode(obj);
      break;
    default:
      tmp = function () {
        throw new Error('Unexpected typeof `' + typeOf + '`');
      }();
      break;
  }
  return tmp;
}
function anyToString(o) {
  return Object.prototype.toString.call(o);
}
function getBooleanHashCode(value) {
  return value ? 1231 : 1237;
}
function getStringHashCode(str) {
  var hash = 0;
  var length = str.length;
  var inductionVariable = 0;
  var last = length - 1 | 0;
  if (inductionVariable <= last)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      // Inline function 'kotlin.js.asDynamic' call
      var code = str.charCodeAt(i);
      hash = imul_0(hash, 31) + code | 0;
    }
     while (!(i === last));
  return hash;
}
function getBigIntHashCode(value) {
  var shiftNumber = BigInt(32);
  var MASK = BigInt(4.294967295E9);
  var bigNumber = value < 0 ? -value : value;
  var hashCode = 0;
  var signum = value < 0 ? -1 : 1;
  while (bigNumber != 0) {
    // Inline function 'kotlin.js.unsafeCast' call
    var chunk = Number(bigNumber & MASK);
    hashCode = imul_0(31, hashCode) + chunk | 0;
    bigNumber = bigNumber >> shiftNumber;
  }
  return imul_0(hashCode, signum);
}
function getSymbolHashCode(value) {
  var hashCodeMap = symbolIsSharable(value) ? getSymbolMap() : getSymbolWeakMap();
  var cachedHashCode = hashCodeMap.get(value);
  if (cachedHashCode !== VOID)
    return cachedHashCode;
  var hash = calculateRandomHash();
  hashCodeMap.set(value, hash);
  return hash;
}
function symbolIsSharable(symbol) {
  return Symbol.keyFor(symbol) != VOID;
}
function getSymbolMap() {
  if (symbolMap === VOID) {
    symbolMap = new Map();
  }
  return symbolMap;
}
function getSymbolWeakMap() {
  if (symbolWeakMap === VOID) {
    symbolWeakMap = new WeakMap();
  }
  return symbolWeakMap;
}
var symbolMap;
var symbolWeakMap;
function boxIntrinsic(x) {
  var message = 'Should be lowered';
  throw IllegalStateException.n4(toString_1(message));
}
function unboxIntrinsic(x) {
  var message = 'Should be lowered';
  throw IllegalStateException.n4(toString_1(message));
}
function captureStack(instance, constructorFunction) {
  if (Error.captureStackTrace != null) {
    Error.captureStackTrace(instance, constructorFunction);
  } else {
    // Inline function 'kotlin.js.asDynamic' call
    instance.stack = (new Error()).stack;
  }
}
function protoOf(constructor) {
  return constructor.prototype;
}
function createThis(ctor, box) {
  var self_0 = Object.create(ctor.prototype);
  boxApply(self_0, box);
  return self_0;
}
function boxApply(self_0, box) {
  if (box !== VOID) {
    Object.assign(self_0, box);
  }
}
function createExternalThis(ctor, superExternalCtor, parameters, box) {
  var tmp;
  if (box === VOID) {
    tmp = ctor;
  } else {
    var newCtor = class  extends ctor {}
    Object.assign(newCtor.prototype, box);
    newCtor.constructor = ctor;
    tmp = newCtor;
  }
  var selfCtor = tmp;
  return Reflect.construct(superExternalCtor, parameters, selfCtor);
}
function setPropertiesToThrowableInstance(this_, message, cause) {
  var errorInfo = calculateErrorInfo(Object.getPrototypeOf(this_));
  if ((errorInfo & 1) === 0) {
    var tmp;
    if (message == null) {
      var tmp_0;
      if (!(message === null)) {
        var tmp1_elvis_lhs = cause == null ? null : cause.toString();
        tmp_0 = tmp1_elvis_lhs == null ? VOID : tmp1_elvis_lhs;
      } else {
        tmp_0 = VOID;
      }
      tmp = tmp_0;
    } else {
      tmp = message;
    }
    this_.message = tmp;
  }
  if ((errorInfo & 2) === 0) {
    this_.cause = cause;
  }
  this_.name = Object.getPrototypeOf(this_).constructor.name;
}
function ensureNotNull(v) {
  var tmp;
  if (v == null) {
    THROW_NPE();
  } else {
    tmp = v;
  }
  return tmp;
}
function THROW_NPE() {
  throw NullPointerException.r4();
}
function noWhenBranchMatchedException() {
  throw NoWhenBranchMatchedException.v4();
}
function THROW_CCE() {
  throw ClassCastException.z4();
}
function throwUninitializedPropertyAccessException(name) {
  throw UninitializedPropertyAccessException.d5('lateinit property ' + name + ' has not been initialized');
}
function throwKotlinNothingValueException() {
  throw KotlinNothingValueException.r1();
}
function THROW_IAE(msg) {
  throw IllegalArgumentException.h(msg);
}
function get_ZERO() {
  _init_properties_longJs_kt__elc2w5();
  return ZERO;
}
var ZERO;
function get_ONE() {
  _init_properties_longJs_kt__elc2w5();
  return ONE;
}
var ONE;
function get_NEG_ONE() {
  _init_properties_longJs_kt__elc2w5();
  return NEG_ONE;
}
var NEG_ONE;
function get_MAX_VALUE() {
  _init_properties_longJs_kt__elc2w5();
  return MAX_VALUE;
}
var MAX_VALUE;
function get_MIN_VALUE() {
  _init_properties_longJs_kt__elc2w5();
  return MIN_VALUE;
}
var MIN_VALUE;
function get_TWO_PWR_24_() {
  _init_properties_longJs_kt__elc2w5();
  return TWO_PWR_24_;
}
var TWO_PWR_24_;
function compare(_this__u8e3s4, other) {
  _init_properties_longJs_kt__elc2w5();
  if (equalsLong(_this__u8e3s4, other)) {
    return 0;
  }
  var thisNeg = isNegative(_this__u8e3s4);
  var otherNeg = isNegative(other);
  return thisNeg && !otherNeg ? -1 : !thisNeg && otherNeg ? 1 : isNegative(subtract(_this__u8e3s4, other)) ? -1 : 1;
}
function add(_this__u8e3s4, other) {
  _init_properties_longJs_kt__elc2w5();
  var a48 = _this__u8e3s4.k1_1 >>> 16 | 0;
  var a32 = _this__u8e3s4.k1_1 & 65535;
  var a16 = _this__u8e3s4.j1_1 >>> 16 | 0;
  var a00 = _this__u8e3s4.j1_1 & 65535;
  var b48 = other.k1_1 >>> 16 | 0;
  var b32 = other.k1_1 & 65535;
  var b16 = other.j1_1 >>> 16 | 0;
  var b00 = other.j1_1 & 65535;
  var c48 = 0;
  var c32 = 0;
  var c16 = 0;
  var c00 = 0;
  c00 = c00 + (a00 + b00 | 0) | 0;
  c16 = c16 + (c00 >>> 16 | 0) | 0;
  c00 = c00 & 65535;
  c16 = c16 + (a16 + b16 | 0) | 0;
  c32 = c32 + (c16 >>> 16 | 0) | 0;
  c16 = c16 & 65535;
  c32 = c32 + (a32 + b32 | 0) | 0;
  c48 = c48 + (c32 >>> 16 | 0) | 0;
  c32 = c32 & 65535;
  c48 = c48 + (a48 + b48 | 0) | 0;
  c48 = c48 & 65535;
  return new Long(c16 << 16 | c00, c48 << 16 | c32);
}
function subtract(_this__u8e3s4, other) {
  _init_properties_longJs_kt__elc2w5();
  return add(_this__u8e3s4, other.o3());
}
function multiply(_this__u8e3s4, other) {
  _init_properties_longJs_kt__elc2w5();
  if (isZero(_this__u8e3s4)) {
    return get_ZERO();
  } else if (isZero(other)) {
    return get_ZERO();
  }
  if (equalsLong(_this__u8e3s4, get_MIN_VALUE())) {
    return isOdd(other) ? get_MIN_VALUE() : get_ZERO();
  } else if (equalsLong(other, get_MIN_VALUE())) {
    return isOdd(_this__u8e3s4) ? get_MIN_VALUE() : get_ZERO();
  }
  if (isNegative(_this__u8e3s4)) {
    var tmp;
    if (isNegative(other)) {
      tmp = multiply(negate(_this__u8e3s4), negate(other));
    } else {
      tmp = negate(multiply(negate(_this__u8e3s4), other));
    }
    return tmp;
  } else if (isNegative(other)) {
    return negate(multiply(_this__u8e3s4, negate(other)));
  }
  if (lessThan(_this__u8e3s4, get_TWO_PWR_24_()) && lessThan(other, get_TWO_PWR_24_())) {
    return fromNumber(toNumber(_this__u8e3s4) * toNumber(other));
  }
  var a48 = _this__u8e3s4.k1_1 >>> 16 | 0;
  var a32 = _this__u8e3s4.k1_1 & 65535;
  var a16 = _this__u8e3s4.j1_1 >>> 16 | 0;
  var a00 = _this__u8e3s4.j1_1 & 65535;
  var b48 = other.k1_1 >>> 16 | 0;
  var b32 = other.k1_1 & 65535;
  var b16 = other.j1_1 >>> 16 | 0;
  var b00 = other.j1_1 & 65535;
  var c48 = 0;
  var c32 = 0;
  var c16 = 0;
  var c00 = 0;
  c00 = c00 + imul_0(a00, b00) | 0;
  c16 = c16 + (c00 >>> 16 | 0) | 0;
  c00 = c00 & 65535;
  c16 = c16 + imul_0(a16, b00) | 0;
  c32 = c32 + (c16 >>> 16 | 0) | 0;
  c16 = c16 & 65535;
  c16 = c16 + imul_0(a00, b16) | 0;
  c32 = c32 + (c16 >>> 16 | 0) | 0;
  c16 = c16 & 65535;
  c32 = c32 + imul_0(a32, b00) | 0;
  c48 = c48 + (c32 >>> 16 | 0) | 0;
  c32 = c32 & 65535;
  c32 = c32 + imul_0(a16, b16) | 0;
  c48 = c48 + (c32 >>> 16 | 0) | 0;
  c32 = c32 & 65535;
  c32 = c32 + imul_0(a00, b32) | 0;
  c48 = c48 + (c32 >>> 16 | 0) | 0;
  c32 = c32 & 65535;
  c48 = c48 + (((imul_0(a48, b00) + imul_0(a32, b16) | 0) + imul_0(a16, b32) | 0) + imul_0(a00, b48) | 0) | 0;
  c48 = c48 & 65535;
  return new Long(c16 << 16 | c00, c48 << 16 | c32);
}
function divide(_this__u8e3s4, other) {
  _init_properties_longJs_kt__elc2w5();
  if (isZero(other)) {
    throw Exception.f5('division by zero');
  } else if (isZero(_this__u8e3s4)) {
    return get_ZERO();
  }
  if (equalsLong(_this__u8e3s4, get_MIN_VALUE())) {
    if (equalsLong(other, get_ONE()) || equalsLong(other, get_NEG_ONE())) {
      return get_MIN_VALUE();
    } else if (equalsLong(other, get_MIN_VALUE())) {
      return get_ONE();
    } else {
      var halfThis = shiftRight(_this__u8e3s4, 1);
      var approx = shiftLeft(halfThis.k3(other), 1);
      if (equalsLong(approx, get_ZERO())) {
        return isNegative(other) ? get_ONE() : get_NEG_ONE();
      } else {
        var rem = subtract(_this__u8e3s4, multiply(other, approx));
        return add(approx, rem.k3(other));
      }
    }
  } else if (equalsLong(other, get_MIN_VALUE())) {
    return get_ZERO();
  }
  if (isNegative(_this__u8e3s4)) {
    var tmp;
    if (isNegative(other)) {
      tmp = negate(_this__u8e3s4).k3(negate(other));
    } else {
      tmp = negate(negate(_this__u8e3s4).k3(other));
    }
    return tmp;
  } else if (isNegative(other)) {
    return negate(_this__u8e3s4.k3(negate(other)));
  }
  var res = get_ZERO();
  var rem_0 = _this__u8e3s4;
  while (greaterThanOrEqual(rem_0, other)) {
    var approxDouble = toNumber(rem_0) / toNumber(other);
    var approx2 = Math.max(1.0, Math.floor(approxDouble));
    var log2 = Math.ceil(Math.log(approx2) / Math.LN2);
    var delta = log2 <= 48 ? 1.0 : Math.pow(2.0, log2 - 48);
    var approxRes = fromNumber(approx2);
    var approxRem = multiply(approxRes, other);
    while (isNegative(approxRem) || greaterThan(approxRem, rem_0)) {
      approx2 = approx2 - delta;
      approxRes = fromNumber(approx2);
      approxRem = multiply(approxRes, other);
    }
    if (isZero(approxRes)) {
      approxRes = get_ONE();
    }
    res = add(res, approxRes);
    rem_0 = subtract(rem_0, approxRem);
  }
  return res;
}
function modulo(_this__u8e3s4, other) {
  _init_properties_longJs_kt__elc2w5();
  return subtract(_this__u8e3s4, multiply(_this__u8e3s4.k3(other), other));
}
function shiftLeft(_this__u8e3s4, numBits) {
  _init_properties_longJs_kt__elc2w5();
  var numBits_0 = numBits & 63;
  if (numBits_0 === 0) {
    return _this__u8e3s4;
  } else {
    if (numBits_0 < 32) {
      return new Long(_this__u8e3s4.j1_1 << numBits_0, _this__u8e3s4.k1_1 << numBits_0 | (_this__u8e3s4.j1_1 >>> (32 - numBits_0 | 0) | 0));
    } else {
      return new Long(0, _this__u8e3s4.j1_1 << (numBits_0 - 32 | 0));
    }
  }
}
function shiftRight(_this__u8e3s4, numBits) {
  _init_properties_longJs_kt__elc2w5();
  var numBits_0 = numBits & 63;
  if (numBits_0 === 0) {
    return _this__u8e3s4;
  } else {
    if (numBits_0 < 32) {
      return new Long(_this__u8e3s4.j1_1 >>> numBits_0 | 0 | _this__u8e3s4.k1_1 << (32 - numBits_0 | 0), _this__u8e3s4.k1_1 >> numBits_0);
    } else {
      return new Long(_this__u8e3s4.k1_1 >> (numBits_0 - 32 | 0), _this__u8e3s4.k1_1 >= 0 ? 0 : -1);
    }
  }
}
function shiftRightUnsigned(_this__u8e3s4, numBits) {
  _init_properties_longJs_kt__elc2w5();
  var numBits_0 = numBits & 63;
  if (numBits_0 === 0) {
    return _this__u8e3s4;
  } else {
    if (numBits_0 < 32) {
      return new Long(_this__u8e3s4.j1_1 >>> numBits_0 | 0 | _this__u8e3s4.k1_1 << (32 - numBits_0 | 0), _this__u8e3s4.k1_1 >>> numBits_0 | 0);
    } else {
      var tmp;
      if (numBits_0 === 32) {
        tmp = new Long(_this__u8e3s4.k1_1, 0);
      } else {
        tmp = new Long(_this__u8e3s4.k1_1 >>> (numBits_0 - 32 | 0) | 0, 0);
      }
      return tmp;
    }
  }
}
function toNumber(_this__u8e3s4) {
  _init_properties_longJs_kt__elc2w5();
  return _this__u8e3s4.k1_1 * 4.294967296E9 + getLowBitsUnsigned(_this__u8e3s4);
}
function toStringImpl(_this__u8e3s4, radix) {
  _init_properties_longJs_kt__elc2w5();
  if (radix < 2 || 36 < radix) {
    throw Exception.f5('radix out of range: ' + radix);
  }
  if (isZero(_this__u8e3s4)) {
    return '0';
  }
  if (isNegative(_this__u8e3s4)) {
    if (equalsLong(_this__u8e3s4, get_MIN_VALUE())) {
      var radixLong = fromInt(radix);
      var div = _this__u8e3s4.k3(radixLong);
      var rem = subtract(multiply(div, radixLong), _this__u8e3s4).l1();
      var tmp = toStringImpl(div, radix);
      // Inline function 'kotlin.js.asDynamic' call
      // Inline function 'kotlin.js.unsafeCast' call
      return tmp + rem.toString(radix);
    } else {
      return '-' + toStringImpl(negate(_this__u8e3s4), radix);
    }
  }
  var digitsPerTime = radix === 2 ? 31 : radix <= 10 ? 9 : radix <= 21 ? 7 : radix <= 35 ? 6 : 5;
  var radixToPower = fromNumber(Math.pow(radix, digitsPerTime));
  var rem_0 = _this__u8e3s4;
  var result = '';
  while (true) {
    var remDiv = rem_0.k3(radixToPower);
    var intval = subtract(rem_0, multiply(remDiv, radixToPower)).l1();
    // Inline function 'kotlin.js.asDynamic' call
    // Inline function 'kotlin.js.unsafeCast' call
    var digits = intval.toString(radix);
    rem_0 = remDiv;
    if (isZero(rem_0)) {
      return digits + result;
    } else {
      while (digits.length < digitsPerTime) {
        digits = '0' + digits;
      }
      result = digits + result;
    }
  }
}
function equalsLong(_this__u8e3s4, other) {
  _init_properties_longJs_kt__elc2w5();
  return _this__u8e3s4.k1_1 === other.k1_1 && _this__u8e3s4.j1_1 === other.j1_1;
}
function hashCode_0(l) {
  _init_properties_longJs_kt__elc2w5();
  return l.j1_1 ^ l.k1_1;
}
function fromInt(value) {
  _init_properties_longJs_kt__elc2w5();
  return new Long(value, value < 0 ? -1 : 0);
}
function isNegative(_this__u8e3s4) {
  _init_properties_longJs_kt__elc2w5();
  return _this__u8e3s4.k1_1 < 0;
}
function isZero(_this__u8e3s4) {
  _init_properties_longJs_kt__elc2w5();
  return _this__u8e3s4.k1_1 === 0 && _this__u8e3s4.j1_1 === 0;
}
function isOdd(_this__u8e3s4) {
  _init_properties_longJs_kt__elc2w5();
  return (_this__u8e3s4.j1_1 & 1) === 1;
}
function negate(_this__u8e3s4) {
  _init_properties_longJs_kt__elc2w5();
  return _this__u8e3s4.o3();
}
function lessThan(_this__u8e3s4, other) {
  _init_properties_longJs_kt__elc2w5();
  return compare(_this__u8e3s4, other) < 0;
}
function fromNumber(value) {
  _init_properties_longJs_kt__elc2w5();
  if (isNaN_0(value)) {
    return get_ZERO();
  } else if (value <= -9.223372036854776E18) {
    return get_MIN_VALUE();
  } else if (value + 1 >= 9.223372036854776E18) {
    return get_MAX_VALUE();
  } else if (value < 0) {
    return negate(fromNumber(-value));
  } else {
    var twoPwr32 = 4.294967296E9;
    // Inline function 'kotlin.js.jsBitwiseOr' call
    var tmp = value % twoPwr32 | 0;
    // Inline function 'kotlin.js.jsBitwiseOr' call
    var tmp$ret$1 = value / twoPwr32 | 0;
    return new Long(tmp, tmp$ret$1);
  }
}
function greaterThan(_this__u8e3s4, other) {
  _init_properties_longJs_kt__elc2w5();
  return compare(_this__u8e3s4, other) > 0;
}
function greaterThanOrEqual(_this__u8e3s4, other) {
  _init_properties_longJs_kt__elc2w5();
  return compare(_this__u8e3s4, other) >= 0;
}
function getLowBitsUnsigned(_this__u8e3s4) {
  _init_properties_longJs_kt__elc2w5();
  return _this__u8e3s4.j1_1 >= 0 ? _this__u8e3s4.j1_1 : 4.294967296E9 + _this__u8e3s4.j1_1;
}
var properties_initialized_longJs_kt_4syf89;
function _init_properties_longJs_kt__elc2w5() {
  if (!properties_initialized_longJs_kt_4syf89) {
    properties_initialized_longJs_kt_4syf89 = true;
    ZERO = fromInt(0);
    ONE = fromInt(1);
    NEG_ONE = fromInt(-1);
    MAX_VALUE = new Long(-1, 2147483647);
    MIN_VALUE = new Long(0, -2147483648);
    TWO_PWR_24_ = fromInt(16777216);
  }
}
function createMetadata(kind, name, defaultConstructor, associatedObjectKey, associatedObjects, suspendArity) {
  var undef = VOID;
  var iid = kind === 'interface' ? generateInterfaceId() : VOID;
  return {kind: kind, simpleName: name, associatedObjectKey: associatedObjectKey, associatedObjects: associatedObjects, suspendArity: suspendArity, $kClass$: undef, defaultConstructor: defaultConstructor, iid: iid};
}
function generateInterfaceId() {
  if (globalInterfaceId === VOID) {
    globalInterfaceId = 0;
  }
  // Inline function 'kotlin.js.unsafeCast' call
  globalInterfaceId = globalInterfaceId + 1 | 0;
  // Inline function 'kotlin.js.unsafeCast' call
  return globalInterfaceId;
}
var globalInterfaceId;
function initMetadataFor(kind, ctor, name, defaultConstructor, parent, interfaces, suspendArity, associatedObjectKey, associatedObjects) {
  if (!(parent == null)) {
    ctor.prototype = Object.create(parent.prototype);
    ctor.prototype.constructor = ctor;
  }
  var metadata = createMetadata(kind, name, defaultConstructor, associatedObjectKey, associatedObjects, suspendArity);
  ctor.$metadata$ = metadata;
  if (!(interfaces == null)) {
    var receiver = !equals(metadata.iid, VOID) ? ctor : ctor.prototype;
    receiver.$imask$ = implement(interfaces);
  }
}
function initMetadataForClass(ctor, name, defaultConstructor, parent, interfaces, suspendArity, associatedObjectKey, associatedObjects) {
  var kind = 'class';
  initMetadataFor(kind, ctor, name, defaultConstructor, parent, interfaces, suspendArity, associatedObjectKey, associatedObjects);
}
function initMetadataForObject(ctor, name, defaultConstructor, parent, interfaces, suspendArity, associatedObjectKey, associatedObjects) {
  var kind = 'object';
  initMetadataFor(kind, ctor, name, defaultConstructor, parent, interfaces, suspendArity, associatedObjectKey, associatedObjects);
}
function initMetadataForInterface(ctor, name, defaultConstructor, parent, interfaces, suspendArity, associatedObjectKey, associatedObjects) {
  var kind = 'interface';
  initMetadataFor(kind, ctor, name, defaultConstructor, parent, interfaces, suspendArity, associatedObjectKey, associatedObjects);
}
function initMetadataForLambda(ctor, parent, interfaces, suspendArity) {
  initMetadataForClass(ctor, 'Lambda', VOID, parent, interfaces, suspendArity, VOID, VOID);
}
function initMetadataForCoroutine(ctor, parent, interfaces, suspendArity) {
  initMetadataForClass(ctor, 'Coroutine', VOID, parent, interfaces, suspendArity, VOID, VOID);
}
function initMetadataForFunctionReference(ctor, parent, interfaces, suspendArity) {
  initMetadataForClass(ctor, 'FunctionReference', VOID, parent, interfaces, suspendArity, VOID, VOID);
}
function initMetadataForCompanion(ctor, parent, interfaces, suspendArity) {
  initMetadataForObject(ctor, 'Companion', VOID, parent, interfaces, suspendArity, VOID, VOID);
}
function taggedArrayCopy(array) {
  var res = array.slice();
  res.$type$ = array.$type$;
  // Inline function 'kotlin.js.unsafeCast' call
  return res;
}
function toByte(a) {
  // Inline function 'kotlin.js.unsafeCast' call
  return a << 24 >> 24;
}
function numberToInt(a) {
  var tmp;
  if (a instanceof Long) {
    tmp = a.l1();
  } else {
    tmp = doubleToInt(a);
  }
  return tmp;
}
function doubleToInt(a) {
  var tmp;
  if (a > 2147483647) {
    tmp = 2147483647;
  } else if (a < -2147483648) {
    tmp = -2147483648;
  } else {
    // Inline function 'kotlin.js.jsBitwiseOr' call
    tmp = a | 0;
  }
  return tmp;
}
function numberToDouble(a) {
  // Inline function 'kotlin.js.unsafeCast' call
  return +a;
}
function toShort(a) {
  // Inline function 'kotlin.js.unsafeCast' call
  return a << 16 >> 16;
}
function numberToLong(a) {
  var tmp;
  if (a instanceof Long) {
    tmp = a;
  } else {
    tmp = fromNumber(a);
  }
  return tmp;
}
function numberToChar(a) {
  // Inline function 'kotlin.toUShort' call
  var this_0 = numberToInt(a);
  var tmp$ret$0 = _UShort___init__impl__jigrne(toShort(this_0));
  return _Char___init__impl__6a9atx_0(tmp$ret$0);
}
function toLong(a) {
  return fromInt(a);
}
function numberRangeToNumber(start, endInclusive) {
  return new IntRange(start, endInclusive);
}
function get_propertyRefClassMetadataCache() {
  _init_properties_reflectRuntime_kt__5r4uu3();
  return propertyRefClassMetadataCache;
}
var propertyRefClassMetadataCache;
function metadataObject() {
  _init_properties_reflectRuntime_kt__5r4uu3();
  return createMetadata('class', VOID, VOID, VOID, VOID, VOID);
}
function getPropertyCallableRef(name, paramCount, superType, getter, setter) {
  _init_properties_reflectRuntime_kt__5r4uu3();
  getter.get = getter;
  getter.set = setter;
  getter.callableName = name;
  // Inline function 'kotlin.js.unsafeCast' call
  return getPropertyRefClass(getter, getKPropMetadata(paramCount, setter), getInterfaceMaskFor(getter, superType));
}
function getPropertyRefClass(obj, metadata, imask) {
  _init_properties_reflectRuntime_kt__5r4uu3();
  obj.$metadata$ = metadata;
  obj.constructor = obj;
  obj.$imask$ = imask;
  return obj;
}
function getKPropMetadata(paramCount, setter) {
  _init_properties_reflectRuntime_kt__5r4uu3();
  return get_propertyRefClassMetadataCache()[paramCount][setter == null ? 0 : 1];
}
function getInterfaceMaskFor(obj, superType) {
  _init_properties_reflectRuntime_kt__5r4uu3();
  var tmp0_elvis_lhs = obj.$imask$;
  var tmp;
  if (tmp0_elvis_lhs == null) {
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var tmp$ret$2 = [superType];
    tmp = implement(tmp$ret$2);
  } else {
    tmp = tmp0_elvis_lhs;
  }
  return tmp;
}
var properties_initialized_reflectRuntime_kt_inkhwd;
function _init_properties_reflectRuntime_kt__5r4uu3() {
  if (!properties_initialized_reflectRuntime_kt_inkhwd) {
    properties_initialized_reflectRuntime_kt_inkhwd = true;
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var tmp = [metadataObject(), metadataObject()];
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var tmp_0 = [metadataObject(), metadataObject()];
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    propertyRefClassMetadataCache = [tmp, tmp_0, [metadataObject(), metadataObject()]];
  }
}
function isArrayish(o) {
  return isJsArray(o) || isView(o);
}
function isJsArray(obj) {
  // Inline function 'kotlin.js.unsafeCast' call
  return Array.isArray(obj);
}
function isInterface(obj, iface) {
  return isInterfaceImpl(obj, iface.$metadata$.iid);
}
function isInterfaceImpl(obj, iface) {
  // Inline function 'kotlin.js.unsafeCast' call
  var tmp0_elvis_lhs = obj.$imask$;
  var tmp;
  if (tmp0_elvis_lhs == null) {
    return false;
  } else {
    tmp = tmp0_elvis_lhs;
  }
  var mask = tmp;
  return isBitSet(mask, iface);
}
function isArray(obj) {
  var tmp;
  if (isJsArray(obj)) {
    // Inline function 'kotlin.js.asDynamic' call
    tmp = !obj.$type$;
  } else {
    tmp = false;
  }
  return tmp;
}
function isNumber(a) {
  var tmp;
  if (typeof a === 'number') {
    tmp = true;
  } else {
    tmp = a instanceof Long;
  }
  return tmp;
}
function isComparable(value) {
  var type = typeof value;
  return type === 'string' || type === 'boolean' || isNumber(value) || isInterface(value, Comparable);
}
function isCharSequence(value) {
  return typeof value === 'string' || isInterface(value, CharSequence);
}
function isBooleanArray(a) {
  return isJsArray(a) && a.$type$ === 'BooleanArray';
}
function isByteArray(a) {
  // Inline function 'kotlin.js.jsInstanceOf' call
  return a instanceof Int8Array;
}
function isShortArray(a) {
  // Inline function 'kotlin.js.jsInstanceOf' call
  return a instanceof Int16Array;
}
function isCharArray(a) {
  var tmp;
  // Inline function 'kotlin.js.jsInstanceOf' call
  if (a instanceof Uint16Array) {
    tmp = a.$type$ === 'CharArray';
  } else {
    tmp = false;
  }
  return tmp;
}
function isIntArray(a) {
  // Inline function 'kotlin.js.jsInstanceOf' call
  return a instanceof Int32Array;
}
function isFloatArray(a) {
  // Inline function 'kotlin.js.jsInstanceOf' call
  return a instanceof Float32Array;
}
function isLongArray(a) {
  return isJsArray(a) && a.$type$ === 'LongArray';
}
function isDoubleArray(a) {
  // Inline function 'kotlin.js.jsInstanceOf' call
  return a instanceof Float64Array;
}
function calculateErrorInfo(proto) {
  var tmp0_safe_receiver = proto.constructor;
  var metadata = tmp0_safe_receiver == null ? null : tmp0_safe_receiver.$metadata$;
  var tmp2_safe_receiver = metadata == null ? null : metadata.errorInfo;
  if (tmp2_safe_receiver == null)
    null;
  else {
    // Inline function 'kotlin.let' call
    return tmp2_safe_receiver;
  }
  var result = 0;
  if (hasProp(proto, 'message'))
    result = result | 1;
  if (hasProp(proto, 'cause'))
    result = result | 2;
  if (!(result === 3)) {
    var parentProto = getPrototypeOf(proto);
    if (parentProto != Error.prototype) {
      result = result | calculateErrorInfo(parentProto);
    }
  }
  if (!(metadata == null)) {
    metadata.errorInfo = result;
  }
  return result;
}
function hasProp(proto, propName) {
  return proto.hasOwnProperty(propName);
}
function getPrototypeOf(obj) {
  return Object.getPrototypeOf(obj);
}
function get_VOID() {
  _init_properties_void_kt__3zg9as();
  return VOID;
}
var VOID;
var properties_initialized_void_kt_e4ret2;
function _init_properties_void_kt__3zg9as() {
  if (!properties_initialized_void_kt_e4ret2) {
    properties_initialized_void_kt_e4ret2 = true;
    VOID = void 0;
  }
}
function copyOfRange(_this__u8e3s4, fromIndex, toIndex) {
  Companion_instance_7.h5(fromIndex, toIndex, _this__u8e3s4.length);
  // Inline function 'kotlin.js.asDynamic' call
  return _this__u8e3s4.slice(fromIndex, toIndex);
}
function copyOf(_this__u8e3s4, newSize) {
  // Inline function 'kotlin.require' call
  if (!(newSize >= 0)) {
    // Inline function 'kotlin.collections.copyOf.<anonymous>' call
    var message = 'Invalid new array size: ' + newSize + '.';
    throw IllegalArgumentException.h(toString_1(message));
  }
  return fillFrom(_this__u8e3s4, new Int32Array(newSize));
}
function copyOf_0(_this__u8e3s4, newSize) {
  // Inline function 'kotlin.require' call
  if (!(newSize >= 0)) {
    // Inline function 'kotlin.collections.copyOf.<anonymous>' call
    var message = 'Invalid new array size: ' + newSize + '.';
    throw IllegalArgumentException.h(toString_1(message));
  }
  return arrayCopyResize(_this__u8e3s4, newSize, null);
}
function fill(_this__u8e3s4, element, fromIndex, toIndex) {
  fromIndex = fromIndex === VOID ? 0 : fromIndex;
  toIndex = toIndex === VOID ? _this__u8e3s4.length : toIndex;
  Companion_instance_7.h5(fromIndex, toIndex, _this__u8e3s4.length);
  // Inline function 'kotlin.js.nativeFill' call
  // Inline function 'kotlin.js.asDynamic' call
  _this__u8e3s4.fill(element, fromIndex, toIndex);
}
function asList(_this__u8e3s4) {
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return ArrayList.i4(_this__u8e3s4);
}
function contentEquals(_this__u8e3s4, other) {
  return contentEqualsInternal(_this__u8e3s4, other);
}
function contentHashCode(_this__u8e3s4) {
  return contentHashCodeInternal(_this__u8e3s4);
}
function contentToString(_this__u8e3s4) {
  var tmp1_elvis_lhs = _this__u8e3s4 == null ? null : joinToString(_this__u8e3s4, ', ', '[', ']');
  return tmp1_elvis_lhs == null ? 'null' : tmp1_elvis_lhs;
}
function contentEquals_0(_this__u8e3s4, other) {
  return contentEqualsInternal(_this__u8e3s4, other);
}
function contentHashCode_0(_this__u8e3s4) {
  return contentHashCodeInternal(_this__u8e3s4);
}
function contentToString_0(_this__u8e3s4) {
  var tmp1_elvis_lhs = _this__u8e3s4 == null ? null : joinToString_0(_this__u8e3s4, ', ', '[', ']');
  return tmp1_elvis_lhs == null ? 'null' : tmp1_elvis_lhs;
}
function sortWith(_this__u8e3s4, comparator) {
  if (_this__u8e3s4.length > 1) {
    sortArrayWith(_this__u8e3s4, comparator);
  }
}
function copyOfRange_0(_this__u8e3s4, fromIndex, toIndex) {
  Companion_instance_7.h5(fromIndex, toIndex, _this__u8e3s4.length);
  // Inline function 'kotlin.js.asDynamic' call
  return _this__u8e3s4.slice(fromIndex, toIndex);
}
function toTypedArray(_this__u8e3s4) {
  return [].slice.call(_this__u8e3s4);
}
function digitToIntImpl(_this__u8e3s4) {
  // Inline function 'kotlin.code' call
  var ch = Char__toInt_impl_vasixd(_this__u8e3s4);
  var index = binarySearchRange(Digit_getInstance().i5_1, ch);
  var diff = ch - Digit_getInstance().i5_1[index] | 0;
  return diff < 10 ? diff : -1;
}
function binarySearchRange(array, needle) {
  var bottom = 0;
  var top = array.length - 1 | 0;
  var middle = -1;
  var value = 0;
  while (bottom <= top) {
    middle = (bottom + top | 0) / 2 | 0;
    value = array[middle];
    if (needle > value)
      bottom = middle + 1 | 0;
    else if (needle === value)
      return middle;
    else
      top = middle - 1 | 0;
  }
  return middle - (needle < value ? 1 : 0) | 0;
}
var Digit_instance;
function Digit_getInstance() {
  if (Digit_instance === VOID)
    new Digit();
  return Digit_instance;
}
function isWhitespaceImpl(_this__u8e3s4) {
  // Inline function 'kotlin.code' call
  var ch = Char__toInt_impl_vasixd(_this__u8e3s4);
  return (9 <= ch ? ch <= 13 : false) || (28 <= ch ? ch <= 32 : false) || ch === 160 || (ch > 4096 && (ch === 5760 || (8192 <= ch ? ch <= 8202 : false) || ch === 8232 || ch === 8233 || ch === 8239 || ch === 8287 || ch === 12288));
}
function isNaN_0(_this__u8e3s4) {
  return !(_this__u8e3s4 === _this__u8e3s4);
}
function isInfinite(_this__u8e3s4) {
  return _this__u8e3s4 === Infinity || _this__u8e3s4 === -Infinity;
}
function toBits(_this__u8e3s4) {
  return doubleToRawBits(isNaN_0(_this__u8e3s4) ? NaN : _this__u8e3s4);
}
function toRawBits(_this__u8e3s4) {
  return doubleToRawBits(_this__u8e3s4);
}
function takeHighestOneBit(_this__u8e3s4) {
  var tmp;
  if (_this__u8e3s4 === 0) {
    tmp = 0;
  } else {
    // Inline function 'kotlin.countLeadingZeroBits' call
    tmp = 1 << (31 - clz32(_this__u8e3s4) | 0);
  }
  return tmp;
}
function isNaN_1(_this__u8e3s4) {
  return !(_this__u8e3s4 === _this__u8e3s4);
}
function isInfinite_0(_this__u8e3s4) {
  return _this__u8e3s4 === Infinity || _this__u8e3s4 === -Infinity;
}
var Unit_instance;
function Unit_getInstance() {
  return Unit_instance;
}
function uintToDouble(value) {
  return (value & 2147483647) + ((value >>> 31 | 0) << 30) * 2;
}
function doubleToUInt(value) {
  var tmp;
  if (isNaN_0(value)) {
    tmp = _UInt___init__impl__l7qpdl(0);
  } else {
    // Inline function 'kotlin.UInt.toDouble' call
    var this_0 = _UInt___init__impl__l7qpdl(0);
    if (value <= uintToDouble(_UInt___get_data__impl__f0vqqw(this_0))) {
      tmp = _UInt___init__impl__l7qpdl(0);
    } else {
      // Inline function 'kotlin.UInt.toDouble' call
      var this_1 = _UInt___init__impl__l7qpdl(-1);
      if (value >= uintToDouble(_UInt___get_data__impl__f0vqqw(this_1))) {
        tmp = _UInt___init__impl__l7qpdl(-1);
      } else {
        if (value <= 2147483647) {
          // Inline function 'kotlin.toUInt' call
          var this_2 = numberToInt(value);
          tmp = _UInt___init__impl__l7qpdl(this_2);
        } else {
          // Inline function 'kotlin.toUInt' call
          var this_3 = numberToInt(value - 2147483647);
          var tmp5 = _UInt___init__impl__l7qpdl(this_3);
          // Inline function 'kotlin.toUInt' call
          var this_4 = 2147483647;
          // Inline function 'kotlin.UInt.plus' call
          var other = _UInt___init__impl__l7qpdl(this_4);
          tmp = _UInt___init__impl__l7qpdl(_UInt___get_data__impl__f0vqqw(tmp5) + _UInt___get_data__impl__f0vqqw(other) | 0);
        }
      }
    }
  }
  return tmp;
}
function collectionToArray(collection) {
  return collectionToArrayCommonImpl(collection);
}
function terminateCollectionToArray(collectionSize, array) {
  return array;
}
function arrayOfNulls(reference, size) {
  // Inline function 'kotlin.arrayOfNulls' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return fillArrayVal(Array(size), null);
}
function listOf(element) {
  return arrayListOf([element]);
}
function sortWith_0(_this__u8e3s4, comparator) {
  collectionsSort(_this__u8e3s4, comparator);
}
function setOf(element) {
  return hashSetOf([element]);
}
function sort(_this__u8e3s4) {
  collectionsSort(_this__u8e3s4, naturalOrder());
}
function mapCapacity(expectedSize) {
  return expectedSize;
}
function arrayCopy(source, destination, destinationOffset, startIndex, endIndex) {
  Companion_instance_7.h5(startIndex, endIndex, source.length);
  var rangeSize = endIndex - startIndex | 0;
  Companion_instance_7.h5(destinationOffset, destinationOffset + rangeSize | 0, destination.length);
  if (isView(destination) && isView(source)) {
    // Inline function 'kotlin.js.asDynamic' call
    var subrange = source.subarray(startIndex, endIndex);
    // Inline function 'kotlin.js.asDynamic' call
    destination.set(subrange, destinationOffset);
  } else {
    if (!(source === destination) || destinationOffset <= startIndex) {
      var inductionVariable = 0;
      if (inductionVariable < rangeSize)
        do {
          var index = inductionVariable;
          inductionVariable = inductionVariable + 1 | 0;
          destination[destinationOffset + index | 0] = source[startIndex + index | 0];
        }
         while (inductionVariable < rangeSize);
    } else {
      var inductionVariable_0 = rangeSize - 1 | 0;
      if (0 <= inductionVariable_0)
        do {
          var index_0 = inductionVariable_0;
          inductionVariable_0 = inductionVariable_0 + -1 | 0;
          destination[destinationOffset + index_0 | 0] = source[startIndex + index_0 | 0];
        }
         while (0 <= inductionVariable_0);
    }
  }
}
function copyToArray(collection) {
  var tmp;
  // Inline function 'kotlin.js.asDynamic' call
  if (collection.toArray !== undefined) {
    // Inline function 'kotlin.js.asDynamic' call
    // Inline function 'kotlin.js.unsafeCast' call
    tmp = collection.toArray();
  } else {
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp = collectionToArray(collection);
  }
  return tmp;
}
function collectionsSort(list, comparator) {
  if (list.a1() <= 1)
    return Unit_instance;
  var array = copyToArray(list);
  sortArrayWith(array, comparator);
  var inductionVariable = 0;
  var last = array.length;
  if (inductionVariable < last)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      list.j5(i, array[i]);
    }
     while (inductionVariable < last);
}
function checkIndexOverflow(index) {
  if (index < 0) {
    throwIndexOverflow();
  }
  return index;
}
function AbstractMutableList$removeAll$lambda($elements) {
  return (it) => $elements.j2(it);
}
function AbstractMutableList$retainAll$lambda($elements) {
  return (it) => !$elements.j2(it);
}
function arrayOfUninitializedElements(capacity) {
  // Inline function 'kotlin.require' call
  if (!(capacity >= 0)) {
    // Inline function 'kotlin.collections.arrayOfUninitializedElements.<anonymous>' call
    var message = 'capacity must be non-negative.';
    throw IllegalArgumentException.h(toString_1(message));
  }
  // Inline function 'kotlin.arrayOfNulls' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return fillArrayVal(Array(capacity), null);
}
function resetRange(_this__u8e3s4, fromIndex, toIndex) {
  // Inline function 'kotlin.js.nativeFill' call
  // Inline function 'kotlin.js.asDynamic' call
  _this__u8e3s4.fill(null, fromIndex, toIndex);
}
function copyOfUninitializedElements(_this__u8e3s4, newSize) {
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return copyOf_0(_this__u8e3s4, newSize);
}
function resetAt(_this__u8e3s4, index) {
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  _this__u8e3s4[index] = null;
}
var Companion_instance_4;
function Companion_getInstance_4() {
  if (Companion_instance_4 === VOID)
    new Companion_4();
  return Companion_instance_4;
}
function increaseLength($this, amount) {
  var previous = $this.a1();
  // Inline function 'kotlin.js.asDynamic' call
  $this.j_1.length = $this.a1() + amount | 0;
  return previous;
}
function rangeCheck($this, index) {
  // Inline function 'kotlin.apply' call
  // Inline function 'kotlin.collections.ArrayList.rangeCheck.<anonymous>' call
  Companion_instance_7.k6(index, $this.a1());
  return index;
}
function insertionRangeCheck($this, index) {
  // Inline function 'kotlin.apply' call
  // Inline function 'kotlin.collections.ArrayList.insertionRangeCheck.<anonymous>' call
  Companion_instance_7.z5(index, $this.a1());
  return index;
}
var _stableSortingIsSupported;
function sortArrayWith(array, comparator) {
  if (getStableSortingIsSupported()) {
    var comparison = sortArrayWith$lambda(comparator);
    // Inline function 'kotlin.js.asDynamic' call
    array.sort(comparison);
  } else {
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    mergeSort(array, 0, get_lastIndex(array), comparator);
  }
}
function mergeSort(array, start, endInclusive, comparator) {
  // Inline function 'kotlin.arrayOfNulls' call
  var size = array.length;
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  var buffer = fillArrayVal(Array(size), null);
  var result = mergeSort_0(array, buffer, start, endInclusive, comparator);
  if (!(result === array)) {
    var inductionVariable = start;
    if (inductionVariable <= endInclusive)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        array[i] = result[i];
      }
       while (!(i === endInclusive));
  }
}
function getStableSortingIsSupported() {
  var tmp0_safe_receiver = _stableSortingIsSupported;
  if (tmp0_safe_receiver == null)
    null;
  else {
    // Inline function 'kotlin.let' call
    return tmp0_safe_receiver;
  }
  _stableSortingIsSupported = false;
  // Inline function 'kotlin.js.unsafeCast' call
  var array = [];
  var inductionVariable = 0;
  if (inductionVariable < 600)
    do {
      var index = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      // Inline function 'kotlin.js.asDynamic' call
      array.push(index);
    }
     while (inductionVariable < 600);
  var comparison = getStableSortingIsSupported$lambda;
  // Inline function 'kotlin.js.asDynamic' call
  array.sort(comparison);
  var inductionVariable_0 = 1;
  var last = array.length;
  if (inductionVariable_0 < last)
    do {
      var index_0 = inductionVariable_0;
      inductionVariable_0 = inductionVariable_0 + 1 | 0;
      var a = array[index_0 - 1 | 0];
      var b = array[index_0];
      if ((a & 3) === (b & 3) && a >= b)
        return false;
    }
     while (inductionVariable_0 < last);
  _stableSortingIsSupported = true;
  return true;
}
function mergeSort_0(array, buffer, start, end, comparator) {
  if (start === end) {
    return array;
  }
  var median = (start + end | 0) / 2 | 0;
  var left = mergeSort_0(array, buffer, start, median, comparator);
  var right = mergeSort_0(array, buffer, median + 1 | 0, end, comparator);
  var target = left === buffer ? array : buffer;
  var leftIndex = start;
  var rightIndex = median + 1 | 0;
  var inductionVariable = start;
  if (inductionVariable <= end)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      if (leftIndex <= median && rightIndex <= end) {
        var leftValue = left[leftIndex];
        var rightValue = right[rightIndex];
        if (comparator.compare(leftValue, rightValue) <= 0) {
          target[i] = leftValue;
          leftIndex = leftIndex + 1 | 0;
        } else {
          target[i] = rightValue;
          rightIndex = rightIndex + 1 | 0;
        }
      } else if (leftIndex <= median) {
        target[i] = left[leftIndex];
        leftIndex = leftIndex + 1 | 0;
      } else {
        target[i] = right[rightIndex];
        rightIndex = rightIndex + 1 | 0;
      }
    }
     while (!(i === end));
  return target;
}
function sortArrayWith$lambda($comparator) {
  return (a, b) => $comparator.compare(a, b);
}
function getStableSortingIsSupported$lambda(a, b) {
  return (a & 3) - (b & 3) | 0;
}
function init_kotlin_collections_HashMap(_this__u8e3s4) {
  _this__u8e3s4.b8_1 = null;
}
function init_kotlin_collections_HashSet(_this__u8e3s4) {
}
function computeHashSize($this, capacity) {
  return takeHighestOneBit(imul_0(coerceAtLeast(capacity, 1), 3));
}
function computeShift($this, hashSize) {
  // Inline function 'kotlin.countLeadingZeroBits' call
  return clz32(hashSize) + 1 | 0;
}
function checkForComodification($this) {
  if (!($this.ga_1.l8_1 === $this.ia_1))
    throw ConcurrentModificationException.fa('The backing map has been modified after this entry was obtained.');
}
function _get_capacity__a9k9f3($this) {
  return $this.e8_1.length;
}
function _get_hashSize__tftcho($this) {
  return $this.h8_1.length;
}
function registerModification($this) {
  $this.l8_1 = $this.l8_1 + 1 | 0;
}
function ensureExtraCapacity($this, n) {
  if (shouldCompact($this, n)) {
    compact($this, true);
  } else {
    ensureCapacity($this, $this.j8_1 + n | 0);
  }
}
function shouldCompact($this, extraCapacity) {
  var spareCapacity = _get_capacity__a9k9f3($this) - $this.j8_1 | 0;
  var gaps = $this.j8_1 - $this.a1() | 0;
  return spareCapacity < extraCapacity && (gaps + spareCapacity | 0) >= extraCapacity && gaps >= (_get_capacity__a9k9f3($this) / 4 | 0);
}
function ensureCapacity($this, minCapacity) {
  if (minCapacity < 0)
    throw RuntimeException.ja('too many elements');
  if (minCapacity > _get_capacity__a9k9f3($this)) {
    var newSize = Companion_instance_7.ka(_get_capacity__a9k9f3($this), minCapacity);
    $this.e8_1 = copyOfUninitializedElements($this.e8_1, newSize);
    var tmp = $this;
    var tmp0_safe_receiver = $this.f8_1;
    tmp.f8_1 = tmp0_safe_receiver == null ? null : copyOfUninitializedElements(tmp0_safe_receiver, newSize);
    $this.g8_1 = copyOf($this.g8_1, newSize);
    var newHashSize = computeHashSize(Companion_instance_5, newSize);
    if (newHashSize > _get_hashSize__tftcho($this)) {
      rehash($this, newHashSize);
    }
  }
}
function allocateValuesArray($this) {
  var curValuesArray = $this.f8_1;
  if (!(curValuesArray == null))
    return curValuesArray;
  var newValuesArray = arrayOfUninitializedElements(_get_capacity__a9k9f3($this));
  $this.f8_1 = newValuesArray;
  return newValuesArray;
}
function hash($this, key) {
  return key == null ? 0 : imul_0(hashCode(key), -1640531527) >>> $this.k8_1 | 0;
}
function compact($this, updateHashArray) {
  var i = 0;
  var j = 0;
  var valuesArray = $this.f8_1;
  while (i < $this.j8_1) {
    var hash = $this.g8_1[i];
    if (hash >= 0) {
      $this.e8_1[j] = $this.e8_1[i];
      if (!(valuesArray == null)) {
        valuesArray[j] = valuesArray[i];
      }
      if (updateHashArray) {
        $this.g8_1[j] = hash;
        $this.h8_1[hash] = j + 1 | 0;
      }
      j = j + 1 | 0;
    }
    i = i + 1 | 0;
  }
  resetRange($this.e8_1, j, $this.j8_1);
  if (valuesArray == null)
    null;
  else {
    resetRange(valuesArray, j, $this.j8_1);
  }
  $this.j8_1 = j;
}
function rehash($this, newHashSize) {
  registerModification($this);
  if ($this.j8_1 > $this.m8_1) {
    compact($this, false);
  }
  $this.h8_1 = new Int32Array(newHashSize);
  $this.k8_1 = computeShift(Companion_instance_5, newHashSize);
  var i = 0;
  while (i < $this.j8_1) {
    var _unary__edvuaz = i;
    i = _unary__edvuaz + 1 | 0;
    if (!putRehash($this, _unary__edvuaz)) {
      throw IllegalStateException.n4('This cannot happen with fixed magic multiplier and grow-only hash array. Have object hashCodes changed?');
    }
  }
}
function putRehash($this, i) {
  var hash_0 = hash($this, $this.e8_1[i]);
  var probesLeft = $this.i8_1;
  while (true) {
    var index = $this.h8_1[hash_0];
    if (index === 0) {
      $this.h8_1[hash_0] = i + 1 | 0;
      $this.g8_1[i] = hash_0;
      return true;
    }
    probesLeft = probesLeft - 1 | 0;
    if (probesLeft < 0)
      return false;
    var _unary__edvuaz = hash_0;
    hash_0 = _unary__edvuaz - 1 | 0;
    if (_unary__edvuaz === 0)
      hash_0 = _get_hashSize__tftcho($this) - 1 | 0;
  }
}
function findKey($this, key) {
  var hash_0 = hash($this, key);
  var probesLeft = $this.i8_1;
  while (true) {
    var index = $this.h8_1[hash_0];
    if (index === 0)
      return -1;
    if (index > 0 && equals($this.e8_1[index - 1 | 0], key))
      return index - 1 | 0;
    probesLeft = probesLeft - 1 | 0;
    if (probesLeft < 0)
      return -1;
    var _unary__edvuaz = hash_0;
    hash_0 = _unary__edvuaz - 1 | 0;
    if (_unary__edvuaz === 0)
      hash_0 = _get_hashSize__tftcho($this) - 1 | 0;
  }
}
function findValue($this, value) {
  var i = $this.j8_1;
  $l$loop: while (true) {
    i = i - 1 | 0;
    if (!(i >= 0)) {
      break $l$loop;
    }
    if ($this.g8_1[i] >= 0 && equals(ensureNotNull($this.f8_1)[i], value))
      return i;
  }
  return -1;
}
function addKey($this, key) {
  $this.b9();
  retry: while (true) {
    var hash_0 = hash($this, key);
    var tentativeMaxProbeDistance = coerceAtMost(imul_0($this.i8_1, 2), _get_hashSize__tftcho($this) / 2 | 0);
    var probeDistance = 0;
    while (true) {
      var index = $this.h8_1[hash_0];
      if (index <= 0) {
        if ($this.j8_1 >= _get_capacity__a9k9f3($this)) {
          ensureExtraCapacity($this, 1);
          continue retry;
        }
        var _unary__edvuaz = $this.j8_1;
        $this.j8_1 = _unary__edvuaz + 1 | 0;
        var putIndex = _unary__edvuaz;
        $this.e8_1[putIndex] = key;
        $this.g8_1[putIndex] = hash_0;
        $this.h8_1[hash_0] = putIndex + 1 | 0;
        $this.m8_1 = $this.m8_1 + 1 | 0;
        registerModification($this);
        if (probeDistance > $this.i8_1)
          $this.i8_1 = probeDistance;
        return putIndex;
      }
      if (equals($this.e8_1[index - 1 | 0], key)) {
        return -index | 0;
      }
      probeDistance = probeDistance + 1 | 0;
      if (probeDistance > tentativeMaxProbeDistance) {
        rehash($this, imul_0(_get_hashSize__tftcho($this), 2));
        continue retry;
      }
      var _unary__edvuaz_0 = hash_0;
      hash_0 = _unary__edvuaz_0 - 1 | 0;
      if (_unary__edvuaz_0 === 0)
        hash_0 = _get_hashSize__tftcho($this) - 1 | 0;
    }
  }
}
function removeEntryAt($this, index) {
  resetAt($this.e8_1, index);
  var tmp0_safe_receiver = $this.f8_1;
  if (tmp0_safe_receiver == null)
    null;
  else {
    resetAt(tmp0_safe_receiver, index);
  }
  removeHashAt($this, $this.g8_1[index]);
  $this.g8_1[index] = -1;
  $this.m8_1 = $this.m8_1 - 1 | 0;
  registerModification($this);
}
function removeHashAt($this, removedHash) {
  var hash_0 = removedHash;
  var hole = removedHash;
  var probeDistance = 0;
  var patchAttemptsLeft = coerceAtMost(imul_0($this.i8_1, 2), _get_hashSize__tftcho($this) / 2 | 0);
  while (true) {
    var _unary__edvuaz = hash_0;
    hash_0 = _unary__edvuaz - 1 | 0;
    if (_unary__edvuaz === 0)
      hash_0 = _get_hashSize__tftcho($this) - 1 | 0;
    probeDistance = probeDistance + 1 | 0;
    if (probeDistance > $this.i8_1) {
      $this.h8_1[hole] = 0;
      return Unit_instance;
    }
    var index = $this.h8_1[hash_0];
    if (index === 0) {
      $this.h8_1[hole] = 0;
      return Unit_instance;
    }
    if (index < 0) {
      $this.h8_1[hole] = -1;
      hole = hash_0;
      probeDistance = 0;
    } else {
      var otherHash = hash($this, $this.e8_1[index - 1 | 0]);
      if (((otherHash - hash_0 | 0) & (_get_hashSize__tftcho($this) - 1 | 0)) >= probeDistance) {
        $this.h8_1[hole] = index;
        $this.g8_1[index - 1 | 0] = hole;
        hole = hash_0;
        probeDistance = 0;
      }
    }
    patchAttemptsLeft = patchAttemptsLeft - 1 | 0;
    if (patchAttemptsLeft < 0) {
      $this.h8_1[hole] = -1;
      return Unit_instance;
    }
  }
}
function contentEquals_1($this, other) {
  return $this.m8_1 === other.a1() && $this.q9(other.v2());
}
var Companion_instance_5;
function Companion_getInstance_5() {
  return Companion_instance_5;
}
var EmptyHolder_instance;
function EmptyHolder_getInstance() {
  if (EmptyHolder_instance === VOID)
    new EmptyHolder();
  return EmptyHolder_instance;
}
function init_kotlin_collections_LinkedHashSet(_this__u8e3s4) {
}
function get_output() {
  _init_properties_console_kt__rfg7jv();
  return output;
}
var output;
function println(message) {
  _init_properties_console_kt__rfg7jv();
  get_output().wb(message);
}
function print(message) {
  _init_properties_console_kt__rfg7jv();
  get_output().vb(message);
}
function println_0() {
  _init_properties_console_kt__rfg7jv();
  get_output().ub();
}
var properties_initialized_console_kt_gll9dl;
function _init_properties_console_kt__rfg7jv() {
  if (!properties_initialized_console_kt_gll9dl) {
    properties_initialized_console_kt_gll9dl = true;
    // Inline function 'kotlin.run' call
    // Inline function 'kotlin.io.output.<anonymous>' call
    var isNode = typeof process !== 'undefined' && process.versions && !!process.versions.node;
    output = isNode ? new NodeJsOutput(process.stdout) : new BufferedOutputToConsoleLog();
  }
}
function init_kotlin_coroutines_cancellation_CancellationException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.jc_1);
}
function intercepted(_this__u8e3s4) {
  var tmp0_safe_receiver = _this__u8e3s4 instanceof InterceptedCoroutine ? _this__u8e3s4 : null;
  var tmp1_elvis_lhs = tmp0_safe_receiver == null ? null : tmp0_safe_receiver.cc();
  return tmp1_elvis_lhs == null ? _this__u8e3s4 : tmp1_elvis_lhs;
}
function asDynamic(_this__u8e3s4) {
  return _this__u8e3s4;
}
function iterator(_this__u8e3s4) {
  var r = _this__u8e3s4;
  var tmp;
  if (_this__u8e3s4['iterator'] != null) {
    tmp = _this__u8e3s4['iterator']();
  } else if (isArrayish(r)) {
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp = arrayIterator(r);
  } else {
    tmp = ((!(r == null) ? isInterface(r, Iterable) : false) ? r : THROW_CCE()).x();
  }
  return tmp;
}
function init_kotlin_Exception(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.e5_1);
}
function init_kotlin_IllegalArgumentException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.g_1);
}
function init_kotlin_IllegalStateException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.m4_1);
}
function init_kotlin_UnsupportedOperationException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.g4_1);
}
function init_kotlin_RuntimeException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.t1_1);
}
function init_kotlin_NoSuchElementException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.r_1);
}
function init_kotlin_Error(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.tc_1);
}
function init_kotlin_IndexOutOfBoundsException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.zc_1);
}
function init_kotlin_NumberFormatException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.fd_1);
}
function init_kotlin_ArithmeticException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.kd_1);
}
function init_kotlin_AssertionError(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.od_1);
}
function init_kotlin_ConcurrentModificationException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.ea_1);
}
function init_kotlin_ClassCastException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.y4_1);
}
function init_kotlin_NullPointerException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.q4_1);
}
function init_kotlin_NoWhenBranchMatchedException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.u4_1);
}
function init_kotlin_UninitializedPropertyAccessException(_this__u8e3s4) {
  captureStack(_this__u8e3s4, _this__u8e3s4.c5_1);
}
function lazy(initializer) {
  return new UnsafeLazyImpl(initializer);
}
function fillFrom(src, dst) {
  var srcLen = src.length;
  var dstLen = dst.length;
  var index = 0;
  // Inline function 'kotlin.js.unsafeCast' call
  var arr = dst;
  while (index < srcLen && index < dstLen) {
    var tmp = index;
    var _unary__edvuaz = index;
    index = _unary__edvuaz + 1 | 0;
    arr[tmp] = src[_unary__edvuaz];
  }
  return dst;
}
function arrayCopyResize(source, newSize, defaultValue) {
  // Inline function 'kotlin.js.unsafeCast' call
  var result = source.slice(0, newSize);
  // Inline function 'kotlin.copyArrayType' call
  if (source.$type$ !== undefined) {
    result.$type$ = source.$type$;
  }
  var index = source.length;
  if (newSize > index) {
    // Inline function 'kotlin.js.asDynamic' call
    result.length = newSize;
    while (index < newSize) {
      var _unary__edvuaz = index;
      index = _unary__edvuaz + 1 | 0;
      result[_unary__edvuaz] = defaultValue;
    }
  }
  return result;
}
function get_sign(_this__u8e3s4) {
  return _this__u8e3s4.r3(63).u3(_this__u8e3s4.o3().s3(63)).l1();
}
function ln(x) {
  return Math.log(x);
}
function round(x) {
  if (!(x % 0.5 === 0.0)) {
    return Math.round(x);
  }
  // Inline function 'kotlin.math.floor' call
  var floor = Math.floor(x);
  var tmp;
  if (floor % 2 === 0.0) {
    tmp = floor;
  } else {
    // Inline function 'kotlin.math.ceil' call
    tmp = Math.ceil(x);
  }
  return tmp;
}
function abs(n) {
  return n.m1(new Long(0, 0)) < 0 ? n.o3() : n;
}
function sqrt_0(x) {
  return Math.sqrt(x);
}
function abs_0(n) {
  return n < 0 ? -n | 0 | 0 : n;
}
function exp(x) {
  return Math.exp(x);
}
function log10_0(x) {
  return log10(x);
}
function asinh_1(x) {
  return asinh_0(x);
}
function sinh_0(x) {
  return sinh(x);
}
function expm1_0(x) {
  return expm1(x);
}
function ln1p(x) {
  return log1p(x);
}
function log2_0(x) {
  return log2(x);
}
var INV_2_26;
var INV_2_53;
function defaultPlatformRandom() {
  _init_properties_PlatformRandom_kt__6kjv62();
  // Inline function 'kotlin.js.unsafeCast' call
  var tmp$ret$0 = Math.random() * Math.pow(2, 32) | 0;
  return Random_0(tmp$ret$0);
}
var properties_initialized_PlatformRandom_kt_uibhw8;
function _init_properties_PlatformRandom_kt__6kjv62() {
  if (!properties_initialized_PlatformRandom_kt_uibhw8) {
    properties_initialized_PlatformRandom_kt_uibhw8 = true;
    // Inline function 'kotlin.math.pow' call
    INV_2_26 = Math.pow(2.0, -26);
    // Inline function 'kotlin.math.pow' call
    INV_2_53 = Math.pow(2.0, -53);
  }
}
var NothingKClassImpl_instance;
function NothingKClassImpl_getInstance() {
  if (NothingKClassImpl_instance === VOID)
    new NothingKClassImpl();
  return NothingKClassImpl_instance;
}
function get_functionClasses() {
  _init_properties_primitives_kt__3fums4();
  return functionClasses;
}
var functionClasses;
function PrimitiveClasses$anyClass$lambda(it) {
  return !(it == null);
}
function PrimitiveClasses$numberClass$lambda(it) {
  return isNumber(it);
}
function PrimitiveClasses$booleanClass$lambda(it) {
  return !(it == null) ? typeof it === 'boolean' : false;
}
function PrimitiveClasses$byteClass$lambda(it) {
  return !(it == null) ? typeof it === 'number' : false;
}
function PrimitiveClasses$shortClass$lambda(it) {
  return !(it == null) ? typeof it === 'number' : false;
}
function PrimitiveClasses$intClass$lambda(it) {
  return !(it == null) ? typeof it === 'number' : false;
}
function PrimitiveClasses$floatClass$lambda(it) {
  return !(it == null) ? typeof it === 'number' : false;
}
function PrimitiveClasses$doubleClass$lambda(it) {
  return !(it == null) ? typeof it === 'number' : false;
}
function PrimitiveClasses$arrayClass$lambda(it) {
  return !(it == null) ? isArray(it) : false;
}
function PrimitiveClasses$stringClass$lambda(it) {
  return !(it == null) ? typeof it === 'string' : false;
}
function PrimitiveClasses$throwableClass$lambda(it) {
  return it instanceof Error;
}
function PrimitiveClasses$booleanArrayClass$lambda(it) {
  return !(it == null) ? isBooleanArray(it) : false;
}
function PrimitiveClasses$charArrayClass$lambda(it) {
  return !(it == null) ? isCharArray(it) : false;
}
function PrimitiveClasses$byteArrayClass$lambda(it) {
  return !(it == null) ? isByteArray(it) : false;
}
function PrimitiveClasses$shortArrayClass$lambda(it) {
  return !(it == null) ? isShortArray(it) : false;
}
function PrimitiveClasses$intArrayClass$lambda(it) {
  return !(it == null) ? isIntArray(it) : false;
}
function PrimitiveClasses$longArrayClass$lambda(it) {
  return !(it == null) ? isLongArray(it) : false;
}
function PrimitiveClasses$floatArrayClass$lambda(it) {
  return !(it == null) ? isFloatArray(it) : false;
}
function PrimitiveClasses$doubleArrayClass$lambda(it) {
  return !(it == null) ? isDoubleArray(it) : false;
}
function PrimitiveClasses$functionClass$lambda($arity) {
  return (it) => {
    var tmp;
    if (typeof it === 'function') {
      // Inline function 'kotlin.js.asDynamic' call
      tmp = it.length === $arity;
    } else {
      tmp = false;
    }
    return tmp;
  };
}
var PrimitiveClasses_instance;
function PrimitiveClasses_getInstance() {
  if (PrimitiveClasses_instance === VOID)
    new PrimitiveClasses();
  return PrimitiveClasses_instance;
}
var properties_initialized_primitives_kt_jle18u;
function _init_properties_primitives_kt__3fums4() {
  if (!properties_initialized_primitives_kt_jle18u) {
    properties_initialized_primitives_kt_jle18u = true;
    // Inline function 'kotlin.arrayOfNulls' call
    functionClasses = fillArrayVal(Array(0), null);
  }
}
function getKClass(jClass) {
  var tmp;
  if (Array.isArray(jClass)) {
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp = getKClassM(jClass);
  } else {
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp = getKClass1(jClass);
  }
  return tmp;
}
function getKClassM(jClasses) {
  var tmp;
  switch (jClasses.length) {
    case 1:
      tmp = getKClass1(jClasses[0]);
      break;
    case 0:
      // Inline function 'kotlin.js.unsafeCast' call

      // Inline function 'kotlin.js.asDynamic' call

      tmp = NothingKClassImpl_getInstance();
      break;
    default:
      // Inline function 'kotlin.js.unsafeCast' call

      // Inline function 'kotlin.js.asDynamic' call

      tmp = new ErrorKClass();
      break;
  }
  return tmp;
}
function getKClass1(jClass) {
  if (jClass === String) {
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    return PrimitiveClasses_getInstance().stringClass;
  }
  // Inline function 'kotlin.js.asDynamic' call
  var metadata = jClass.$metadata$;
  var tmp;
  if (metadata != null) {
    var tmp_0;
    if (metadata.$kClass$ == null) {
      var kClass = new SimpleKClassImpl(jClass);
      metadata.$kClass$ = kClass;
      tmp_0 = kClass;
    } else {
      tmp_0 = metadata.$kClass$;
    }
    tmp = tmp_0;
  } else {
    tmp = new SimpleKClassImpl(jClass);
  }
  return tmp;
}
function getKClassFromExpression(e) {
  var tmp;
  switch (typeof e) {
    case 'string':
      tmp = PrimitiveClasses_getInstance().stringClass;
      break;
    case 'number':
      var tmp_0;
      // Inline function 'kotlin.js.jsBitwiseOr' call

      // Inline function 'kotlin.js.asDynamic' call

      if ((e | 0) === e) {
        tmp_0 = PrimitiveClasses_getInstance().intClass;
      } else {
        tmp_0 = PrimitiveClasses_getInstance().doubleClass;
      }

      tmp = tmp_0;
      break;
    case 'boolean':
      tmp = PrimitiveClasses_getInstance().booleanClass;
      break;
    case 'function':
      var tmp_1 = PrimitiveClasses_getInstance();
      // Inline function 'kotlin.js.asDynamic' call

      tmp = tmp_1.functionClass(e.length);
      break;
    default:
      var tmp_2;
      if (isBooleanArray(e)) {
        tmp_2 = PrimitiveClasses_getInstance().booleanArrayClass;
      } else {
        if (isCharArray(e)) {
          tmp_2 = PrimitiveClasses_getInstance().charArrayClass;
        } else {
          if (isByteArray(e)) {
            tmp_2 = PrimitiveClasses_getInstance().byteArrayClass;
          } else {
            if (isShortArray(e)) {
              tmp_2 = PrimitiveClasses_getInstance().shortArrayClass;
            } else {
              if (isIntArray(e)) {
                tmp_2 = PrimitiveClasses_getInstance().intArrayClass;
              } else {
                if (isLongArray(e)) {
                  tmp_2 = PrimitiveClasses_getInstance().longArrayClass;
                } else {
                  if (isFloatArray(e)) {
                    tmp_2 = PrimitiveClasses_getInstance().floatArrayClass;
                  } else {
                    if (isDoubleArray(e)) {
                      tmp_2 = PrimitiveClasses_getInstance().doubleArrayClass;
                    } else {
                      if (isInterface(e, KClass)) {
                        tmp_2 = getKClass(KClass);
                      } else {
                        if (isArray(e)) {
                          tmp_2 = PrimitiveClasses_getInstance().arrayClass;
                        } else {
                          var constructor = Object.getPrototypeOf(e).constructor;
                          var tmp_3;
                          if (constructor === Object) {
                            tmp_3 = PrimitiveClasses_getInstance().anyClass;
                          } else if (constructor === Error) {
                            tmp_3 = PrimitiveClasses_getInstance().throwableClass;
                          } else {
                            var jsClass = constructor;
                            tmp_3 = getKClass1(jsClass);
                          }
                          tmp_2 = tmp_3;
                        }
                      }
                    }
                  }
                }
              }
            }
          }
        }
      }

      tmp = tmp_2;
      break;
  }
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return tmp;
}
function uppercaseChar(_this__u8e3s4) {
  // Inline function 'kotlin.text.uppercase' call
  // Inline function 'kotlin.js.asDynamic' call
  // Inline function 'kotlin.js.unsafeCast' call
  var uppercase = toString(_this__u8e3s4).toUpperCase();
  return uppercase.length > 1 ? _this__u8e3s4 : charSequenceGet(uppercase, 0);
}
function isWhitespace(_this__u8e3s4) {
  return isWhitespaceImpl(_this__u8e3s4);
}
function toString_2(_this__u8e3s4, radix) {
  return toStringImpl(_this__u8e3s4, checkRadix(radix));
}
function checkRadix(radix) {
  if (!(2 <= radix ? radix <= 36 : false)) {
    throw IllegalArgumentException.h('radix ' + radix + ' was not in valid range 2..36');
  }
  return radix;
}
function toInt(_this__u8e3s4, radix) {
  var tmp0_elvis_lhs = toIntOrNull(_this__u8e3s4, radix);
  var tmp;
  if (tmp0_elvis_lhs == null) {
    numberFormatError(_this__u8e3s4);
  } else {
    tmp = tmp0_elvis_lhs;
  }
  return tmp;
}
function toDouble(_this__u8e3s4) {
  // Inline function 'kotlin.js.asDynamic' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.also' call
  var this_0 = +_this__u8e3s4;
  // Inline function 'kotlin.text.toDouble.<anonymous>' call
  if (isNaN_0(this_0) && !isNaN_2(_this__u8e3s4) || (this_0 === 0.0 && isBlank(_this__u8e3s4))) {
    numberFormatError(_this__u8e3s4);
  }
  return this_0;
}
function toString_3(_this__u8e3s4, radix) {
  // Inline function 'kotlin.js.asDynamic' call
  return _this__u8e3s4.toString(checkRadix(radix));
}
function isNaN_2(_this__u8e3s4) {
  // Inline function 'kotlin.text.lowercase' call
  // Inline function 'kotlin.js.asDynamic' call
  switch (_this__u8e3s4.toLowerCase()) {
    case 'nan':
    case '+nan':
    case '-nan':
      return true;
    default:
      return false;
  }
}
function digitOf(char, radix) {
  // Inline function 'kotlin.let' call
  // Inline function 'kotlin.text.digitOf.<anonymous>' call
  var it = Char__compareTo_impl_ypi4mb(char, _Char___init__impl__6a9atx(48)) >= 0 && Char__compareTo_impl_ypi4mb(char, _Char___init__impl__6a9atx(57)) <= 0 ? Char__minus_impl_a2frrh(char, _Char___init__impl__6a9atx(48)) : Char__compareTo_impl_ypi4mb(char, _Char___init__impl__6a9atx(65)) >= 0 && Char__compareTo_impl_ypi4mb(char, _Char___init__impl__6a9atx(90)) <= 0 ? Char__minus_impl_a2frrh(char, _Char___init__impl__6a9atx(65)) + 10 | 0 : Char__compareTo_impl_ypi4mb(char, _Char___init__impl__6a9atx(97)) >= 0 && Char__compareTo_impl_ypi4mb(char, _Char___init__impl__6a9atx(122)) <= 0 ? Char__minus_impl_a2frrh(char, _Char___init__impl__6a9atx(97)) + 10 | 0 : Char__compareTo_impl_ypi4mb(char, _Char___init__impl__6a9atx(128)) < 0 ? -1 : Char__compareTo_impl_ypi4mb(char, _Char___init__impl__6a9atx(65313)) >= 0 && Char__compareTo_impl_ypi4mb(char, _Char___init__impl__6a9atx(65338)) <= 0 ? Char__minus_impl_a2frrh(char, _Char___init__impl__6a9atx(65313)) + 10 | 0 : Char__compareTo_impl_ypi4mb(char, _Char___init__impl__6a9atx(65345)) >= 0 && Char__compareTo_impl_ypi4mb(char, _Char___init__impl__6a9atx(65370)) <= 0 ? Char__minus_impl_a2frrh(char, _Char___init__impl__6a9atx(65345)) + 10 | 0 : digitToIntImpl(char);
  return it >= radix ? -1 : it;
}
var Companion_instance_6;
function Companion_getInstance_6() {
  if (Companion_instance_6 === VOID)
    new Companion_6();
  return Companion_instance_6;
}
var STRING_CASE_INSENSITIVE_ORDER;
function compareTo_0(_this__u8e3s4, other, ignoreCase) {
  ignoreCase = ignoreCase === VOID ? false : ignoreCase;
  _init_properties_stringJs_kt__bg7zye();
  if (ignoreCase) {
    var n1 = _this__u8e3s4.length;
    var n2 = other.length;
    // Inline function 'kotlin.comparisons.minOf' call
    var min = Math.min(n1, n2);
    if (min === 0)
      return n1 - n2 | 0;
    var inductionVariable = 0;
    if (inductionVariable < min)
      do {
        var index = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var thisChar = charSequenceGet(_this__u8e3s4, index);
        var otherChar = charSequenceGet(other, index);
        if (!(thisChar === otherChar)) {
          thisChar = uppercaseChar(thisChar);
          otherChar = uppercaseChar(otherChar);
          if (!(thisChar === otherChar)) {
            // Inline function 'kotlin.text.lowercaseChar' call
            // Inline function 'kotlin.text.lowercase' call
            var this_0 = thisChar;
            // Inline function 'kotlin.js.asDynamic' call
            // Inline function 'kotlin.js.unsafeCast' call
            var tmp$ret$3 = toString(this_0).toLowerCase();
            thisChar = charSequenceGet(tmp$ret$3, 0);
            // Inline function 'kotlin.text.lowercaseChar' call
            // Inline function 'kotlin.text.lowercase' call
            var this_1 = otherChar;
            // Inline function 'kotlin.js.asDynamic' call
            // Inline function 'kotlin.js.unsafeCast' call
            var tmp$ret$7 = toString(this_1).toLowerCase();
            otherChar = charSequenceGet(tmp$ret$7, 0);
            if (!(thisChar === otherChar)) {
              return Char__compareTo_impl_ypi4mb(thisChar, otherChar);
            }
          }
        }
      }
       while (inductionVariable < min);
    return n1 - n2 | 0;
  } else {
    return compareTo(_this__u8e3s4, other);
  }
}
function concatToString(_this__u8e3s4) {
  _init_properties_stringJs_kt__bg7zye();
  var result = '';
  var inductionVariable = 0;
  var last = _this__u8e3s4.length;
  while (inductionVariable < last) {
    var char = _this__u8e3s4[inductionVariable];
    inductionVariable = inductionVariable + 1 | 0;
    result = result + toString(char);
  }
  return result;
}
function STRING_CASE_INSENSITIVE_ORDER$lambda(a, b) {
  _init_properties_stringJs_kt__bg7zye();
  return compareTo_0(a, b, true);
}
var properties_initialized_stringJs_kt_nta8o4;
function _init_properties_stringJs_kt__bg7zye() {
  if (!properties_initialized_stringJs_kt_nta8o4) {
    properties_initialized_stringJs_kt_nta8o4 = true;
    var tmp = STRING_CASE_INSENSITIVE_ORDER$lambda;
    STRING_CASE_INSENSITIVE_ORDER = new sam$kotlin_Comparator$0(tmp);
  }
}
function replaceFirst(_this__u8e3s4, oldValue, newValue, ignoreCase) {
  ignoreCase = ignoreCase === VOID ? false : ignoreCase;
  var tmp1 = new RegExp(Companion_getInstance_6().gf(oldValue), ignoreCase ? 'ui' : 'u');
  // Inline function 'kotlin.text.nativeReplace' call
  var replacement = Companion_getInstance_6().hf(newValue);
  // Inline function 'kotlin.js.asDynamic' call
  return _this__u8e3s4.replace(tmp1, replacement);
}
function equals_0(_this__u8e3s4, other, ignoreCase) {
  ignoreCase = ignoreCase === VOID ? false : ignoreCase;
  if (_this__u8e3s4 == null)
    return other == null;
  if (other == null)
    return false;
  if (!ignoreCase)
    return _this__u8e3s4 == other;
  if (!(_this__u8e3s4.length === other.length))
    return false;
  var inductionVariable = 0;
  var last = _this__u8e3s4.length;
  if (inductionVariable < last)
    do {
      var index = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      var thisChar = charSequenceGet(_this__u8e3s4, index);
      var otherChar = charSequenceGet(other, index);
      if (!equals_1(thisChar, otherChar, ignoreCase)) {
        return false;
      }
    }
     while (inductionVariable < last);
  return true;
}
function replace(_this__u8e3s4, oldValue, newValue, ignoreCase) {
  ignoreCase = ignoreCase === VOID ? false : ignoreCase;
  var tmp1 = new RegExp(Companion_getInstance_6().gf(oldValue), ignoreCase ? 'gui' : 'gu');
  // Inline function 'kotlin.text.nativeReplace' call
  var replacement = Companion_getInstance_6().hf(newValue);
  // Inline function 'kotlin.js.asDynamic' call
  return _this__u8e3s4.replace(tmp1, replacement);
}
function regionMatches(_this__u8e3s4, thisOffset, other, otherOffset, length, ignoreCase) {
  ignoreCase = ignoreCase === VOID ? false : ignoreCase;
  return regionMatchesImpl(_this__u8e3s4, thisOffset, other, otherOffset, length, ignoreCase);
}
function addSuppressed(_this__u8e3s4, exception) {
  if (!(_this__u8e3s4 === exception)) {
    // Inline function 'kotlin.js.asDynamic' call
    // Inline function 'kotlin.js.unsafeCast' call
    var suppressed = _this__u8e3s4._suppressed;
    if (suppressed == null) {
      // Inline function 'kotlin.js.asDynamic' call
      _this__u8e3s4._suppressed = mutableListOf([exception]);
    } else {
      suppressed.o(exception);
    }
  }
}
function printStackTrace(_this__u8e3s4) {
  console.error(stackTraceToString(_this__u8e3s4));
}
function stackTraceToString(_this__u8e3s4) {
  return (new ExceptionTraceBuilder()).of(_this__u8e3s4);
}
function hasSeen($this, exception) {
  var tmp0 = $this.lf_1;
  var tmp$ret$1;
  $l$block: {
    // Inline function 'kotlin.collections.any' call
    var inductionVariable = 0;
    var last = tmp0.length;
    while (inductionVariable < last) {
      var element = tmp0[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      // Inline function 'kotlin.ExceptionTraceBuilder.hasSeen.<anonymous>' call
      if (element === exception) {
        tmp$ret$1 = true;
        break $l$block;
      }
    }
    tmp$ret$1 = false;
  }
  return tmp$ret$1;
}
function dumpFullTrace(_this__u8e3s4, $this, indent, qualifier) {
  if (dumpSelfTrace(_this__u8e3s4, $this, indent, qualifier))
    true;
  else
    return Unit_instance;
  var cause = _this__u8e3s4.cause;
  while (!(cause == null)) {
    if (dumpSelfTrace(cause, $this, indent, 'Caused by: '))
      true;
    else
      return Unit_instance;
    cause = cause.cause;
  }
}
function dumpSelfTrace(_this__u8e3s4, $this, indent, qualifier) {
  $this.kf_1.lb(indent).lb(qualifier);
  var shortInfo = _this__u8e3s4.toString();
  if (hasSeen($this, _this__u8e3s4)) {
    $this.kf_1.lb('[CIRCULAR REFERENCE, SEE ABOVE: ').lb(shortInfo).lb(']\n');
    return false;
  }
  // Inline function 'kotlin.js.asDynamic' call
  $this.lf_1.push(_this__u8e3s4);
  // Inline function 'kotlin.js.asDynamic' call
  var tmp = _this__u8e3s4.stack;
  var stack = (tmp == null ? true : typeof tmp === 'string') ? tmp : THROW_CCE();
  if (!(stack == null)) {
    // Inline function 'kotlin.let' call
    // Inline function 'kotlin.ExceptionTraceBuilder.dumpSelfTrace.<anonymous>' call
    var it = indexOf_0(stack, shortInfo);
    var stackStart = it < 0 ? 0 : it + shortInfo.length | 0;
    if (stackStart === 0) {
      $this.kf_1.lb(shortInfo).lb('\n');
    }
    // Inline function 'kotlin.text.isEmpty' call
    var this_0 = $this.mf_1;
    if (charSequenceLength(this_0) === 0) {
      $this.mf_1 = stack;
      $this.nf_1 = stackStart;
    } else {
      stack = dropCommonFrames($this, stack, stackStart);
    }
    // Inline function 'kotlin.text.isNotEmpty' call
    if (charSequenceLength(indent) > 0) {
      var tmp_0;
      if (stackStart === 0) {
        tmp_0 = 0;
      } else {
        // Inline function 'kotlin.text.count' call
        var count = 0;
        var inductionVariable = 0;
        while (inductionVariable < charSequenceLength(shortInfo)) {
          var element = charSequenceGet(shortInfo, inductionVariable);
          inductionVariable = inductionVariable + 1 | 0;
          // Inline function 'kotlin.ExceptionTraceBuilder.dumpSelfTrace.<anonymous>' call
          if (element === _Char___init__impl__6a9atx(10)) {
            count = count + 1 | 0;
          }
        }
        tmp_0 = 1 + count | 0;
      }
      var messageLines = tmp_0;
      // Inline function 'kotlin.sequences.forEachIndexed' call
      var index = 0;
      var _iterator__ex2g4s = lineSequence(stack).x();
      while (_iterator__ex2g4s.y()) {
        var item = _iterator__ex2g4s.z();
        var _unary__edvuaz = index;
        index = _unary__edvuaz + 1 | 0;
        // Inline function 'kotlin.ExceptionTraceBuilder.dumpSelfTrace.<anonymous>' call
        if (checkIndexOverflow(_unary__edvuaz) >= messageLines) {
          $this.kf_1.lb(indent);
        }
        $this.kf_1.lb(item).lb('\n');
      }
    } else {
      $this.kf_1.lb(stack).lb('\n');
    }
  } else {
    $this.kf_1.lb(shortInfo).lb('\n');
  }
  var suppressed = get_suppressedExceptions(_this__u8e3s4);
  // Inline function 'kotlin.collections.isNotEmpty' call
  if (!suppressed.c1()) {
    var suppressedIndent = indent + '    ';
    var _iterator__ex2g4s_0 = suppressed.x();
    while (_iterator__ex2g4s_0.y()) {
      var s = _iterator__ex2g4s_0.z();
      dumpFullTrace(s, $this, suppressedIndent, 'Suppressed: ');
    }
  }
  return true;
}
function dropCommonFrames($this, stack, stackStart) {
  var commonFrames = 0;
  var lastBreak = 0;
  var preLastBreak = 0;
  var inductionVariable = 0;
  var tmp0 = $this.mf_1.length - $this.nf_1 | 0;
  // Inline function 'kotlin.comparisons.minOf' call
  var b = stack.length - stackStart | 0;
  var last = Math.min(tmp0, b);
  if (inductionVariable < last)
    $l$loop: do {
      var pos = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      var c = charSequenceGet(stack, get_lastIndex_1(stack) - pos | 0);
      if (!(c === charSequenceGet($this.mf_1, get_lastIndex_1($this.mf_1) - pos | 0)))
        break $l$loop;
      if (c === _Char___init__impl__6a9atx(10)) {
        commonFrames = commonFrames + 1 | 0;
        preLastBreak = lastBreak;
        lastBreak = pos;
      }
    }
     while (inductionVariable < last);
  if (commonFrames <= 1)
    return stack;
  while (preLastBreak > 0 && charSequenceGet(stack, get_lastIndex_1(stack) - (preLastBreak - 1 | 0) | 0) === _Char___init__impl__6a9atx(32))
    preLastBreak = preLastBreak - 1 | 0;
  return dropLast(stack, preLastBreak) + ('... and ' + (commonFrames - 1 | 0) + ' more common stack frames skipped');
}
function get_suppressedExceptions(_this__u8e3s4) {
  // Inline function 'kotlin.js.asDynamic' call
  var tmp0_safe_receiver = _this__u8e3s4._suppressed;
  var tmp;
  if (tmp0_safe_receiver == null) {
    tmp = null;
  } else {
    // Inline function 'kotlin.js.unsafeCast' call
    tmp = tmp0_safe_receiver;
  }
  var tmp1_elvis_lhs = tmp;
  return tmp1_elvis_lhs == null ? emptyList() : tmp1_elvis_lhs;
}
function AbstractCollection$toString$lambda(this$0) {
  return (it) => it === this$0 ? '(this Collection)' : toString_0(it);
}
var Companion_instance_7;
function Companion_getInstance_7() {
  return Companion_instance_7;
}
function toString_4($this, entry) {
  return toString_5($this, entry.q2()) + '=' + toString_5($this, entry.r2());
}
function toString_5($this, o) {
  return o === $this ? '(this Map)' : toString_0(o);
}
function implFindEntry($this, key) {
  var tmp0 = $this.v2();
  var tmp$ret$1;
  $l$block: {
    // Inline function 'kotlin.collections.firstOrNull' call
    var _iterator__ex2g4s = tmp0.x();
    while (_iterator__ex2g4s.y()) {
      var element = _iterator__ex2g4s.z();
      // Inline function 'kotlin.collections.AbstractMap.implFindEntry.<anonymous>' call
      if (equals(element.q2(), key)) {
        tmp$ret$1 = element;
        break $l$block;
      }
    }
    tmp$ret$1 = null;
  }
  return tmp$ret$1;
}
var Companion_instance_8;
function Companion_getInstance_8() {
  return Companion_instance_8;
}
function AbstractMap$toString$lambda(this$0) {
  return (it) => toString_4(this$0, it);
}
var Companion_instance_9;
function Companion_getInstance_9() {
  return Companion_instance_9;
}
function ensureCapacity_0($this, minCapacity) {
  if (minCapacity < 0)
    throw IllegalStateException.n4('Deque is too big.');
  if (minCapacity <= $this.bg_1.length)
    return Unit_instance;
  if ($this.bg_1 === Companion_getInstance_10().dg_1) {
    var tmp = $this;
    // Inline function 'kotlin.arrayOfNulls' call
    var size = coerceAtLeast(minCapacity, 10);
    tmp.bg_1 = fillArrayVal(Array(size), null);
    return Unit_instance;
  }
  var newCapacity = Companion_instance_7.ka($this.bg_1.length, minCapacity);
  copyElements($this, newCapacity);
}
function copyElements($this, newCapacity) {
  // Inline function 'kotlin.arrayOfNulls' call
  var newElements = fillArrayVal(Array(newCapacity), null);
  var tmp1 = $this.bg_1;
  var tmp4 = $this.ag_1;
  // Inline function 'kotlin.collections.copyInto' call
  var endIndex = $this.bg_1.length;
  arrayCopy(tmp1, newElements, 0, tmp4, endIndex);
  var tmp6 = $this.bg_1;
  var tmp8 = $this.bg_1.length - $this.ag_1 | 0;
  // Inline function 'kotlin.collections.copyInto' call
  var endIndex_0 = $this.ag_1;
  arrayCopy(tmp6, newElements, tmp8, 0, endIndex_0);
  $this.ag_1 = 0;
  $this.bg_1 = newElements;
}
function positiveMod($this, index) {
  return index >= $this.bg_1.length ? index - $this.bg_1.length | 0 : index;
}
function negativeMod($this, index) {
  return index < 0 ? index + $this.bg_1.length | 0 : index;
}
function incremented($this, index) {
  return index === get_lastIndex($this.bg_1) ? 0 : index + 1 | 0;
}
function decremented($this, index) {
  return index === 0 ? get_lastIndex($this.bg_1) : index - 1 | 0;
}
function copyCollectionElements($this, internalIndex, elements) {
  var iterator = elements.x();
  var inductionVariable = internalIndex;
  var last = $this.bg_1.length;
  if (inductionVariable < last)
    $l$loop: do {
      var index = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      if (!iterator.y())
        break $l$loop;
      $this.bg_1[index] = iterator.z();
    }
     while (inductionVariable < last);
  var inductionVariable_0 = 0;
  var last_0 = $this.ag_1;
  if (inductionVariable_0 < last_0)
    $l$loop_0: do {
      var index_0 = inductionVariable_0;
      inductionVariable_0 = inductionVariable_0 + 1 | 0;
      if (!iterator.y())
        break $l$loop_0;
      $this.bg_1[index_0] = iterator.z();
    }
     while (inductionVariable_0 < last_0);
  $this.cg_1 = $this.cg_1 + elements.a1() | 0;
}
function removeRangeShiftPreceding($this, fromIndex, toIndex) {
  // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
  var index = fromIndex - 1 | 0;
  var copyFromIndex = positiveMod($this, $this.ag_1 + index | 0);
  // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
  var index_0 = toIndex - 1 | 0;
  var copyToIndex = positiveMod($this, $this.ag_1 + index_0 | 0);
  var copyCount = fromIndex;
  while (copyCount > 0) {
    var tmp0 = copyCount;
    var tmp1 = copyFromIndex + 1 | 0;
    // Inline function 'kotlin.comparisons.minOf' call
    var c = copyToIndex + 1 | 0;
    var segmentLength = Math.min(tmp0, tmp1, c);
    var tmp3 = $this.bg_1;
    var tmp4 = $this.bg_1;
    var tmp5 = (copyToIndex - segmentLength | 0) + 1 | 0;
    var tmp6 = (copyFromIndex - segmentLength | 0) + 1 | 0;
    // Inline function 'kotlin.collections.copyInto' call
    var endIndex = copyFromIndex + 1 | 0;
    arrayCopy(tmp3, tmp4, tmp5, tmp6, endIndex);
    copyFromIndex = negativeMod($this, copyFromIndex - segmentLength | 0);
    copyToIndex = negativeMod($this, copyToIndex - segmentLength | 0);
    copyCount = copyCount - segmentLength | 0;
  }
}
function removeRangeShiftSucceeding($this, fromIndex, toIndex) {
  // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
  var copyFromIndex = positiveMod($this, $this.ag_1 + toIndex | 0);
  // Inline function 'kotlin.collections.ArrayDeque.internalIndex' call
  var copyToIndex = positiveMod($this, $this.ag_1 + fromIndex | 0);
  var copyCount = $this.cg_1 - toIndex | 0;
  while (copyCount > 0) {
    var tmp0 = copyCount;
    var tmp1 = $this.bg_1.length - copyFromIndex | 0;
    // Inline function 'kotlin.comparisons.minOf' call
    var c = $this.bg_1.length - copyToIndex | 0;
    var segmentLength = Math.min(tmp0, tmp1, c);
    var tmp3 = $this.bg_1;
    var tmp4 = $this.bg_1;
    var tmp5 = copyToIndex;
    var tmp6 = copyFromIndex;
    // Inline function 'kotlin.collections.copyInto' call
    var endIndex = copyFromIndex + segmentLength | 0;
    arrayCopy(tmp3, tmp4, tmp5, tmp6, endIndex);
    copyFromIndex = positiveMod($this, copyFromIndex + segmentLength | 0);
    copyToIndex = positiveMod($this, copyToIndex + segmentLength | 0);
    copyCount = copyCount - segmentLength | 0;
  }
}
function nullifyNonEmpty($this, internalFromIndex, internalToIndex) {
  if (internalFromIndex < internalToIndex) {
    fill($this.bg_1, null, internalFromIndex, internalToIndex);
  } else {
    fill($this.bg_1, null, internalFromIndex, $this.bg_1.length);
    fill($this.bg_1, null, 0, internalToIndex);
  }
}
function registerModification_0($this) {
  $this.t5_1 = $this.t5_1 + 1 | 0;
}
var Companion_instance_10;
function Companion_getInstance_10() {
  if (Companion_instance_10 === VOID)
    new Companion_10();
  return Companion_instance_10;
}
function init_kotlin_collections_ArrayDeque(_this__u8e3s4) {
  Companion_getInstance_10();
  _this__u8e3s4.ag_1 = 0;
  _this__u8e3s4.cg_1 = 0;
}
function collectionToArrayCommonImpl(collection) {
  if (collection.c1()) {
    // Inline function 'kotlin.emptyArray' call
    return [];
  }
  // Inline function 'kotlin.arrayOfNulls' call
  var size = collection.a1();
  var destination = fillArrayVal(Array(size), null);
  var iterator = collection.x();
  var index = 0;
  while (iterator.y()) {
    var _unary__edvuaz = index;
    index = _unary__edvuaz + 1 | 0;
    destination[_unary__edvuaz] = iterator.z();
  }
  return destination;
}
function listOf_0(elements) {
  return elements.length > 0 ? asList(elements) : emptyList();
}
function emptyList() {
  return EmptyList_getInstance();
}
function arrayListOf(elements) {
  return elements.length === 0 ? ArrayList.e1() : ArrayList.l(new ArrayAsCollection(elements, true));
}
function mutableListOf(elements) {
  return elements.length === 0 ? ArrayList.e1() : ArrayList.l(new ArrayAsCollection(elements, true));
}
function listOfNotNull(element) {
  return !(element == null) ? listOf(element) : emptyList();
}
function get_lastIndex_0(_this__u8e3s4) {
  return _this__u8e3s4.a1() - 1 | 0;
}
function asCollection(_this__u8e3s4) {
  return new ArrayAsCollection(_this__u8e3s4, false);
}
var EmptyIterator_instance;
function EmptyIterator_getInstance() {
  return EmptyIterator_instance;
}
function optimizeReadOnlyList(_this__u8e3s4) {
  switch (_this__u8e3s4.a1()) {
    case 0:
      return emptyList();
    case 1:
      return listOf(_this__u8e3s4.b1(0));
    default:
      return _this__u8e3s4;
  }
}
var EmptyList_instance;
function EmptyList_getInstance() {
  if (EmptyList_instance === VOID)
    new EmptyList();
  return EmptyList_instance;
}
function rangeCheck_0(size, fromIndex, toIndex) {
  if (fromIndex > toIndex)
    throw IllegalArgumentException.h('fromIndex (' + fromIndex + ') is greater than toIndex (' + toIndex + ').');
  else if (fromIndex < 0)
    throw IndexOutOfBoundsException.bd('fromIndex (' + fromIndex + ') is less than zero.');
  else if (toIndex > size)
    throw IndexOutOfBoundsException.bd('toIndex (' + toIndex + ') is greater than size (' + size + ').');
}
function throwIndexOverflow() {
  throw ArithmeticException.md('Index overflow has happened.');
}
function binarySearch(_this__u8e3s4, element, comparator, fromIndex, toIndex) {
  fromIndex = fromIndex === VOID ? 0 : fromIndex;
  toIndex = toIndex === VOID ? _this__u8e3s4.a1() : toIndex;
  rangeCheck_0(_this__u8e3s4.a1(), fromIndex, toIndex);
  var low = fromIndex;
  var high = toIndex - 1 | 0;
  while (low <= high) {
    var mid = (low + high | 0) >>> 1 | 0;
    var midVal = _this__u8e3s4.b1(mid);
    var cmp = comparator.compare(midVal, element);
    if (cmp < 0)
      low = mid + 1 | 0;
    else if (cmp > 0)
      high = mid - 1 | 0;
    else
      return mid;
  }
  return -(low + 1 | 0) | 0;
}
function collectionSizeOrDefault(_this__u8e3s4, default_0) {
  var tmp;
  if (isInterface(_this__u8e3s4, Collection)) {
    tmp = _this__u8e3s4.a1();
  } else {
    tmp = default_0;
  }
  return tmp;
}
function addAll(_this__u8e3s4, elements) {
  return _this__u8e3s4.x2(asList(elements));
}
function filterInPlace(_this__u8e3s4, predicate, predicateResultToRemove) {
  var result = false;
  // Inline function 'kotlin.with' call
  // Inline function 'kotlin.collections.filterInPlace.<anonymous>' call
  var $this$with = _this__u8e3s4.x();
  while ($this$with.y())
    if (predicate($this$with.z()) === predicateResultToRemove) {
      $this$with.n5();
      result = true;
    }
  return result;
}
function removeAll(_this__u8e3s4, predicate) {
  return filterInPlace_0(_this__u8e3s4, predicate, true);
}
function filterInPlace_0(_this__u8e3s4, predicate, predicateResultToRemove) {
  if (!isInterface(_this__u8e3s4, RandomAccess)) {
    return filterInPlace(isInterface(_this__u8e3s4, MutableIterable) ? _this__u8e3s4 : THROW_CCE(), predicate, predicateResultToRemove);
  }
  var writeIndex = 0;
  var inductionVariable = 0;
  var last = get_lastIndex_0(_this__u8e3s4);
  if (inductionVariable <= last)
    $l$loop: do {
      var readIndex = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      var element = _this__u8e3s4.b1(readIndex);
      if (predicate(element) === predicateResultToRemove)
        continue $l$loop;
      if (!(writeIndex === readIndex)) {
        _this__u8e3s4.j5(writeIndex, element);
      }
      writeIndex = writeIndex + 1 | 0;
    }
     while (!(readIndex === last));
  if (writeIndex < _this__u8e3s4.a1()) {
    var inductionVariable_0 = get_lastIndex_0(_this__u8e3s4);
    var last_0 = writeIndex;
    if (last_0 <= inductionVariable_0)
      do {
        var removeIndex = inductionVariable_0;
        inductionVariable_0 = inductionVariable_0 + -1 | 0;
        _this__u8e3s4.u5(removeIndex);
      }
       while (!(removeIndex === last_0));
    return true;
  } else {
    return false;
  }
}
function calcNext($this) {
  $this.ug_1 = $this.vg_1 === -2 ? $this.wg_1.xg_1() : $this.wg_1.yg_1(ensureNotNull($this.ug_1));
  $this.vg_1 = $this.ug_1 == null ? 0 : 1;
}
function emptySequence() {
  return EmptySequence_instance;
}
var EmptySequence_instance;
function EmptySequence_getInstance() {
  return EmptySequence_instance;
}
function sequenceOf(elements) {
  return asSequence(elements);
}
function generateSequence(nextFunction) {
  return constrainOnce(new GeneratorSequence(nextFunction, generateSequence$lambda(nextFunction)));
}
function constrainOnce(_this__u8e3s4) {
  var tmp;
  if (_this__u8e3s4 instanceof ConstrainedOnceSequence) {
    tmp = _this__u8e3s4;
  } else {
    tmp = new ConstrainedOnceSequence(_this__u8e3s4);
  }
  return tmp;
}
function generateSequence$lambda($nextFunction) {
  return (it) => $nextFunction();
}
function setOf_0(elements) {
  return toSet(elements);
}
function emptySet() {
  return EmptySet_getInstance();
}
var EmptySet_instance;
function EmptySet_getInstance() {
  if (EmptySet_instance === VOID)
    new EmptySet();
  return EmptySet_instance;
}
function hashSetOf(elements) {
  return toCollection(elements, HashSet.ba(mapCapacity(elements.length)));
}
function optimizeReadOnlySet(_this__u8e3s4) {
  switch (_this__u8e3s4.a1()) {
    case 0:
      return emptySet();
    case 1:
      return setOf(_this__u8e3s4.x().z());
    default:
      return _this__u8e3s4;
  }
}
function naturalOrder() {
  var tmp = NaturalOrderComparator_instance;
  return isInterface(tmp, Comparator) ? tmp : THROW_CCE();
}
function compareValues(a, b) {
  if (a === b)
    return 0;
  if (a == null)
    return -1;
  if (b == null)
    return 1;
  return compareTo((!(a == null) ? isComparable(a) : false) ? a : THROW_CCE(), b);
}
var NaturalOrderComparator_instance;
function NaturalOrderComparator_getInstance() {
  return NaturalOrderComparator_instance;
}
var Key_instance;
function Key_getInstance() {
  return Key_instance;
}
function get_COROUTINE_SUSPENDED() {
  return CoroutineSingletons_COROUTINE_SUSPENDED_getInstance();
}
var CoroutineSingletons_COROUTINE_SUSPENDED_instance;
var CoroutineSingletons_UNDECIDED_instance;
var CoroutineSingletons_RESUMED_instance;
var CoroutineSingletons_entriesInitialized;
function CoroutineSingletons_initEntries() {
  if (CoroutineSingletons_entriesInitialized)
    return Unit_instance;
  CoroutineSingletons_entriesInitialized = true;
  CoroutineSingletons_COROUTINE_SUSPENDED_instance = new CoroutineSingletons('COROUTINE_SUSPENDED', 0);
  CoroutineSingletons_UNDECIDED_instance = new CoroutineSingletons('UNDECIDED', 1);
  CoroutineSingletons_RESUMED_instance = new CoroutineSingletons('RESUMED', 2);
}
function CoroutineSingletons_COROUTINE_SUSPENDED_getInstance() {
  CoroutineSingletons_initEntries();
  return CoroutineSingletons_COROUTINE_SUSPENDED_instance;
}
function enumEntries(entries) {
  return EnumEntriesList.lh(entries);
}
function getProgressionLastElement(start, end, step) {
  var tmp;
  if (step > 0) {
    tmp = start >= end ? end : end - differenceModulo(end, start, step) | 0;
  } else if (step < 0) {
    tmp = start <= end ? end : end + differenceModulo(start, end, -step | 0) | 0;
  } else {
    throw IllegalArgumentException.h('Step is zero.');
  }
  return tmp;
}
function differenceModulo(a, b, c) {
  return mod(mod(a, c) - mod(b, c) | 0, c);
}
function mod(a, b) {
  var mod = a % b | 0;
  return mod >= 0 ? mod : mod + b | 0;
}
var Delegates_instance;
function Delegates_getInstance() {
  return Delegates_instance;
}
var Default_instance;
function Default_getInstance() {
  if (Default_instance === VOID)
    Default.xh();
  return Default_instance;
}
function Random_0(seed) {
  return XorWowRandom.ii(seed, seed >> 31);
}
function takeUpperBits(_this__u8e3s4, bitCount) {
  return (_this__u8e3s4 >>> (32 - bitCount | 0) | 0) & (-bitCount | 0) >> 31;
}
var Companion_instance_11;
function Companion_getInstance_11() {
  if (Companion_instance_11 === VOID)
    new Companion_11();
  return Companion_instance_11;
}
var Companion_instance_12;
function Companion_getInstance_12() {
  if (Companion_instance_12 === VOID)
    new Companion_12();
  return Companion_instance_12;
}
var Companion_instance_13;
function Companion_getInstance_13() {
  return Companion_instance_13;
}
function appendElement(_this__u8e3s4, element, transform) {
  if (!(transform == null))
    _this__u8e3s4.v(transform(element));
  else {
    if (element == null ? true : isCharSequence(element))
      _this__u8e3s4.v(element);
    else {
      if (element instanceof Char)
        _this__u8e3s4.mb(element.x1_1);
      else {
        _this__u8e3s4.v(toString_1(element));
      }
    }
  }
}
function equals_1(_this__u8e3s4, other, ignoreCase) {
  ignoreCase = ignoreCase === VOID ? false : ignoreCase;
  if (_this__u8e3s4 === other)
    return true;
  if (!ignoreCase)
    return false;
  var thisUpper = uppercaseChar(_this__u8e3s4);
  var otherUpper = uppercaseChar(other);
  var tmp;
  if (thisUpper === otherUpper) {
    tmp = true;
  } else {
    // Inline function 'kotlin.text.lowercaseChar' call
    // Inline function 'kotlin.text.lowercase' call
    // Inline function 'kotlin.js.asDynamic' call
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp$ret$2 = toString(thisUpper).toLowerCase();
    var tmp_0 = charSequenceGet(tmp$ret$2, 0);
    // Inline function 'kotlin.text.lowercaseChar' call
    // Inline function 'kotlin.text.lowercase' call
    // Inline function 'kotlin.js.asDynamic' call
    // Inline function 'kotlin.js.unsafeCast' call
    var tmp$ret$6 = toString(otherUpper).toLowerCase();
    tmp = tmp_0 === charSequenceGet(tmp$ret$6, 0);
  }
  return tmp;
}
function toIntOrNull(_this__u8e3s4, radix) {
  checkRadix(radix);
  var length = _this__u8e3s4.length;
  if (length === 0)
    return null;
  var start;
  var isNegative;
  var limit;
  var firstChar = charSequenceGet(_this__u8e3s4, 0);
  if (Char__compareTo_impl_ypi4mb(firstChar, _Char___init__impl__6a9atx(48)) < 0) {
    if (length === 1)
      return null;
    start = 1;
    if (firstChar === _Char___init__impl__6a9atx(45)) {
      isNegative = true;
      limit = -2147483648;
    } else if (firstChar === _Char___init__impl__6a9atx(43)) {
      isNegative = false;
      limit = -2147483647;
    } else
      return null;
  } else {
    start = 0;
    isNegative = false;
    limit = -2147483647;
  }
  var limitForMaxRadix = -59652323;
  var limitBeforeMul = limitForMaxRadix;
  var result = 0;
  var inductionVariable = start;
  if (inductionVariable < length)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      var digit = digitOf(charSequenceGet(_this__u8e3s4, i), radix);
      if (digit < 0)
        return null;
      if (result < limitBeforeMul) {
        if (limitBeforeMul === limitForMaxRadix) {
          limitBeforeMul = limit / radix | 0;
          if (result < limitBeforeMul) {
            return null;
          }
        } else {
          return null;
        }
      }
      result = imul_0(result, radix);
      if (result < (limit + digit | 0))
        return null;
      result = result - digit | 0;
    }
     while (inductionVariable < length);
  return isNegative ? result : -result | 0;
}
function numberFormatError(input) {
  throw NumberFormatException.hd("Invalid number format: '" + input + "'");
}
function lastIndexOf_0(_this__u8e3s4, char, startIndex, ignoreCase) {
  startIndex = startIndex === VOID ? get_lastIndex_1(_this__u8e3s4) : startIndex;
  ignoreCase = ignoreCase === VOID ? false : ignoreCase;
  var tmp;
  var tmp_0;
  if (ignoreCase) {
    tmp_0 = true;
  } else {
    tmp_0 = !(typeof _this__u8e3s4 === 'string');
  }
  if (tmp_0) {
    // Inline function 'kotlin.charArrayOf' call
    var tmp$ret$0 = charArrayOf([char]);
    tmp = lastIndexOfAny(_this__u8e3s4, tmp$ret$0, startIndex, ignoreCase);
  } else {
    // Inline function 'kotlin.text.nativeLastIndexOf' call
    // Inline function 'kotlin.text.nativeLastIndexOf' call
    var str = toString(char);
    // Inline function 'kotlin.js.asDynamic' call
    tmp = _this__u8e3s4.lastIndexOf(str, startIndex);
  }
  return tmp;
}
function removeRange(_this__u8e3s4, startIndex, endIndex) {
  if (endIndex < startIndex)
    throw IndexOutOfBoundsException.bd('End index (' + endIndex + ') is less than start index (' + startIndex + ').');
  if (endIndex === startIndex)
    return charSequenceSubSequence(_this__u8e3s4, 0, charSequenceLength(_this__u8e3s4));
  var sb = StringBuilder.pb(charSequenceLength(_this__u8e3s4) - (endIndex - startIndex | 0) | 0);
  // Inline function 'kotlin.text.appendRange' call
  sb.bf(_this__u8e3s4, 0, startIndex);
  // Inline function 'kotlin.text.appendRange' call
  var endIndex_0 = charSequenceLength(_this__u8e3s4);
  sb.bf(_this__u8e3s4, endIndex, endIndex_0);
  return sb;
}
function contains_2(_this__u8e3s4, other, ignoreCase) {
  ignoreCase = ignoreCase === VOID ? false : ignoreCase;
  var tmp;
  if (typeof other === 'string') {
    tmp = indexOf_0(_this__u8e3s4, other, VOID, ignoreCase) >= 0;
  } else {
    tmp = indexOf_1(_this__u8e3s4, other, 0, charSequenceLength(_this__u8e3s4), ignoreCase) >= 0;
  }
  return tmp;
}
function indexOf_0(_this__u8e3s4, string, startIndex, ignoreCase) {
  startIndex = startIndex === VOID ? 0 : startIndex;
  ignoreCase = ignoreCase === VOID ? false : ignoreCase;
  var tmp;
  var tmp_0;
  if (ignoreCase) {
    tmp_0 = true;
  } else {
    tmp_0 = !(typeof _this__u8e3s4 === 'string');
  }
  if (tmp_0) {
    tmp = indexOf_1(_this__u8e3s4, string, startIndex, charSequenceLength(_this__u8e3s4), ignoreCase);
  } else {
    // Inline function 'kotlin.text.nativeIndexOf' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp = _this__u8e3s4.indexOf(string, startIndex);
  }
  return tmp;
}
function split(_this__u8e3s4, delimiters, ignoreCase, limit) {
  ignoreCase = ignoreCase === VOID ? false : ignoreCase;
  limit = limit === VOID ? 0 : limit;
  if (delimiters.length === 1) {
    var delimiter = delimiters[0];
    // Inline function 'kotlin.text.isEmpty' call
    if (!(charSequenceLength(delimiter) === 0)) {
      return split_0(_this__u8e3s4, delimiter, ignoreCase, limit);
    }
  }
  // Inline function 'kotlin.collections.map' call
  var this_0 = asIterable(rangesDelimitedBy(_this__u8e3s4, delimiters, VOID, ignoreCase, limit));
  // Inline function 'kotlin.collections.mapTo' call
  var destination = ArrayList.o7(collectionSizeOrDefault(this_0, 10));
  var _iterator__ex2g4s = this_0.x();
  while (_iterator__ex2g4s.y()) {
    var item = _iterator__ex2g4s.z();
    // Inline function 'kotlin.text.split.<anonymous>' call
    var tmp$ret$1 = substring(_this__u8e3s4, item);
    destination.o(tmp$ret$1);
  }
  return destination;
}
function get_lastIndex_1(_this__u8e3s4) {
  return charSequenceLength(_this__u8e3s4) - 1 | 0;
}
function lastIndexOfAny(_this__u8e3s4, chars, startIndex, ignoreCase) {
  startIndex = startIndex === VOID ? get_lastIndex_1(_this__u8e3s4) : startIndex;
  ignoreCase = ignoreCase === VOID ? false : ignoreCase;
  var tmp;
  if (!ignoreCase && chars.length === 1) {
    tmp = typeof _this__u8e3s4 === 'string';
  } else {
    tmp = false;
  }
  if (tmp) {
    var char = single(chars);
    // Inline function 'kotlin.text.nativeLastIndexOf' call
    // Inline function 'kotlin.text.nativeLastIndexOf' call
    var str = toString(char);
    // Inline function 'kotlin.js.asDynamic' call
    return _this__u8e3s4.lastIndexOf(str, startIndex);
  }
  var inductionVariable = coerceAtMost(startIndex, get_lastIndex_1(_this__u8e3s4));
  if (0 <= inductionVariable)
    do {
      var index = inductionVariable;
      inductionVariable = inductionVariable + -1 | 0;
      var charAtIndex = charSequenceGet(_this__u8e3s4, index);
      var tmp$ret$4;
      $l$block: {
        // Inline function 'kotlin.collections.any' call
        var inductionVariable_0 = 0;
        var last = chars.length;
        while (inductionVariable_0 < last) {
          var element = chars[inductionVariable_0];
          inductionVariable_0 = inductionVariable_0 + 1 | 0;
          // Inline function 'kotlin.text.lastIndexOfAny.<anonymous>' call
          if (equals_1(element, charAtIndex, ignoreCase)) {
            tmp$ret$4 = true;
            break $l$block;
          }
        }
        tmp$ret$4 = false;
      }
      if (tmp$ret$4)
        return index;
    }
     while (0 <= inductionVariable);
  return -1;
}
function indexOf_1(_this__u8e3s4, other, startIndex, endIndex, ignoreCase, last) {
  last = last === VOID ? false : last;
  var indices = !last ? numberRangeToNumber(coerceAtLeast(startIndex, 0), coerceAtMost(endIndex, charSequenceLength(_this__u8e3s4))) : downTo(coerceAtMost(startIndex, get_lastIndex_1(_this__u8e3s4)), coerceAtLeast(endIndex, 0));
  var tmp;
  if (typeof _this__u8e3s4 === 'string') {
    tmp = typeof other === 'string';
  } else {
    tmp = false;
  }
  if (tmp) {
    var inductionVariable = indices.pi_1;
    var last_0 = indices.qi_1;
    var step = indices.ri_1;
    if (step > 0 && inductionVariable <= last_0 || (step < 0 && last_0 <= inductionVariable))
      do {
        var index = inductionVariable;
        inductionVariable = inductionVariable + step | 0;
        if (regionMatches(other, 0, _this__u8e3s4, index, other.length, ignoreCase))
          return index;
      }
       while (!(index === last_0));
  } else {
    var inductionVariable_0 = indices.pi_1;
    var last_1 = indices.qi_1;
    var step_0 = indices.ri_1;
    if (step_0 > 0 && inductionVariable_0 <= last_1 || (step_0 < 0 && last_1 <= inductionVariable_0))
      do {
        var index_0 = inductionVariable_0;
        inductionVariable_0 = inductionVariable_0 + step_0 | 0;
        if (regionMatchesImpl(other, 0, _this__u8e3s4, index_0, charSequenceLength(other), ignoreCase))
          return index_0;
      }
       while (!(index_0 === last_1));
  }
  return -1;
}
function isBlank(_this__u8e3s4) {
  var tmp$ret$1;
  $l$block: {
    // Inline function 'kotlin.text.all' call
    var inductionVariable = 0;
    while (inductionVariable < charSequenceLength(_this__u8e3s4)) {
      var element = charSequenceGet(_this__u8e3s4, inductionVariable);
      inductionVariable = inductionVariable + 1 | 0;
      // Inline function 'kotlin.text.isBlank.<anonymous>' call
      if (!isWhitespace(element)) {
        tmp$ret$1 = false;
        break $l$block;
      }
    }
    tmp$ret$1 = true;
  }
  return tmp$ret$1;
}
function regionMatchesImpl(_this__u8e3s4, thisOffset, other, otherOffset, length, ignoreCase) {
  if (otherOffset < 0 || thisOffset < 0 || thisOffset > (charSequenceLength(_this__u8e3s4) - length | 0) || otherOffset > (charSequenceLength(other) - length | 0)) {
    return false;
  }
  var inductionVariable = 0;
  if (inductionVariable < length)
    do {
      var index = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      if (!equals_1(charSequenceGet(_this__u8e3s4, thisOffset + index | 0), charSequenceGet(other, otherOffset + index | 0), ignoreCase))
        return false;
    }
     while (inductionVariable < length);
  return true;
}
function split_0(_this__u8e3s4, delimiter, ignoreCase, limit) {
  requireNonNegativeLimit(limit);
  var currentOffset = 0;
  var nextIndex = indexOf_0(_this__u8e3s4, delimiter, currentOffset, ignoreCase);
  if (nextIndex === -1 || limit === 1) {
    return listOf(toString_1(_this__u8e3s4));
  }
  var isLimited = limit > 0;
  var result = ArrayList.o7(isLimited ? coerceAtMost(limit, 10) : 10);
  $l$loop: do {
    var tmp1 = currentOffset;
    // Inline function 'kotlin.text.substring' call
    var endIndex = nextIndex;
    var tmp$ret$0 = toString_1(charSequenceSubSequence(_this__u8e3s4, tmp1, endIndex));
    result.o(tmp$ret$0);
    currentOffset = nextIndex + delimiter.length | 0;
    if (isLimited && result.a1() === (limit - 1 | 0))
      break $l$loop;
    nextIndex = indexOf_0(_this__u8e3s4, delimiter, currentOffset, ignoreCase);
  }
   while (!(nextIndex === -1));
  var tmp4 = currentOffset;
  // Inline function 'kotlin.text.substring' call
  var endIndex_0 = charSequenceLength(_this__u8e3s4);
  var tmp$ret$1 = toString_1(charSequenceSubSequence(_this__u8e3s4, tmp4, endIndex_0));
  result.o(tmp$ret$1);
  return result;
}
function substring(_this__u8e3s4, range) {
  return toString_1(charSequenceSubSequence(_this__u8e3s4, range.oi(), range.si() + 1 | 0));
}
function rangesDelimitedBy(_this__u8e3s4, delimiters, startIndex, ignoreCase, limit) {
  startIndex = startIndex === VOID ? 0 : startIndex;
  ignoreCase = ignoreCase === VOID ? false : ignoreCase;
  limit = limit === VOID ? 0 : limit;
  requireNonNegativeLimit(limit);
  var delimitersList = asList(delimiters);
  return new DelimitedRangesSequence(_this__u8e3s4, startIndex, limit, rangesDelimitedBy$lambda(delimitersList, ignoreCase));
}
function requireNonNegativeLimit(limit) {
  var tmp;
  if (!(limit >= 0)) {
    // Inline function 'kotlin.text.requireNonNegativeLimit.<anonymous>' call
    var message = 'Limit must be non-negative, but was ' + limit;
    throw IllegalArgumentException.h(toString_1(message));
  }
  return tmp;
}
function calcNext_0($this) {
  if ($this.aj_1 < 0) {
    $this.yi_1 = 0;
    $this.bj_1 = null;
  } else {
    var tmp;
    var tmp_0;
    if ($this.dj_1.gj_1 > 0) {
      $this.cj_1 = $this.cj_1 + 1 | 0;
      tmp_0 = $this.cj_1 >= $this.dj_1.gj_1;
    } else {
      tmp_0 = false;
    }
    if (tmp_0) {
      tmp = true;
    } else {
      tmp = $this.aj_1 > charSequenceLength($this.dj_1.ej_1);
    }
    if (tmp) {
      $this.bj_1 = numberRangeToNumber($this.zi_1, get_lastIndex_1($this.dj_1.ej_1));
      $this.aj_1 = -1;
    } else {
      var match = $this.dj_1.hj_1($this.dj_1.ej_1, $this.aj_1);
      if (match == null) {
        $this.bj_1 = numberRangeToNumber($this.zi_1, get_lastIndex_1($this.dj_1.ej_1));
        $this.aj_1 = -1;
      } else {
        var index = match.kj();
        var length = match.lj();
        $this.bj_1 = until($this.zi_1, index);
        $this.zi_1 = index + length | 0;
        $this.aj_1 = $this.zi_1 + (length === 0 ? 1 : 0) | 0;
      }
    }
    $this.yi_1 = 1;
  }
}
function findAnyOf(_this__u8e3s4, strings, startIndex, ignoreCase, last) {
  if (!ignoreCase && strings.a1() === 1) {
    var string = single_1(strings);
    var index = !last ? indexOf_0(_this__u8e3s4, string, startIndex) : lastIndexOf_1(_this__u8e3s4, string, startIndex);
    return index < 0 ? null : to(index, string);
  }
  var indices = !last ? numberRangeToNumber(coerceAtLeast(startIndex, 0), charSequenceLength(_this__u8e3s4)) : downTo(coerceAtMost(startIndex, get_lastIndex_1(_this__u8e3s4)), 0);
  if (typeof _this__u8e3s4 === 'string') {
    var inductionVariable = indices.pi_1;
    var last_0 = indices.qi_1;
    var step = indices.ri_1;
    if (step > 0 && inductionVariable <= last_0 || (step < 0 && last_0 <= inductionVariable))
      do {
        var index_0 = inductionVariable;
        inductionVariable = inductionVariable + step | 0;
        var tmp$ret$1;
        $l$block: {
          // Inline function 'kotlin.collections.firstOrNull' call
          var _iterator__ex2g4s = strings.x();
          while (_iterator__ex2g4s.y()) {
            var element = _iterator__ex2g4s.z();
            // Inline function 'kotlin.text.findAnyOf.<anonymous>' call
            if (regionMatches(element, 0, _this__u8e3s4, index_0, element.length, ignoreCase)) {
              tmp$ret$1 = element;
              break $l$block;
            }
          }
          tmp$ret$1 = null;
        }
        var matchingString = tmp$ret$1;
        if (!(matchingString == null))
          return to(index_0, matchingString);
      }
       while (!(index_0 === last_0));
  } else {
    var inductionVariable_0 = indices.pi_1;
    var last_1 = indices.qi_1;
    var step_0 = indices.ri_1;
    if (step_0 > 0 && inductionVariable_0 <= last_1 || (step_0 < 0 && last_1 <= inductionVariable_0))
      do {
        var index_1 = inductionVariable_0;
        inductionVariable_0 = inductionVariable_0 + step_0 | 0;
        var tmp$ret$3;
        $l$block_0: {
          // Inline function 'kotlin.collections.firstOrNull' call
          var _iterator__ex2g4s_0 = strings.x();
          while (_iterator__ex2g4s_0.y()) {
            var element_0 = _iterator__ex2g4s_0.z();
            // Inline function 'kotlin.text.findAnyOf.<anonymous>' call
            if (regionMatchesImpl(element_0, 0, _this__u8e3s4, index_1, element_0.length, ignoreCase)) {
              tmp$ret$3 = element_0;
              break $l$block_0;
            }
          }
          tmp$ret$3 = null;
        }
        var matchingString_0 = tmp$ret$3;
        if (!(matchingString_0 == null))
          return to(index_1, matchingString_0);
      }
       while (!(index_1 === last_1));
  }
  return null;
}
function lastIndexOf_1(_this__u8e3s4, string, startIndex, ignoreCase) {
  startIndex = startIndex === VOID ? get_lastIndex_1(_this__u8e3s4) : startIndex;
  ignoreCase = ignoreCase === VOID ? false : ignoreCase;
  var tmp;
  var tmp_0;
  if (ignoreCase) {
    tmp_0 = true;
  } else {
    tmp_0 = !(typeof _this__u8e3s4 === 'string');
  }
  if (tmp_0) {
    tmp = indexOf_1(_this__u8e3s4, string, startIndex, 0, ignoreCase, true);
  } else {
    // Inline function 'kotlin.text.nativeLastIndexOf' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp = _this__u8e3s4.lastIndexOf(string, startIndex);
  }
  return tmp;
}
function lineSequence(_this__u8e3s4) {
  // Inline function 'kotlin.sequences.Sequence' call
  return new lineSequence$$inlined$Sequence$1(_this__u8e3s4);
}
var State_instance;
function State_getInstance() {
  return State_instance;
}
function rangesDelimitedBy$lambda($delimitersList, $ignoreCase) {
  return ($this$DelimitedRangesSequence, currentIndex) => {
    var tmp0_safe_receiver = findAnyOf($this$DelimitedRangesSequence, $delimitersList, currentIndex, $ignoreCase, false);
    var tmp;
    if (tmp0_safe_receiver == null) {
      tmp = null;
    } else {
      // Inline function 'kotlin.let' call
      // Inline function 'kotlin.text.rangesDelimitedBy.<anonymous>.<anonymous>' call
      tmp = to(tmp0_safe_receiver.ij_1, tmp0_safe_receiver.jj_1.length);
    }
    return tmp;
  };
}
var UNINITIALIZED_VALUE_instance;
function UNINITIALIZED_VALUE_getInstance() {
  return UNINITIALIZED_VALUE_instance;
}
function _Result___init__impl__xyqfz8(value) {
  return value;
}
function _Result___get_value__impl__bjfvqg($this) {
  return $this;
}
function Result__exceptionOrNull_impl_p6xea9($this) {
  var tmp;
  if (_Result___get_value__impl__bjfvqg($this) instanceof Failure) {
    tmp = _Result___get_value__impl__bjfvqg($this).yj_1;
  } else {
    tmp = null;
  }
  return tmp;
}
var Companion_instance_14;
function Companion_getInstance_14() {
  return Companion_instance_14;
}
function createFailure(exception) {
  return new Failure(exception);
}
function to(_this__u8e3s4, that) {
  return new Pair(_this__u8e3s4, that);
}
function _UByte___init__impl__g9hnc4(data) {
  return data;
}
function _UByte___get_data__impl__jof9qr($this) {
  return $this;
}
function UByte__toString_impl_v72jg($this) {
  // Inline function 'kotlin.UByte.toInt' call
  return (_UByte___get_data__impl__jof9qr($this) & 255).toString();
}
function _UInt___init__impl__l7qpdl(data) {
  return data;
}
function _UInt___get_data__impl__f0vqqw($this) {
  return $this;
}
function _UShort___init__impl__jigrne(data) {
  return data;
}
function _UShort___get_data__impl__g0245($this) {
  return $this;
}
function toString_6(_this__u8e3s4, radix) {
  // Inline function 'kotlin.UByte.toInt' call
  var tmp$ret$0 = _UByte___get_data__impl__jof9qr(_this__u8e3s4) & 255;
  return toString_3(tmp$ret$0, radix);
}
var Iterables_instance;
function Iterables_getInstance() {
  return Iterables_instance;
}
function empty(_this__u8e3s4) {
  return _this__u8e3s4.c1();
}
function peek(_this__u8e3s4) {
  var tmp;
  // Inline function 'kotlin.collections.isNotEmpty' call
  if (!_this__u8e3s4.c1()) {
    tmp = _this__u8e3s4.b1(get_lastIndex_0(_this__u8e3s4));
  } else {
    tmp = null;
  }
  return tmp;
}
function pop(_this__u8e3s4) {
  var tmp;
  // Inline function 'kotlin.collections.isNotEmpty' call
  if (!_this__u8e3s4.c1()) {
    tmp = _this__u8e3s4.u5(get_lastIndex_0(_this__u8e3s4));
  } else {
    tmp = null;
  }
  return tmp;
}
function arraycopy(src, srcPos, dst, dstPos, size) {
  // Inline function 'kotlin.run' call
  // Inline function 'com.macrofocus.common.collection.arraycopy.<anonymous>' call
  // Inline function 'kotlin.collections.copyInto' call
  var endIndex = srcPos + size | 0;
  arrayCopy(src, dst, dstPos, srcPos, endIndex);
  return Unit_instance;
}
function arraycopy_0(src, srcPos, dst, dstPos, size) {
  // Inline function 'kotlin.run' call
  // Inline function 'com.macrofocus.common.collection.arraycopy.<anonymous>' call
  // Inline function 'kotlin.collections.copyInto' call
  var endIndex = srcPos + size | 0;
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  var tmp = src;
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  arrayCopy(tmp, dst, dstPos, srcPos, endIndex);
  return Unit_instance;
}
function arraycopy_1(src, srcPos, dst, dstPos, size) {
  // Inline function 'kotlin.run' call
  // Inline function 'com.macrofocus.common.collection.arraycopy.<anonymous>' call
  // Inline function 'kotlin.collections.copyInto' call
  var endIndex = srcPos + size | 0;
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  var tmp = src;
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  arrayCopy(tmp, dst, dstPos, srcPos, endIndex);
  return Unit_instance;
}
var Companion_instance_15;
function Companion_getInstance_15() {
  if (Companion_instance_15 === VOID)
    new Companion_15();
  return Companion_instance_15;
}
function init_com_macrofocus_common_geom_Dimension(_this__u8e3s4) {
}
function compare_0(v1, v2) {
  return compareTo(v1, v2);
}
function isNaN_3(value) {
  return isNaN_0(value);
}
function doubleToLongBits(value) {
  return toRawBits(value);
}
function convertRadiansToDegrees(angdeg) {
  return angdeg * 57.29577951308232;
}
function convertDegreesToRadians(angdeg) {
  return angdeg * 0.017453292519943295;
}
function isInfinite_1(value) {
  return isInfinite(value);
}
function isNaN_4(value) {
  return isNaN_1(value);
}
function isInfinite_2(value) {
  return isInfinite_0(value);
}
var Companion_instance_16;
function Companion_getInstance_16() {
  if (Companion_instance_16 === VOID)
    new Companion_16();
  return Companion_instance_16;
}
var Companion_instance_17;
function Companion_getInstance_17() {
  if (Companion_instance_17 === VOID)
    new Companion_17();
  return Companion_instance_17;
}
function unitIndex($this, bitIndex) {
  return bitIndex >>> 6 | 0;
}
function bit($this, bitIndex) {
  return (new Long(1, 0)).q3(bitIndex & 63);
}
function get_1($this, bitIndex) {
  var unitIndex_0 = unitIndex(Companion_getInstance_18(), bitIndex);
  return !ensureNotNull($this.cr_1)[unitIndex_0].t3(bit(Companion_getInstance_18(), bitIndex)).equals(new Long(0, 0));
}
function set($this, bitIndex) {
  var unitIndex_0 = unitIndex(Companion_getInstance_18(), bitIndex);
  ensureNotNull($this.cr_1)[unitIndex_0] = ensureNotNull($this.cr_1)[unitIndex_0].u3(bit(Companion_getInstance_18(), bitIndex));
}
function sieveSearch($this, limit, start) {
  if (start >= limit) {
    return -1;
  }
  var index = start;
  do {
    if (!get_1($this, index)) {
      return index;
    }
    index = index + 1 | 0;
  }
   while (index < (limit - 1 | 0));
  return -1;
}
function sieveSingle($this, limit, start, step) {
  var start_0 = start;
  while (start_0 < limit) {
    set($this, start_0);
    start_0 = start_0 + step | 0;
  }
}
var Companion_instance_18;
function Companion_getInstance_18() {
  if (Companion_instance_18 === VOID)
    new Companion_18();
  return Companion_instance_18;
}
function init_com_macrofocus_common_math_big_BitSieve(_this__u8e3s4) {
  Companion_getInstance_18();
  _this__u8e3s4.cr_1 = null;
  _this__u8e3s4.dr_1 = 0;
}
var Companion_instance_19;
function Companion_getInstance_19() {
  if (Companion_instance_19 === VOID)
    new Companion_19();
  return Companion_instance_19;
}
function parseExp($this, in_0, offset, len) {
  var offset_0 = offset;
  var len_0 = len;
  var exp = new Long(0, 0);
  offset_0 = offset_0 + 1 | 0;
  var c = in_0[offset_0];
  len_0 = len_0 - 1 | 0;
  var negexp = c === _Char___init__impl__6a9atx(45);
  if (negexp || c === _Char___init__impl__6a9atx(43)) {
    offset_0 = offset_0 + 1 | 0;
    c = in_0[offset_0];
    len_0 = len_0 - 1 | 0;
  }
  if (len_0 <= 0) {
    throw NumberFormatException.hd('No exponent digits.');
  }
  while (len_0 > 10 && (c === _Char___init__impl__6a9atx(48) || toDigit(c, 10) === 0)) {
    offset_0 = offset_0 + 1 | 0;
    c = in_0[offset_0];
    len_0 = len_0 - 1 | 0;
  }
  if (len_0 > 10) {
    throw NumberFormatException.hd('Too many nonzero exponent digits.');
  }
  $l$loop: while (true) {
    var v;
    if (_Char___init__impl__6a9atx(48) <= c ? c <= _Char___init__impl__6a9atx(57) : false) {
      v = Char__minus_impl_a2frrh(c, _Char___init__impl__6a9atx(48));
    } else {
      v = toDigit(c, 10);
      if (v < 0) {
        throw NumberFormatException.hd('Not a digit.');
      }
    }
    // Inline function 'kotlin.Long.times' call
    var tmp2 = exp.j3(toLong(10));
    // Inline function 'kotlin.Long.plus' call
    var other = v;
    exp = tmp2.h3(toLong(other));
    if (len_0 === 1) {
      break $l$loop;
    }
    offset_0 = offset_0 + 1 | 0;
    c = in_0[offset_0];
    len_0 = len_0 - 1 | 0;
  }
  if (negexp) {
    exp = exp.o3();
  }
  return exp;
}
function bigTenToThe($this, n) {
  if (n < 0) {
    return Companion_getInstance_21().ZERO;
  }
  if (n < $this.mt_1) {
    var pows = $this.kt_1;
    var tmp;
    if (n < pows.length) {
      tmp = ensureNotNull(pows[n]);
    } else {
      tmp = expandBigIntegerTenPowers($this, n);
    }
    return tmp;
  }
  return Companion_getInstance_21().TEN.pow(n);
}
function expandBigIntegerTenPowers($this, n) {
  // Inline function 'com.macrofocus.common.math.big.lock' call
  var pows = Companion_getInstance_20().kt_1;
  var curLen = pows.length;
  if (curLen <= n) {
    var newLen = curLen << 1;
    while (newLen <= n) {
      newLen = newLen << 1;
    }
    pows = copyOf_0(pows, newLen);
    var inductionVariable = curLen;
    var last = newLen;
    if (inductionVariable < last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        pows[i] = ensureNotNull(pows[i - 1 | 0]).times(Companion_getInstance_21().TEN);
      }
       while (inductionVariable < last);
    Companion_getInstance_20().kt_1 = pows;
  }
  return ensureNotNull(pows[n]);
}
function longMultiplyPowerTen($this, val, n) {
  if (val.equals(new Long(0, 0)) || n <= 0) {
    return val;
  }
  var tab = $this.jt_1;
  var bounds = $this.nt_1;
  if (n < tab.length && n < bounds.length) {
    var tenpower = tab[n];
    if (val.equals(new Long(1, 0))) {
      return tenpower;
    }
    if (abs(val).m1(bounds[n]) <= 0) {
      return val.j3(tenpower);
    }
  }
  return new Long(0, -2147483648);
}
function matchScale($this, val) {
  if (val[0].rt_1 < val[1].rt_1) {
    val[0] = val[0].setScaleInt(val[1].rt_1, RoundingMode_UNNECESSARY_getInstance().value);
  } else if (val[1].rt_1 < val[0].rt_1) {
    val[1] = val[1].setScaleInt(val[0].rt_1, RoundingMode_UNNECESSARY_getInstance().value);
  }
}
function bigDigitLength($this, b) {
  if (b.pr_1 === 0) {
    return 1;
  }
  // Inline function 'kotlin.Long.plus' call
  // Inline function 'kotlin.Long.times' call
  var r = toLong(b.bitLength).h3(toLong(1)).j3(toLong(646456993)).s3(31).l1();
  return b.xt(bigTenToThe($this, r)) < 0 ? r : r + 1 | 0;
}
function compactValFor($this, b) {
  var m = b.qr_1;
  var len = m.length;
  if (len === 0) {
    return new Long(0, 0);
  }
  var d = m[0];
  if (len > 2 || (len === 2 && d < 0)) {
    return new Long(0, -2147483648);
  }
  var tmp;
  if (len === 2) {
    tmp = toLong(m[1]).t3(new Long(-1, 0)).h3(toLong(d).q3(32));
  } else {
    tmp = toLong(d).t3(new Long(-1, 0));
  }
  var u = tmp;
  return b.pr_1 < 0 ? u.o3() : u;
}
function longCompareMagnitude($this, x, y) {
  var x_0 = x;
  var y_0 = y;
  if (x_0.m1(new Long(0, 0)) < 0) {
    x_0 = x_0.o3();
  }
  if (y_0.m1(new Long(0, 0)) < 0) {
    y_0 = y_0.o3();
  }
  var tmp;
  if (x_0.m1(y_0) < 0) {
    tmp = -1;
  } else if (x_0.equals(y_0)) {
    tmp = 0;
  } else {
    tmp = 1;
  }
  return tmp;
}
function saturateLong($this, s) {
  var i = s.l1();
  var tmp;
  if (s.equals(toLong(i))) {
    tmp = i;
  } else if (s.m1(new Long(0, 0)) < 0) {
    tmp = -2147483648;
  } else {
    tmp = 2147483647;
  }
  return tmp;
}
function checkScaleNonZero($this, val) {
  var asInt = val.l1();
  if (!toLong(asInt).equals(val)) {
    throw ArithmeticException.md(asInt > 0 ? 'Underflow' : 'Overflow');
  }
  return asInt;
}
function checkScale($this, intCompact, val) {
  var asInt = val.l1();
  if (!toLong(asInt).equals(val)) {
    asInt = val.m1(new Long(2147483647, 0)) > 0 ? 2147483647 : -2147483648;
    if (!intCompact.equals(new Long(0, 0))) {
      throw ArithmeticException.md(asInt > 0 ? 'Underflow' : 'Overflow');
    }
  }
  return asInt;
}
function checkScale_0($this, intVal, val) {
  var asInt = val.l1();
  if (!toLong(asInt).equals(val)) {
    asInt = val.m1(new Long(2147483647, 0)) > 0 ? 2147483647 : -2147483648;
    if (!(ensureNotNull(intVal).signum === 0)) {
      throw ArithmeticException.md(asInt > 0 ? 'Underflow' : 'Overflow');
    }
  }
  return asInt;
}
function doRound($this, val, mc) {
  var mcp = mc.precision;
  var wasDivided = false;
  if (mcp > 0) {
    var intVal = ensureNotNull(val).qt_1;
    var compactVal = val.ut_1;
    var scale = val.rt_1;
    var prec = val.precision;
    var mode = mc.roundingMode.value;
    var drop;
    if (compactVal.equals(new Long(0, -2147483648))) {
      drop = prec - mcp | 0;
      $l$loop: while (drop > 0) {
        var tmp0 = toLong(scale);
        // Inline function 'kotlin.Long.minus' call
        var other = drop;
        var tmp$ret$0 = tmp0.i3(toLong(other));
        scale = checkScaleNonZero($this, tmp$ret$0);
        intVal = divideAndRoundByTenPow($this, ensureNotNull(intVal), drop, mode);
        wasDivided = true;
        compactVal = compactValFor($this, intVal);
        if (!compactVal.equals(new Long(0, -2147483648))) {
          prec = $this.yt(compactVal);
          break $l$loop;
        }
        prec = bigDigitLength($this, intVal);
        drop = prec - mcp | 0;
      }
    }
    if (!compactVal.equals(new Long(0, -2147483648))) {
      drop = prec - mcp | 0;
      while (drop > 0) {
        var tmp2 = toLong(scale);
        // Inline function 'kotlin.Long.minus' call
        var other_0 = drop;
        var tmp$ret$1 = tmp2.i3(toLong(other_0));
        scale = checkScaleNonZero($this, tmp$ret$1);
        compactVal = divideAndRound_0($this, compactVal, $this.jt_1[drop], mc.roundingMode.value);
        wasDivided = true;
        prec = $this.yt(compactVal);
        drop = prec - mcp | 0;
        intVal = null;
      }
    }
    return wasDivided ? CommonBigDecimal.zt(intVal, compactVal, scale, prec) : val;
  }
  return val;
}
function doRound_0($this, compactVal, scale, mc) {
  var compactVal_0 = compactVal;
  var scale_0 = scale;
  var mcp = mc.precision;
  if (mcp > 0 && mcp < 19) {
    var prec = $this.yt(compactVal_0);
    var drop = prec - mcp | 0;
    while (drop > 0) {
      var tmp0 = toLong(scale_0);
      // Inline function 'kotlin.Long.minus' call
      var other = drop;
      var tmp$ret$0 = tmp0.i3(toLong(other));
      scale_0 = checkScaleNonZero($this, tmp$ret$0);
      compactVal_0 = divideAndRound_0($this, compactVal_0, $this.jt_1[drop], mc.roundingMode.value);
      prec = $this.yt(compactVal_0);
      drop = prec - mcp | 0;
    }
    return $this.ofScaledLongWithPrecision(compactVal_0, scale_0, prec);
  }
  return $this.ofScaledLong(compactVal_0, scale_0);
}
function doRound_1($this, intVal, scale, mc) {
  var intVal_0 = intVal;
  var scale_0 = scale;
  var mcp = mc.precision;
  var prec = 0;
  if (mcp > 0) {
    var compactVal = compactValFor($this, intVal_0);
    var mode = mc.roundingMode.value;
    var drop;
    if (compactVal.equals(new Long(0, -2147483648))) {
      prec = bigDigitLength($this, intVal_0);
      drop = prec - mcp | 0;
      $l$loop: while (drop > 0) {
        var tmp0 = toLong(scale_0);
        // Inline function 'kotlin.Long.minus' call
        var other = drop;
        var tmp$ret$0 = tmp0.i3(toLong(other));
        scale_0 = checkScaleNonZero($this, tmp$ret$0);
        intVal_0 = divideAndRoundByTenPow($this, intVal_0, drop, mode);
        compactVal = compactValFor($this, intVal_0);
        if (!compactVal.equals(new Long(0, -2147483648))) {
          break $l$loop;
        }
        prec = bigDigitLength($this, intVal_0);
        drop = prec - mcp | 0;
      }
    }
    if (!compactVal.equals(new Long(0, -2147483648))) {
      prec = $this.yt(compactVal);
      drop = prec - mcp | 0;
      while (drop > 0) {
        var tmp2 = toLong(scale_0);
        // Inline function 'kotlin.Long.minus' call
        var other_0 = drop;
        var tmp$ret$1 = tmp2.i3(toLong(other_0));
        scale_0 = checkScaleNonZero($this, tmp$ret$1);
        compactVal = divideAndRound_0($this, compactVal, $this.jt_1[drop], mc.roundingMode.value);
        prec = $this.yt(compactVal);
        drop = prec - mcp | 0;
      }
      return $this.ofScaledLongWithPrecision(compactVal, scale_0, prec);
    }
  }
  return CommonBigDecimal.zt(intVal_0, new Long(0, -2147483648), scale_0, prec);
}
function divideAndRoundByTenPow($this, intVal, tenPow, roundingMode) {
  var intVal_0 = intVal;
  if (tenPow < $this.jt_1.length) {
    intVal_0 = divideAndRound_1($this, intVal_0, $this.jt_1[tenPow], roundingMode);
  } else {
    intVal_0 = divideAndRound_3($this, intVal_0, bigTenToThe($this, tenPow), roundingMode);
  }
  return intVal_0;
}
function divideAndRound($this, ldividend, ldivisor, scale, roundingMode, preferredScale) {
  var qsign;
  var q = ldividend.k3(ldivisor);
  if (roundingMode === RoundingMode_DOWN_getInstance().value && scale === preferredScale) {
    return $this.ofScaledLong(q, scale);
  }
  var r = ldividend.l3(ldivisor);
  qsign = ldividend.m1(new Long(0, 0)) < 0 === ldivisor.m1(new Long(0, 0)) < 0 ? 1 : -1;
  if (!r.equals(new Long(0, 0))) {
    var increment = needIncrement($this, ldivisor, roundingMode, qsign, q, r);
    var tmp;
    if (increment) {
      // Inline function 'kotlin.Long.plus' call
      tmp = q.h3(toLong(qsign));
    } else {
      tmp = q;
    }
    return $this.ofScaledLong(tmp, scale);
  } else {
    var tmp_0;
    if (!(preferredScale === scale)) {
      tmp_0 = createAndStripZerosToMatchScale_0($this, q, scale, toLong(preferredScale));
    } else {
      tmp_0 = $this.ofScaledLong(q, scale);
    }
    return tmp_0;
  }
}
function divideAndRound_0($this, ldividend, ldivisor, roundingMode) {
  var qsign;
  var q = ldividend.k3(ldivisor);
  if (roundingMode === RoundingMode_DOWN_getInstance().value) {
    return q;
  }
  var r = ldividend.l3(ldivisor);
  qsign = ldividend.m1(new Long(0, 0)) < 0 === ldivisor.m1(new Long(0, 0)) < 0 ? 1 : -1;
  if (!r.equals(new Long(0, 0))) {
    var increment = needIncrement($this, ldivisor, roundingMode, qsign, q, r);
    var tmp;
    if (increment) {
      // Inline function 'kotlin.Long.plus' call
      tmp = q.h3(toLong(qsign));
    } else {
      tmp = q;
    }
    return tmp;
  } else {
    return q;
  }
}
function commonNeedIncrement($this, roundingMode, qsign, cmpFracHalf, oddQuot) {
  if (roundingMode === RoundingMode_UNNECESSARY_getInstance().value)
    throw ArithmeticException.md('Rounding necessary');
  else if (roundingMode === RoundingMode_UP_getInstance().value)
    return true;
  else if (roundingMode === RoundingMode_DOWN_getInstance().value)
    return false;
  else if (roundingMode === RoundingMode_CEILING_getInstance().value)
    return qsign > 0;
  else if (roundingMode === RoundingMode_FLOOR_getInstance().value)
    return qsign < 0;
  else {
    // Inline function 'kotlin.require' call
    if (!(roundingMode >= RoundingMode_HALF_UP_getInstance().value && roundingMode <= RoundingMode_HALF_EVEN_getInstance().value)) {
      // Inline function 'com.macrofocus.common.math.big.Companion.commonNeedIncrement.<anonymous>' call
      var message = 'Unexpected rounding mode' + Companion_instance_24.valueOfInt(roundingMode).toString();
      throw IllegalArgumentException.h(toString_1(message));
    }
    if (cmpFracHalf < 0) {
      return false;
    } else if (cmpFracHalf > 0) {
      return true;
    } else {
      // Inline function 'kotlin.require' call
      // Inline function 'kotlin.require' call
      if (!(cmpFracHalf === 0)) {
        // Inline function 'kotlin.require.<anonymous>' call
        var message_0 = 'Failed requirement.';
        throw IllegalArgumentException.h(toString_1(message_0));
      }
      if (roundingMode === RoundingMode_HALF_DOWN_getInstance().value)
        return false;
      else if (roundingMode === RoundingMode_HALF_UP_getInstance().value)
        return true;
      else if (roundingMode === RoundingMode_HALF_EVEN_getInstance().value)
        return oddQuot;
      else
        throw AssertionError.qd('Unexpected rounding mode' + roundingMode);
    }
  }
}
function needIncrement($this, ldivisor, roundingMode, qsign, q, r) {
  // Inline function 'kotlin.require' call
  // Inline function 'kotlin.require' call
  if (!!r.equals(new Long(0, 0))) {
    // Inline function 'kotlin.require.<anonymous>' call
    var message = 'Failed requirement.';
    throw IllegalArgumentException.h(toString_1(message));
  }
  var cmpFracHalf;
  if (r.m1(new Long(0, -1073741824)) <= 0 || r.m1(new Long(-1, 1073741823)) > 0) {
    cmpFracHalf = 1;
  } else {
    cmpFracHalf = longCompareMagnitude($this, numberToLong(2).j3(r), ldivisor);
  }
  return commonNeedIncrement($this, roundingMode, qsign, cmpFracHalf, !q.t3(new Long(1, 0)).equals(new Long(0, 0)));
}
function divideAndRound_1($this, bdividend, ldivisor, roundingMode) {
  var mdividend = MutableBigInteger.au(bdividend.qr_1);
  var mq = MutableBigInteger.lr();
  var r = mdividend.bu(ldivisor, mq);
  var isRemainderZero = r.equals(new Long(0, 0));
  var qsign = ldivisor.m1(new Long(0, 0)) < 0 ? -bdividend.pr_1 | 0 : bdividend.pr_1;
  if (!isRemainderZero) {
    if (needIncrement_0($this, ldivisor, roundingMode, qsign, mq, r)) {
      mq.fu(Companion_getInstance_23().cu_1);
    }
  }
  return mq.gu(qsign);
}
function divideAndRound_2($this, bdividend, ldivisor, scale, roundingMode, preferredScale) {
  var mdividend = MutableBigInteger.au(bdividend.qr_1);
  var mq = MutableBigInteger.lr();
  var r = mdividend.bu(ldivisor, mq);
  var isRemainderZero = r.equals(new Long(0, 0));
  var qsign = ldivisor.m1(new Long(0, 0)) < 0 ? -bdividend.pr_1 | 0 : bdividend.pr_1;
  if (!isRemainderZero) {
    if (needIncrement_0($this, ldivisor, roundingMode, qsign, mq, r)) {
      mq.fu(Companion_getInstance_23().cu_1);
    }
    return mq.hu(qsign, scale);
  } else {
    if (!(preferredScale === scale)) {
      var compactVal = mq.iu(qsign);
      if (!compactVal.equals(new Long(0, -2147483648))) {
        return createAndStripZerosToMatchScale_0($this, compactVal, scale, toLong(preferredScale));
      }
      var intVal = mq.gu(qsign);
      return createAndStripZerosToMatchScale($this, intVal, scale, toLong(preferredScale));
    } else {
      return mq.hu(qsign, scale);
    }
  }
}
function needIncrement_0($this, ldivisor, roundingMode, qsign, mq, r) {
  // Inline function 'kotlin.require' call
  // Inline function 'kotlin.require' call
  if (!!r.equals(new Long(0, 0))) {
    // Inline function 'kotlin.require.<anonymous>' call
    var message = 'Failed requirement.';
    throw IllegalArgumentException.h(toString_1(message));
  }
  var cmpFracHalf;
  if (r.m1(new Long(0, -1073741824)) <= 0 || r.m1(new Long(-1, 1073741823)) > 0) {
    cmpFracHalf = 1;
  } else {
    cmpFracHalf = longCompareMagnitude($this, numberToLong(2).j3(r), ldivisor);
  }
  return commonNeedIncrement($this, roundingMode, qsign, cmpFracHalf, mq.ju());
}
function divideAndRound_3($this, bdividend, bdivisor, roundingMode) {
  var isRemainderZero;
  var qsign;
  var mdividend = MutableBigInteger.au(bdividend.qr_1);
  var mq = MutableBigInteger.lr();
  var mdivisor = MutableBigInteger.au(bdivisor.qr_1);
  var mr = mdividend.ku(mdivisor, mq);
  isRemainderZero = ensureNotNull(mr).lu();
  qsign = !(bdividend.pr_1 === bdivisor.pr_1) ? -1 : 1;
  if (!isRemainderZero) {
    if (needIncrement_1($this, mdivisor, roundingMode, qsign, mq, mr)) {
      mq.fu(Companion_getInstance_23().cu_1);
    }
  }
  return mq.gu(qsign);
}
function divideAndRound_4($this, bdividend, bdivisor, scale, roundingMode, preferredScale) {
  var isRemainderZero;
  var qsign;
  var mdividend = MutableBigInteger.au(bdividend.qr_1);
  var mq = MutableBigInteger.lr();
  var mdivisor = MutableBigInteger.au(bdivisor.qr_1);
  var mr = mdividend.ku(mdivisor, mq);
  isRemainderZero = ensureNotNull(mr).lu();
  qsign = !(bdividend.pr_1 === bdivisor.pr_1) ? -1 : 1;
  if (!isRemainderZero) {
    if (needIncrement_1($this, mdivisor, roundingMode, qsign, mq, mr)) {
      mq.fu(Companion_getInstance_23().cu_1);
    }
    return mq.hu(qsign, scale);
  } else {
    if (!(preferredScale === scale)) {
      var compactVal = mq.iu(qsign);
      if (!compactVal.equals(new Long(0, -2147483648))) {
        return createAndStripZerosToMatchScale_0($this, compactVal, scale, toLong(preferredScale));
      }
      var intVal = mq.gu(qsign);
      return createAndStripZerosToMatchScale($this, intVal, scale, toLong(preferredScale));
    } else {
      return mq.hu(qsign, scale);
    }
  }
}
function needIncrement_1($this, mdivisor, roundingMode, qsign, mq, mr) {
  // Inline function 'kotlin.require' call
  // Inline function 'kotlin.require' call
  if (!!mr.lu()) {
    // Inline function 'kotlin.require.<anonymous>' call
    var message = 'Failed requirement.';
    throw IllegalArgumentException.h(toString_1(message));
  }
  var cmpFracHalf = mr.mu(mdivisor);
  return commonNeedIncrement($this, roundingMode, qsign, cmpFracHalf, mq.ju());
}
function createAndStripZerosToMatchScale($this, intVal, scale, preferredScale) {
  var intVal_0 = intVal;
  var scale_0 = scale;
  var qr;
  $l$loop_0: while (intVal_0.xt(Companion_getInstance_21().TEN) >= 0 && toLong(scale_0).m1(preferredScale) > 0 && !intVal_0.testBit(0)) {
    qr = intVal_0.divideAndRemainder(Companion_getInstance_21().TEN);
    if (!(qr[1].signum === 0)) {
      break $l$loop_0;
    }
    intVal_0 = qr[0];
    var tmp = intVal_0;
    // Inline function 'kotlin.Long.minus' call
    var tmp$ret$0 = toLong(scale_0).i3(toLong(1));
    scale_0 = checkScale_0($this, tmp, tmp$ret$0);
  }
  return $this.ofScaledBigIntegerWithPrecision(intVal_0, scale_0, 0);
}
function createAndStripZerosToMatchScale_0($this, compactVal, scale, preferredScale) {
  var compactVal_0 = compactVal;
  var scale_0 = scale;
  $l$loop_0: while (abs(compactVal_0).m1(new Long(10, 0)) >= 0 && toLong(scale_0).m1(preferredScale) > 0 && compactVal_0.t3(new Long(1, 0)).equals(new Long(0, 0))) {
    var r = compactVal_0.l3(new Long(10, 0));
    if (!r.equals(new Long(0, 0))) {
      break $l$loop_0;
    }
    // Inline function 'kotlin.Long.div' call
    compactVal_0 = compactVal_0.k3(toLong(10));
    var tmp = compactVal_0;
    // Inline function 'kotlin.Long.minus' call
    var tmp$ret$1 = toLong(scale_0).i3(toLong(1));
    scale_0 = checkScale($this, tmp, tmp$ret$1);
  }
  return $this.ofScaledLong(compactVal_0, scale_0);
}
function stripZerosToMatchScale($this, intVal, intCompact, scale, preferredScale) {
  var tmp;
  if (!intCompact.equals(new Long(0, -2147483648))) {
    tmp = createAndStripZerosToMatchScale_0($this, intCompact, scale, toLong(preferredScale));
  } else {
    tmp = createAndStripZerosToMatchScale($this, intVal == null ? $this.bt_1 : intVal, scale, toLong(preferredScale));
  }
  return tmp;
}
function sum($this, xs, ys) {
  var sum = xs.h3(ys);
  var tmp;
  if (sum.v3(xs).t3(sum.v3(ys)).m1(new Long(0, 0)) >= 0) {
    tmp = sum;
  } else {
    tmp = new Long(0, -2147483648);
  }
  return tmp;
}
function sum_0($this, xs, ys, scale) {
  var sum_0 = sum($this, xs, ys);
  var tmp;
  if (!sum_0.equals(new Long(0, -2147483648))) {
    tmp = Companion_getInstance_20().ofScaledLong(sum_0, scale);
  } else {
    tmp = CommonBigDecimal.ou(Companion_getInstance_21().ofLong(xs).nu(ys), scale);
  }
  return tmp;
}
function sum_1($this, xs, scale1, ys, scale2) {
  // Inline function 'kotlin.Long.minus' call
  var sdiff = toLong(scale1).i3(toLong(scale2));
  if (sdiff.equals(new Long(0, 0))) {
    return sum_0($this, xs, ys, scale1);
  } else if (sdiff.m1(new Long(0, 0)) < 0) {
    var raise = checkScale($this, xs, sdiff.o3());
    var scaledX = longMultiplyPowerTen($this, xs, raise);
    if (!scaledX.equals(new Long(0, -2147483648))) {
      return sum_0($this, scaledX, ys, scale2);
    } else {
      var bigsum = bigMultiplyPowerTen($this, xs, raise).nu(ys);
      var tmp;
      if (xs.v3(ys).m1(new Long(0, 0)) >= 0) {
        tmp = CommonBigDecimal.zt(bigsum, new Long(0, -2147483648), scale2, 0);
      } else {
        tmp = $this.ofScaledBigIntegerWithPrecision(bigsum, scale2, 0);
      }
      return tmp;
    }
  } else {
    var raise_0 = checkScale($this, ys, sdiff);
    var scaledY = longMultiplyPowerTen($this, ys, raise_0);
    if (!scaledY.equals(new Long(0, -2147483648))) {
      return sum_0($this, xs, scaledY, scale1);
    } else {
      var bigsum_0 = bigMultiplyPowerTen($this, ys, raise_0).nu(xs);
      var tmp_0;
      if (xs.v3(ys).m1(new Long(0, 0)) >= 0) {
        tmp_0 = CommonBigDecimal.zt(bigsum_0, new Long(0, -2147483648), scale1, 0);
      } else {
        tmp_0 = $this.ofScaledBigIntegerWithPrecision(bigsum_0, scale1, 0);
      }
      return tmp_0;
    }
  }
}
function sum_2($this, xs, scale1, snd, scale2) {
  var snd_0 = snd;
  var rscale = scale1;
  // Inline function 'kotlin.Long.minus' call
  var sdiff = toLong(rscale).i3(toLong(scale2));
  var sameSigns = get_sign(xs) === snd_0.pr_1;
  var sum;
  if (sdiff.m1(new Long(0, 0)) < 0) {
    var raise = checkScale($this, xs, sdiff.o3());
    rscale = scale2;
    var scaledX = longMultiplyPowerTen($this, xs, raise);
    if (scaledX.equals(new Long(0, -2147483648))) {
      sum = snd_0.plus(bigMultiplyPowerTen($this, xs, raise));
    } else {
      sum = snd_0.nu(scaledX);
    }
  } else {
    var raise_0 = checkScale_0($this, snd_0, sdiff);
    snd_0 = ensureNotNull(bigMultiplyPowerTen_0($this, snd_0, raise_0));
    sum = snd_0.nu(xs);
  }
  var tmp;
  if (sameSigns) {
    tmp = CommonBigDecimal.zt(sum, new Long(0, -2147483648), rscale, 0);
  } else {
    tmp = $this.ofScaledBigIntegerWithPrecision(sum, rscale, 0);
  }
  return tmp;
}
function sum_3($this, fst, scale1, snd, scale2) {
  var fst_0 = fst;
  var snd_0 = snd;
  var rscale = scale1;
  // Inline function 'kotlin.Long.minus' call
  var sdiff = toLong(rscale).i3(toLong(scale2));
  if (!sdiff.equals(new Long(0, 0))) {
    if (sdiff.m1(new Long(0, 0)) < 0) {
      var raise = checkScale_0($this, fst_0, sdiff.o3());
      rscale = scale2;
      fst_0 = bigMultiplyPowerTen_0($this, fst_0, raise);
    } else {
      var raise_0 = checkScale_0($this, snd_0, sdiff);
      snd_0 = bigMultiplyPowerTen_0($this, snd_0, raise_0);
    }
  }
  var sum = ensureNotNull(fst_0).plus(ensureNotNull(snd_0));
  var tmp;
  if (fst_0.pr_1 === snd_0.pr_1) {
    tmp = CommonBigDecimal.zt(sum, new Long(0, -2147483648), rscale, 0);
  } else {
    tmp = $this.ofScaledBigIntegerWithPrecision(sum, rscale, 0);
  }
  return tmp;
}
function bigMultiplyPowerTen($this, value, n) {
  return n <= 0 ? Companion_getInstance_21().ofLong(value) : bigTenToThe($this, n).pu(value);
}
function bigMultiplyPowerTen_0($this, value, n) {
  if (n <= 0) {
    return value;
  }
  var tmp;
  if (n < $this.jt_1.length) {
    tmp = ensureNotNull(value).pu($this.jt_1[n]);
  } else {
    tmp = ensureNotNull(value).times(bigTenToThe($this, n));
  }
  return tmp;
}
function divideSmallFastPath($this, xs, xscale, ys, yscale, preferredScale, mc) {
  var yscale_0 = yscale;
  var mcp = mc.precision;
  var roundingMode = mc.roundingMode.value;
  // Inline function 'kotlin.require' call
  // Inline function 'kotlin.require' call
  if (!(xscale <= yscale_0 && yscale_0 < 18 && mcp < 18)) {
    // Inline function 'kotlin.require.<anonymous>' call
    var message = 'Failed requirement.';
    throw IllegalArgumentException.h(toString_1(message));
  }
  var xraise = yscale_0 - xscale | 0;
  var tmp;
  if (xraise === 0) {
    tmp = xs;
  } else {
    tmp = longMultiplyPowerTen($this, xs, xraise);
  }
  var scaledX = tmp;
  var quotient;
  var cmp = longCompareMagnitude($this, scaledX, ys);
  if (cmp > 0) {
    yscale_0 = yscale_0 - 1 | 0;
    // Inline function 'kotlin.Long.plus' call
    var other = yscale_0;
    // Inline function 'kotlin.Long.minus' call
    // Inline function 'kotlin.Long.plus' call
    var tmp$ret$3 = preferredScale.h3(toLong(other)).i3(toLong(xscale)).h3(toLong(mcp));
    var scl = checkScaleNonZero($this, tmp$ret$3);
    var tmp7 = toLong(mcp);
    // Inline function 'kotlin.Long.plus' call
    var other_0 = yscale_0;
    // Inline function 'kotlin.Long.minus' call
    var tmp$ret$5 = tmp7.h3(toLong(other_0)).i3(toLong(xscale));
    if (checkScaleNonZero($this, tmp$ret$5) > 0) {
      var tmp11 = toLong(mcp);
      // Inline function 'kotlin.Long.plus' call
      var other_1 = yscale_0;
      // Inline function 'kotlin.Long.minus' call
      var tmp$ret$7 = tmp11.h3(toLong(other_1)).i3(toLong(xscale));
      var raise = checkScaleNonZero($this, tmp$ret$7);
      var scaledXs;
      scaledXs = longMultiplyPowerTen($this, xs, raise);
      if (scaledXs.equals(new Long(0, -2147483648))) {
        quotient = null;
        if ((mcp - 1 | 0) >= 0 && (mcp - 1 | 0) < $this.jt_1.length) {
          quotient = multiplyDivideAndRound($this, $this.jt_1[mcp - 1 | 0], scaledX, ys, scl, roundingMode, checkScaleNonZero($this, preferredScale));
        }
        if (quotient == null) {
          var rb = bigMultiplyPowerTen($this, scaledX, mcp - 1 | 0);
          quotient = divideAndRound_2($this, rb, ys, scl, roundingMode, checkScaleNonZero($this, preferredScale));
        }
      } else {
        quotient = divideAndRound($this, scaledXs, ys, scl, roundingMode, checkScaleNonZero($this, preferredScale));
      }
    } else {
      // Inline function 'kotlin.Long.minus' call
      var tmp$ret$8 = toLong(xscale).i3(toLong(mcp));
      var newScale = checkScaleNonZero($this, tmp$ret$8);
      if (newScale === yscale_0) {
        quotient = divideAndRound($this, xs, ys, scl, roundingMode, checkScaleNonZero($this, preferredScale));
      } else {
        var tmp17 = toLong(newScale);
        // Inline function 'kotlin.Long.minus' call
        var other_2 = yscale_0;
        var tmp$ret$9 = tmp17.i3(toLong(other_2));
        var raise_0 = checkScaleNonZero($this, tmp$ret$9);
        var scaledYs = longMultiplyPowerTen($this, ys, raise_0);
        if (scaledYs.equals(new Long(0, -2147483648))) {
          var rb_0 = bigMultiplyPowerTen($this, ys, raise_0);
          quotient = divideAndRound_4($this, Companion_getInstance_21().ofLong(xs), rb_0, scl, roundingMode, checkScaleNonZero($this, preferredScale));
        } else {
          quotient = divideAndRound($this, xs, scaledYs, scl, roundingMode, checkScaleNonZero($this, preferredScale));
        }
      }
    }
  } else {
    // Inline function 'kotlin.Long.plus' call
    var other_3 = yscale_0;
    // Inline function 'kotlin.Long.minus' call
    // Inline function 'kotlin.Long.plus' call
    var tmp$ret$12 = preferredScale.h3(toLong(other_3)).i3(toLong(xscale)).h3(toLong(mcp));
    var scl_0 = checkScaleNonZero($this, tmp$ret$12);
    if (cmp === 0) {
      quotient = roundedTenPower($this, scaledX.m1(new Long(0, 0)) < 0 === ys.m1(new Long(0, 0)) < 0 ? 1 : -1, mcp, scl_0, checkScaleNonZero($this, preferredScale));
    } else {
      var scaledXs_0 = longMultiplyPowerTen($this, scaledX, mcp);
      if (scaledXs_0.equals(new Long(0, -2147483648))) {
        quotient = null;
        if (mcp < $this.jt_1.length) {
          quotient = multiplyDivideAndRound($this, $this.jt_1[mcp], scaledX, ys, scl_0, roundingMode, checkScaleNonZero($this, preferredScale));
        }
        if (quotient == null) {
          var rb_1 = bigMultiplyPowerTen($this, scaledX, mcp);
          quotient = divideAndRound_2($this, rb_1, ys, scl_0, roundingMode, checkScaleNonZero($this, preferredScale));
        }
      } else {
        quotient = divideAndRound($this, scaledXs_0, ys, scl_0, roundingMode, checkScaleNonZero($this, preferredScale));
      }
    }
  }
  return doRound($this, quotient, mc);
}
function divide_0($this, xs, xscale, ys, yscale, preferredScale, mc) {
  var yscale_0 = yscale;
  var mcp = mc.precision;
  if (xscale <= yscale_0 && yscale_0 < 18 && mcp < 18) {
    return divideSmallFastPath($this, xs, xscale, ys, yscale_0, preferredScale, mc);
  }
  if (compareMagnitudeNormalized($this, xs, xscale, ys, yscale_0) > 0) {
    yscale_0 = yscale_0 - 1 | 0;
  }
  var roundingMode = mc.roundingMode.value;
  // Inline function 'kotlin.Long.plus' call
  var other = yscale_0;
  // Inline function 'kotlin.Long.minus' call
  // Inline function 'kotlin.Long.plus' call
  var tmp$ret$2 = preferredScale.h3(toLong(other)).i3(toLong(xscale)).h3(toLong(mcp));
  var scl = checkScaleNonZero($this, tmp$ret$2);
  var quotient;
  var tmp6 = toLong(mcp);
  // Inline function 'kotlin.Long.plus' call
  var other_0 = yscale_0;
  // Inline function 'kotlin.Long.minus' call
  var tmp$ret$4 = tmp6.h3(toLong(other_0)).i3(toLong(xscale));
  if (checkScaleNonZero($this, tmp$ret$4) > 0) {
    var tmp10 = toLong(mcp);
    // Inline function 'kotlin.Long.plus' call
    var other_1 = yscale_0;
    // Inline function 'kotlin.Long.minus' call
    var tmp$ret$6 = tmp10.h3(toLong(other_1)).i3(toLong(xscale));
    var raise = checkScaleNonZero($this, tmp$ret$6);
    var scaledXs = longMultiplyPowerTen($this, xs, raise);
    if (scaledXs.equals(new Long(0, -2147483648))) {
      var rb = bigMultiplyPowerTen($this, xs, raise);
      quotient = divideAndRound_2($this, rb, ys, scl, roundingMode, checkScaleNonZero($this, preferredScale));
    } else {
      quotient = divideAndRound($this, scaledXs, ys, scl, roundingMode, checkScaleNonZero($this, preferredScale));
    }
  } else {
    // Inline function 'kotlin.Long.minus' call
    var tmp$ret$7 = toLong(xscale).i3(toLong(mcp));
    var newScale = checkScaleNonZero($this, tmp$ret$7);
    if (newScale === yscale_0) {
      quotient = divideAndRound($this, xs, ys, scl, roundingMode, checkScaleNonZero($this, preferredScale));
    } else {
      var tmp16 = toLong(newScale);
      // Inline function 'kotlin.Long.minus' call
      var other_2 = yscale_0;
      var tmp$ret$8 = tmp16.i3(toLong(other_2));
      var raise_0 = checkScaleNonZero($this, tmp$ret$8);
      var scaledYs = longMultiplyPowerTen($this, ys, raise_0);
      if (scaledYs.equals(new Long(0, -2147483648))) {
        var rb_0 = bigMultiplyPowerTen($this, ys, raise_0);
        quotient = divideAndRound_4($this, Companion_getInstance_21().ofLong(xs), rb_0, scl, roundingMode, checkScaleNonZero($this, preferredScale));
      } else {
        quotient = divideAndRound($this, xs, scaledYs, scl, roundingMode, checkScaleNonZero($this, preferredScale));
      }
    }
  }
  return doRound($this, quotient, mc);
}
function divide_1($this, xs, xscale, ys, yscale, preferredScale, mc) {
  var yscale_0 = yscale;
  if ((-compareMagnitudeNormalized_0($this, ys, yscale_0, xs, xscale) | 0) > 0) {
    yscale_0 = yscale_0 - 1 | 0;
  }
  var mcp = mc.precision;
  var roundingMode = mc.roundingMode.value;
  var quotient;
  // Inline function 'kotlin.Long.plus' call
  var other = yscale_0;
  // Inline function 'kotlin.Long.minus' call
  // Inline function 'kotlin.Long.plus' call
  var tmp$ret$2 = preferredScale.h3(toLong(other)).i3(toLong(xscale)).h3(toLong(mcp));
  var scl = checkScaleNonZero($this, tmp$ret$2);
  var tmp6 = toLong(mcp);
  // Inline function 'kotlin.Long.plus' call
  var other_0 = yscale_0;
  // Inline function 'kotlin.Long.minus' call
  var tmp$ret$4 = tmp6.h3(toLong(other_0)).i3(toLong(xscale));
  if (checkScaleNonZero($this, tmp$ret$4) > 0) {
    var tmp10 = toLong(mcp);
    // Inline function 'kotlin.Long.plus' call
    var other_1 = yscale_0;
    // Inline function 'kotlin.Long.minus' call
    var tmp$ret$6 = tmp10.h3(toLong(other_1)).i3(toLong(xscale));
    var raise = checkScaleNonZero($this, tmp$ret$6);
    var rb = bigMultiplyPowerTen_0($this, xs, raise);
    quotient = divideAndRound_2($this, ensureNotNull(rb), ys, scl, roundingMode, checkScaleNonZero($this, preferredScale));
  } else {
    // Inline function 'kotlin.Long.minus' call
    var tmp$ret$7 = toLong(xscale).i3(toLong(mcp));
    var newScale = checkScaleNonZero($this, tmp$ret$7);
    if (newScale === yscale_0) {
      quotient = divideAndRound_2($this, ensureNotNull(xs), ys, scl, roundingMode, checkScaleNonZero($this, preferredScale));
    } else {
      var tmp16 = toLong(newScale);
      // Inline function 'kotlin.Long.minus' call
      var other_2 = yscale_0;
      var tmp$ret$8 = tmp16.i3(toLong(other_2));
      var raise_0 = checkScaleNonZero($this, tmp$ret$8);
      var scaledYs = longMultiplyPowerTen($this, ys, raise_0);
      if (scaledYs.equals(new Long(0, -2147483648))) {
        var rb_0 = bigMultiplyPowerTen($this, ys, raise_0);
        quotient = divideAndRound_4($this, ensureNotNull(xs), rb_0, scl, roundingMode, checkScaleNonZero($this, preferredScale));
      } else {
        quotient = divideAndRound_2($this, ensureNotNull(xs), scaledYs, scl, roundingMode, checkScaleNonZero($this, preferredScale));
      }
    }
  }
  return doRound($this, quotient, mc);
}
function divide_2($this, xs, xscale, ys, yscale, preferredScale, mc) {
  var yscale_0 = yscale;
  if (compareMagnitudeNormalized_0($this, xs, xscale, ys, yscale_0) > 0) {
    yscale_0 = yscale_0 - 1 | 0;
  }
  var mcp = mc.precision;
  // Inline function 'kotlin.also' call
  var this_0 = mc.roundingMode;
  // Inline function 'com.macrofocus.common.math.big.Companion.divide.<anonymous>' call
  log_0(CommonBigDecimal$Companion$divide$lambda(this_0));
  var roundingMode = this_0.value;
  var quotient;
  // Inline function 'kotlin.Long.plus' call
  var other = yscale_0;
  // Inline function 'kotlin.Long.minus' call
  // Inline function 'kotlin.Long.plus' call
  var tmp$ret$3 = preferredScale.h3(toLong(other)).i3(toLong(xscale)).h3(toLong(mcp));
  var scl = checkScaleNonZero($this, tmp$ret$3);
  var tmp8 = toLong(mcp);
  // Inline function 'kotlin.Long.plus' call
  var other_0 = yscale_0;
  // Inline function 'kotlin.Long.minus' call
  var tmp$ret$5 = tmp8.h3(toLong(other_0)).i3(toLong(xscale));
  if (checkScaleNonZero($this, tmp$ret$5) > 0) {
    var tmp12 = toLong(mcp);
    // Inline function 'kotlin.Long.plus' call
    var other_1 = yscale_0;
    // Inline function 'kotlin.Long.minus' call
    var tmp$ret$7 = tmp12.h3(toLong(other_1)).i3(toLong(xscale));
    var raise = checkScaleNonZero($this, tmp$ret$7);
    var rb = bigMultiplyPowerTen($this, xs, raise);
    quotient = divideAndRound_4($this, rb, ensureNotNull(ys), scl, roundingMode, checkScaleNonZero($this, preferredScale));
  } else {
    // Inline function 'kotlin.Long.minus' call
    var tmp$ret$8 = toLong(xscale).i3(toLong(mcp));
    var newScale = checkScaleNonZero($this, tmp$ret$8);
    var tmp18 = toLong(newScale);
    // Inline function 'kotlin.Long.minus' call
    var other_2 = yscale_0;
    var tmp$ret$9 = tmp18.i3(toLong(other_2));
    var raise_0 = checkScaleNonZero($this, tmp$ret$9);
    var rb_0 = bigMultiplyPowerTen_0($this, ys, raise_0);
    quotient = divideAndRound_4($this, Companion_getInstance_21().ofLong(xs), ensureNotNull(rb_0), scl, roundingMode, checkScaleNonZero($this, preferredScale));
  }
  return doRound($this, quotient, mc);
}
function divide_3($this, xs, xscale, ys, yscale, preferredScale, mc) {
  var yscale_0 = yscale;
  if (compareMagnitudeNormalized_1($this, xs, xscale, ys, yscale_0) > 0) {
    yscale_0 = yscale_0 - 1 | 0;
  }
  var mcp = mc.precision;
  var roundingMode = mc.roundingMode.value;
  var quotient;
  // Inline function 'kotlin.Long.plus' call
  var other = yscale_0;
  // Inline function 'kotlin.Long.minus' call
  // Inline function 'kotlin.Long.plus' call
  var tmp$ret$2 = preferredScale.h3(toLong(other)).i3(toLong(xscale)).h3(toLong(mcp));
  var scl = checkScaleNonZero($this, tmp$ret$2);
  var tmp6 = toLong(mcp);
  // Inline function 'kotlin.Long.plus' call
  var other_0 = yscale_0;
  // Inline function 'kotlin.Long.minus' call
  var tmp$ret$4 = tmp6.h3(toLong(other_0)).i3(toLong(xscale));
  if (checkScaleNonZero($this, tmp$ret$4) > 0) {
    var tmp10 = toLong(mcp);
    // Inline function 'kotlin.Long.plus' call
    var other_1 = yscale_0;
    // Inline function 'kotlin.Long.minus' call
    var tmp$ret$6 = tmp10.h3(toLong(other_1)).i3(toLong(xscale));
    var raise = checkScaleNonZero($this, tmp$ret$6);
    var rb = bigMultiplyPowerTen_0($this, xs, raise);
    quotient = divideAndRound_4($this, ensureNotNull(rb), ensureNotNull(ys), scl, roundingMode, checkScaleNonZero($this, preferredScale));
  } else {
    // Inline function 'kotlin.Long.minus' call
    var tmp$ret$7 = toLong(xscale).i3(toLong(mcp));
    var newScale = checkScaleNonZero($this, tmp$ret$7);
    var tmp16 = toLong(newScale);
    // Inline function 'kotlin.Long.minus' call
    var other_2 = yscale_0;
    var tmp$ret$8 = tmp16.i3(toLong(other_2));
    var raise_0 = checkScaleNonZero($this, tmp$ret$8);
    var rb_0 = bigMultiplyPowerTen_0($this, ys, raise_0);
    quotient = divideAndRound_4($this, ensureNotNull(xs), ensureNotNull(rb_0), scl, roundingMode, checkScaleNonZero($this, preferredScale));
  }
  return doRound($this, quotient, mc);
}
function multiplyDivideAndRound($this, dividend0, dividend1, divisor, scale, roundingMode, preferredScale) {
  var dividend0_0 = dividend0;
  var dividend1_0 = dividend1;
  var divisor_0 = divisor;
  var qsign = imul_0(imul_0(get_sign(dividend0_0), get_sign(dividend1_0)), get_sign(divisor_0));
  dividend0_0 = abs(dividend0_0);
  dividend1_0 = abs(dividend1_0);
  divisor_0 = abs(divisor_0);
  var d0_hi = dividend0_0.s3(32);
  var d0_lo = dividend0_0.t3(new Long(-1, 0));
  var d1_hi = dividend1_0.s3(32);
  var d1_lo = dividend1_0.t3(new Long(-1, 0));
  var product = d0_lo.j3(d1_lo);
  var d0 = product.t3(new Long(-1, 0));
  var d1 = product.s3(32);
  product = d0_hi.j3(d1_lo).h3(d1);
  d1 = product.t3(new Long(-1, 0));
  var d2 = product.s3(32);
  product = d0_lo.j3(d1_hi).h3(d1);
  d1 = product.t3(new Long(-1, 0));
  d2 = d2.h3(product.s3(32));
  var d3 = d2.s3(32);
  d2 = d2.t3(new Long(-1, 0));
  product = d0_hi.j3(d1_hi).h3(d2);
  d2 = product.t3(new Long(-1, 0));
  d3 = product.s3(32).h3(d3).t3(new Long(-1, 0));
  var dividendHi = make64($this, d3, d2);
  var dividendLo = make64($this, d1, d0);
  return divideAndRound128($this, dividendHi, dividendLo, divisor_0, qsign, scale, roundingMode, preferredScale);
}
function divideAndRound128($this, dividendHi, dividendLo, divisor, sign, scale, roundingMode, preferredScale) {
  var divisor_0 = divisor;
  if (dividendHi.m1(divisor_0) >= 0) {
    return null;
  }
  var shift = numberOfLeadingZeros_0(divisor_0);
  divisor_0 = divisor_0.q3(shift);
  var v1 = divisor_0.s3(32);
  var v0 = divisor_0.t3(new Long(-1, 0));
  var tmp = dividendLo.q3(shift);
  var u1 = tmp.s3(32);
  var u0 = tmp.t3(new Long(-1, 0));
  tmp = dividendHi.q3(shift).u3(dividendLo.s3(64 - shift | 0));
  var u2 = tmp.t3(new Long(-1, 0));
  var q1;
  var r_tmp;
  if (v1.equals(new Long(1, 0))) {
    q1 = tmp;
    r_tmp = new Long(0, 0);
  } else if (tmp.m1(new Long(0, 0)) >= 0) {
    q1 = tmp.k3(v1);
    r_tmp = tmp.i3(q1.j3(v1));
  } else {
    var rq = divRemNegativeLong($this, tmp, v1);
    q1 = rq[1];
    r_tmp = rq[0];
  }
  $l$loop: while (q1.m1(new Long(0, 1)) >= 0 || unsignedLongCompare($this, q1.j3(v0), make64($this, r_tmp, u1))) {
    q1 = q1.n3();
    r_tmp = r_tmp.h3(v1);
    if (r_tmp.m1(new Long(0, 1)) >= 0) {
      break $l$loop;
    }
  }
  tmp = mulsub($this, u2, u1, v1, v0, q1);
  u1 = tmp.t3(new Long(-1, 0));
  var q0;
  if (v1.equals(new Long(1, 0))) {
    q0 = tmp;
    r_tmp = new Long(0, 0);
  } else if (tmp.m1(new Long(0, 0)) >= 0) {
    q0 = tmp.k3(v1);
    r_tmp = tmp.i3(q0.j3(v1));
  } else {
    var rq_0 = divRemNegativeLong($this, tmp, v1);
    q0 = rq_0[1];
    r_tmp = rq_0[0];
  }
  $l$loop_0: while (q0.m1(new Long(0, 1)) >= 0 || unsignedLongCompare($this, q0.j3(v0), make64($this, r_tmp, u0))) {
    q0 = q0.n3();
    r_tmp = r_tmp.h3(v1);
    if (r_tmp.m1(new Long(0, 1)) >= 0) {
      break $l$loop_0;
    }
  }
  if (q1.l1() < 0) {
    // Inline function 'kotlin.intArrayOf' call
    var tmp$ret$0 = new Int32Array([q1.l1(), q0.l1()]);
    var mq = MutableBigInteger.au(tmp$ret$0);
    if (roundingMode === RoundingMode_DOWN_getInstance().value && scale === preferredScale) {
      return mq.hu(sign, scale);
    }
    var r = mulsub($this, u1, u0, v1, v0, q0).s3(shift);
    if (!r.equals(new Long(0, 0))) {
      if (needIncrement_0($this, divisor_0.s3(shift), roundingMode, sign, mq, r)) {
        mq.fu(Companion_getInstance_23().cu_1);
      }
      return mq.hu(sign, scale);
    } else {
      if (!(preferredScale === scale)) {
        var intVal = mq.gu(sign);
        return createAndStripZerosToMatchScale($this, intVal, scale, toLong(preferredScale));
      } else {
        return mq.hu(sign, scale);
      }
    }
  }
  var q = make64($this, q1, q0);
  q = q.j3(toLong(sign));
  if (roundingMode === RoundingMode_DOWN_getInstance().value && scale === preferredScale) {
    return $this.ofScaledLong(q, scale);
  }
  var r_0 = mulsub($this, u1, u0, v1, v0, q0).s3(shift);
  if (!r_0.equals(new Long(0, 0))) {
    var increment = needIncrement($this, divisor_0.s3(shift), roundingMode, sign, q, r_0);
    var tmp_0;
    if (increment) {
      // Inline function 'kotlin.Long.plus' call
      tmp_0 = q.h3(toLong(sign));
    } else {
      tmp_0 = q;
    }
    return $this.ofScaledLong(tmp_0, scale);
  } else {
    var tmp_1;
    if (!(preferredScale === scale)) {
      tmp_1 = createAndStripZerosToMatchScale_0($this, q, scale, toLong(preferredScale));
    } else {
      tmp_1 = $this.ofScaledLong(q, scale);
    }
    return tmp_1;
  }
}
function roundedTenPower($this, qsign, raise, scale, preferredScale) {
  if (scale > preferredScale) {
    var diff = scale - preferredScale | 0;
    var tmp;
    if (diff < raise) {
      tmp = $this.qu(raise - diff | 0, qsign, preferredScale);
    } else {
      tmp = $this.ofScaledLong(toLong(qsign), scale - raise | 0);
    }
    return tmp;
  } else {
    return $this.qu(raise, qsign, scale);
  }
}
function divRemNegativeLong($this, n, d) {
  // Inline function 'kotlin.require' call
  if (!(n.m1(new Long(0, 0)) < 0)) {
    // Inline function 'com.macrofocus.common.math.big.Companion.divRemNegativeLong.<anonymous>' call
    var message = 'Non-negative numerator ' + n.toString();
    throw IllegalArgumentException.h(toString_1(message));
  }
  // Inline function 'kotlin.require' call
  if (!!d.equals(new Long(1, 0))) {
    // Inline function 'com.macrofocus.common.math.big.Companion.divRemNegativeLong.<anonymous>' call
    var message_0 = 'Unity denominator';
    throw IllegalArgumentException.h(toString_1(message_0));
  }
  var q = n.s3(1).k3(d.s3(1));
  var r = n.i3(q.j3(d));
  while (r.m1(new Long(0, 0)) < 0) {
    r = r.h3(d);
    q = q.n3();
  }
  while (r.m1(d) >= 0) {
    r = r.i3(d);
    q = q.m3();
  }
  // Inline function 'kotlin.longArrayOf' call
  return longArrayOf([r, q]);
}
function make64($this, hi, lo) {
  return hi.q3(32).u3(lo);
}
function mulsub($this, u1, u0, v1, v0, q0) {
  var tmp = u0.i3(q0.j3(v0));
  return make64($this, u1.h3(tmp.s3(32)).i3(q0.j3(v1)), tmp.t3(new Long(-1, 0)));
}
function unsignedLongCompare($this, one, two) {
  return one.h3(new Long(0, -2147483648)).m1(two.h3(new Long(0, -2147483648))) > 0;
}
function unsignedLongCompareEq($this, one, two) {
  return one.h3(new Long(0, -2147483648)).m1(two.h3(new Long(0, -2147483648))) >= 0;
}
function compareMagnitudeNormalized($this, xs, xscale, ys, yscale) {
  var xs_0 = xs;
  var ys_0 = ys;
  var sdiff = xscale - yscale | 0;
  if (!(sdiff === 0)) {
    if (sdiff < 0) {
      xs_0 = longMultiplyPowerTen($this, xs_0, -sdiff | 0);
    } else {
      ys_0 = longMultiplyPowerTen($this, ys_0, sdiff);
    }
  }
  var tmp;
  if (!xs_0.equals(new Long(0, -2147483648))) {
    tmp = !ys_0.equals(new Long(0, -2147483648)) ? longCompareMagnitude($this, xs_0, ys_0) : -1;
  } else {
    tmp = 1;
  }
  return tmp;
}
function compareMagnitudeNormalized_0($this, xs, xscale, ys, yscale) {
  if (xs.equals(new Long(0, 0))) {
    return -1;
  }
  var sdiff = xscale - yscale | 0;
  if (sdiff < 0) {
    if (longMultiplyPowerTen($this, xs, -sdiff | 0).equals(new Long(0, -2147483648))) {
      return bigMultiplyPowerTen($this, xs, -sdiff | 0).xt(ensureNotNull(ys));
    }
  }
  return -1;
}
function compareMagnitudeNormalized_1($this, xs, xscale, ys, yscale) {
  var sdiff = xscale - yscale | 0;
  var tmp;
  if (sdiff < 0) {
    tmp = ensureNotNull(bigMultiplyPowerTen_0($this, xs, -sdiff | 0)).xt(ensureNotNull(ys));
  } else {
    tmp = ensureNotNull(xs).xt(ensureNotNull(bigMultiplyPowerTen_0($this, ys, sdiff)));
  }
  return tmp;
}
function multiply_0($this, x, y) {
  var product = x.j3(y);
  var ax = abs(x);
  var ay = abs(y);
  var tmp;
  if (ax.u3(ay).s3(31).equals(new Long(0, 0)) || y.equals(new Long(0, 0)) || product.k3(y).equals(x)) {
    tmp = product;
  } else {
    tmp = new Long(0, -2147483648);
  }
  return tmp;
}
function multiply_1($this, x, y, scale) {
  var product = multiply_0($this, x, y);
  var tmp;
  if (!product.equals(new Long(0, -2147483648))) {
    tmp = $this.ofScaledLong(product, scale);
  } else {
    tmp = CommonBigDecimal.zt(Companion_getInstance_21().ofLong(x).pu(y), new Long(0, -2147483648), scale, 0);
  }
  return tmp;
}
function multiply_2($this, x, y, scale) {
  var tmp;
  if (x.equals(new Long(0, 0))) {
    tmp = $this.ru(scale);
  } else {
    tmp = CommonBigDecimal.zt(ensureNotNull(y).pu(x), new Long(0, -2147483648), scale, 0);
  }
  return tmp;
}
function multiply_3($this, x, y, scale) {
  return CommonBigDecimal.zt(x.times(ensureNotNull(y)), new Long(0, -2147483648), scale, 0);
}
function multiplyAndRound($this, x, y, scale, mc) {
  var x_0 = x;
  var y_0 = y;
  var product = multiply_0($this, x_0, y_0);
  if (!product.equals(new Long(0, -2147483648))) {
    return doRound_0($this, product, scale, mc);
  }
  var rsign = 1;
  if (x_0.m1(new Long(0, 0)) < 0) {
    x_0 = x_0.o3();
    rsign = -1;
  }
  if (y_0.m1(new Long(0, 0)) < 0) {
    y_0 = y_0.o3();
    rsign = imul_0(rsign, -1);
  }
  var m0_hi = x_0.s3(32);
  var m0_lo = x_0.t3(new Long(-1, 0));
  var m1_hi = y_0.s3(32);
  var m1_lo = y_0.t3(new Long(-1, 0));
  product = m0_lo.j3(m1_lo);
  var m0 = product.t3(new Long(-1, 0));
  var m1 = product.s3(32);
  product = m0_hi.j3(m1_lo).h3(m1);
  m1 = product.t3(new Long(-1, 0));
  var m2 = product.s3(32);
  product = m0_lo.j3(m1_hi).h3(m1);
  m1 = product.t3(new Long(-1, 0));
  m2 = m2.h3(product.s3(32));
  var m3 = m2.s3(32);
  m2 = m2.t3(new Long(-1, 0));
  product = m0_hi.j3(m1_hi).h3(m2);
  m2 = product.t3(new Long(-1, 0));
  m3 = product.s3(32).h3(m3).t3(new Long(-1, 0));
  var mHi = make64($this, m3, m2);
  var mLo = make64($this, m1, m0);
  var res = doRound128($this, mHi, mLo, rsign, scale, mc);
  if (!(res == null)) {
    return res;
  }
  var tmp = Companion_getInstance_21().ofLong(x_0);
  var tmp0 = y_0;
  // Inline function 'kotlin.Long.times' call
  var other = rsign;
  var tmp$ret$0 = tmp0.j3(toLong(other));
  res = CommonBigDecimal.zt(tmp.pu(tmp$ret$0), new Long(0, -2147483648), scale, 0);
  return ensureNotNull(doRound($this, res, mc));
}
function multiplyAndRound_0($this, x, y, scale, mc) {
  var tmp;
  if (x.equals(new Long(0, 0))) {
    tmp = $this.ru(scale);
  } else {
    tmp = doRound_1($this, ensureNotNull(y).pu(x), scale, mc);
  }
  return tmp;
}
function multiplyAndRound_1($this, x, y, scale, mc) {
  return doRound_1($this, x.times(ensureNotNull(y)), scale, mc);
}
function doRound128($this, hi, lo, sign, scale, mc) {
  var scale_0 = scale;
  var mcp = mc.precision;
  var drop = precision($this, hi, lo) - mcp | 0;
  var res = null;
  if (drop > 0 && drop < $this.jt_1.length) {
    // Inline function 'kotlin.Long.minus' call
    var tmp$ret$0 = toLong(scale_0).i3(toLong(drop));
    scale_0 = checkScaleNonZero($this, tmp$ret$0);
    res = divideAndRound128($this, hi, lo, $this.jt_1[drop], sign, scale_0, mc.roundingMode.value, scale_0);
  }
  var tmp;
  if (!(res == null)) {
    tmp = doRound($this, res, mc);
  } else {
    tmp = null;
  }
  return tmp;
}
function precision($this, hi, lo) {
  if (hi.equals(new Long(0, 0))) {
    if (lo.m1(new Long(0, 0)) >= 0) {
      return $this.yt(lo);
    }
    return unsignedLongCompareEq($this, lo, $this.pt_1[0][1]) ? 20 : 19;
  }
  var r = imul_0((128 - numberOfLeadingZeros_0(hi) | 0) + 1 | 0, 1233) >>> 12 | 0;
  var idx = r - 19 | 0;
  var tmp;
  if (idx >= $this.pt_1.length || longLongCompareMagnitude($this, hi, lo, $this.pt_1[idx][0], $this.pt_1[idx][1])) {
    tmp = r;
  } else {
    tmp = r + 1 | 0;
  }
  return tmp;
}
function longLongCompareMagnitude($this, hi0, lo0, hi1, lo1) {
  var tmp;
  if (!hi0.equals(hi1)) {
    tmp = hi0.m1(hi1) < 0;
  } else {
    tmp = lo0.h3(new Long(0, -2147483648)).m1(lo1.h3(new Long(0, -2147483648))) < 0;
  }
  return tmp;
}
function CommonBigDecimal$Companion$divide$lambda($it) {
  return () => $it;
}
function _get_isPowerOfTen__mg2oyo($this) {
  return Companion_getInstance_21().ONE.equals($this.unscaledValue);
}
function adjustScale($this, scl, exp) {
  var scl_0 = scl;
  var adjustedScale = numberToLong(scl_0).i3(exp);
  if (adjustedScale.m1(new Long(2147483647, 0)) > 0 || adjustedScale.m1(new Long(-2147483648, -1)) < 0) {
    throw NumberFormatException.hd('Scale out of range.');
  }
  scl_0 = adjustedScale.l1();
  return scl_0;
}
function preAlign($this, lhs, augend, padding, mc) {
  // Inline function 'kotlin.require' call
  // Inline function 'kotlin.require' call
  if (!!padding.equals(new Long(0, 0))) {
    // Inline function 'kotlin.require.<anonymous>' call
    var message = 'Failed requirement.';
    throw IllegalArgumentException.h(toString_1(message));
  }
  var big;
  var small;
  if (padding.m1(new Long(0, 0)) < 0) {
    big = lhs;
    small = augend;
  } else {
    big = augend;
    small = lhs;
  }
  var tmp1 = toLong(big.rt_1);
  // Inline function 'kotlin.Long.minus' call
  var other = big.precision;
  var tmp3 = tmp1.i3(toLong(other));
  // Inline function 'kotlin.Long.plus' call
  var other_0 = mc.precision;
  var estResultUlpScale = tmp3.h3(toLong(other_0));
  var tmp5 = toLong(small.rt_1);
  // Inline function 'kotlin.Long.minus' call
  var other_1 = small.precision;
  // Inline function 'kotlin.Long.plus' call
  var smallHighDigitPos = tmp5.i3(toLong(other_1)).h3(toLong(1));
  var tmp;
  if (smallHighDigitPos.m1(toLong(big.rt_1 + 2 | 0)) > 0) {
    // Inline function 'kotlin.Long.plus' call
    var tmp$ret$5 = estResultUlpScale.h3(toLong(2));
    tmp = smallHighDigitPos.m1(tmp$ret$5) > 0;
  } else {
    tmp = false;
  }
  if (tmp) {
    var tmp_0 = Companion_getInstance_20();
    var tmp_1 = toLong(small.signum);
    // Inline function 'kotlin.math.max' call
    var a = toLong(big.rt_1);
    // Inline function 'kotlin.Long.plus' call
    var tmp$ret$7 = (a.m1(estResultUlpScale) >= 0 ? a : estResultUlpScale).h3(toLong(3));
    small = tmp_0.ofScaledLong(tmp_1, checkScale_1($this, tmp$ret$7));
  }
  // Inline function 'kotlin.arrayOf' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return [big, small];
}
function squareRootResultAssertions($this, result, mc) {
  if (result.signum === 0) {
    return squareRootZeroResultAssertions($this, result, mc);
  } else {
    var rm = mc.roundingMode;
    var ulp = result.ulp();
    var neighborUp = result.plus(ulp);
    if (_get_isPowerOfTen__mg2oyo($this)) {
      ulp = ulp.div(Companion_getInstance_20().TEN);
    }
    var neighborDown = result.minus(ulp);
    if (!(result.signum === 1) || !($this.signum === 1)) {
      return false;
    }
    switch (rm.z2_1) {
      case 1:
      case 3:
        return result.times(result).nq($this) <= 0 && neighborUp.times(neighborUp).nq($this) > 0;
      case 0:
      case 2:
        return result.times(result).nq($this) >= 0 && neighborDown.times(neighborDown).nq($this) < 0;
      case 5:
      case 6:
      case 4:
        var err = result.times(result).minus($this).absoluteValue;
        var errUp = neighborUp.times(neighborUp).minus($this);
        var errDown = $this.minus(neighborDown.times(neighborDown));
        var errCompErrup = err.nq(errUp);
        var errCompErrdown = err.nq(errDown);
        return errUp.signum === 1 && errDown.signum === 1 && errCompErrup <= 0 && errCompErrdown <= 0 && (errCompErrup === 0 ? errCompErrdown < 0 : true) && (errCompErrdown === 0 ? errCompErrup < 0 : true);
      default:
        return true;
    }
  }
}
function squareRootZeroResultAssertions($this, result, mc) {
  return $this.nq(Companion_getInstance_20().ZERO) === 0;
}
function compareMagnitude($this, val) {
  var ys = val.ut_1;
  var xs = $this.ut_1;
  if (xs.equals(new Long(0, 0))) {
    return ys.equals(new Long(0, 0)) ? 0 : -1;
  }
  if (ys.equals(new Long(0, 0))) {
    return 1;
  }
  var tmp0 = toLong($this.rt_1);
  // Inline function 'kotlin.Long.minus' call
  var other = val.rt_1;
  var sdiff = tmp0.i3(toLong(other));
  if (!sdiff.equals(new Long(0, 0))) {
    var tmp2 = toLong($this.precision);
    // Inline function 'kotlin.Long.minus' call
    var other_0 = $this.rt_1;
    var xae = tmp2.i3(toLong(other_0));
    var tmp4 = toLong(val.precision);
    // Inline function 'kotlin.Long.minus' call
    var other_1 = val.rt_1;
    var yae = tmp4.i3(toLong(other_1));
    if (xae.m1(yae) < 0) {
      return -1;
    }
    if (xae.m1(yae) > 0) {
      return 1;
    }
    if (sdiff.m1(new Long(0, 0)) < 0) {
      var tmp;
      var tmp_0;
      if (sdiff.m1(new Long(-2147483648, -1)) > 0) {
        var tmp_1;
        if (xs.equals(new Long(0, -2147483648))) {
          tmp_1 = true;
        } else {
          // Inline function 'kotlin.run' call
          // Inline function 'com.macrofocus.common.math.big.CommonBigDecimal.compareMagnitude.<anonymous>' call
          xs = longMultiplyPowerTen(Companion_getInstance_20(), xs, sdiff.o3().l1());
          tmp_1 = xs.equals(new Long(0, -2147483648));
        }
        tmp_0 = tmp_1;
      } else {
        tmp_0 = false;
      }
      if (tmp_0) {
        tmp = ys.equals(new Long(0, -2147483648));
      } else {
        tmp = false;
      }
      if (tmp) {
        var rb = bigMultiplyPowerTen_1($this, sdiff.o3().l1());
        return rb.xt(ensureNotNull(val.qt_1));
      }
    } else {
      var tmp_2;
      var tmp_3;
      if (sdiff.m1(new Long(2147483647, 0)) <= 0) {
        var tmp_4;
        if (ys.equals(new Long(0, -2147483648))) {
          tmp_4 = true;
        } else {
          // Inline function 'kotlin.run' call
          // Inline function 'com.macrofocus.common.math.big.CommonBigDecimal.compareMagnitude.<anonymous>' call
          ys = longMultiplyPowerTen(Companion_getInstance_20(), ys, sdiff.l1());
          tmp_4 = ys.equals(new Long(0, -2147483648));
        }
        tmp_3 = tmp_4;
      } else {
        tmp_3 = false;
      }
      if (tmp_3) {
        tmp_2 = xs.equals(new Long(0, -2147483648));
      } else {
        tmp_2 = false;
      }
      if (tmp_2) {
        var rb_0 = bigMultiplyPowerTen_1(val, sdiff.l1());
        return ensureNotNull($this.qt_1).xt(rb_0);
      }
    }
  }
  var tmp_5;
  if (!xs.equals(new Long(0, -2147483648))) {
    tmp_5 = !ys.equals(new Long(0, -2147483648)) ? longCompareMagnitude(Companion_getInstance_20(), xs, ys) : -1;
  } else if (!ys.equals(new Long(0, -2147483648))) {
    tmp_5 = 1;
  } else {
    tmp_5 = ensureNotNull($this.qt_1).xt(ensureNotNull(val.qt_1));
  }
  return tmp_5;
}
function getValueString($this, signum, intString, scale) {
  var buf;
  var insertionPoint = intString.length - scale | 0;
  if (insertionPoint === 0) {
    return (signum < 0 ? '-0.' : '0.') + intString;
  } else if (insertionPoint > 0) {
    buf = StringBuilder.ye(intString);
    insertChar(buf, insertionPoint, _Char___init__impl__6a9atx(46));
    if (signum < 0) {
      insertChar(buf, 0, _Char___init__impl__6a9atx(45));
    }
  } else {
    buf = StringBuilder.pb((3 - insertionPoint | 0) + intString.length | 0);
    buf.lb(signum < 0 ? '-0.' : '0.');
    var inductionVariable = 0;
    var last = -insertionPoint | 0;
    if (inductionVariable < last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        buf.mb(_Char___init__impl__6a9atx(48));
      }
       while (inductionVariable < last);
    buf.lb(intString);
  }
  return buf.toString();
}
var LongOverflow_instance;
function LongOverflow_getInstance() {
  if (LongOverflow_instance === VOID)
    new LongOverflow();
  return LongOverflow_instance;
}
function layoutChars($this, sci) {
  if ($this.rt_1 === 0) {
    var tmp;
    if (!$this.ut_1.equals(new Long(0, -2147483648))) {
      tmp = $this.ut_1.toString();
    } else {
      tmp = ensureNotNull($this.qt_1).toString();
    }
    return tmp;
  }
  if ($this.rt_1 === 2 && $this.ut_1.m1(new Long(0, 0)) >= 0 && $this.ut_1.m1(new Long(2147483647, 0)) < 0) {
    var lowInt = $this.ut_1.l1() % 100 | 0;
    var highInt = $this.ut_1.l1() / 100 | 0;
    return highInt.toString() + '.' + new Char(Companion_getInstance_19().wr_1[lowInt]) + toString(Companion_getInstance_19().xr_1[lowInt]);
  }
  var sbHelper = new StringBuilderHelper();
  var coeff;
  var offset;
  if (!$this.ut_1.equals(new Long(0, -2147483648))) {
    offset = sbHelper.yu(abs($this.ut_1));
    coeff = sbHelper.wu_1;
  } else {
    offset = 0;
    coeff = toCharArray(ensureNotNull($this.qt_1).absoluteValue.toString());
  }
  var buf = sbHelper.xu();
  if ($this.signum < 0) {
    buf.mb(_Char___init__impl__6a9atx(45));
  }
  var coeffLen = coeff.length - offset | 0;
  var tmp0 = toLong($this.rt_1).o3();
  // Inline function 'kotlin.Long.plus' call
  var other = coeffLen - 1 | 0;
  var adjusted = tmp0.h3(toLong(other));
  if ($this.rt_1 >= 0 && adjusted.m1(new Long(-6, -1)) >= 0) {
    var pad = $this.rt_1 - coeffLen | 0;
    if (pad >= 0) {
      buf.mb(_Char___init__impl__6a9atx(48));
      buf.mb(_Char___init__impl__6a9atx(46));
      while (pad > 0) {
        buf.mb(_Char___init__impl__6a9atx(48));
        pad = pad - 1 | 0;
      }
      appendCharArray(buf, coeff, offset, coeffLen);
    } else {
      appendCharArray(buf, coeff, offset, -pad | 0);
      buf.mb(_Char___init__impl__6a9atx(46));
      appendCharArray(buf, coeff, (-pad | 0) + offset | 0, $this.rt_1);
    }
  } else {
    if (sci) {
      buf.mb(coeff[offset]);
      if (coeffLen > 1) {
        buf.mb(_Char___init__impl__6a9atx(46));
        appendCharArray(buf, coeff, offset + 1 | 0, coeffLen - 1 | 0);
      }
    } else {
      // Inline function 'kotlin.Long.rem' call
      var sig = adjusted.l3(toLong(3)).l1();
      if (sig < 0) {
        sig = sig + 3 | 0;
      }
      adjusted = adjusted.i3(toLong(sig));
      sig = sig + 1 | 0;
      if ($this.signum === 0) {
        switch (sig) {
          case 1:
            buf.mb(_Char___init__impl__6a9atx(48));
            break;
          case 2:
            buf.lb('0.00');
            // Inline function 'kotlin.Long.plus' call

            adjusted = adjusted.h3(toLong(3));
            break;
          case 3:
            buf.lb('0.0');
            // Inline function 'kotlin.Long.plus' call

            adjusted = adjusted.h3(toLong(3));
            break;
          default:
            throw AssertionError.qd('Unexpected sig value ' + sig);
        }
      } else if (sig >= coeffLen) {
        appendCharArray(buf, coeff, offset, coeffLen);
        var inductionVariable = sig - coeffLen | 0;
        if (1 <= inductionVariable)
          do {
            var i = inductionVariable;
            inductionVariable = inductionVariable + -1 | 0;
            buf.mb(_Char___init__impl__6a9atx(48));
          }
           while (1 <= inductionVariable);
      } else {
        appendCharArray(buf, coeff, offset, sig);
        buf.mb(_Char___init__impl__6a9atx(46));
        appendCharArray(buf, coeff, offset + sig | 0, coeffLen - sig | 0);
      }
    }
    if (!adjusted.equals(new Long(0, 0))) {
      buf.mb(_Char___init__impl__6a9atx(69));
      if (adjusted.m1(new Long(0, 0)) > 0) {
        buf.mb(_Char___init__impl__6a9atx(43));
      }
      buf.af(adjusted);
    }
  }
  return buf.toString();
}
function bigMultiplyPowerTen_1($this, n) {
  if (n <= 0) {
    return inflated($this);
  }
  var tmp;
  if (!$this.ut_1.equals(new Long(0, -2147483648))) {
    tmp = bigTenToThe(Companion_getInstance_20(), n).pu($this.ut_1);
  } else {
    tmp = ensureNotNull($this.qt_1).times(bigTenToThe(Companion_getInstance_20(), n));
  }
  return tmp;
}
function inflated($this) {
  var tmp0_elvis_lhs = $this.qt_1;
  return tmp0_elvis_lhs == null ? Companion_getInstance_21().ofLong($this.ut_1) : tmp0_elvis_lhs;
}
function checkScale_1($this, val) {
  var asInt = val.l1();
  if (!toLong(asInt).equals(val)) {
    asInt = val.m1(new Long(2147483647, 0)) > 0 ? 2147483647 : -2147483648;
    var b;
    var tmp;
    if (!$this.ut_1.equals(new Long(0, 0))) {
      var tmp_0;
      // Inline function 'kotlin.run' call
      // Inline function 'com.macrofocus.common.math.big.CommonBigDecimal.checkScale.<anonymous>' call
      b = $this.qt_1;
      if (b == null) {
        tmp_0 = true;
      } else {
        tmp_0 = !(ensureNotNull(b).signum === 0);
      }
      tmp = tmp_0;
    } else {
      tmp = false;
    }
    if (tmp) {
      throw ArithmeticException.md(asInt > 0 ? 'Underflow' : 'Overflow');
    }
  }
  return asInt;
}
var Companion_instance_20;
function Companion_getInstance_20() {
  if (Companion_instance_20 === VOID)
    new Companion_20();
  return Companion_instance_20;
}
function init_com_macrofocus_common_math_big_CommonBigDecimal(_this__u8e3s4) {
  Companion_getInstance_20();
  _this__u8e3s4.st_1 = 0;
  _this__u8e3s4.tt_1 = null;
}
function destructiveMulAdd($this, x, y, z) {
  var ylong = toLong(y).t3(new Long(-1, 0));
  var zlong = toLong(z).t3(new Long(-1, 0));
  var len = x.length;
  var product = new Long(0, 0);
  var carry = new Long(0, 0);
  var inductionVariable = len - 1 | 0;
  if (0 <= inductionVariable)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + -1 | 0;
      product = ylong.j3(toLong(x[i]).t3(new Long(-1, 0))).h3(carry);
      x[i] = product.l1();
      carry = product.s3(32);
    }
     while (0 <= inductionVariable);
  var sum = toLong(x[len - 1 | 0]).t3(new Long(-1, 0)).h3(zlong);
  x[len - 1 | 0] = sum.l1();
  carry = sum.s3(32);
  var inductionVariable_0 = len - 2 | 0;
  if (0 <= inductionVariable_0)
    do {
      var i_0 = inductionVariable_0;
      inductionVariable_0 = inductionVariable_0 + -1 | 0;
      sum = toLong(x[i_0]).t3(new Long(-1, 0)).h3(carry);
      x[i_0] = sum.l1();
      carry = sum.s3(32);
    }
     while (0 <= inductionVariable_0);
}
function randomBits($this, numBits, rnd) {
  if (numBits < 0) {
    throw IllegalArgumentException.h('numBits must be non-negative');
  }
  // Inline function 'kotlin.Long.plus' call
  // Inline function 'kotlin.Long.div' call
  var numBytes = toLong(numBits).h3(toLong(7)).k3(toLong(8)).l1();
  var randomBits = new Int8Array(numBytes);
  if (numBytes > 0) {
    rnd.ai(randomBits);
    var excessBits = imul_0(8, numBytes) - numBits | 0;
    var tmp4 = randomBits[0];
    // Inline function 'kotlin.experimental.and' call
    var other = toByte((1 << (8 - excessBits | 0)) - 1 | 0);
    randomBits[0] = toByte(tmp4 & other);
  }
  return randomBits;
}
function smallPrime($this, bitLength, certainty, rnd) {
  var magLen = (bitLength + 31 | 0) >>> 5 | 0;
  var temp = new Int32Array(magLen);
  var highBit = 1 << ((bitLength + 31 | 0) & 31);
  var highMask = (highBit << 1) - 1 | 0;
  $l$loop: while (true) {
    var inductionVariable = 0;
    if (inductionVariable < magLen)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        temp[i] = rnd.tg();
      }
       while (inductionVariable < magLen);
    temp[0] = temp[0] & highMask | highBit;
    if (bitLength > 2) {
      temp[magLen - 1 | 0] = temp[magLen - 1 | 0] | 1;
    }
    var p = CommonBigInteger.jv(temp, 1);
    if (bitLength > 6) {
      var r = p.reminder($this.ns_1).toLong();
      var tmp;
      var tmp_0;
      var tmp_1;
      var tmp_2;
      var tmp_3;
      var tmp_4;
      var tmp_5;
      var tmp_6;
      var tmp_7;
      var tmp_8;
      var tmp_9;
      // Inline function 'kotlin.Long.rem' call
      if (r.l3(toLong(3)).equals(new Long(0, 0))) {
        tmp_9 = true;
      } else {
        // Inline function 'kotlin.Long.rem' call
        tmp_9 = r.l3(toLong(5)).equals(new Long(0, 0));
      }
      if (tmp_9) {
        tmp_8 = true;
      } else {
        // Inline function 'kotlin.Long.rem' call
        tmp_8 = r.l3(toLong(7)).equals(new Long(0, 0));
      }
      if (tmp_8) {
        tmp_7 = true;
      } else {
        // Inline function 'kotlin.Long.rem' call
        tmp_7 = r.l3(toLong(11)).equals(new Long(0, 0));
      }
      if (tmp_7) {
        tmp_6 = true;
      } else {
        // Inline function 'kotlin.Long.rem' call
        tmp_6 = r.l3(toLong(13)).equals(new Long(0, 0));
      }
      if (tmp_6) {
        tmp_5 = true;
      } else {
        // Inline function 'kotlin.Long.rem' call
        tmp_5 = r.l3(toLong(17)).equals(new Long(0, 0));
      }
      if (tmp_5) {
        tmp_4 = true;
      } else {
        // Inline function 'kotlin.Long.rem' call
        tmp_4 = r.l3(toLong(19)).equals(new Long(0, 0));
      }
      if (tmp_4) {
        tmp_3 = true;
      } else {
        // Inline function 'kotlin.Long.rem' call
        tmp_3 = r.l3(toLong(23)).equals(new Long(0, 0));
      }
      if (tmp_3) {
        tmp_2 = true;
      } else {
        // Inline function 'kotlin.Long.rem' call
        tmp_2 = r.l3(toLong(29)).equals(new Long(0, 0));
      }
      if (tmp_2) {
        tmp_1 = true;
      } else {
        // Inline function 'kotlin.Long.rem' call
        tmp_1 = r.l3(toLong(31)).equals(new Long(0, 0));
      }
      if (tmp_1) {
        tmp_0 = true;
      } else {
        // Inline function 'kotlin.Long.rem' call
        tmp_0 = r.l3(toLong(37)).equals(new Long(0, 0));
      }
      if (tmp_0) {
        tmp = true;
      } else {
        // Inline function 'kotlin.Long.rem' call
        tmp = r.l3(toLong(41)).equals(new Long(0, 0));
      }
      if (tmp) {
        continue $l$loop;
      }
    }
    if (bitLength < 4) {
      return p;
    }
    if (p.vr(certainty, rnd)) {
      return p;
    }
  }
}
function largePrime($this, bitLength, certainty, rnd) {
  var p;
  p = CommonBigInteger.kv(bitLength, rnd).setBit(bitLength - 1 | 0);
  p.qr_1[p.qr_1.length - 1 | 0] = p.qr_1[p.qr_1.length - 1 | 0] & -2;
  var searchLen = getPrimeSearchLen($this, bitLength);
  var searchSieve = BitSieve.gr(p, searchLen);
  var candidate = searchSieve.nr(p, certainty, rnd);
  while (candidate == null || !(candidate.bitLength === bitLength)) {
    p = p.plus($this.ofLong(toLong(imul_0(2, searchLen))));
    if (!(p.bitLength === bitLength)) {
      p = CommonBigInteger.kv(bitLength, rnd).setBit(bitLength - 1 | 0);
    }
    p.qr_1[p.qr_1.length - 1 | 0] = p.qr_1[p.qr_1.length - 1 | 0] & -2;
    searchSieve = BitSieve.gr(p, searchLen);
    candidate = searchSieve.nr(p, certainty, rnd);
  }
  return candidate;
}
function getPrimeSearchLen($this, bitLength) {
  if (bitLength > 500000001) {
    throw ArithmeticException.md('Prime search implementation restriction on bitLength');
  }
  return imul_0(bitLength / 20 | 0, 64);
}
function jacobiSymbol($this, p, n) {
  var p_0 = p;
  if (p_0 === 0) {
    return 0;
  }
  var j = 1;
  var u = n.qr_1[n.qr_1.length - 1 | 0];
  if (p_0 < 0) {
    p_0 = -p_0 | 0;
    var n8 = u & 7;
    if (n8 === 3 || n8 === 7) {
      j = -j | 0;
    }
  }
  while ((p_0 & 3) === 0)
    p_0 = p_0 >> 2;
  if ((p_0 & 1) === 0) {
    p_0 = p_0 >> 1;
    if (!(((u ^ u >> 1) & 2) === 0)) {
      j = -j | 0;
    }
  }
  if (p_0 === 1) {
    return j;
  }
  if (!((p_0 & u & 2) === 0)) {
    j = -j | 0;
  }
  u = n.rem($this.ofLong(toLong(p_0))).toInt();
  while (!(u === 0)) {
    while ((u & 3) === 0)
      u = u >> 2;
    if ((u & 1) === 0) {
      u = u >> 1;
      if (!(((p_0 ^ p_0 >> 1) & 2) === 0)) {
        j = -j | 0;
      }
    }
    if (u === 1) {
      return j;
    }
    // Inline function 'kotlin.require' call
    // Inline function 'kotlin.require' call
    if (!(u < p_0)) {
      // Inline function 'kotlin.require.<anonymous>' call
      var message = 'Failed requirement.';
      throw IllegalArgumentException.h(toString_1(message));
    }
    var t = u;
    u = p_0;
    p_0 = t;
    if (!((u & p_0 & 2) === 0)) {
      j = -j | 0;
    }
    u = u % p_0 | 0;
  }
  return 0;
}
function lucasLehmerSequence($this, z, k, n) {
  var d = $this.ofLong(toLong(z));
  var u = $this.ONE;
  var u2;
  var v = $this.ONE;
  var v2;
  var inductionVariable = k.bitLength - 2 | 0;
  if (0 <= inductionVariable)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + -1 | 0;
      u2 = u.times(v).rem(n);
      v2 = square(v).plus(d.times(square(u))).rem(n);
      if (v2.testBit(0)) {
        v2 = v2.minus(n);
      }
      v2 = v2.shr(1);
      u = u2;
      v = v2;
      if (k.testBit(i)) {
        u2 = u.plus(v).rem(n);
        if (u2.testBit(0)) {
          u2 = u2.minus(n);
        }
        u2 = u2.shr(1);
        v2 = v.plus(d.times(u)).rem(n);
        if (v2.testBit(0)) {
          v2 = v2.minus(n);
        }
        v2 = v2.shr(1);
        u = u2;
        v = v2;
      }
    }
     while (0 <= inductionVariable);
  return u;
}
function reportOverflow($this) {
  throw ArithmeticException.md('BigInteger would overflow supported range');
}
function sum_4($this, x, other) {
  var sum = new Long(0, 0);
  var xIndex = x.length;
  var result;
  var highWord = other.s3(32).l1();
  if (highWord === 0) {
    result = new Int32Array(xIndex);
    xIndex = xIndex - 1 | 0;
    sum = toLong(x[xIndex]).t3(new Long(-1, 0)).h3(other);
    result[xIndex] = sum.l1();
  } else {
    if (xIndex === 1) {
      result = new Int32Array(2);
      sum = other.h3(toLong(x[0]).t3(new Long(-1, 0)));
      result[1] = sum.l1();
      result[0] = sum.s3(32).l1();
      return result;
    } else {
      result = new Int32Array(xIndex);
      xIndex = xIndex - 1 | 0;
      sum = toLong(x[xIndex]).t3(new Long(-1, 0)).h3(other.y3().t3(new Long(-1, 0)));
      result[xIndex] = sum.l1();
      xIndex = xIndex - 1 | 0;
      sum = toLong(x[xIndex]).t3(new Long(-1, 0)).h3(toLong(highWord).t3(new Long(-1, 0))).h3(sum.s3(32));
      result[xIndex] = sum.l1();
    }
  }
  var carry = !sum.s3(32).equals(new Long(0, 0));
  while (xIndex > 0 && carry) {
    result[xIndex - 1 | 0] = x[xIndex] + 1 | 0;
    xIndex = xIndex - 1 | 0;
    carry = result[xIndex] === 0;
  }
  while (xIndex > 0) {
    xIndex = xIndex - 1 | 0;
    result[xIndex] = x[xIndex];
  }
  if (carry) {
    var bigger = new Int32Array(result.length + 1 | 0);
    arrayCopy_0(result, 0, bigger, 1, result.length);
    bigger[0] = 1;
    return bigger;
  }
  return result;
}
function sum_5($this, x, y) {
  var x_0 = x;
  var y_0 = y;
  if (x_0.length < y_0.length) {
    var tmp = x_0;
    x_0 = y_0;
    y_0 = tmp;
  }
  var xIndex = x_0.length;
  var yIndex = y_0.length;
  var result = new Int32Array(xIndex);
  var sum = new Long(0, 0);
  if (yIndex === 1) {
    xIndex = xIndex - 1 | 0;
    sum = toLong(x_0[xIndex]).t3(new Long(-1, 0)).h3(toLong(y_0[0]).t3(new Long(-1, 0)));
    result[xIndex] = sum.l1();
  } else {
    while (yIndex > 0) {
      var tmp_0 = x_0;
      xIndex = xIndex - 1 | 0;
      var tmp_1 = toLong(tmp_0[xIndex]).t3(new Long(-1, 0));
      var tmp_2 = y_0;
      yIndex = yIndex - 1 | 0;
      sum = tmp_1.h3(toLong(tmp_2[yIndex]).t3(new Long(-1, 0))).h3(sum.s3(32));
      result[xIndex] = sum.l1();
    }
  }
  var carry = !sum.s3(32).equals(new Long(0, 0));
  while (xIndex > 0 && carry) {
    xIndex = xIndex - 1 | 0;
    result[xIndex] = x_0[xIndex] + 1 | 0;
    carry = result[xIndex] === 0;
  }
  while (xIndex > 0) {
    xIndex = xIndex - 1 | 0;
    result[xIndex] = x_0[xIndex];
  }
  if (carry) {
    var bigger = new Int32Array(result.length + 1 | 0);
    arrayCopy_0(result, 0, bigger, 1, result.length);
    bigger[0] = 1;
    return bigger;
  }
  return result;
}
function subtract_0($this, other, little) {
  var highWord = other.s3(32).l1();
  if (highWord === 0) {
    var result = new Int32Array(1);
    result[0] = other.i3(toLong(little[0]).t3(new Long(-1, 0))).l1();
    return result;
  } else {
    var result_0 = new Int32Array(2);
    if (little.length === 1) {
      var difference = toLong(other.l1()).t3(new Long(-1, 0)).i3(toLong(little[0]).t3(new Long(-1, 0)));
      result_0[1] = difference.l1();
      var borrow = !difference.r3(32).equals(new Long(0, 0));
      if (borrow) {
        result_0[0] = highWord - 1 | 0;
      } else {
        result_0[0] = highWord;
      }
      return result_0;
    } else {
      var difference_0 = toLong(other.l1()).t3(new Long(-1, 0)).i3(toLong(little[1]).t3(new Long(-1, 0)));
      result_0[1] = difference_0.l1();
      difference_0 = toLong(highWord).t3(new Long(-1, 0)).i3(toLong(little[0]).t3(new Long(-1, 0))).h3(difference_0.r3(32));
      result_0[0] = difference_0.l1();
      return result_0;
    }
  }
}
function subtract_1($this, big, other) {
  var highWord = other.s3(32).l1();
  var bigIndex = big.length;
  var result = new Int32Array(bigIndex);
  var difference = new Long(0, 0);
  if (highWord === 0) {
    bigIndex = bigIndex - 1 | 0;
    difference = toLong(big[bigIndex]).t3(new Long(-1, 0)).i3(other);
    result[bigIndex] = difference.l1();
  } else {
    bigIndex = bigIndex - 1 | 0;
    difference = toLong(big[bigIndex]).t3(new Long(-1, 0)).i3(other.t3(new Long(-1, 0)));
    result[bigIndex] = difference.l1();
    bigIndex = bigIndex - 1 | 0;
    difference = toLong(big[bigIndex]).t3(new Long(-1, 0)).i3(toLong(highWord).t3(new Long(-1, 0))).h3(difference.r3(32));
    result[bigIndex] = difference.l1();
  }
  var borrow = !difference.r3(32).equals(new Long(0, 0));
  while (bigIndex > 0 && borrow) {
    bigIndex = bigIndex - 1 | 0;
    result[bigIndex] = big[bigIndex] - 1 | 0;
    borrow = result[bigIndex] === -1;
  }
  while (bigIndex > 0) {
    bigIndex = bigIndex - 1 | 0;
    result[bigIndex] = big[bigIndex];
  }
  return result;
}
function subtract_2($this, big, little) {
  var bigIndex = big.length;
  var result = new Int32Array(bigIndex);
  var littleIndex = little.length;
  var difference = new Long(0, 0);
  while (littleIndex > 0) {
    bigIndex = bigIndex - 1 | 0;
    var tmp = toLong(big[bigIndex]).t3(new Long(-1, 0));
    littleIndex = littleIndex - 1 | 0;
    difference = tmp.i3(toLong(little[littleIndex]).t3(new Long(-1, 0))).h3(difference.r3(32));
    result[bigIndex] = difference.l1();
  }
  var borrow = !difference.r3(32).equals(new Long(0, 0));
  while (bigIndex > 0 && borrow) {
    bigIndex = bigIndex - 1 | 0;
    result[bigIndex] = big[bigIndex] - 1 | 0;
    borrow = result[bigIndex] === -1;
  }
  while (bigIndex > 0) {
    bigIndex = bigIndex - 1 | 0;
    result[bigIndex] = big[bigIndex];
  }
  return result;
}
function multiplyByInt($this, x, y, sign) {
  if (bitCount(y) === 1) {
    return CommonBigInteger.jv(shl($this, x, numberOfTrailingZeros(y)), sign);
  }
  var xlen = x.length;
  var rmag = new Int32Array(xlen + 1 | 0);
  var carry = new Long(0, 0);
  var yl = toLong(y).t3(new Long(-1, 0));
  var rstart = rmag.length - 1 | 0;
  var inductionVariable = xlen - 1 | 0;
  if (0 <= inductionVariable)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + -1 | 0;
      var product = toLong(x[i]).t3(new Long(-1, 0)).j3(yl).h3(carry);
      var tmp = rmag;
      var _unary__edvuaz = rstart;
      rstart = _unary__edvuaz - 1 | 0;
      tmp[_unary__edvuaz] = product.l1();
      carry = product.s3(32);
    }
     while (0 <= inductionVariable);
  if (carry.equals(new Long(0, 0))) {
    rmag = copyOfRange(rmag, 1, rmag.length);
  } else {
    rmag[rstart] = carry.l1();
  }
  return CommonBigInteger.jv(rmag, sign);
}
function multiplyToLen($this, x, xlen, y, ylen, z) {
  multiplyToLenCheck($this, x, xlen);
  multiplyToLenCheck($this, y, ylen);
  return implMultiplyToLen($this, x, xlen, y, ylen, z);
}
function implMultiplyToLen($this, x, xlen, y, ylen, z) {
  var z_0 = z;
  var xstart = xlen - 1 | 0;
  var ystart = ylen - 1 | 0;
  if (z_0 == null || z_0.length < (xlen + ylen | 0)) {
    z_0 = new Int32Array(xlen + ylen | 0);
  }
  var carry = new Long(0, 0);
  // Inline function 'kotlin.run' call
  // Inline function 'com.macrofocus.common.math.big.Companion.implMultiplyToLen.<anonymous>' call
  var j = ystart;
  var k = (ystart + 1 | 0) + xstart | 0;
  while (j >= 0) {
    var product = toLong(y[j]).t3(new Long(-1, 0)).j3(toLong(x[xstart]).t3(new Long(-1, 0))).h3(carry);
    z_0[k] = product.l1();
    carry = product.s3(32);
    j = j - 1 | 0;
    k = k - 1 | 0;
  }
  z_0[xstart] = carry.l1();
  var inductionVariable = xstart - 1 | 0;
  if (0 <= inductionVariable)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + -1 | 0;
      carry = new Long(0, 0);
      var j_0 = ystart;
      var k_0 = (ystart + 1 | 0) + i | 0;
      while (j_0 >= 0) {
        var product_0 = toLong(y[j_0]).t3(new Long(-1, 0)).j3(toLong(x[i]).t3(new Long(-1, 0))).h3(toLong(z_0[k_0]).t3(new Long(-1, 0))).h3(carry);
        z_0[k_0] = product_0.l1();
        carry = product_0.s3(32);
        j_0 = j_0 - 1 | 0;
        k_0 = k_0 - 1 | 0;
      }
      z_0[i] = carry.l1();
    }
     while (0 <= inductionVariable);
  return z_0;
}
function multiplyToLenCheck($this, array, length) {
  if (length <= 0) {
    return Unit_instance;
  }
  if (length > array.length) {
    throw IndexOutOfBoundsException.bd('' + (length - 1 | 0));
  }
}
function multiplyKaratsuba($this, x, y) {
  var xlen = x.qr_1.length;
  var ylen = y.qr_1.length;
  // Inline function 'kotlin.math.max' call
  var half = (Math.max(xlen, ylen) + 1 | 0) / 2 | 0;
  var xl = getLower(x, half);
  var xh = getUpper(x, half);
  var yl = getLower(y, half);
  var yh = getUpper(y, half);
  var p1 = xh.times(yh);
  var p2 = xl.times(yl);
  var p3 = xh.plus(xl).times(yh.plus(yl));
  var result = p1.shl(imul_0(32, half)).plus(p3.minus(p1).minus(p2)).shl(imul_0(32, half)).plus(p2);
  var tmp;
  if (!(x.pr_1 === y.pr_1)) {
    tmp = result.unaryMinus();
  } else {
    tmp = result;
  }
  return tmp;
}
function multiplyToomCook3($this, a, b) {
  var alen = a.qr_1.length;
  var blen = b.qr_1.length;
  // Inline function 'kotlin.math.max' call
  var largest = Math.max(alen, blen);
  var k = (largest + 2 | 0) / 3 | 0;
  var r = largest - imul_0(2, k) | 0;
  var a0;
  var a1;
  var a2;
  var b0;
  var b1;
  var b2;
  a2 = getToomSlice(a, k, r, 0, largest);
  a1 = getToomSlice(a, k, r, 1, largest);
  a0 = getToomSlice(a, k, r, 2, largest);
  b2 = getToomSlice(b, k, r, 0, largest);
  b1 = getToomSlice(b, k, r, 1, largest);
  b0 = getToomSlice(b, k, r, 2, largest);
  var v0;
  var v1;
  var v2;
  var vm1;
  var vinf;
  var t1;
  var t2;
  var tm1;
  var da1;
  var db1;
  v0 = a0.times(b0);
  da1 = a2.plus(a0);
  db1 = b2.plus(b0);
  vm1 = da1.minus(a1).times(db1.minus(b1));
  da1 = da1.plus(a1);
  db1 = db1.plus(b1);
  v1 = da1.times(db1);
  v2 = da1.plus(a2).shl(1).minus(a0).times(db1.plus(b2).shl(1).minus(b0));
  vinf = a2.times(b2);
  t2 = exactDivideBy3(v2.minus(vm1));
  tm1 = v1.minus(vm1).shr(1);
  t1 = v1.minus(v0);
  t2 = t2.minus(t1).shr(1);
  t1 = t1.minus(tm1).minus(vinf);
  t2 = t2.minus(vinf.shl(1));
  tm1 = tm1.minus(t2);
  var ss = imul_0(k, 32);
  var result = vinf.shl(ss).plus(t2).shl(ss).plus(t1).shl(ss).plus(tm1).shl(ss).plus(v0);
  var tmp;
  if (!(a.pr_1 === b.pr_1)) {
    tmp = result.unaryMinus();
  } else {
    tmp = result;
  }
  return tmp;
}
function squareToLen($this, x, len, z) {
  var z_0 = z;
  var zlen = len << 1;
  if (z_0 == null || z_0.length < zlen) {
    z_0 = new Int32Array(zlen);
  }
  implSquareToLenChecks($this, x, len, z_0, zlen);
  return implSquareToLen($this, x, len, z_0, zlen);
}
function implSquareToLenChecks($this, x, len, z, zlen) {
  if (len < 1) {
    throw IllegalArgumentException.h('invalid input length: ' + len);
  }
  if (len > x.length) {
    throw IllegalArgumentException.h('input length out of bound: ' + len + ' > ' + x.length);
  }
  if (imul_0(len, 2) > z.length) {
    throw IllegalArgumentException.h('input length out of bound: ' + imul_0(len, 2) + ' > ' + z.length);
  }
  if (zlen < 1) {
    throw IllegalArgumentException.h('invalid input length: ' + zlen);
  }
  if (zlen > z.length) {
    throw IllegalArgumentException.h('input length out of bound: ' + len + ' > ' + z.length);
  }
}
function implSquareToLen($this, x, len, z, zlen) {
  var lastProductLowWord = 0;
  // Inline function 'kotlin.run' call
  // Inline function 'com.macrofocus.common.math.big.Companion.implSquareToLen.<anonymous>' call
  var j = 0;
  var i = 0;
  while (j < len) {
    var piece = toLong(x[j]).t3(new Long(-1, 0));
    var product = piece.j3(piece);
    var _unary__edvuaz = i;
    i = _unary__edvuaz + 1 | 0;
    z[_unary__edvuaz] = lastProductLowWord << 31 | product.s3(33).l1();
    var _unary__edvuaz_0 = i;
    i = _unary__edvuaz_0 + 1 | 0;
    z[_unary__edvuaz_0] = product.s3(1).l1();
    lastProductLowWord = product.l1();
    j = j + 1 | 0;
  }
  var i_0 = len;
  var offset = 1;
  while (i_0 > 0) {
    var t = x[i_0 - 1 | 0];
    t = mulAdd($this, z, x, offset, i_0 - 1 | 0, t);
    addOne($this, z, offset - 1 | 0, i_0, t);
    i_0 = i_0 - 1 | 0;
    offset = offset + 2 | 0;
  }
  primitiveLeftShift($this, z, zlen, 1);
  z[zlen - 1 | 0] = z[zlen - 1 | 0] | x[len - 1 | 0] & 1;
  return z;
}
function leftShift($this, a, len, n) {
  var nInts = n >>> 5 | 0;
  var nBits = n & 31;
  var bitsInHighWord = $this.lv(a[0]);
  if (n <= (32 - bitsInHighWord | 0)) {
    primitiveLeftShift($this, a, len, nBits);
    return a;
  } else {
    if (nBits <= (32 - bitsInHighWord | 0)) {
      var result = new Int32Array(nInts + len | 0);
      arrayCopy_0(a, 0, result, 0, len);
      primitiveLeftShift($this, result, result.length, nBits);
      return result;
    } else {
      var result_0 = new Int32Array((nInts + len | 0) + 1 | 0);
      arrayCopy_0(a, 0, result_0, 0, len);
      primitiveRightShift($this, result_0, result_0.length, 32 - nBits | 0);
      return result_0;
    }
  }
}
function primitiveRightShift($this, a, len, n) {
  var n2 = 32 - n | 0;
  var i = len - 1 | 0;
  var c = a[i];
  while (i > 0) {
    var b = c;
    c = a[i - 1 | 0];
    a[i] = c << n2 | (b >>> n | 0);
    i = i - 1 | 0;
  }
  a[0] = a[0] >>> n | 0;
}
function primitiveLeftShift($this, a, len, n) {
  if (len === 0 || n === 0) {
    return Unit_instance;
  }
  var n2 = 32 - n | 0;
  var i = 0;
  var c = a[i];
  var m = (i + len | 0) - 1 | 0;
  while (i < m) {
    var b = c;
    c = a[i + 1 | 0];
    a[i] = b << n | (c >>> n2 | 0);
    i = i + 1 | 0;
  }
  a[len - 1 | 0] = a[len - 1 | 0] << n;
}
function bitLength($this, other, len) {
  return len === 0 ? 0 : ((len - 1 | 0) << 5) + $this.lv(other[0]) | 0;
}
function montgomeryMultiply($this, a, b, n, len, inv, product) {
  var product_0 = product;
  implMontgomeryMultiplyChecks($this, a, b, n, len, product_0);
  if (len > 512) {
    product_0 = multiplyToLen($this, a, len, b, len, product_0);
    return montReduce($this, product_0, n, len, inv.l1());
  } else {
    return implMontgomeryMultiply($this, a, b, n, len, inv, materialize($this, product_0, len));
  }
}
function montgomerySquare($this, a, n, len, inv, product) {
  var product_0 = product;
  implMontgomeryMultiplyChecks($this, a, a, n, len, product_0);
  if (len > 512) {
    product_0 = squareToLen($this, a, len, product_0);
    return montReduce($this, product_0, n, len, inv.l1());
  } else {
    return implMontgomerySquare($this, a, n, len, inv, materialize($this, product_0, len));
  }
}
function implMontgomeryMultiplyChecks($this, a, b, n, len, product) {
  if (!((len % 2 | 0) === 0)) {
    throw IllegalArgumentException.h('input array length must be even: ' + len);
  }
  if (len < 1) {
    throw IllegalArgumentException.h('invalid input length: ' + len);
  }
  if (len > a.length || len > b.length || len > n.length || (!(product == null) && len > product.length)) {
    throw IllegalArgumentException.h('input array length out of bound: ' + len);
  }
}
function materialize($this, z, len) {
  var z_0 = z;
  if (z_0 == null || z_0.length < len) {
    z_0 = new Int32Array(len);
  }
  return z_0;
}
function implMontgomeryMultiply($this, a, b, n, len, inv, product) {
  var product_0 = product;
  product_0 = multiplyToLen($this, a, len, b, len, product_0);
  return montReduce($this, product_0, n, len, inv.l1());
}
function implMontgomerySquare($this, a, n, len, inv, product) {
  var product_0 = product;
  product_0 = squareToLen($this, a, len, product_0);
  return montReduce($this, product_0, n, len, inv.l1());
}
function montReduce($this, n, mod, mlen, inv) {
  var c = 0;
  var len = mlen;
  var offset = 0;
  $l$1: do {
    $l$0: do {
      var nEnd = n[(n.length - 1 | 0) - offset | 0];
      var carry = mulAdd($this, n, mod, offset, mlen, imul_0(inv, nEnd));
      c = c + addOne($this, n, offset, mlen, carry) | 0;
      offset = offset + 1 | 0;
    }
     while (false);
    len = len - 1 | 0;
  }
   while (len > 0);
  while (c > 0)
    c = c + subN($this, n, mod, mlen) | 0;
  while (intArrayCmpToLen($this, n, mod, mlen) >= 0) {
    subN($this, n, mod, mlen);
  }
  return n;
}
function intArrayCmpToLen($this, arg1, arg2, len) {
  var inductionVariable = 0;
  if (inductionVariable < len)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      var b1 = toLong(arg1[i]).t3(new Long(-1, 0));
      var b2 = toLong(arg2[i]).t3(new Long(-1, 0));
      if (b1.m1(b2) < 0) {
        return -1;
      }
      if (b1.m1(b2) > 0) {
        return 1;
      }
    }
     while (inductionVariable < len);
  return 0;
}
function subN($this, a, b, len) {
  var len_0 = len;
  var sum = new Long(0, 0);
  $l$loop: while (true) {
    len_0 = len_0 - 1 | 0;
    if (!(len_0 >= 0)) {
      break $l$loop;
    }
    sum = toLong(a[len_0]).t3(new Long(-1, 0)).i3(toLong(b[len_0]).t3(new Long(-1, 0))).h3(sum.r3(32));
    a[len_0] = sum.l1();
  }
  return sum.r3(32).l1();
}
function mulAdd($this, out, in_0, offset, len, k) {
  implMulAddCheck($this, out, in_0, offset, len, k);
  return implMulAdd($this, out, in_0, offset, len, k);
}
function implMulAddCheck($this, out, in_0, offset, len, k) {
  if (len > in_0.length) {
    throw IllegalArgumentException.h('input length is out of bound: ' + len + ' > ' + in_0.length);
  }
  if (offset < 0) {
    throw IllegalArgumentException.h('input offset is invalid: ' + offset);
  }
  if (offset > (out.length - 1 | 0)) {
    throw IllegalArgumentException.h('input offset is out of bound: ' + offset + ' > ' + (out.length - 1 | 0));
  }
  if (len > (out.length - offset | 0)) {
    throw IllegalArgumentException.h('input len is out of bound: ' + len + ' > ' + (out.length - offset | 0));
  }
}
function implMulAdd($this, out, in_0, offset, len, k) {
  var offset_0 = offset;
  var kLong = toLong(k).t3(new Long(-1, 0));
  var carry = new Long(0, 0);
  offset_0 = (out.length - offset_0 | 0) - 1 | 0;
  var inductionVariable = len - 1 | 0;
  if (0 <= inductionVariable)
    do {
      var j = inductionVariable;
      inductionVariable = inductionVariable + -1 | 0;
      var product = toLong(in_0[j]).t3(new Long(-1, 0)).j3(kLong).h3(toLong(out[offset_0]).t3(new Long(-1, 0))).h3(carry);
      var _unary__edvuaz = offset_0;
      offset_0 = _unary__edvuaz - 1 | 0;
      out[_unary__edvuaz] = product.l1();
      carry = product.s3(32);
    }
     while (0 <= inductionVariable);
  return carry.l1();
}
function addOne($this, a, offset, mlen, carry) {
  var offset_0 = offset;
  var mlen_0 = mlen;
  offset_0 = ((a.length - 1 | 0) - mlen_0 | 0) - offset_0 | 0;
  var t = toLong(a[offset_0]).t3(new Long(-1, 0)).h3(toLong(carry).t3(new Long(-1, 0)));
  a[offset_0] = t.l1();
  if (t.s3(32).equals(new Long(0, 0))) {
    return 0;
  }
  $l$loop: while (true) {
    mlen_0 = mlen_0 - 1 | 0;
    if (!(mlen_0 >= 0)) {
      break $l$loop;
    }
    offset_0 = offset_0 - 1 | 0;
    if (offset_0 < 0) {
      return 1;
    } else {
      var _index_0__fvwizt = offset_0;
      a[_index_0__fvwizt] = a[_index_0__fvwizt] + 1 | 0;
      if (!(a[offset_0] === 0)) {
        return 0;
      }
    }
  }
  return 1;
}
function shl($this, mag, n) {
  var nInts = n >>> 5 | 0;
  var nBits = n & 31;
  var magLen = mag.length;
  var newMag = null;
  if (nBits === 0) {
    newMag = new Int32Array(magLen + nInts | 0);
    arrayCopy_0(mag, 0, newMag, 0, magLen);
  } else {
    var i = 0;
    var nBits2 = 32 - nBits | 0;
    var highBits = mag[0] >>> nBits2 | 0;
    if (!(highBits === 0)) {
      newMag = new Int32Array((magLen + nInts | 0) + 1 | 0);
      var tmp = newMag;
      var _unary__edvuaz = i;
      i = _unary__edvuaz + 1 | 0;
      tmp[_unary__edvuaz] = highBits;
    } else {
      newMag = new Int32Array(magLen + nInts | 0);
    }
    var j = 0;
    while (j < (magLen - 1 | 0)) {
      var tmp_0 = newMag;
      var _unary__edvuaz_0 = i;
      i = _unary__edvuaz_0 + 1 | 0;
      var _unary__edvuaz_1 = j;
      j = _unary__edvuaz_1 + 1 | 0;
      tmp_0[_unary__edvuaz_0] = mag[_unary__edvuaz_1] << nBits | (mag[j] >>> nBits2 | 0);
    }
    newMag[i] = mag[j] << nBits;
  }
  return newMag;
}
function toString_7($this, u, sb, radix, digits) {
  if (u.qr_1.length <= 20) {
    var s = smallToString(u, radix);
    if (s.length < digits && sb.a() > 0) {
      var inductionVariable = s.length;
      if (inductionVariable < digits)
        do {
          var i = inductionVariable;
          inductionVariable = inductionVariable + 1 | 0;
          sb.mb(_Char___init__impl__6a9atx(48));
        }
         while (inductionVariable < digits);
    }
    sb.lb(s);
    return Unit_instance;
  }
  var b;
  var n;
  b = u.bitLength;
  // Inline function 'kotlin.math.ln' call
  var x = b * $this.ts_1 / $this.ss_1[radix];
  var tmp$ret$0 = Math.log(x);
  n = numberToInt(round(tmp$ret$0 / $this.ts_1 - 1.0));
  var v = getRadixConversionCache($this, radix, n);
  var results;
  results = u.divideAndRemainder(v);
  var expectedDigits = 1 << n;
  toString_7($this, results[0], sb, radix, digits - expectedDigits | 0);
  toString_7($this, results[1], sb, radix, expectedDigits);
}
function getRadixConversionCache($this, radix, exponent) {
  var cacheLine = $this.rs_1[radix];
  if (exponent < ensureNotNull(cacheLine).length) {
    return cacheLine[exponent];
  }
  var oldLength = cacheLine.length;
  var cacheLine2 = copyOf_0(cacheLine, exponent + 1 | 0);
  var inductionVariable = oldLength;
  if (inductionVariable <= exponent)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      cacheLine2[i] = ensureNotNull(cacheLine2[i - 1 | 0]).pow(2);
    }
     while (!(i === exponent));
  var pc = $this.rs_1;
  if (exponent >= ensureNotNull(pc[radix]).length) {
    // Inline function 'com.macrofocus.common.math.big.cloneArray' call
    var this_0 = pc;
    var tmp = 0;
    var tmp_0 = this_0.length;
    // Inline function 'kotlin.arrayOfNulls' call
    var tmp_1 = fillArrayVal(Array(tmp_0), null);
    while (tmp < tmp_0) {
      var tmp_2 = tmp;
      tmp_1[tmp_2] = this_0[tmp_2];
      tmp = tmp + 1 | 0;
    }
    pc = tmp_1;
    pc[radix] = requireNoNulls(cacheLine2);
    $this.rs_1 = pc;
  }
  return ensureNotNull(cacheLine2[exponent]);
}
function stripLeadingZeroInts($this, other) {
  var vlen = other.length;
  var keep;
  keep = 0;
  while (keep < vlen && other[keep] === 0) {
    keep = keep + 1 | 0;
  }
  return copyOfRange(other, keep, vlen);
}
function trustedStripLeadingZeroInts($this, other) {
  var vlen = other.length;
  var keep;
  keep = 0;
  while (keep < vlen && other[keep] === 0) {
    keep = keep + 1 | 0;
  }
  return keep === 0 ? other : copyOfRange(other, keep, vlen);
}
function stripLeadingZeroBytes($this, a, off, len) {
  var indexBound = off + len | 0;
  var keep;
  keep = off;
  while (keep < indexBound && a[keep] === 0) {
    keep = keep + 1 | 0;
  }
  var intLength = ((indexBound - keep | 0) + 3 | 0) >>> 2 | 0;
  var result = new Int32Array(intLength);
  var b = indexBound - 1 | 0;
  var inductionVariable = intLength - 1 | 0;
  if (0 <= inductionVariable)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + -1 | 0;
      var _unary__edvuaz = b;
      b = _unary__edvuaz - 1 | 0;
      result[i] = a[_unary__edvuaz] & 255;
      var bytesRemaining = (b - keep | 0) + 1 | 0;
      // Inline function 'kotlin.math.min' call
      var bytesToTransfer = Math.min(3, bytesRemaining);
      var j = 8;
      while (j <= bytesToTransfer << 3) {
        var tmp = result[i];
        var _unary__edvuaz_0 = b;
        b = _unary__edvuaz_0 - 1 | 0;
        result[i] = tmp | (a[_unary__edvuaz_0] & 255) << j;
        j = j + 8 | 0;
      }
    }
     while (0 <= inductionVariable);
  return result;
}
function makePositive($this, a) {
  var keep;
  var j;
  keep = 0;
  while (keep < a.length && a[keep] === -1) {
    keep = keep + 1 | 0;
  }
  j = keep;
  while (j < a.length && a[j] === 0) {
    j = j + 1 | 0;
  }
  var extraInt = j === a.length ? 1 : 0;
  var result = new Int32Array((a.length - keep | 0) + extraInt | 0);
  var inductionVariable = keep;
  var last = a.length;
  if (inductionVariable < last)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      result[(i - keep | 0) + extraInt | 0] = ~a[i];
    }
     while (inductionVariable < last);
  var i_0 = result.length - 1 | 0;
  $l$loop: while (true) {
    var _index_0__fvwizt = i_0;
    result[_index_0__fvwizt] = result[_index_0__fvwizt] + 1 | 0;
    if (!(result[_index_0__fvwizt] === 0)) {
      break $l$loop;
    }
    i_0 = i_0 - 1 | 0;
  }
  return result;
}
function _get_lowestSetBit__xjmtq($this) {
  var lsb = $this.tr_1 - 2 | 0;
  if (lsb === -2) {
    lsb = 0;
    if ($this.pr_1 === 0) {
      lsb = lsb - 1 | 0;
    } else {
      var i;
      var b;
      i = 0;
      b = getInt($this, i);
      while (b === 0) {
        i = i + 1 | 0;
        b = getInt($this, i);
      }
      lsb = lsb + ((i << 5) + numberOfTrailingZeros(b) | 0) | 0;
    }
    $this.tr_1 = lsb + 2 | 0;
  }
  return lsb;
}
function parseInt($this, source, start, end) {
  var result = toDigit(source[start], 10);
  if (result === -1) {
    throw NumberFormatException.hd(concatToString(source));
  }
  var inductionVariable = start + 1 | 0;
  if (inductionVariable < end)
    do {
      var index = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      var nextVal = toDigit(source[index], 10);
      if (nextVal === -1) {
        throw NumberFormatException.hd(concatToString(source));
      }
      result = imul_0(10, result) + nextVal | 0;
    }
     while (inductionVariable < end);
  return result;
}
function passesLucasLehmer($this) {
  var thisPlusOne = $this.plus(Companion_getInstance_21().ONE);
  var d = 5;
  while (!(jacobiSymbol(Companion_getInstance_21(), d, $this) === -1)) {
    var tmp;
    if (d < 0) {
      // Inline function 'kotlin.math.absoluteValue' call
      var this_0 = d;
      tmp = abs_0(this_0) + 2 | 0;
    } else {
      tmp = -(d + 2 | 0) | 0;
    }
    d = tmp;
  }
  var u = lucasLehmerSequence(Companion_getInstance_21(), d, thisPlusOne, $this);
  return u.rem($this).equals(Companion_getInstance_21().ZERO);
}
function passesMillerRabin($this, iterations, rnd) {
  var rnd_0 = rnd;
  var thisMinusOne = $this.minus(Companion_getInstance_21().ONE);
  var m = thisMinusOne;
  var a = _get_lowestSetBit__xjmtq(m);
  m = m.shr(a);
  if (rnd_0 == null) {
    rnd_0 = Default_getInstance();
  }
  var inductionVariable = 0;
  if (inductionVariable < iterations)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      var b;
      do {
        b = CommonBigInteger.kv($this.bitLength, rnd_0);
      }
       while (b.wq(Companion_getInstance_21().ONE) <= 0 || b.wq($this) >= 0);
      var j = 0;
      var z = b.modPow(m, $this);
      while (!(j === 0 && z.equals(Companion_getInstance_21().ONE) || z.equals(thisMinusOne))) {
        var tmp;
        if (j > 0 && z.equals(Companion_getInstance_21().ONE)) {
          tmp = true;
        } else {
          j = j + 1 | 0;
          tmp = j === a;
        }
        if (tmp) {
          return false;
        }
        z = z.modPow(Companion_getInstance_21().TWO, $this);
      }
    }
     while (inductionVariable < iterations);
  return true;
}
function checkRange($this) {
  if ($this.qr_1.length > 67108864 || ($this.qr_1.length === 67108864 && $this.qr_1[0] < 0)) {
    reportOverflow(Companion_getInstance_21());
  }
}
function getToomSlice($this, lowerSize, upperSize, slice, fullsize) {
  var start;
  var end;
  var sliceSize;
  var len;
  var offset;
  len = $this.qr_1.length;
  offset = fullsize - len | 0;
  if (slice === 0) {
    start = 0 - offset | 0;
    end = (upperSize - 1 | 0) - offset | 0;
  } else {
    start = (upperSize + imul_0(slice - 1 | 0, lowerSize) | 0) - offset | 0;
    end = (start + lowerSize | 0) - 1 | 0;
  }
  if (start < 0) {
    start = 0;
  }
  if (end < 0) {
    return Companion_getInstance_21().ZERO;
  }
  sliceSize = (end - start | 0) + 1 | 0;
  if (sliceSize <= 0) {
    return Companion_getInstance_21().ZERO;
  }
  if (start === 0 && sliceSize >= len) {
    return $this.absoluteValue;
  }
  var intSlice = new Int32Array(sliceSize);
  arrayCopy_0($this.qr_1, start, intSlice, 0, sliceSize);
  return CommonBigInteger.jv(trustedStripLeadingZeroInts(Companion_getInstance_21(), intSlice), 1);
}
function exactDivideBy3($this) {
  var len = $this.qr_1.length;
  var result = new Int32Array(len);
  var x;
  var w;
  var q;
  var borrow;
  borrow = new Long(0, 0);
  var inductionVariable = len - 1 | 0;
  if (0 <= inductionVariable)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + -1 | 0;
      x = toLong($this.qr_1[i]).t3(new Long(-1, 0));
      w = x.i3(borrow);
      if (borrow.m1(x) > 0) {
        borrow = new Long(1, 0);
      } else {
        borrow = new Long(0, 0);
      }
      q = w.j3(new Long(-1431655765, 0)).t3(new Long(-1, 0));
      result[i] = q.l1();
      if (q.m1(new Long(1431655766, 0)) >= 0) {
        borrow = borrow.m3();
        if (q.m1(new Long(-1431655765, 0)) >= 0) {
          borrow = borrow.m3();
        }
      }
    }
     while (0 <= inductionVariable);
  result = trustedStripLeadingZeroInts(Companion_getInstance_21(), result);
  return CommonBigInteger.jv(result, $this.pr_1);
}
function getLower($this, n) {
  var len = $this.qr_1.length;
  if (len <= n) {
    return $this.absoluteValue;
  }
  var lowerInts = new Int32Array(n);
  arrayCopy_0($this.qr_1, len - n | 0, lowerInts, 0, n);
  return CommonBigInteger.jv(trustedStripLeadingZeroInts(Companion_getInstance_21(), lowerInts), 1);
}
function getUpper($this, n) {
  var len = $this.qr_1.length;
  if (len <= n) {
    return Companion_getInstance_21().ZERO;
  }
  var upperLen = len - n | 0;
  var upperInts = new Int32Array(upperLen);
  arrayCopy_0($this.qr_1, 0, upperInts, 0, upperLen);
  return CommonBigInteger.jv(trustedStripLeadingZeroInts(Companion_getInstance_21(), upperInts), 1);
}
function square($this) {
  if ($this.pr_1 === 0) {
    return Companion_getInstance_21().ZERO;
  }
  var len = $this.qr_1.length;
  if (len < 128) {
    var z = squareToLen(Companion_getInstance_21(), $this.qr_1, len, null);
    return CommonBigInteger.jv(trustedStripLeadingZeroInts(Companion_getInstance_21(), z), 1);
  } else {
    var tmp;
    if (len < 216) {
      tmp = squareKaratsuba($this);
    } else {
      tmp = squareToomCook3($this);
    }
    return tmp;
  }
}
function squareKaratsuba($this) {
  var half = ($this.qr_1.length + 1 | 0) / 2 | 0;
  var xl = getLower($this, half);
  var xh = getUpper($this, half);
  var xhs = square(xh);
  var xls = square(xl);
  return xhs.shl(imul_0(half, 32)).plus(square(xl.plus(xh)).minus(xhs.plus(xls))).shl(imul_0(half, 32)).plus(xls);
}
function squareToomCook3($this) {
  var len = $this.qr_1.length;
  var k = (len + 2 | 0) / 3 | 0;
  var r = len - imul_0(2, k) | 0;
  var a0;
  var a1;
  var a2;
  a2 = getToomSlice($this, k, r, 0, len);
  a1 = getToomSlice($this, k, r, 1, len);
  a0 = getToomSlice($this, k, r, 2, len);
  var v0;
  var v1;
  var v2;
  var vm1;
  var vinf;
  var t1;
  var t2;
  var tm1;
  var da1;
  v0 = square(a0);
  da1 = a2.plus(a0);
  vm1 = square(da1.minus(a1));
  da1 = da1.plus(a1);
  v1 = square(da1);
  vinf = square(a2);
  v2 = square(da1.plus(a2).shl(1).minus(a0));
  t2 = exactDivideBy3(v2.minus(vm1));
  tm1 = v1.minus(vm1).shr(1);
  t1 = v1.minus(v0);
  t2 = t2.minus(t1).shr(1);
  t1 = t1.minus(tm1).minus(vinf);
  t2 = t2.minus(vinf.shl(1));
  tm1 = tm1.minus(t2);
  var ss = imul_0(k, 32);
  return vinf.shl(ss).plus(t2).shl(ss).plus(t1).shl(ss).plus(tm1).shl(ss).plus(v0);
}
function divideKnuth($this, other) {
  var q = MutableBigInteger.lr();
  var a = MutableBigInteger.au($this.qr_1);
  var b = MutableBigInteger.au(other.qr_1);
  a.mv(b, q, false);
  return q.gu(imul_0($this.pr_1, other.pr_1));
}
function divideAndRemainderKnuth($this, other) {
  var q = MutableBigInteger.lr();
  var a = MutableBigInteger.au($this.qr_1);
  var b = MutableBigInteger.au(other.qr_1);
  var r = a.nv(b, q);
  // Inline function 'kotlin.arrayOf' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return [q.gu($this.pr_1 === other.pr_1 ? 1 : -1), ensureNotNull(r).gu($this.pr_1)];
}
function remainderKnuth($this, other) {
  var q = MutableBigInteger.lr();
  var a = MutableBigInteger.au($this.qr_1);
  var b = MutableBigInteger.au(other.qr_1);
  return ensureNotNull(a.nv(b, q)).gu($this.pr_1);
}
function divideBurnikelZiegler($this, other) {
  return divideAndRemainderBurnikelZiegler($this, other)[0];
}
function remainderBurnikelZiegler($this, other) {
  return divideAndRemainderBurnikelZiegler($this, other)[1];
}
function divideAndRemainderBurnikelZiegler($this, other) {
  var q = MutableBigInteger.lr();
  var r = MutableBigInteger.kr($this).ov(MutableBigInteger.kr(other), q);
  var qBigInt = q.lu() ? Companion_getInstance_21().ZERO : q.gu(imul_0($this.pr_1, other.pr_1));
  var rBigInt = r.lu() ? Companion_getInstance_21().ZERO : r.gu($this.pr_1);
  // Inline function 'kotlin.arrayOf' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return [qBigInt, rBigInt];
}
function oddModPow($this, y, z) {
  if (y.equals(Companion_getInstance_21().ONE)) {
    return $this;
  }
  if ($this.pr_1 === 0) {
    return Companion_getInstance_21().ZERO;
  }
  var base = cloneArray($this.qr_1);
  var exp = y.qr_1;
  var mod = z.qr_1;
  var modLen = mod.length;
  if (!((modLen & 1) === 0)) {
    var x = new Int32Array(modLen + 1 | 0);
    arrayCopy_0(mod, 0, x, 1, modLen);
    mod = x;
    modLen = modLen + 1 | 0;
  }
  var wbits = 0;
  var ebits = bitLength(Companion_getInstance_21(), exp, exp.length);
  if (!(ebits === 17) || !(exp[0] === 65537)) {
    while (ebits > Companion_getInstance_21().us_1[wbits]) {
      wbits = wbits + 1 | 0;
    }
  }
  var tblmask = 1 << wbits;
  // Inline function 'kotlin.collections.map' call
  var this_0 = until(0, tblmask);
  // Inline function 'kotlin.collections.mapTo' call
  var destination = ArrayList.o7(collectionSizeOrDefault(this_0, 10));
  var inductionVariable = this_0.pi_1;
  var last = this_0.qi_1;
  if (inductionVariable <= last)
    do {
      var item = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      // Inline function 'com.macrofocus.common.math.big.CommonBigInteger.oddModPow.<anonymous>' call
      var tmp$ret$0 = new Int32Array(modLen);
      destination.o(tmp$ret$0);
    }
     while (!(item === last));
  // Inline function 'kotlin.collections.toTypedArray' call
  var table = copyToArray(destination);
  var n0 = toLong(mod[modLen - 1 | 0]).t3(new Long(-1, 0)).h3(toLong(mod[modLen - 2 | 0]).t3(new Long(-1, 0)).q3(32));
  var inv = Companion_getInstance_23().pv(n0).o3();
  var a = leftShift(Companion_getInstance_21(), base, base.length, modLen << 5);
  var q = MutableBigInteger.lr();
  var a2 = MutableBigInteger.au(a);
  var b2 = MutableBigInteger.au(mod);
  b2.qv();
  var r = a2.ku(b2, q);
  table[0] = ensureNotNull(r).rv();
  if (table[0].length < modLen) {
    var offset = modLen - table[0].length | 0;
    var t2 = new Int32Array(modLen);
    arrayCopy_0(table[0], 0, t2, offset, table[0].length);
    table[0] = t2;
  }
  var b = montgomerySquare(Companion_getInstance_21(), table[0], mod, modLen, inv, null);
  var t = copyOf(b, modLen);
  var inductionVariable_0 = 1;
  if (inductionVariable_0 < tblmask)
    do {
      var i = inductionVariable_0;
      inductionVariable_0 = inductionVariable_0 + 1 | 0;
      table[i] = montgomeryMultiply(Companion_getInstance_21(), t, table[i - 1 | 0], mod, modLen, inv, null);
    }
     while (inductionVariable_0 < tblmask);
  var bitpos = 1 << ((ebits - 1 | 0) & 31);
  var buf = 0;
  var elen = exp.length;
  var eIndex = 0;
  var inductionVariable_1 = 0;
  var last_0 = wbits;
  if (inductionVariable_1 <= last_0)
    do {
      var i_0 = inductionVariable_1;
      inductionVariable_1 = inductionVariable_1 + 1 | 0;
      buf = buf << 1 | (!((exp[eIndex] & bitpos) === 0) ? 1 : 0);
      bitpos = bitpos >>> 1 | 0;
      if (bitpos === 0) {
        eIndex = eIndex + 1 | 0;
        bitpos = -2147483648;
        elen = elen - 1 | 0;
      }
    }
     while (!(i_0 === last_0));
  var multpos = ebits;
  ebits = ebits - 1 | 0;
  var isone = true;
  multpos = ebits - wbits | 0;
  while ((buf & 1) === 0) {
    buf = buf >>> 1 | 0;
    multpos = multpos + 1 | 0;
  }
  var mult = table[buf >>> 1 | 0];
  buf = 0;
  if (multpos === ebits) {
    isone = false;
  }
  $l$loop: while (true) {
    ebits = ebits - 1 | 0;
    buf = buf << 1;
    if (!(elen === 0)) {
      buf = buf | (!((exp[eIndex] & bitpos) === 0) ? 1 : 0);
      bitpos = bitpos >>> 1 | 0;
      if (bitpos === 0) {
        eIndex = eIndex + 1 | 0;
        bitpos = -2147483648;
        elen = elen - 1 | 0;
      }
    }
    if (!((buf & tblmask) === 0)) {
      multpos = ebits - wbits | 0;
      while ((buf & 1) === 0) {
        buf = buf >>> 1 | 0;
        multpos = multpos + 1 | 0;
      }
      mult = table[buf >>> 1 | 0];
      buf = 0;
    }
    if (ebits === multpos) {
      if (isone) {
        b = cloneArray(mult);
        isone = false;
      } else {
        t = b;
        a = montgomeryMultiply(Companion_getInstance_21(), t, mult, mod, modLen, inv, a);
        t = a;
        a = b;
        b = t;
      }
    }
    if (ebits === 0) {
      break $l$loop;
    }
    if (!isone) {
      t = b;
      a = montgomerySquare(Companion_getInstance_21(), t, mod, modLen, inv, a);
      t = a;
      a = b;
      b = t;
    }
  }
  var t2_0 = new Int32Array(imul_0(2, modLen));
  arrayCopy_0(b, 0, t2_0, modLen, modLen);
  b = montReduce(Companion_getInstance_21(), t2_0, mod, modLen, inv.l1());
  t2_0 = copyOf(b, modLen);
  return CommonBigInteger.sv(1, t2_0);
}
function modPow2($this, exponent, p) {
  var result = Companion_getInstance_21().ONE;
  var baseToPow2 = mod2($this, p);
  var expOffset = 0;
  var limit = exponent.bitLength;
  if ($this.testBit(0)) {
    limit = (p - 1 | 0) < limit ? p - 1 | 0 : limit;
  }
  while (expOffset < limit) {
    if (exponent.testBit(expOffset)) {
      result = mod2(result.times(baseToPow2), p);
    }
    expOffset = expOffset + 1 | 0;
    if (expOffset < limit) {
      baseToPow2 = mod2(square(baseToPow2), p);
    }
  }
  return result;
}
function mod2($this, p) {
  if ($this.bitLength <= p) {
    return $this;
  }
  var numInts = (p + 31 | 0) >>> 5 | 0;
  var mag = new Int32Array(numInts);
  arrayCopy_0($this.qr_1, $this.qr_1.length - numInts | 0, mag, 0, numInts);
  var excessBits = (numInts << 5) - p | 0;
  var tmp = mag[0];
  // Inline function 'kotlin.Long.minus' call
  mag[0] = tmp & (new Long(1, 0)).q3(32 - excessBits | 0).i3(toLong(1)).l1();
  return mag[0] === 0 ? CommonBigInteger.sv(1, mag) : CommonBigInteger.jv(mag, 1);
}
function shiftRightImpl($this, n) {
  var nInts = n >>> 5 | 0;
  var nBits = n & 31;
  var magLen = $this.qr_1.length;
  var newMag = null;
  if (nInts >= magLen) {
    var tmp;
    if ($this.pr_1 >= 0) {
      tmp = Companion_getInstance_21().ZERO;
    } else {
      var tmp0_elvis_lhs = Companion_getInstance_21().qs_1[1];
      var tmp_0;
      if (tmp0_elvis_lhs == null) {
        throw IllegalStateException.lc();
      } else {
        tmp_0 = tmp0_elvis_lhs;
      }
      tmp = tmp_0;
    }
    return tmp;
  }
  if (nBits === 0) {
    var newMagLen = magLen - nInts | 0;
    newMag = copyOf($this.qr_1, newMagLen);
  } else {
    var i = 0;
    var highBits = $this.qr_1[0] >>> nBits | 0;
    if (!(highBits === 0)) {
      newMag = new Int32Array(magLen - nInts | 0);
      var tmp_1 = newMag;
      var _unary__edvuaz = i;
      i = _unary__edvuaz + 1 | 0;
      tmp_1[_unary__edvuaz] = highBits;
    } else {
      newMag = new Int32Array((magLen - nInts | 0) - 1 | 0);
    }
    var nBits2 = 32 - nBits | 0;
    var j = 0;
    while (j < ((magLen - nInts | 0) - 1 | 0)) {
      var tmp_2 = newMag;
      var _unary__edvuaz_0 = i;
      i = _unary__edvuaz_0 + 1 | 0;
      var _unary__edvuaz_1 = j;
      j = _unary__edvuaz_1 + 1 | 0;
      tmp_2[_unary__edvuaz_0] = $this.qr_1[_unary__edvuaz_1] << nBits2 | ($this.qr_1[j] >>> nBits | 0);
    }
  }
  if ($this.pr_1 < 0) {
    var onesLost = false;
    var i_0 = magLen - 1 | 0;
    var j_0 = magLen - nInts | 0;
    while (i_0 >= j_0 && !onesLost) {
      onesLost = !($this.qr_1[i_0] === 0);
      i_0 = i_0 - 1 | 0;
    }
    if (!onesLost && !(nBits === 0)) {
      onesLost = !($this.qr_1[(magLen - nInts | 0) - 1 | 0] << (32 - nBits | 0) === 0);
    }
    if (onesLost) {
      newMag = javaIncrement($this, newMag);
    }
  }
  return CommonBigInteger.jv(newMag, $this.pr_1);
}
function javaIncrement($this, other) {
  var result = other;
  var lastSum = 0;
  var i = result.length - 1 | 0;
  while (i >= 0 && lastSum === 0) {
    var _array__4zh2yp = result;
    var _index_0__fvwizt = i;
    var _unary__edvuaz = _array__4zh2yp[_index_0__fvwizt];
    _array__4zh2yp[_index_0__fvwizt] = _unary__edvuaz + 1 | 0;
    lastSum = _unary__edvuaz;
    i = i - 1 | 0;
  }
  if (lastSum === 0) {
    result = new Int32Array(result.length + 1 | 0);
    result[0] = 1;
  }
  return result;
}
function compareMagnitude_0($this, other) {
  var other_0 = other;
  // Inline function 'kotlin.require' call
  // Inline function 'kotlin.require' call
  if (!!other_0.equals(new Long(0, -2147483648))) {
    // Inline function 'kotlin.require.<anonymous>' call
    var message = 'Failed requirement.';
    throw IllegalArgumentException.h(toString_1(message));
  }
  var m1 = $this.qr_1;
  var len = m1.length;
  if (len > 2) {
    return 1;
  }
  if (other_0.m1(new Long(0, 0)) < 0) {
    other_0 = other_0.o3();
  }
  var highWord = other_0.s3(32).l1();
  if (highWord === 0) {
    if (len < 1) {
      return -1;
    }
    if (len > 1) {
      return 1;
    }
    var a = m1[0];
    var b = other_0.l1();
    var tmp;
    if (!(a === b)) {
      tmp = toLong(a).t3(new Long(-1, 0)).m1(toLong(b).t3(new Long(-1, 0))) < 0 ? -1 : 1;
    } else {
      tmp = 0;
    }
    return tmp;
  } else {
    if (len < 2) {
      return -1;
    }
    var a_0 = m1[0];
    var b_0 = highWord;
    if (!(a_0 === b_0)) {
      return toLong(a_0).t3(new Long(-1, 0)).m1(toLong(b_0).t3(new Long(-1, 0))) < 0 ? -1 : 1;
    }
    a_0 = m1[1];
    b_0 = other_0.l1();
    var tmp_0;
    if (!(a_0 === b_0)) {
      tmp_0 = toLong(a_0).t3(new Long(-1, 0)).m1(toLong(b_0).t3(new Long(-1, 0))) < 0 ? -1 : 1;
    } else {
      tmp_0 = 0;
    }
    return tmp_0;
  }
}
function smallToString($this, radix) {
  if ($this.pr_1 === 0) {
    return '0';
  }
  var maxNumDigitGroups = (imul_0(4, $this.qr_1.length) + 6 | 0) / 7 | 0;
  // Inline function 'kotlin.arrayOfNulls' call
  var digitGroup = fillArrayVal(Array(maxNumDigitGroups), null);
  var tmp = $this.absoluteValue;
  var numGroups = 0;
  while (!(tmp.pr_1 === 0)) {
    var d = Companion_getInstance_21().xs_1[radix];
    var q = MutableBigInteger.lr();
    var a = MutableBigInteger.au(tmp.qr_1);
    var b = MutableBigInteger.au(ensureNotNull(d).qr_1);
    var r = a.ku(b, q);
    var q2 = q.gu(imul_0(tmp.pr_1, d.pr_1));
    var r2 = ensureNotNull(r).gu(imul_0(tmp.pr_1, d.pr_1));
    var _unary__edvuaz = numGroups;
    numGroups = _unary__edvuaz + 1 | 0;
    digitGroup[_unary__edvuaz] = toString_2(r2.toLong(), radix);
    tmp = q2;
  }
  var buf = StringBuilder.pb(imul_0(numGroups, Companion_getInstance_21().ws_1[radix]) + 1 | 0);
  if ($this.pr_1 < 0) {
    buf.mb(_Char___init__impl__6a9atx(45));
  }
  buf.lb(digitGroup[numGroups - 1 | 0]);
  var inductionVariable = numGroups - 2 | 0;
  if (0 <= inductionVariable)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + -1 | 0;
      var numLeadingZeros = Companion_getInstance_21().ws_1[radix] - ensureNotNull(digitGroup[i]).length | 0;
      if (!(numLeadingZeros === 0)) {
        buf.lb(Companion_getInstance_21().vs_1[numLeadingZeros]);
      }
      buf.lb(digitGroup[i]);
    }
     while (0 <= inductionVariable);
  return buf.toString();
}
function _get_intLength__55caik($this) {
  return ($this.bitLength >>> 5 | 0) + 1 | 0;
}
function _get_signInt__uq6bvl($this) {
  return $this.pr_1 < 0 ? -1 : 0;
}
function getInt($this, n) {
  if (n < 0) {
    return 0;
  }
  if (n >= $this.qr_1.length) {
    return _get_signInt__uq6bvl($this);
  }
  var magInt = $this.qr_1[($this.qr_1.length - n | 0) - 1 | 0];
  var tmp;
  if ($this.pr_1 >= 0) {
    tmp = magInt;
  } else {
    tmp = n <= firstNonzeroIntNum($this) ? -magInt | 0 : ~magInt;
  }
  return tmp;
}
function firstNonzeroIntNum($this) {
  var fn = $this.ur_1 - 2 | 0;
  if (fn === -2) {
    var i;
    var mlen = $this.qr_1.length;
    i = mlen - 1 | 0;
    while (i >= 0 && $this.qr_1[i] === 0) {
      i = i - 1 | 0;
    }
    fn = (mlen - i | 0) - 1 | 0;
    $this.ur_1 = fn + 2 | 0;
  }
  return fn;
}
var Companion_instance_21;
function Companion_getInstance_21() {
  if (Companion_instance_21 === VOID)
    new Companion_21();
  return Companion_instance_21;
}
function init_com_macrofocus_common_math_big_CommonBigInteger(_this__u8e3s4) {
  Companion_getInstance_21();
  _this__u8e3s4.rr_1 = 0;
  _this__u8e3s4.sr_1 = 0;
  _this__u8e3s4.tr_1 = 0;
  _this__u8e3s4.ur_1 = 0;
}
var Companion_instance_22;
function Companion_getInstance_22() {
  if (Companion_instance_22 === VOID)
    new Companion_22();
  return Companion_instance_22;
}
function copyAndShift($this, src, srcFrom, srcLen, dst, dstFrom, shift) {
  var srcFrom_0 = srcFrom;
  var n2 = 32 - shift | 0;
  var c = src[srcFrom_0];
  var inductionVariable = 0;
  var last = srcLen - 1 | 0;
  if (inductionVariable < last)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      var b = c;
      srcFrom_0 = srcFrom_0 + 1 | 0;
      c = src[srcFrom_0];
      dst[dstFrom + i | 0] = b << shift | (c >>> n2 | 0);
    }
     while (inductionVariable < last);
  dst[(dstFrom + srcLen | 0) - 1 | 0] = c << shift;
}
function _get_magnitudeArray__ns4ohu($this) {
  return $this.jr_1 > 0 || !($this.hr_1.length === $this.ir_1) ? copyOfRange($this.hr_1, $this.jr_1, $this.jr_1 + $this.ir_1 | 0) : $this.hr_1;
}
function _get_lowestSetBit__xjmtq_0($this) {
  if ($this.ir_1 === 0) {
    return -1;
  }
  var j;
  var b;
  j = $this.ir_1 - 1 | 0;
  while (j > 0 && $this.hr_1[j + $this.jr_1 | 0] === 0) {
    j = j - 1 | 0;
  }
  b = $this.hr_1[j + $this.jr_1 | 0];
  return b === 0 ? -1 : ((($this.ir_1 - 1 | 0) - j | 0) << 5) + numberOfTrailingZeros(b) | 0;
}
function ones($this, n) {
  if (n > $this.hr_1.length) {
    $this.hr_1 = new Int32Array(n);
  }
  fill_0($this.hr_1, -1);
  $this.jr_1 = 0;
  $this.ir_1 = n;
}
function toLong_0($this) {
  // Inline function 'kotlin.require' call
  if (!($this.ir_1 <= 2)) {
    // Inline function 'com.macrofocus.common.math.big.MutableBigInteger.toLong.<anonymous>' call
    var message = 'this MutableBigInteger exceeds the range of long';
    throw IllegalArgumentException.h(toString_1(message));
  }
  if ($this.ir_1 === 0) {
    return new Long(0, 0);
  }
  var d = toLong($this.hr_1[$this.jr_1]).t3(new Long(-1, 0));
  return $this.ir_1 === 2 ? d.q3(32).u3(toLong($this.hr_1[$this.jr_1 + 1 | 0]).t3(new Long(-1, 0))) : d;
}
function compareShifted($this, b, ints) {
  var blen = b.ir_1;
  var alen = $this.ir_1 - ints | 0;
  if (alen < blen) {
    return -1;
  }
  if (alen > blen) {
    return 1;
  }
  var bval = b.hr_1;
  var i = $this.jr_1;
  var j = b.jr_1;
  while (i < (alen + $this.jr_1 | 0)) {
    var b1 = $this.hr_1[i] + -2147483648 | 0;
    var b2 = bval[j] + -2147483648 | 0;
    if (b1 < b2) {
      return -1;
    }
    if (b1 > b2) {
      return 1;
    }
    i = i + 1 | 0;
    j = j + 1 | 0;
  }
  return 0;
}
function divadd($this, a, result, offset) {
  var carry = new Long(0, 0);
  var inductionVariable = a.length - 1 | 0;
  if (0 <= inductionVariable)
    do {
      var j = inductionVariable;
      inductionVariable = inductionVariable + -1 | 0;
      var sum = toLong(a[j]).t3(new Long(-1, 0)).h3(toLong(result[j + offset | 0]).t3(new Long(-1, 0))).h3(carry);
      result[j + offset | 0] = sum.l1();
      carry = sum.s3(32);
    }
     while (0 <= inductionVariable);
  return carry.l1();
}
function mulsub_0($this, q, a, x, len, offset) {
  var offset_0 = offset;
  var xLong = toLong(x).t3(new Long(-1, 0));
  var carry = new Long(0, 0);
  offset_0 = offset_0 + len | 0;
  var inductionVariable = len - 1 | 0;
  if (0 <= inductionVariable)
    do {
      var j = inductionVariable;
      inductionVariable = inductionVariable + -1 | 0;
      var product = toLong(a[j]).t3(new Long(-1, 0)).j3(xLong).h3(carry);
      var difference = numberToLong(q[offset_0]).i3(product);
      var _unary__edvuaz = offset_0;
      offset_0 = _unary__edvuaz - 1 | 0;
      q[_unary__edvuaz] = difference.l1();
      var tmp0 = product.s3(32);
      var tmp;
      if (difference.t3(new Long(-1, 0)).m1(toLong(~product.l1()).t3(new Long(-1, 0))) > 0) {
        tmp = 1;
      } else {
        tmp = 0;
      }
      // Inline function 'kotlin.Long.plus' call
      var other = tmp;
      carry = tmp0.h3(toLong(other));
    }
     while (0 <= inductionVariable);
  return carry.l1();
}
function mulsubBorrow($this, q, a, x, len, offset) {
  var offset_0 = offset;
  var xLong = toLong(x).t3(new Long(-1, 0));
  var carry = new Long(0, 0);
  offset_0 = offset_0 + len | 0;
  var inductionVariable = len - 1 | 0;
  if (0 <= inductionVariable)
    do {
      var j = inductionVariable;
      inductionVariable = inductionVariable + -1 | 0;
      var product = toLong(a[j]).t3(new Long(-1, 0)).j3(xLong).h3(carry);
      var _unary__edvuaz = offset_0;
      offset_0 = _unary__edvuaz - 1 | 0;
      var difference = numberToLong(q[_unary__edvuaz]).i3(product);
      var tmp0 = product.s3(32);
      var tmp;
      if (difference.t3(new Long(-1, 0)).m1(toLong(~product.l1()).t3(new Long(-1, 0))) > 0) {
        tmp = 1;
      } else {
        tmp = 0;
      }
      // Inline function 'kotlin.Long.plus' call
      var other = tmp;
      carry = tmp0.h3(toLong(other));
    }
     while (0 <= inductionVariable);
  return carry.l1();
}
function primitiveRightShift_0($this, n) {
  var val = $this.hr_1;
  var n2 = 32 - n | 0;
  var i = ($this.jr_1 + $this.ir_1 | 0) - 1 | 0;
  var c = val[i];
  while (i > $this.jr_1) {
    var b = c;
    c = val[i - 1 | 0];
    val[i] = c << n2 | (b >>> n | 0);
    i = i - 1 | 0;
  }
  val[$this.jr_1] = val[$this.jr_1] >>> n | 0;
}
function primitiveLeftShift_0($this, n) {
  var val = $this.hr_1;
  var n2 = 32 - n | 0;
  var i = $this.jr_1;
  var c = val[i];
  var m = (i + $this.ir_1 | 0) - 1 | 0;
  while (i < m) {
    var b = c;
    c = val[i + 1 | 0];
    val[i] = b << n | (c >>> n2 | 0);
    i = i + 1 | 0;
  }
  val[($this.jr_1 + $this.ir_1 | 0) - 1 | 0] = val[($this.jr_1 + $this.ir_1 | 0) - 1 | 0] << n;
}
function getLower_0($this, n) {
  if ($this.lu()) {
    return Companion_getInstance_21().ZERO;
  } else if ($this.ir_1 < n) {
    return $this.gu(1);
  } else {
    var len = n;
    while (len > 0 && $this.hr_1[($this.jr_1 + $this.ir_1 | 0) - len | 0] === 0) {
      len = len - 1 | 0;
    }
    var sign = len > 0 ? 1 : 0;
    return CommonBigInteger.jv(copyOfRange($this.hr_1, ($this.jr_1 + $this.ir_1 | 0) - len | 0, $this.jr_1 + $this.ir_1 | 0), sign);
  }
}
function keepLower($this, n) {
  if ($this.ir_1 >= n) {
    $this.jr_1 = $this.jr_1 + ($this.ir_1 - n | 0) | 0;
    $this.ir_1 = n;
  }
}
function difference($this, b) {
  var b_0 = b;
  var a = $this;
  var sign = a.iw(b_0);
  if (sign === 0) {
    return 0;
  }
  if (sign < 0) {
    var tmp = a;
    a = b_0;
    b_0 = tmp;
  }
  var diff = new Long(0, 0);
  var x = a.ir_1;
  var y = b_0.ir_1;
  while (y > 0) {
    x = x - 1 | 0;
    y = y - 1 | 0;
    diff = toLong(a.hr_1[a.jr_1 + x | 0]).t3(new Long(-1, 0)).i3(toLong(b_0.hr_1[b_0.jr_1 + y | 0]).t3(new Long(-1, 0))).i3(toLong(diff.r3(32).o3().l1()));
    a.hr_1[a.jr_1 + x | 0] = diff.l1();
  }
  while (x > 0) {
    x = x - 1 | 0;
    var tmp0 = toLong(a.hr_1[a.jr_1 + x | 0]).t3(new Long(-1, 0));
    // Inline function 'kotlin.Long.minus' call
    var other = diff.r3(32).o3().l1();
    diff = tmp0.i3(toLong(other));
    a.hr_1[a.jr_1 + x | 0] = diff.l1();
  }
  a.qv();
  return sign;
}
function divide2n1n($this, b, quotient) {
  var n = b.ir_1;
  if (!((n % 2 | 0) === 0) || n < 80) {
    return $this.nv(b, quotient);
  }
  var aUpper = MutableBigInteger.jw($this);
  aUpper.kw(imul_0(32, n / 2 | 0));
  keepLower($this, n / 2 | 0);
  var q1 = MutableBigInteger.lr();
  var r1 = divide3n2n(aUpper, b, q1);
  $this.lw(r1, n / 2 | 0);
  var r2 = divide3n2n($this, b, quotient);
  quotient.lw(q1, n / 2 | 0);
  return r2;
}
function divide3n2n($this, b, quotient) {
  var n = b.ir_1 / 2 | 0;
  var a12 = MutableBigInteger.jw($this);
  a12.kw(imul_0(32, n));
  var b1 = MutableBigInteger.jw(b);
  b1.kw(imul_0(n, 32));
  var b2 = getLower_0(b, n);
  var r;
  var d;
  if (compareShifted($this, b, n) < 0) {
    r = divide2n1n(a12, b1, quotient);
    d = MutableBigInteger.kr(quotient.yv().times(b2));
  } else {
    ones(quotient, n);
    a12.fu(b1);
    b1.mw(imul_0(32, n));
    a12.nw(b1);
    r = a12;
    d = MutableBigInteger.kr(b2);
    d.mw(imul_0(32, n));
    d.nw(MutableBigInteger.kr(b2));
  }
  ensureNotNull(r).mw(imul_0(32, n));
  r.ow($this, n);
  while (r.iw(d) < 0) {
    r.fu(b);
    quotient.nw(Companion_getInstance_23().cu_1);
  }
  r.nw(d);
  return r;
}
function getBlock($this, index, numBlocks, blockLength) {
  var blockStart = imul_0(index, blockLength);
  if (blockStart >= $this.ir_1) {
    return MutableBigInteger.lr();
  }
  var blockEnd;
  if (index === (numBlocks - 1 | 0)) {
    blockEnd = $this.ir_1;
  } else {
    blockEnd = imul_0(index + 1 | 0, blockLength);
  }
  if (blockEnd > $this.ir_1) {
    return MutableBigInteger.lr();
  }
  var newVal = copyOfRange($this.hr_1, ($this.jr_1 + $this.ir_1 | 0) - blockEnd | 0, ($this.jr_1 + $this.ir_1 | 0) - blockStart | 0);
  return MutableBigInteger.au(newVal);
}
function divideMagnitude($this, div, quotient, needRemainder) {
  var shift = numberOfLeadingZeros(div.hr_1[div.jr_1]);
  var dlen = div.ir_1;
  var divisor;
  var rem;
  if (shift > 0) {
    divisor = new Int32Array(dlen);
    copyAndShift(Companion_getInstance_23(), div.hr_1, div.jr_1, dlen, divisor, 0, shift);
    if (numberOfLeadingZeros($this.hr_1[$this.jr_1]) >= shift) {
      var remarr = new Int32Array($this.ir_1 + 1 | 0);
      rem = MutableBigInteger.au(remarr);
      rem.ir_1 = $this.ir_1;
      rem.jr_1 = 1;
      copyAndShift(Companion_getInstance_23(), $this.hr_1, $this.jr_1, $this.ir_1, remarr, 1, shift);
    } else {
      var remarr_0 = new Int32Array($this.ir_1 + 2 | 0);
      rem = MutableBigInteger.au(remarr_0);
      rem.ir_1 = $this.ir_1 + 1 | 0;
      rem.jr_1 = 1;
      var rFrom = $this.jr_1;
      var c = 0;
      var n2 = 32 - shift | 0;
      var i = 1;
      while (i < ($this.ir_1 + 1 | 0)) {
        var b = c;
        c = $this.hr_1[rFrom];
        remarr_0[i] = b << shift | (c >>> n2 | 0);
        i = i + 1 | 0;
        rFrom = rFrom + 1 | 0;
      }
      remarr_0[$this.ir_1 + 1 | 0] = c << shift;
    }
  } else {
    divisor = copyOfRange(div.hr_1, div.jr_1, div.jr_1 + div.ir_1 | 0);
    rem = MutableBigInteger.au(new Int32Array($this.ir_1 + 1 | 0));
    arrayCopy_0($this.hr_1, $this.jr_1, rem.hr_1, 1, $this.ir_1);
    rem.ir_1 = $this.ir_1;
    rem.jr_1 = 1;
  }
  var nlen = rem.ir_1;
  var limit = (nlen - dlen | 0) + 1 | 0;
  if (quotient.hr_1.length < limit) {
    quotient.hr_1 = new Int32Array(limit);
    quotient.jr_1 = 0;
  }
  quotient.ir_1 = limit;
  var q = quotient.hr_1;
  if (rem.ir_1 === nlen) {
    rem.jr_1 = 0;
    rem.hr_1[0] = 0;
    var _receiver__tnumb7 = rem;
    _receiver__tnumb7.ir_1 = _receiver__tnumb7.ir_1 + 1 | 0;
  }
  var dh = divisor[0];
  var dhLong = toLong(dh).t3(new Long(-1, 0));
  var dl = divisor[1];
  var inductionVariable = 0;
  var last = limit - 1 | 0;
  if (inductionVariable < last)
    $l$loop: do {
      var j = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      var qhat = 0;
      var qrem = 0;
      var skipCorrection = false;
      var nh = rem.hr_1[j + rem.jr_1 | 0];
      var nh2 = nh + -2147483648 | 0;
      var nm = rem.hr_1[(j + 1 | 0) + rem.jr_1 | 0];
      if (nh === dh) {
        qhat = -1;
        qrem = nh + nm | 0;
        skipCorrection = (qrem + -2147483648 | 0) < nh2;
      } else {
        var nChunk = toLong(nh).q3(32).u3(toLong(nm).y3().t3(new Long(-1, 0)));
        if (nChunk.m1(new Long(0, 0)) >= 0) {
          qhat = nChunk.k3(dhLong).l1();
          qrem = nChunk.i3(numberToLong(qhat).j3(dhLong)).l1();
        } else {
          var tmp = Companion_getInstance_23().pw(nChunk, dh);
          qhat = tmp.y3().t3(new Long(-1, 0)).l1();
          qrem = tmp.s3(32).l1();
        }
      }
      if (qhat === 0) {
        continue $l$loop;
      }
      if (!skipCorrection) {
        var nl = toLong(rem.hr_1[(j + 2 | 0) + rem.jr_1 | 0]).t3(new Long(-1, 0));
        var rs = toLong(qrem).t3(new Long(-1, 0)).q3(32).u3(nl);
        var estProduct = toLong(dl).t3(new Long(-1, 0)).j3(toLong(qhat).t3(new Long(-1, 0)));
        if (unsignedLongCompare_0($this, estProduct, rs)) {
          qhat = qhat - 1 | 0;
          qrem = toLong(qrem).t3(new Long(-1, 0)).h3(dhLong).l1();
          if (toLong(qrem).t3(new Long(-1, 0)).m1(dhLong) >= 0) {
            estProduct = estProduct.i3(toLong(dl).t3(new Long(-1, 0)));
            rs = toLong(qrem).t3(new Long(-1, 0)).q3(32).u3(nl);
            if (unsignedLongCompare_0($this, estProduct, rs)) {
              qhat = qhat - 1 | 0;
            }
          }
        }
      }
      rem.hr_1[j + rem.jr_1 | 0] = 0;
      var borrow = mulsub_0($this, rem.hr_1, divisor, qhat, dlen, j + rem.jr_1 | 0);
      if ((borrow + -2147483648 | 0) > nh2) {
        divadd($this, divisor, rem.hr_1, (j + 1 | 0) + rem.jr_1 | 0);
        qhat = qhat - 1 | 0;
      }
      q[j] = qhat;
    }
     while (inductionVariable < last);
  var qhat_0 = 0;
  var qrem_0 = 0;
  var skipCorrection_0 = false;
  var nh_0 = rem.hr_1[(limit - 1 | 0) + rem.jr_1 | 0];
  var nh2_0 = nh_0 + -2147483648 | 0;
  var nm_0 = rem.hr_1[limit + rem.jr_1 | 0];
  if (nh_0 === dh) {
    qhat_0 = -1;
    qrem_0 = nh_0 + nm_0 | 0;
    skipCorrection_0 = (qrem_0 + -2147483648 | 0) < nh2_0;
  } else {
    var nChunk_0 = toLong(nh_0).q3(32).u3(toLong(nm_0).t3(new Long(-1, 0)));
    if (nChunk_0.m1(new Long(0, 0)) >= 0) {
      qhat_0 = nChunk_0.k3(dhLong).l1();
      qrem_0 = nChunk_0.i3(numberToLong(qhat_0).j3(dhLong)).l1();
    } else {
      var tmp_0 = Companion_getInstance_23().pw(nChunk_0, dh);
      qhat_0 = tmp_0.t3(new Long(-1, 0)).l1();
      qrem_0 = tmp_0.s3(32).l1();
    }
  }
  if (!(qhat_0 === 0)) {
    if (!skipCorrection_0) {
      var nl_0 = toLong(rem.hr_1[(limit + 1 | 0) + rem.jr_1 | 0]).t3(new Long(-1, 0));
      var rs_0 = toLong(qrem_0).t3(new Long(-1, 0)).q3(32).u3(nl_0);
      var estProduct_0 = toLong(dl).t3(new Long(-1, 0)).j3(toLong(qhat_0).t3(new Long(-1, 0)));
      if (unsignedLongCompare_0($this, estProduct_0, rs_0)) {
        qhat_0 = qhat_0 - 1 | 0;
        qrem_0 = toLong(qrem_0).t3(new Long(-1, 0)).h3(dhLong).l1();
        if (toLong(qrem_0).t3(new Long(-1, 0)).m1(dhLong) >= 0) {
          estProduct_0 = estProduct_0.i3(toLong(dl).t3(new Long(-1, 0)));
          rs_0 = toLong(qrem_0).t3(new Long(-1, 0)).q3(32).u3(nl_0);
          if (unsignedLongCompare_0($this, estProduct_0, rs_0)) {
            qhat_0 = qhat_0 - 1 | 0;
          }
        }
      }
    }
    var borrow_0;
    rem.hr_1[(limit - 1 | 0) + rem.jr_1 | 0] = 0;
    if (needRemainder) {
      borrow_0 = mulsub_0($this, rem.hr_1, divisor, qhat_0, dlen, (limit - 1 | 0) + rem.jr_1 | 0);
    } else {
      borrow_0 = mulsubBorrow($this, rem.hr_1, divisor, qhat_0, dlen, (limit - 1 | 0) + rem.jr_1 | 0);
    }
    if ((borrow_0 + -2147483648 | 0) > nh2_0) {
      if (needRemainder) {
        divadd($this, divisor, rem.hr_1, ((limit - 1 | 0) + 1 | 0) + rem.jr_1 | 0);
      }
      qhat_0 = qhat_0 - 1 | 0;
    }
    q[limit - 1 | 0] = qhat_0;
  }
  if (needRemainder) {
    if (shift > 0) {
      rem.qw(shift);
    }
    rem.qv();
  }
  quotient.qv();
  return needRemainder ? rem : null;
}
function divideLongMagnitude($this, ldivisor, quotient) {
  var ldivisor_0 = ldivisor;
  var rem = MutableBigInteger.au(new Int32Array($this.ir_1 + 1 | 0));
  arrayCopy_0($this.hr_1, $this.jr_1, rem.hr_1, 1, $this.ir_1);
  rem.ir_1 = $this.ir_1;
  rem.jr_1 = 1;
  var nlen = rem.ir_1;
  var limit = (nlen - 2 | 0) + 1 | 0;
  if (quotient.hr_1.length < limit) {
    quotient.hr_1 = new Int32Array(limit);
    quotient.jr_1 = 0;
  }
  quotient.ir_1 = limit;
  var q = quotient.hr_1;
  var shift = numberOfLeadingZeros_0(ldivisor_0);
  if (shift > 0) {
    ldivisor_0 = ldivisor_0.q3(shift);
    rem.mw(shift);
  }
  if (rem.ir_1 === nlen) {
    rem.jr_1 = 0;
    rem.hr_1[0] = 0;
    rem.ir_1 = rem.ir_1 + 1 | 0;
  }
  var dh = ldivisor_0.s3(32).l1();
  var dhLong = toLong(dh).t3(new Long(-1, 0));
  var dl = ldivisor_0.y3().t3(new Long(-1, 0)).l1();
  var inductionVariable = 0;
  if (inductionVariable < limit)
    $l$loop: do {
      var j = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      var qhat = 0;
      var qrem = 0;
      var skipCorrection = false;
      var nh = rem.hr_1[j + rem.jr_1 | 0];
      var nh2 = nh + -2147483648 | 0;
      var nm = rem.hr_1[(j + 1 | 0) + rem.jr_1 | 0];
      if (nh === dh) {
        qhat = -1;
        qrem = nh + nm | 0;
        skipCorrection = (qrem + -2147483648 | 0) < nh2;
      } else {
        var nChunk = toLong(nh).q3(32).u3(toLong(nm).t3(new Long(-1, 0)));
        if (nChunk.m1(new Long(0, 0)) >= 0) {
          qhat = nChunk.k3(dhLong).l1();
          qrem = nChunk.i3(numberToLong(qhat).j3(dhLong)).l1();
        } else {
          var tmp = Companion_getInstance_23().pw(nChunk, dh);
          qhat = tmp.y3().t3(new Long(-1, 0)).l1();
          qrem = tmp.s3(32).l1();
        }
      }
      if (qhat === 0) {
        continue $l$loop;
      }
      if (!skipCorrection) {
        var nl = toLong(rem.hr_1[(j + 2 | 0) + rem.jr_1 | 0]).t3(new Long(-1, 0));
        var rs = toLong(qrem).t3(new Long(-1, 0)).q3(32).u3(nl);
        var estProduct = toLong(dl).t3(new Long(-1, 0)).j3(toLong(qhat).t3(new Long(-1, 0)));
        if (unsignedLongCompare_0($this, estProduct, rs)) {
          qhat = qhat - 1 | 0;
          qrem = toLong(qrem).t3(new Long(-1, 0)).h3(dhLong).l1();
          if (toLong(qrem).t3(new Long(-1, 0)).m1(dhLong) >= 0) {
            estProduct = estProduct.i3(toLong(dl).t3(new Long(-1, 0)));
            rs = toLong(qrem).t3(new Long(-1, 0)).q3(32).u3(nl);
            if (unsignedLongCompare_0($this, estProduct, rs)) {
              qhat = qhat - 1 | 0;
            }
          }
        }
      }
      rem.hr_1[j + rem.jr_1 | 0] = 0;
      var borrow = mulsubLong($this, rem.hr_1, dh, dl, qhat, j + rem.jr_1 | 0);
      if ((borrow + -2147483648 | 0) > nh2) {
        divaddLong($this, dh, dl, rem.hr_1, (j + 1 | 0) + rem.jr_1 | 0);
        qhat = qhat - 1 | 0;
      }
      q[j] = qhat;
    }
     while (inductionVariable < limit);
  if (shift > 0) {
    rem.qw(shift);
  }
  quotient.qv();
  rem.qv();
  return rem;
}
function divaddLong($this, dh, dl, result, offset) {
  var carry = new Long(0, 0);
  var sum = toLong(dl).t3(new Long(-1, 0)).h3(toLong(result[1 + offset | 0]).t3(new Long(-1, 0)));
  result[1 + offset | 0] = sum.l1();
  sum = toLong(dh).t3(new Long(-1, 0)).h3(toLong(result[offset]).t3(new Long(-1, 0))).h3(carry);
  result[offset] = sum.l1();
  carry = sum.s3(32);
  return carry.l1();
}
function mulsubLong($this, q, dh, dl, x, offset) {
  var offset_0 = offset;
  var xLong = toLong(x).t3(new Long(-1, 0));
  offset_0 = offset_0 + 2 | 0;
  var product = toLong(dl).t3(new Long(-1, 0)).j3(xLong);
  var difference = numberToLong(q[offset_0]).i3(product);
  var _unary__edvuaz = offset_0;
  offset_0 = _unary__edvuaz - 1 | 0;
  q[_unary__edvuaz] = difference.l1();
  var tmp0 = product.s3(32);
  var tmp;
  if (difference.y3().t3(new Long(-1, 0)).m1(product.p3().y3().t3(new Long(-1, 0))) > 0) {
    tmp = 1;
  } else {
    tmp = 0;
  }
  // Inline function 'kotlin.Long.plus' call
  var other = tmp;
  var carry = tmp0.h3(toLong(other));
  product = toLong(dh).t3(new Long(-1, 0)).j3(xLong).h3(carry);
  difference = numberToLong(q[offset_0]).i3(product);
  var _unary__edvuaz_0 = offset_0;
  offset_0 = _unary__edvuaz_0 - 1 | 0;
  q[_unary__edvuaz_0] = difference.l1();
  var tmp2 = product.s3(32);
  var tmp_0;
  if (difference.y3().t3(new Long(-1, 0)).m1(product.p3().y3().t3(new Long(-1, 0))) > 0) {
    tmp_0 = 1;
  } else {
    tmp_0 = 0;
  }
  // Inline function 'kotlin.Long.plus' call
  var other_0 = tmp_0;
  carry = tmp2.h3(toLong(other_0));
  return carry.l1();
}
function unsignedLongCompare_0($this, one, two) {
  return one.h3(new Long(0, -2147483648)).m1(two.h3(new Long(0, -2147483648))) > 0;
}
function binaryGCD($this, v) {
  var v_0 = v;
  var u = $this;
  var r = MutableBigInteger.lr();
  var s1 = _get_lowestSetBit__xjmtq_0(u);
  var s2 = _get_lowestSetBit__xjmtq_0(v_0);
  var k = s1 < s2 ? s1 : s2;
  if (!(k === 0)) {
    u.qw(k);
    v_0.qw(k);
  }
  var uOdd = k === s1;
  var t = uOdd ? v_0 : u;
  var tsign = uOdd ? -1 : 1;
  var lb = _get_lowestSetBit__xjmtq_0(t);
  $l$loop: while (lb >= 0) {
    t.qw(lb);
    if (tsign > 0) {
      u = t;
    } else {
      v_0 = t;
    }
    if (u.ir_1 < 2 && v_0.ir_1 < 2) {
      var x = u.hr_1[u.jr_1];
      var y = v_0.hr_1[v_0.jr_1];
      x = Companion_getInstance_23().rw(x, y);
      r.hr_1[0] = x;
      r.ir_1 = 1;
      r.jr_1 = 0;
      if (k > 0) {
        r.mw(k);
      }
      return r;
    }
    tsign = difference(u, v_0);
    if (tsign === 0) {
      lb = _get_lowestSetBit__xjmtq_0(t);
      break $l$loop;
    }
    t = tsign >= 0 ? u : v_0;
    lb = _get_lowestSetBit__xjmtq_0(t);
  }
  if (k > 0) {
    u.mw(k);
  }
  return u;
}
function modInverse($this, mod) {
  var p = MutableBigInteger.jw(mod);
  var f = MutableBigInteger.jw($this);
  var g = MutableBigInteger.jw(p);
  var c = SignedMutableBigInteger.ww(1);
  var d = SignedMutableBigInteger.xw();
  var temp;
  var sTemp;
  var k = 0;
  if (f.yw()) {
    var trailingZeros = _get_lowestSetBit__xjmtq_0(f);
    f.qw(trailingZeros);
    d.mw(trailingZeros);
    k = trailingZeros;
  }
  while (!f.zw()) {
    if (f.lu()) {
      throw ArithmeticException.md('BigInteger not invertible.');
    }
    if (f.iw(g) < 0) {
      temp = f;
      f = g;
      g = temp;
      sTemp = d;
      d = c;
      c = sTemp;
    }
    if (((f.hr_1[(f.jr_1 + f.ir_1 | 0) - 1 | 0] ^ g.hr_1[(g.jr_1 + g.ir_1 | 0) - 1 | 0]) & 3) === 0) {
      f.nw(g);
      c.bx(d);
    } else {
      f.fu(g);
      c.ax(d);
    }
    var trailingZeros_0 = _get_lowestSetBit__xjmtq_0(f);
    f.qw(trailingZeros_0);
    d.mw(trailingZeros_0);
    k = k + trailingZeros_0 | 0;
  }
  while (c.vw_1 < 0)
    c.cx(p);
  return Companion_getInstance_23().dx(c, p, k);
}
var Companion_instance_23;
function Companion_getInstance_23() {
  if (Companion_instance_23 === VOID)
    new Companion_23();
  return Companion_instance_23;
}
function init_com_macrofocus_common_math_big_MutableBigInteger(_this__u8e3s4) {
  Companion_getInstance_23();
  _this__u8e3s4.ir_1 = 0;
  _this__u8e3s4.jr_1 = 0;
}
var RoundingMode_UP_instance;
var RoundingMode_DOWN_instance;
var RoundingMode_CEILING_instance;
var RoundingMode_FLOOR_instance;
var RoundingMode_HALF_UP_instance;
var RoundingMode_HALF_DOWN_instance;
var RoundingMode_HALF_EVEN_instance;
var RoundingMode_UNNECESSARY_instance;
var Companion_instance_24;
function Companion_getInstance_24() {
  return Companion_instance_24;
}
function values() {
  return [RoundingMode_UP_getInstance(), RoundingMode_DOWN_getInstance(), RoundingMode_CEILING_getInstance(), RoundingMode_FLOOR_getInstance(), RoundingMode_HALF_UP_getInstance(), RoundingMode_HALF_DOWN_getInstance(), RoundingMode_HALF_EVEN_getInstance(), RoundingMode_UNNECESSARY_getInstance()];
}
function valueOf(value) {
  switch (value) {
    case 'UP':
      return RoundingMode_UP_getInstance();
    case 'DOWN':
      return RoundingMode_DOWN_getInstance();
    case 'CEILING':
      return RoundingMode_CEILING_getInstance();
    case 'FLOOR':
      return RoundingMode_FLOOR_getInstance();
    case 'HALF_UP':
      return RoundingMode_HALF_UP_getInstance();
    case 'HALF_DOWN':
      return RoundingMode_HALF_DOWN_getInstance();
    case 'HALF_EVEN':
      return RoundingMode_HALF_EVEN_getInstance();
    case 'UNNECESSARY':
      return RoundingMode_UNNECESSARY_getInstance();
    default:
      RoundingMode_initEntries();
      THROW_IAE('No enum constant value.');
      break;
  }
}
var RoundingMode_entriesInitialized;
function RoundingMode_initEntries() {
  if (RoundingMode_entriesInitialized)
    return Unit_instance;
  RoundingMode_entriesInitialized = true;
  RoundingMode_UP_instance = new RoundingMode('UP', 0, 0);
  RoundingMode_DOWN_instance = new RoundingMode('DOWN', 1, 1);
  RoundingMode_CEILING_instance = new RoundingMode('CEILING', 2, 2);
  RoundingMode_FLOOR_instance = new RoundingMode('FLOOR', 3, 3);
  RoundingMode_HALF_UP_instance = new RoundingMode('HALF_UP', 4, 4);
  RoundingMode_HALF_DOWN_instance = new RoundingMode('HALF_DOWN', 5, 5);
  RoundingMode_HALF_EVEN_instance = new RoundingMode('HALF_EVEN', 6, 6);
  RoundingMode_UNNECESSARY_instance = new RoundingMode('UNNECESSARY', 7, 7);
}
function RoundingMode_UP_getInstance() {
  RoundingMode_initEntries();
  return RoundingMode_UP_instance;
}
function RoundingMode_DOWN_getInstance() {
  RoundingMode_initEntries();
  return RoundingMode_DOWN_instance;
}
function RoundingMode_CEILING_getInstance() {
  RoundingMode_initEntries();
  return RoundingMode_CEILING_instance;
}
function RoundingMode_FLOOR_getInstance() {
  RoundingMode_initEntries();
  return RoundingMode_FLOOR_instance;
}
function RoundingMode_HALF_UP_getInstance() {
  RoundingMode_initEntries();
  return RoundingMode_HALF_UP_instance;
}
function RoundingMode_HALF_DOWN_getInstance() {
  RoundingMode_initEntries();
  return RoundingMode_HALF_DOWN_instance;
}
function RoundingMode_HALF_EVEN_getInstance() {
  RoundingMode_initEntries();
  return RoundingMode_HALF_EVEN_instance;
}
function RoundingMode_UNNECESSARY_getInstance() {
  RoundingMode_initEntries();
  return RoundingMode_UNNECESSARY_instance;
}
function init_com_macrofocus_common_math_big_SignedMutableBigInteger(_this__u8e3s4) {
  _this__u8e3s4.vw_1 = 1;
}
function numberOfTrailingZeros(_this__u8e3s4) {
  var y;
  var i = _this__u8e3s4;
  if (i === 0)
    return 32;
  var n = 31;
  y = i << 16;
  if (!(y === 0)) {
    n = n - 16 | 0;
    i = y;
  }
  y = i << 8;
  if (!(y === 0)) {
    n = n - 8 | 0;
    i = y;
  }
  y = i << 4;
  if (!(y === 0)) {
    n = n - 4 | 0;
    i = y;
  }
  y = i << 2;
  if (!(y === 0)) {
    n = n - 2 | 0;
    i = y;
  }
  return n - (i << 1 >>> 31 | 0) | 0;
}
function toDigit(_this__u8e3s4, radix) {
  if (2 <= radix ? radix <= 36 : false) {
    if (radix > 10) {
      var delta = radix - 10 | 0;
      if (_Char___init__impl__6a9atx(48) <= _this__u8e3s4 ? _this__u8e3s4 <= _Char___init__impl__6a9atx(57) : false)
        return Char__minus_impl_a2frrh(_this__u8e3s4, _Char___init__impl__6a9atx(48));
      else if (_Char___init__impl__6a9atx(97) <= _this__u8e3s4 ? _this__u8e3s4 < Char__plus_impl_qi7pgj(_Char___init__impl__6a9atx(97), delta) : false)
        return Char__minus_impl_a2frrh(_this__u8e3s4, _Char___init__impl__6a9atx(97)) + 10 | 0;
      else if (_Char___init__impl__6a9atx(65) <= _this__u8e3s4 ? _this__u8e3s4 < Char__plus_impl_qi7pgj(_Char___init__impl__6a9atx(65), delta) : false)
        return Char__minus_impl_a2frrh(_this__u8e3s4, _Char___init__impl__6a9atx(65)) + 10 | 0;
    } else {
      if (_Char___init__impl__6a9atx(48) <= _this__u8e3s4 ? _this__u8e3s4 < Char__plus_impl_qi7pgj(_Char___init__impl__6a9atx(48), radix) : false) {
        return Char__minus_impl_a2frrh(_this__u8e3s4, _Char___init__impl__6a9atx(48));
      }
    }
  }
  return -1;
}
function arrayCopy_0(src, srcIndex, dest, destIndex, size) {
  var inductionVariable = 0;
  if (inductionVariable < size)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      dest[destIndex + i | 0] = src[srcIndex + i | 0];
    }
     while (inductionVariable < size);
}
function cloneArray(_this__u8e3s4) {
  var tmp = 0;
  var tmp_0 = _this__u8e3s4.length;
  var tmp_1 = new Int32Array(tmp_0);
  while (tmp < tmp_0) {
    var tmp_2 = tmp;
    tmp_1[tmp_2] = _this__u8e3s4[tmp_2];
    tmp = tmp + 1 | 0;
  }
  return tmp_1;
}
function bitCount(_this__u8e3s4) {
  var i = _this__u8e3s4;
  i = i - ((i >>> 1 | 0) & 1431655765) | 0;
  i = (i & 858993459) + ((i >>> 2 | 0) & 858993459) | 0;
  i = (i + (i >>> 4 | 0) | 0) & 252645135;
  i = i + (i >>> 8 | 0) | 0;
  i = i + (i >>> 16 | 0) | 0;
  return i & 63;
}
function insertChar(_this__u8e3s4, index, char) {
  return insertCharSeq(_this__u8e3s4, index, toString(char));
}
function getRadix(_this__u8e3s4) {
  var tmp;
  if (contains_2(_this__u8e3s4, '0B', true)) {
    tmp = new Pair(2, replaceFirst(replaceFirst(_this__u8e3s4, '0B', ''), '0b', ''));
  } else if (contains_2(_this__u8e3s4, '0O', true)) {
    tmp = new Pair(8, replaceFirst(replaceFirst(_this__u8e3s4, '0O', ''), '0o', ''));
  } else if (contains_2(_this__u8e3s4, '0X', true)) {
    tmp = new Pair(16, replaceFirst(replaceFirst(_this__u8e3s4, '0X', ''), '0x', ''));
  } else {
    tmp = new Pair(10, _this__u8e3s4);
  }
  return tmp;
}
function numberOfLeadingZeros(_this__u8e3s4) {
  var x = _this__u8e3s4;
  if (x === 0) {
    return 32;
  }
  var n = 1;
  if ((x >>> 16 | 0) === 0) {
    n = n + 16 | 0;
    x = x << 16;
  }
  if ((x >>> 24 | 0) === 0) {
    n = n + 8 | 0;
    x = x << 8;
  }
  if ((x >>> 28 | 0) === 0) {
    n = n + 4 | 0;
    x = x << 4;
  }
  if ((x >>> 30 | 0) === 0) {
    n = n + 2 | 0;
    x = x << 2;
  }
  n = n - (x >>> 31 | 0) | 0;
  return n;
}
function isDigit(_this__u8e3s4) {
  return isDigit_0(_this__u8e3s4, 10);
}
function toCharArray(_this__u8e3s4) {
  var tmp = 0;
  var tmp_0 = charSequenceLength(_this__u8e3s4);
  var tmp_1 = charArray(tmp_0);
  while (tmp < tmp_0) {
    var tmp_2 = tmp;
    tmp_1[tmp_2] = charSequenceGet(_this__u8e3s4, tmp_2);
    tmp = tmp + 1 | 0;
  }
  return tmp_1;
}
function appendCharArray(_this__u8e3s4, char, offset, len) {
  var inductionVariable = offset;
  var last = offset + len | 0;
  if (inductionVariable < last)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      _this__u8e3s4.mb(char[i]);
    }
     while (inductionVariable < last);
  return _this__u8e3s4;
}
function numberOfLeadingZeros_0(_this__u8e3s4) {
  if (_this__u8e3s4.equals(new Long(0, 0))) {
    return 64;
  }
  var n = 1;
  var x = _this__u8e3s4.s3(32).l1();
  if (x === 0) {
    n = n + 32 | 0;
    x = _this__u8e3s4.l1();
  }
  if ((x >>> 16 | 0) === 0) {
    n = n + 16 | 0;
    x = x << 16;
  }
  if ((x >>> 24 | 0) === 0) {
    n = n + 8 | 0;
    x = x << 8;
  }
  if ((x >>> 28 | 0) === 0) {
    n = n + 4 | 0;
    x = x << 4;
  }
  if ((x >>> 30 | 0) === 0) {
    n = n + 2 | 0;
    x = x << 2;
  }
  n = n - (x >>> 31 | 0) | 0;
  return n;
}
function log_0(lazyObject) {
  if (false) {
    logImpl(lazyObject);
  }
}
function insertCharSeq(_this__u8e3s4, index, string) {
  var temp = StringBuilder.ze(_this__u8e3s4.c(0, index));
  temp.v(string);
  temp.v(_this__u8e3s4.c(index, _this__u8e3s4.a()));
  return temp;
}
function isDigit_0(_this__u8e3s4, radix) {
  var tmp;
  if (36 <= radix ? radix <= 36 : false) {
    var tmp_0;
    if (radix > 10) {
      var delta = radix - 10 | 0;
      tmp_0 = (_Char___init__impl__6a9atx(48) <= _this__u8e3s4 ? _this__u8e3s4 <= _Char___init__impl__6a9atx(57) : false) || (_Char___init__impl__6a9atx(97) <= _this__u8e3s4 ? _this__u8e3s4 < Char__plus_impl_qi7pgj(_Char___init__impl__6a9atx(97), delta) : false) || (_Char___init__impl__6a9atx(65) <= _this__u8e3s4 ? _this__u8e3s4 < Char__plus_impl_qi7pgj(_Char___init__impl__6a9atx(65), delta) : false);
    } else {
      tmp_0 = _Char___init__impl__6a9atx(48) <= _this__u8e3s4 ? _this__u8e3s4 < Char__plus_impl_qi7pgj(_Char___init__impl__6a9atx(48), radix) : false;
    }
    tmp = tmp_0;
  } else {
    tmp = false;
  }
  return tmp;
}
function fill_0(_this__u8e3s4, x) {
  return fill_1(_this__u8e3s4, 0, _this__u8e3s4.length, x);
}
function fill_1(_this__u8e3s4, from, to, x) {
  var inductionVariable = from;
  if (inductionVariable < to)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      _this__u8e3s4[i] = x;
    }
     while (inductionVariable < to);
  return _this__u8e3s4;
}
function _get_reference__19y5ba($this) {
  return $this.fy_1.xk();
}
function _get_listeners__760gzy($this) {
  var tmp0 = $this.sx_1;
  // Inline function 'kotlin.getValue' call
  listeners$factory();
  return tmp0.r2();
}
function AbstractProperty$listernersDelegate$lambda() {
  return CollectionFactory_instance.ll();
}
function listeners$factory() {
  return getPropertyCallableRef('listeners', 1, KProperty1, (receiver) => _get_listeners__760gzy(receiver), null);
}
var Companion_instance_25;
function Companion_getInstance_25() {
  return Companion_instance_25;
}
var PropertyDelegates_instance;
function PropertyDelegates_getInstance() {
  return PropertyDelegates_instance;
}
var Companion_instance_26;
function Companion_getInstance_26() {
  return Companion_instance_26;
}
function value$factory() {
  return getPropertyCallableRef('value', 1, KMutableProperty1, (receiver) => receiver.r2(), (receiver, value) => receiver.vo(value));
}
function value$factory_0() {
  return getPropertyCallableRef('value', 1, KMutableProperty1, (receiver) => receiver.r2(), (receiver, value) => receiver.vo(value));
}
var StartEnd_Start_instance;
var StartEnd_End_instance;
var StartEnd_entriesInitialized;
function StartEnd_initEntries() {
  if (StartEnd_entriesInitialized)
    return Unit_instance;
  StartEnd_entriesInitialized = true;
  StartEnd_Start_instance = new StartEnd('Start', 0);
  StartEnd_End_instance = new StartEnd('End', 1);
}
function StartEnd_Start_getInstance() {
  StartEnd_initEntries();
  return StartEnd_Start_instance;
}
var NumericTransform_ASN_instance;
var NumericTransform_ATANH_instance;
var NumericTransform_ASINH_instance;
var NumericTransform_EXP_instance;
var NumericTransform_EXP2_instance;
var NumericTransform_EXP10_instance;
var NumericTransform_EXP1P_instance;
var NumericTransform_IDENTITY_instance;
var NumericTransform_LOG_instance;
var NumericTransform_LOG2_instance;
var NumericTransform_LOG10_instance;
var NumericTransform_LOG1P_instance;
var NumericTransform_PSEUDO_LOG_instance;
var NumericTransform_LOGIT_instance;
var NumericTransform_PROBIT_instance;
var NumericTransform_RECIPROCAL_instance;
var NumericTransform_REVERSE_instance;
var NumericTransform_SQRT_instance;
function NumericTransform$lambda(x) {
  // Inline function 'kotlin.math.sqrt' call
  // Inline function 'kotlin.math.asin' call
  var x_0 = Math.sqrt(x);
  return 2.0 * Math.asin(x_0);
}
function NumericTransform$lambda_0(y) {
  // Inline function 'kotlin.math.pow' call
  // Inline function 'kotlin.math.sqrt' call
  var x = y - Math.pow(y, 2.0);
  return 1.0 / Math.sqrt(x);
}
function NumericTransform$lambda_1(x) {
  // Inline function 'kotlin.math.pow' call
  // Inline function 'kotlin.math.sqrt' call
  var x_0 = x - Math.pow(x, 2.0);
  return 1.0 / Math.sqrt(x_0);
}
function NumericTransform$lambda_2(y) {
  // Inline function 'kotlin.math.sin' call
  return Math.sin(y) / 2;
}
function NumericTransform$lambda_3(x) {
  // Inline function 'kotlin.math.pow' call
  return 1.0 / (1.0 - Math.pow(x, 2.0));
}
function NumericTransform$lambda_4(y) {
  // Inline function 'kotlin.math.cosh' call
  // Inline function 'kotlin.math.pow' call
  var this_0 = cosh(y);
  return 1.0 / Math.pow(this_0, 2.0);
}
function asinh$ref() {
  var l = (p0) => asinh_1(p0);
  l.callableName = 'asinh';
  return l;
}
function sinh$ref() {
  var l = (p0) => sinh_0(p0);
  l.callableName = 'sinh';
  return l;
}
function NumericTransform$lambda_5(x) {
  // Inline function 'kotlin.math.pow' call
  // Inline function 'kotlin.math.sqrt' call
  var x_0 = Math.pow(x, 2.0) + 1.0;
  return 1.0 / Math.sqrt(x_0);
}
function NumericTransform$lambda_6(y) {
  // Inline function 'kotlin.math.cosh' call
  return cosh(y);
}
function exp$ref() {
  var l = (p0) => exp(p0);
  l.callableName = 'exp';
  return l;
}
function ln$ref() {
  var l = (p0) => ln(p0);
  l.callableName = 'ln';
  return l;
}
function NumericTransform$lambda_7(x) {
  // Inline function 'kotlin.math.pow' call
  var x_0 = 2.718281828459045;
  var tmp = Math.pow(x, x_0);
  // Inline function 'kotlin.math.ln' call
  var x_1 = 2.718281828459045;
  return tmp * Math.log(x_1);
}
function NumericTransform$lambda_8(y) {
  var tmp = 1.0 / y;
  // Inline function 'kotlin.math.ln' call
  var x = 2.718281828459045;
  return tmp / Math.log(x);
}
function NumericTransform$lambda_9(x) {
  // Inline function 'kotlin.math.pow' call
  return Math.pow(x, 2.0);
}
function NumericTransform$lambda_10(y) {
  // Inline function 'kotlin.math.ln' call
  var tmp = Math.log(y);
  // Inline function 'kotlin.math.ln' call
  return tmp / Math.log(2.0);
}
function NumericTransform$lambda_11(x) {
  // Inline function 'kotlin.math.pow' call
  var tmp = Math.pow(x, 2.0);
  // Inline function 'kotlin.math.ln' call
  return tmp * Math.log(2.0);
}
function NumericTransform$lambda_12(y) {
  var tmp = 1.0 / y;
  // Inline function 'kotlin.math.ln' call
  return tmp / Math.log(2.0);
}
function NumericTransform$lambda_13(x) {
  // Inline function 'kotlin.math.pow' call
  return Math.pow(x, 10.0);
}
function NumericTransform$lambda_14(y) {
  // Inline function 'kotlin.math.log10' call
  return log10(y);
}
function NumericTransform$lambda_15(x) {
  // Inline function 'kotlin.math.pow' call
  var tmp = Math.pow(x, 10.0);
  // Inline function 'kotlin.math.ln' call
  return tmp * Math.log(10.0);
}
function NumericTransform$lambda_16(y) {
  var tmp = 1.0 / y;
  // Inline function 'kotlin.math.ln' call
  return tmp / Math.log(10.0);
}
function expm1$ref() {
  var l = (p0) => expm1_0(p0);
  l.callableName = 'expm1';
  return l;
}
function ln1p$ref() {
  var l = (p0) => ln1p(p0);
  l.callableName = 'ln1p';
  return l;
}
function exp$ref_0() {
  var l = (p0) => exp(p0);
  l.callableName = 'exp';
  return l;
}
function NumericTransform$lambda_17(y) {
  return 1.0 / (1.0 + y);
}
function NumericTransform$lambda_18(x) {
  return x;
}
function NumericTransform$lambda_19(y) {
  return y;
}
function ln$ref_0() {
  var l = (p0) => ln(p0);
  l.callableName = 'ln';
  return l;
}
function exp$ref_1() {
  var l = (p0) => exp(p0);
  l.callableName = 'exp';
  return l;
}
function NumericTransform$lambda_20(x) {
  var tmp = 1.0 / x;
  // Inline function 'kotlin.math.ln' call
  var x_0 = 2.718281828459045;
  return tmp / Math.log(x_0);
}
function NumericTransform$lambda_21(y) {
  // Inline function 'kotlin.math.pow' call
  var x = 2.718281828459045;
  var tmp = Math.pow(y, x);
  // Inline function 'kotlin.math.ln' call
  var x_0 = 2.718281828459045;
  return tmp * Math.log(x_0);
}
function log2$ref() {
  var l = (p0) => log2_0(p0);
  l.callableName = 'log2';
  return l;
}
function NumericTransform$lambda_22(y) {
  // Inline function 'kotlin.math.pow' call
  return Math.pow(y, 2.0);
}
function NumericTransform$lambda_23(x) {
  var tmp = 1.0 / x;
  // Inline function 'kotlin.math.ln' call
  return tmp / Math.log(2.0);
}
function NumericTransform$lambda_24(y) {
  // Inline function 'kotlin.math.pow' call
  var tmp = Math.pow(y, 2.0);
  // Inline function 'kotlin.math.ln' call
  return tmp * Math.log(2.0);
}
function log10$ref() {
  var l = (p0) => log10_0(p0);
  l.callableName = 'log10';
  return l;
}
function NumericTransform$lambda_25(y) {
  // Inline function 'kotlin.math.pow' call
  return Math.pow(y, 10.0);
}
function NumericTransform$lambda_26(x) {
  var tmp = 1.0 / x;
  // Inline function 'kotlin.math.ln' call
  return tmp / Math.log(10.0);
}
function NumericTransform$lambda_27(y) {
  // Inline function 'kotlin.math.pow' call
  var tmp = Math.pow(y, 10.0);
  // Inline function 'kotlin.math.ln' call
  return tmp * Math.log(10.0);
}
function ln1p$ref_0() {
  var l = (p0) => ln1p(p0);
  l.callableName = 'ln1p';
  return l;
}
function expm1$ref_0() {
  var l = (p0) => expm1_0(p0);
  l.callableName = 'expm1';
  return l;
}
function NumericTransform$lambda_28(x) {
  return 1.0 / (1.0 + x);
}
function NumericTransform$lambda_29(y) {
  // Inline function 'kotlin.math.exp' call
  return Math.exp(y);
}
function NumericTransform$lambda_30(x) {
  // Inline function 'kotlin.math.asinh' call
  var x_0 = x / (2.0 * 1.0);
  var tmp = asinh_0(x_0);
  // Inline function 'kotlin.math.exp' call
  // Inline function 'kotlin.math.ln' call
  var x_1 = Math.exp(1.0);
  return tmp / Math.log(x_1);
}
function NumericTransform$lambda_31(y) {
  var tmp = 2.0 * 1.0;
  // Inline function 'kotlin.math.exp' call
  // Inline function 'kotlin.math.ln' call
  var x = Math.exp(1.0);
  // Inline function 'kotlin.math.sinh' call
  var x_0 = y * Math.log(x);
  return tmp * sinh(x_0);
}
function NumericTransform$lambda_32(x) {
  // Inline function 'kotlin.math.pow' call
  var tmp = Math.pow(x, 2.0);
  // Inline function 'kotlin.math.pow' call
  // Inline function 'kotlin.math.sqrt' call
  var x_0 = 4.0 + tmp / Math.pow(1.0, 2.0);
  var tmp_0 = Math.sqrt(x_0) * 1.0;
  // Inline function 'kotlin.math.exp' call
  // Inline function 'kotlin.math.ln' call
  var x_1 = Math.exp(1.0);
  return 1.0 / (tmp_0 * Math.log(x_1));
}
function NumericTransform$lambda_33(y) {
  var tmp = 2.0 * 1.0;
  // Inline function 'kotlin.math.exp' call
  // Inline function 'kotlin.math.ln' call
  var x = Math.exp(1.0);
  // Inline function 'kotlin.math.cosh' call
  var x_0 = y * Math.log(x);
  var tmp_0 = tmp * cosh(x_0);
  // Inline function 'kotlin.math.exp' call
  // Inline function 'kotlin.math.ln' call
  var x_1 = Math.exp(1.0);
  return tmp_0 * Math.log(x_1);
}
function NumericTransform$lambda_34(x) {
  // Inline function 'kotlin.math.ln' call
  var x_0 = x / (1.0 - x);
  return Math.log(x_0);
}
function NumericTransform$lambda_35(y) {
  // Inline function 'kotlin.math.exp' call
  return 1.0 / (1 + Math.exp(y));
}
function Probit$probit$ref($boundThis) {
  var l = (p0) => $boundThis.h12(p0);
  l.callableName = 'probit';
  return l;
}
function NumericTransform$lambda_36(x) {
  return 1.0 / x;
}
function NumericTransform$lambda_37(y) {
  return 1.0 / y;
}
function NumericTransform$lambda_38(x) {
  var tmp = -1.0;
  // Inline function 'kotlin.math.pow' call
  return tmp / Math.pow(x, 2.0);
}
function NumericTransform$lambda_39(y) {
  // Inline function 'kotlin.math.pow' call
  return -1 / Math.pow(y, 2.0);
}
function NumericTransform$lambda_40(x) {
  return -x;
}
function NumericTransform$lambda_41(y) {
  return -y;
}
function sqrt$ref() {
  var l = (p0) => sqrt_0(p0);
  l.callableName = 'sqrt';
  return l;
}
function NumericTransform$lambda_42(y) {
  // Inline function 'kotlin.math.pow' call
  return Math.pow(y, 2.0);
}
function NumericTransform$lambda_43(x) {
  // Inline function 'kotlin.math.sqrt' call
  return 0.5 / Math.sqrt(x);
}
function NumericTransform$lambda_44(y) {
  return 2.0 * y;
}
var NumericTransform_entriesInitialized;
function NumericTransform_initEntries() {
  if (NumericTransform_entriesInitialized)
    return Unit_instance;
  NumericTransform_entriesInitialized = true;
  var tmp = NumericTransform$lambda;
  var tmp_0 = NumericTransform$lambda_0;
  var tmp_1 = NumericTransform$lambda_1;
  NumericTransform_ASN_instance = new NumericTransform('ASN', 0, 'asn', tmp, tmp_0, tmp_1, NumericTransform$lambda_2, OpenInterval.go(0.0, 1.0));
  var tmp_2 = NumericTransform$lambda_3;
  NumericTransform_ATANH_instance = new NumericTransform('ATANH', 1, 'atanh', tmp_2, NumericTransform$lambda_4, null, null, OpenInterval.go(-1.0, 2.0));
  var tmp_3 = asinh$ref();
  var tmp_4 = sinh$ref();
  var tmp_5 = NumericTransform$lambda_5;
  NumericTransform_ASINH_instance = new NumericTransform('ASINH', 2, 'asinh', tmp_3, tmp_4, tmp_5, NumericTransform$lambda_6, OpenInterval.go(-1.0, 2.0));
  var tmp_6 = exp$ref();
  var tmp_7 = ln$ref();
  var tmp_8 = NumericTransform$lambda_7;
  NumericTransform_EXP_instance = new NumericTransform('EXP', 3, 'exp', tmp_6, tmp_7, tmp_8, NumericTransform$lambda_8, OpenInterval.go(-Infinity, Infinity));
  var tmp_9 = NumericTransform$lambda_9;
  var tmp_10 = NumericTransform$lambda_10;
  var tmp_11 = NumericTransform$lambda_11;
  NumericTransform_EXP2_instance = new NumericTransform('EXP2', 4, 'exp2', tmp_9, tmp_10, tmp_11, NumericTransform$lambda_12, OpenInterval.go(-Infinity, Infinity));
  var tmp_12 = NumericTransform$lambda_13;
  var tmp_13 = NumericTransform$lambda_14;
  var tmp_14 = NumericTransform$lambda_15;
  NumericTransform_EXP10_instance = new NumericTransform('EXP10', 5, 'exp10', tmp_12, tmp_13, tmp_14, NumericTransform$lambda_16, OpenInterval.go(-Infinity, Infinity));
  var tmp_15 = expm1$ref();
  var tmp_16 = ln1p$ref();
  var tmp_17 = exp$ref_0();
  NumericTransform_EXP1P_instance = new NumericTransform('EXP1P', 6, 'expm1', tmp_15, tmp_16, tmp_17, NumericTransform$lambda_17, OpenInterval.go(-Infinity, Infinity));
  var tmp_18 = NumericTransform$lambda_18;
  NumericTransform_IDENTITY_instance = new NumericTransform('IDENTITY', 7, 'identity', tmp_18, NumericTransform$lambda_19, null, null, OpenInterval.go(-Infinity, Infinity));
  var tmp_19 = ln$ref_0();
  var tmp_20 = exp$ref_1();
  var tmp_21 = NumericTransform$lambda_20;
  NumericTransform_LOG_instance = new NumericTransform('LOG', 8, 'log', tmp_19, tmp_20, tmp_21, NumericTransform$lambda_21, OpenInterval.go(0.0, Infinity));
  var tmp_22 = log2$ref();
  var tmp_23 = NumericTransform$lambda_22;
  var tmp_24 = NumericTransform$lambda_23;
  NumericTransform_LOG2_instance = new NumericTransform('LOG2', 9, 'log2', tmp_22, tmp_23, tmp_24, NumericTransform$lambda_24, OpenInterval.go(0.0, Infinity));
  var tmp_25 = log10$ref();
  var tmp_26 = NumericTransform$lambda_25;
  var tmp_27 = NumericTransform$lambda_26;
  NumericTransform_LOG10_instance = new NumericTransform('LOG10', 10, 'log10', tmp_25, tmp_26, tmp_27, NumericTransform$lambda_27, OpenInterval.go(0.0, Infinity));
  var tmp_28 = ln1p$ref_0();
  var tmp_29 = expm1$ref_0();
  var tmp_30 = NumericTransform$lambda_28;
  NumericTransform_LOG1P_instance = new NumericTransform('LOG1P', 11, 'log1p', tmp_28, tmp_29, tmp_30, NumericTransform$lambda_29, OpenInterval.go(1.0 + 4.9E-324, Infinity));
  var tmp_31 = NumericTransform$lambda_30;
  var tmp_32 = NumericTransform$lambda_31;
  var tmp_33 = NumericTransform$lambda_32;
  NumericTransform_PSEUDO_LOG_instance = new NumericTransform('PSEUDO_LOG', 12, 'pseudo_log', tmp_31, tmp_32, tmp_33, NumericTransform$lambda_33, null);
  var tmp_34 = NumericTransform$lambda_34;
  NumericTransform_LOGIT_instance = new NumericTransform('LOGIT', 13, 'logit', tmp_34, NumericTransform$lambda_35, null, null, null);
  NumericTransform_PROBIT_instance = new NumericTransform('PROBIT', 14, 'probit', Probit$probit$ref(Probit_instance), null, null, null, null);
  var tmp_35 = NumericTransform$lambda_36;
  var tmp_36 = NumericTransform$lambda_37;
  var tmp_37 = NumericTransform$lambda_38;
  NumericTransform_RECIPROCAL_instance = new NumericTransform('RECIPROCAL', 15, 'reciprocal', tmp_35, tmp_36, tmp_37, NumericTransform$lambda_39, null);
  var tmp_38 = NumericTransform$lambda_40;
  NumericTransform_REVERSE_instance = new NumericTransform('REVERSE', 16, 'reverse', tmp_38, NumericTransform$lambda_41, null, null, null);
  var tmp_39 = sqrt$ref();
  var tmp_40 = NumericTransform$lambda_42;
  var tmp_41 = NumericTransform$lambda_43;
  NumericTransform_SQRT_instance = new NumericTransform('SQRT', 17, 'sqrt', tmp_39, tmp_40, tmp_41, NumericTransform$lambda_44, OpenInterval.go(0.0, Infinity));
}
function NumericTransform_PSEUDO_LOG_getInstance() {
  NumericTransform_initEntries();
  return NumericTransform_PSEUDO_LOG_instance;
}
function NumericTransform_SQRT_getInstance() {
  NumericTransform_initEntries();
  return NumericTransform_SQRT_instance;
}
var Probit_instance;
function Probit_getInstance() {
  return Probit_instance;
}
function init_com_macrofocus_common_selection_SimpleSingleSelection(_this__u8e3s4) {
  _this__u8e3s4.v14_1 = null;
}
function adjustValues($this, range, diff) {
  var diff_0 = diff;
  if (isNaN_3(diff_0)) {
    diff_0 = 0.0;
  }
  var value = range.start + diff_0 / 2;
  var extent = range.extent - diff_0;
  if (value < range.bn()) {
    value = range.bn();
  }
  if (extent > range.kp()) {
    extent = range.kp();
  }
  if (value + extent > range.cn()) {
    value = range.cn() - extent;
  }
  range.lo(value, extent);
}
var CollectionFactory_instance;
function CollectionFactory_getInstance() {
  return CollectionFactory_instance;
}
var WeakHashMap_Ids;
var Companion_instance_27;
function Companion_getInstance_27() {
  return Companion_instance_27;
}
var Companion_instance_28;
function Companion_getInstance_28() {
  if (Companion_instance_28 === VOID)
    new Companion_28();
  return Companion_instance_28;
}
function CPHelper$visualizationExecutorService$delegate$lambda(this$0) {
  return () => this$0.k17('VisualizationExecutorService', 0, Companion_instance_27.f17().g17());
}
function createTimeoutCallback($this, timer) {
  return Timer$createTimeoutCallback$lambda(timer);
}
function Timer$createTimeoutCallback$lambda($timer) {
  return () => {
    $timer.e18();
    return Unit_instance;
  };
}
var Companion_instance_29;
function Companion_getInstance_29() {
  if (Companion_instance_29 === VOID)
    new Companion_29();
  return Companion_instance_29;
}
function bigInteger(x) {
  var tmp;
  if (x instanceof Long) {
    var tmp_0 = Companion_getInstance_21();
    tmp = tmp_0.ofLong(x instanceof Long ? x : THROW_CCE());
  } else {
    if (!(x == null) ? typeof x === 'number' : false) {
      var tmp_1 = Companion_getInstance_21();
      tmp = tmp_1.of((!(x == null) ? typeof x === 'number' : false) ? x : THROW_CCE());
    } else {
      if (isNumber(x)) {
        var tmp_2 = Companion_getInstance_21();
        tmp = tmp_2.ofLong(numberToLong(isNumber(x) ? x : THROW_CCE()));
      } else {
        if (!(x == null) ? typeof x === 'string' : false) {
          tmp = Companion_getInstance_21().parse(toString_1(x));
        } else {
          if (!(x == null) ? isArray(x) : false) {
            var y = (!(x == null) ? isArray(x) : false) ? x : THROW_CCE();
            var tmp_3;
            var tmp_4;
            if (y.length === 2) {
              var tmp_5 = y[0];
              tmp_4 = !(tmp_5 == null) ? typeof tmp_5 === 'string' : false;
            } else {
              tmp_4 = false;
            }
            if (tmp_4) {
              var tmp_6 = y[1];
              tmp_3 = isNumber(tmp_6);
            } else {
              tmp_3 = false;
            }
            // Inline function 'kotlin.require' call
            // Inline function 'kotlin.require' call
            if (!tmp_3) {
              // Inline function 'kotlin.require.<anonymous>' call
              var message = 'Failed requirement.';
              throw IllegalArgumentException.h(toString_1(message));
            }
            var tmp_7 = Companion_getInstance_21();
            var tmp_8 = y[0];
            var tmp_9 = (!(tmp_8 == null) ? typeof tmp_8 === 'string' : false) ? tmp_8 : THROW_CCE();
            var tmp_10 = y[1];
            return tmp_7.parseWithRadix(tmp_9, (!(tmp_10 == null) ? typeof tmp_10 === 'number' : false) ? tmp_10 : THROW_CCE());
          } else {
            throw IllegalArgumentException.qc();
          }
        }
      }
    }
  }
  return tmp;
}
function bigDecimal(x) {
  var tmp;
  if (!(x == null) ? isArray(x) : false) {
    var tmp_0;
    if (x.length === 2) {
      var tmp_1 = x[1];
      tmp_0 = tmp_1 instanceof MathContext;
    } else {
      tmp_0 = false;
    }
    // Inline function 'kotlin.require' call
    // Inline function 'kotlin.require' call
    if (!tmp_0) {
      // Inline function 'kotlin.require.<anonymous>' call
      var message = 'Failed requirement.';
      throw IllegalArgumentException.h(toString_1(message));
    }
    var tmp_2;
    if (x[1] instanceof MathContext) {
      var tmp_3 = Companion_getInstance_16();
      var tmp_4 = toString_1(x[0]);
      var tmp_5 = x[1];
      tmp_2 = tmp_3.parse(tmp_4, tmp_5 instanceof MathContext ? tmp_5 : THROW_CCE());
    } else {
      throw IllegalArgumentException.qc();
    }
    tmp = tmp_2;
  } else {
    if (!(x == null)) {
      tmp = Companion_getInstance_16().parse(toString_1(x));
    } else {
      throw IllegalArgumentException.qc();
    }
  }
  return tmp;
}
function get_exceptionalDoubles() {
  _init_properties_JsUtils_kt__tti4wa();
  return exceptionalDoubles;
}
var exceptionalDoubles;
var BigDecimals_instance;
function BigDecimals_getInstance() {
  if (BigDecimals_instance === VOID)
    new BigDecimals();
  return BigDecimals_instance;
}
function bigDecimalOf(unscaledVal, scale) {
  _init_properties_JsUtils_kt__tti4wa();
  return Companion_getInstance_20().ofScaledLong(unscaledVal, scale);
}
function bigDecimalOf_0(unscaledVal, scale, prec) {
  _init_properties_JsUtils_kt__tti4wa();
  return Companion_getInstance_20().ofScaledLongWithPrecision(unscaledVal, scale, prec);
}
function bigDecimalOf_1(val) {
  _init_properties_JsUtils_kt__tti4wa();
  return Companion_getInstance_20().ofInt(val);
}
function bigDecimalOf_2(val) {
  _init_properties_JsUtils_kt__tti4wa();
  return Companion_getInstance_20().of(val);
}
function bigDecimalOf_3(intVal, scale, prec) {
  _init_properties_JsUtils_kt__tti4wa();
  var tmp = Companion_getInstance_20();
  // Inline function 'com.macrofocus.common.math.big.castTo' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return tmp.ofScaledBigIntegerWithPrecision(intVal, scale, prec);
}
function bigDecimalOf_4(val, ctx) {
  ctx = ctx === VOID ? null : ctx;
  _init_properties_JsUtils_kt__tti4wa();
  var tmp;
  if (get_exceptionalDoubles().j2(val)) {
    throw NumberFormatException.hd('Infinite or NaN');
  } else if (ctx == null) {
    tmp = CommonBigDecimal.zu(val);
  } else {
    tmp = Companion_getInstance_20().ofDouble(val, ctx);
  }
  return tmp;
}
function bigDecimalOf_5(val, ctx) {
  ctx = ctx === VOID ? null : ctx;
  _init_properties_JsUtils_kt__tti4wa();
  return bigDecimalOf_4(val, ctx);
}
function bigDecimalOf_6(val, ctx) {
  ctx = ctx === VOID ? null : ctx;
  _init_properties_JsUtils_kt__tti4wa();
  var tmp;
  if (ctx == null) {
    tmp = CommonBigDecimal.bv(val);
  } else {
    tmp = Companion_getInstance_20().fq(val, ctx);
  }
  return tmp;
}
function bigDecimalOf_7(val, ctx) {
  ctx = ctx === VOID ? null : ctx;
  _init_properties_JsUtils_kt__tti4wa();
  // Inline function 'com.macrofocus.common.math.big.castTo' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  var value = val;
  var tmp;
  if (ctx == null) {
    tmp = CommonBigDecimal.ev(value);
  } else {
    tmp = Companion_getInstance_20().cv(value, ctx);
  }
  return tmp;
}
function bigDecimalOf_8(val, ctx) {
  _init_properties_JsUtils_kt__tti4wa();
  return Companion_getInstance_20().ofIntWithContext(val, ctx);
}
function bigDecimalOf_9(val, ctx) {
  _init_properties_JsUtils_kt__tti4wa();
  return Companion_getInstance_20().ofWithContext(val, ctx);
}
var BigIntegers_instance;
function BigIntegers_getInstance() {
  if (BigIntegers_instance === VOID)
    new BigIntegers();
  return BigIntegers_instance;
}
function bigProbablePrimeInteger(bitLength, rnd) {
  _init_properties_JsUtils_kt__tti4wa();
  return Companion_getInstance_21().probablePrime(bitLength, rnd);
}
function bigIntegerOf(value) {
  _init_properties_JsUtils_kt__tti4wa();
  return Companion_getInstance_21().ofLong(value);
}
function bigIntegerOf_0(value) {
  _init_properties_JsUtils_kt__tti4wa();
  return Companion_getInstance_21().of(value);
}
function bigIntegerOf_1(value) {
  _init_properties_JsUtils_kt__tti4wa();
  return Companion_getInstance_21().parse(value);
}
function bigIntegerOf_2(value, radix) {
  _init_properties_JsUtils_kt__tti4wa();
  return Companion_getInstance_21().parseWithRadix(value, radix);
}
function bigIntegerOf_3(value) {
  _init_properties_JsUtils_kt__tti4wa();
  return Companion_getInstance_21().ofIntArray(value);
}
function bigIntegerOf_4(signum, magnitude, off, len) {
  off = off === VOID ? 0 : off;
  len = len === VOID ? magnitude.length : len;
  _init_properties_JsUtils_kt__tti4wa();
  return CommonBigInteger.wv(signum, magnitude, off, len);
}
function logImpl(lazyObject) {
  _init_properties_JsUtils_kt__tti4wa();
  console.warn(lazyObject());
}
var properties_initialized_JsUtils_kt_k4zh3s;
function _init_properties_JsUtils_kt__tti4wa() {
  if (!properties_initialized_JsUtils_kt_k4zh3s) {
    properties_initialized_JsUtils_kt_k4zh3s = true;
    exceptionalDoubles = setOf_0([NaN, -Infinity, Infinity]);
  }
}
var None_instance;
function None_getInstance() {
  if (None_instance === VOID)
    new None();
  return None_instance;
}
function atomic$ref$1(initial) {
  return atomic$ref$(initial, None_getInstance());
}
function atomic$boolean$1(initial) {
  return atomic$boolean$(initial, None_getInstance());
}
function atomic$int$1(initial) {
  return atomic$int$(initial, None_getInstance());
}
function atomic$ref$(initial, trace) {
  trace = trace === VOID ? None_getInstance() : trace;
  return new AtomicRef(initial);
}
function atomic$boolean$(initial, trace) {
  trace = trace === VOID ? None_getInstance() : trace;
  return new AtomicBoolean(initial);
}
function atomic$int$(initial, trace) {
  trace = trace === VOID ? None_getInstance() : trace;
  return new AtomicInt(initial);
}
function invokeOnCancellation(_this__u8e3s4, handler) {
  var tmp;
  if (_this__u8e3s4 instanceof CancellableContinuationImpl) {
    _this__u8e3s4.k19(handler);
    tmp = Unit_instance;
  } else {
    throw UnsupportedOperationException.t9('third-party implementation of CancellableContinuation is not supported');
  }
  return tmp;
}
function _get_parentHandle__f8dcex($this) {
  return $this.j19_1.kotlinx$atomicfu$value;
}
function _get_stateDebugRepresentation__bf18u4($this) {
  var tmp0_subject = $this.l19();
  var tmp;
  if (!(tmp0_subject == null) ? isInterface(tmp0_subject, NotCompleted) : false) {
    tmp = 'Active';
  } else {
    if (tmp0_subject instanceof CancelledContinuation) {
      tmp = 'Cancelled';
    } else {
      tmp = 'Completed';
    }
  }
  return tmp;
}
function isReusable($this) {
  var tmp;
  if (get_isReusableMode($this.t19_1)) {
    var tmp_0 = $this.f19_1;
    tmp = (tmp_0 instanceof DispatchedContinuation ? tmp_0 : THROW_CCE()).s19();
  } else {
    tmp = false;
  }
  return tmp;
}
function cancelLater($this, cause) {
  if (!isReusable($this))
    return false;
  var tmp = $this.f19_1;
  var dispatched = tmp instanceof DispatchedContinuation ? tmp : THROW_CCE();
  return dispatched.u19(cause);
}
function callSegmentOnCancellation($this, segment, cause) {
  // Inline function 'kotlinx.coroutines.index' call
  var index = $this.h19_1.kotlinx$atomicfu$value & 536870911;
  // Inline function 'kotlin.check' call
  if (!!(index === 536870911)) {
    // Inline function 'kotlinx.coroutines.CancellableContinuationImpl.callSegmentOnCancellation.<anonymous>' call
    var message = 'The index for Segment.onCancellation(..) is broken';
    throw IllegalStateException.n4(toString_1(message));
  }
  // Inline function 'kotlinx.coroutines.CancellableContinuationImpl.callCancelHandlerSafely' call
  try {
    // Inline function 'kotlinx.coroutines.CancellableContinuationImpl.callSegmentOnCancellation.<anonymous>' call
    segment.v19(index, cause, $this.dc());
  } catch ($p) {
    if ($p instanceof Error) {
      var ex = $p;
      handleCoroutineException($this.dc(), CompletionHandlerException.z19('Exception in invokeOnCancellation handler for ' + $this.toString(), ex));
    } else {
      throw $p;
    }
  }
}
function trySuspend($this) {
  // Inline function 'kotlinx.atomicfu.loop' call
  var this_0 = $this.h19_1;
  while (true) {
    // Inline function 'kotlinx.coroutines.CancellableContinuationImpl.trySuspend.<anonymous>' call
    var cur = this_0.kotlinx$atomicfu$value;
    // Inline function 'kotlinx.coroutines.decision' call
    switch (cur >> 29) {
      case 0:
        // Inline function 'kotlinx.coroutines.index' call

        // Inline function 'kotlinx.coroutines.decisionAndIndex' call

        var tmp$ret$2 = (1 << 29) + (cur & 536870911) | 0;
        if ($this.h19_1.atomicfu$compareAndSet(cur, tmp$ret$2))
          return true;
        break;
      case 2:
        return false;
      default:
        // Inline function 'kotlin.error' call

        var message = 'Already suspended';
        throw IllegalStateException.n4(toString_1(message));
    }
  }
}
function tryResume($this) {
  // Inline function 'kotlinx.atomicfu.loop' call
  var this_0 = $this.h19_1;
  while (true) {
    // Inline function 'kotlinx.coroutines.CancellableContinuationImpl.tryResume.<anonymous>' call
    var cur = this_0.kotlinx$atomicfu$value;
    // Inline function 'kotlinx.coroutines.decision' call
    switch (cur >> 29) {
      case 0:
        // Inline function 'kotlinx.coroutines.index' call

        // Inline function 'kotlinx.coroutines.decisionAndIndex' call

        var tmp$ret$2 = (2 << 29) + (cur & 536870911) | 0;
        if ($this.h19_1.atomicfu$compareAndSet(cur, tmp$ret$2))
          return true;
        break;
      case 1:
        return false;
      default:
        // Inline function 'kotlin.error' call

        var message = 'Already resumed';
        throw IllegalStateException.n4(toString_1(message));
    }
  }
}
function installParentHandle($this) {
  var tmp0_elvis_lhs = $this.dc().ec(Key_instance_2);
  var tmp;
  if (tmp0_elvis_lhs == null) {
    return null;
  } else {
    tmp = tmp0_elvis_lhs;
  }
  var parent = tmp;
  var handle = invokeOnCompletion(parent, VOID, new ChildContinuation($this));
  $this.j19_1.atomicfu$compareAndSet(null, handle);
  return handle;
}
function invokeOnCancellationImpl($this, handler) {
  // Inline function 'kotlinx.coroutines.assert' call
  // Inline function 'kotlinx.atomicfu.loop' call
  var this_0 = $this.i19_1;
  while (true) {
    // Inline function 'kotlinx.coroutines.CancellableContinuationImpl.invokeOnCancellationImpl.<anonymous>' call
    var state = this_0.kotlinx$atomicfu$value;
    if (state instanceof Active) {
      if ($this.i19_1.atomicfu$compareAndSet(state, handler))
        return Unit_instance;
    } else {
      var tmp;
      if (!(state == null) ? isInterface(state, CancelHandler) : false) {
        tmp = true;
      } else {
        tmp = state instanceof Segment;
      }
      if (tmp) {
        multipleHandlersError($this, handler, state);
      } else {
        if (state instanceof CompletedExceptionally) {
          if (!state.k1a()) {
            multipleHandlersError($this, handler, state);
          }
          if (state instanceof CancelledContinuation) {
            var tmp1_safe_receiver = state instanceof CompletedExceptionally ? state : null;
            var cause = tmp1_safe_receiver == null ? null : tmp1_safe_receiver.i1a_1;
            if (isInterface(handler, CancelHandler)) {
              $this.f1a(handler, cause);
            } else {
              var segment = handler instanceof Segment ? handler : THROW_CCE();
              callSegmentOnCancellation($this, segment, cause);
            }
          }
          return Unit_instance;
        } else {
          if (state instanceof CompletedContinuation) {
            if (!(state.b1a_1 == null)) {
              multipleHandlersError($this, handler, state);
            }
            if (handler instanceof Segment)
              return Unit_instance;
            if (!isInterface(handler, CancelHandler))
              THROW_CCE();
            if (state.g1a()) {
              $this.f1a(handler, state.e1a_1);
              return Unit_instance;
            }
            var update = state.h1a(VOID, handler);
            if ($this.i19_1.atomicfu$compareAndSet(state, update))
              return Unit_instance;
          } else {
            if (handler instanceof Segment)
              return Unit_instance;
            if (!isInterface(handler, CancelHandler))
              THROW_CCE();
            var update_0 = new CompletedContinuation(state, handler);
            if ($this.i19_1.atomicfu$compareAndSet(state, update_0))
              return Unit_instance;
          }
        }
      }
    }
  }
}
function multipleHandlersError($this, handler, state) {
  // Inline function 'kotlin.error' call
  var message = "It's prohibited to register multiple handlers, tried to register " + toString_1(handler) + ', already has ' + toString_0(state);
  throw IllegalStateException.n4(toString_1(message));
}
function dispatchResume($this, mode) {
  if (tryResume($this))
    return Unit_instance;
  dispatch($this, mode);
}
function resumedState($this, state, proposedUpdate, resumeMode, onCancellation, idempotent) {
  var tmp;
  if (proposedUpdate instanceof CompletedExceptionally) {
    // Inline function 'kotlinx.coroutines.assert' call
    // Inline function 'kotlinx.coroutines.assert' call
    tmp = proposedUpdate;
  } else {
    if (!get_isCancellableMode(resumeMode) && idempotent == null) {
      tmp = proposedUpdate;
    } else {
      var tmp_0;
      var tmp_1;
      if (!(onCancellation == null)) {
        tmp_1 = true;
      } else {
        tmp_1 = isInterface(state, CancelHandler);
      }
      if (tmp_1) {
        tmp_0 = true;
      } else {
        tmp_0 = !(idempotent == null);
      }
      if (tmp_0) {
        tmp = new CompletedContinuation(proposedUpdate, isInterface(state, CancelHandler) ? state : null, onCancellation, idempotent);
      } else {
        tmp = proposedUpdate;
      }
    }
  }
  return tmp;
}
function alreadyResumedError($this, proposedUpdate) {
  // Inline function 'kotlin.error' call
  var message = 'Already resumed, but proposed with update ' + toString_0(proposedUpdate);
  throw IllegalStateException.n4(toString_1(message));
}
function detachChildIfNonReusable($this) {
  if (!isReusable($this)) {
    $this.l1a();
  }
}
var Active_instance;
function Active_getInstance() {
  return Active_instance;
}
function toState(_this__u8e3s4, caller) {
  // Inline function 'kotlin.getOrElse' call
  var exception = Result__exceptionOrNull_impl_p6xea9(_this__u8e3s4);
  var tmp;
  if (exception == null) {
    var tmp_0 = _Result___get_value__impl__bjfvqg(_this__u8e3s4);
    tmp = (tmp_0 == null ? true : !(tmp_0 == null)) ? tmp_0 : THROW_CCE();
  } else {
    // Inline function 'kotlinx.coroutines.toState.<anonymous>' call
    tmp = new CompletedExceptionally(recoverStackTrace(exception, caller));
  }
  return tmp;
}
function toState_0(_this__u8e3s4) {
  // Inline function 'kotlin.getOrElse' call
  var exception = Result__exceptionOrNull_impl_p6xea9(_this__u8e3s4);
  var tmp;
  if (exception == null) {
    var tmp_0 = _Result___get_value__impl__bjfvqg(_this__u8e3s4);
    tmp = (tmp_0 == null ? true : !(tmp_0 == null)) ? tmp_0 : THROW_CCE();
  } else {
    // Inline function 'kotlinx.coroutines.toState.<anonymous>' call
    tmp = new CompletedExceptionally(exception);
  }
  return tmp;
}
function CoroutineDispatcher$Key$_init_$lambda_akl8b5(it) {
  return it instanceof CoroutineDispatcher ? it : null;
}
var Key_instance_0;
function Key_getInstance_0() {
  if (Key_instance_0 === VOID)
    new Key_0();
  return Key_instance_0;
}
function handleCoroutineException(context, exception) {
  var tmp;
  if (exception instanceof DispatchException) {
    tmp = exception.m1c_1;
  } else {
    tmp = exception;
  }
  var reportException = tmp;
  try {
    var tmp0_safe_receiver = context.ec(Key_instance_1);
    if (tmp0_safe_receiver == null)
      null;
    else {
      // Inline function 'kotlin.let' call
      tmp0_safe_receiver.o1c(context, reportException);
      return Unit_instance;
    }
  } catch ($p) {
    if ($p instanceof Error) {
      var t = $p;
      handleUncaughtCoroutineException(context, handlerException(reportException, t));
      return Unit_instance;
    } else {
      throw $p;
    }
  }
  handleUncaughtCoroutineException(context, reportException);
}
var Key_instance_1;
function Key_getInstance_1() {
  return Key_instance_1;
}
function handlerException(originalException, thrownException) {
  if (originalException === thrownException)
    return originalException;
  // Inline function 'kotlin.apply' call
  var this_0 = RuntimeException.rc('Exception while trying to handle coroutine exception', thrownException);
  // Inline function 'kotlinx.coroutines.handlerException.<anonymous>' call
  addSuppressed(this_0, originalException);
  return this_0;
}
function delta($this, unconfined) {
  return unconfined ? new Long(0, 1) : new Long(1, 0);
}
var ThreadLocalEventLoop_instance;
function ThreadLocalEventLoop_getInstance() {
  if (ThreadLocalEventLoop_instance === VOID)
    new ThreadLocalEventLoop();
  return ThreadLocalEventLoop_instance;
}
var Key_instance_2;
function Key_getInstance_2() {
  return Key_instance_2;
}
var NonDisposableHandle_instance;
function NonDisposableHandle_getInstance() {
  return NonDisposableHandle_instance;
}
function invokeOnCompletion(_this__u8e3s4, invokeImmediately, handler) {
  invokeImmediately = invokeImmediately === VOID ? true : invokeImmediately;
  var tmp;
  if (_this__u8e3s4 instanceof JobSupport) {
    tmp = _this__u8e3s4.j1d(invokeImmediately, handler);
  } else {
    var tmp_0 = handler.v1b();
    tmp = _this__u8e3s4.h1d(tmp_0, invokeImmediately, JobNode$invoke$ref(handler));
  }
  return tmp;
}
function JobNode$invoke$ref($boundThis) {
  var l = (p0) => {
    $boundThis.v1a(p0);
    return Unit_instance;
  };
  l.callableName = 'invoke';
  return l;
}
var COMPLETING_ALREADY;
var COMPLETING_WAITING_CHILDREN;
var COMPLETING_RETRY;
var TOO_LATE_TO_CANCEL;
var SEALED;
var EMPTY_NEW;
function get_EMPTY_ACTIVE() {
  _init_properties_JobSupport_kt__68f172();
  return EMPTY_ACTIVE;
}
var EMPTY_ACTIVE;
function promoteEmptyToNodeList($this, state) {
  var list = new NodeList();
  var update = state.k1d_1 ? list : new InactiveNodeList(list);
  $this.i1d_1.atomicfu$compareAndSet(state, update);
}
function promoteSingleToNodeList($this, state) {
  state.h1c(new NodeList());
  // Inline function 'kotlinx.coroutines.internal.LockFreeLinkedListNode.nextNode' call
  var list = state.c1c_1;
  $this.i1d_1.atomicfu$compareAndSet(state, list);
}
var properties_initialized_JobSupport_kt_5iq8a4;
function _init_properties_JobSupport_kt__68f172() {
  if (!properties_initialized_JobSupport_kt_5iq8a4) {
    properties_initialized_JobSupport_kt_5iq8a4 = true;
    COMPLETING_ALREADY = new Symbol_0('COMPLETING_ALREADY');
    COMPLETING_WAITING_CHILDREN = new Symbol_0('COMPLETING_WAITING_CHILDREN');
    COMPLETING_RETRY = new Symbol_0('COMPLETING_RETRY');
    TOO_LATE_TO_CANCEL = new Symbol_0('TOO_LATE_TO_CANCEL');
    SEALED = new Symbol_0('SEALED');
    EMPTY_NEW = new Empty(false);
    EMPTY_ACTIVE = new Empty(true);
  }
}
function handleUncaughtCoroutineException(context, exception) {
  var _iterator__ex2g4s = get_platformExceptionHandlers().x();
  while (_iterator__ex2g4s.y()) {
    var handler = _iterator__ex2g4s.z();
    try {
      handler.o1c(context, exception);
    } catch ($p) {
      if ($p instanceof ExceptionSuccessfullyProcessed) {
        var _unused_var__etf5q3 = $p;
        return Unit_instance;
      } else {
        if ($p instanceof Error) {
          var t = $p;
          propagateExceptionFinalResort(handlerException(exception, t));
        } else {
          throw $p;
        }
      }
    }
  }
  try {
    addSuppressed(exception, DiagnosticCoroutineContextException.w1d(context));
  } catch ($p) {
    if ($p instanceof Error) {
      var e = $p;
    } else {
      throw $p;
    }
  }
  propagateExceptionFinalResort(exception);
}
function get_UNDEFINED() {
  _init_properties_DispatchedContinuation_kt__tnmqc0();
  return UNDEFINED;
}
var UNDEFINED;
function get_REUSABLE_CLAIMED() {
  _init_properties_DispatchedContinuation_kt__tnmqc0();
  return REUSABLE_CLAIMED;
}
var REUSABLE_CLAIMED;
function safeDispatch(_this__u8e3s4, context, runnable) {
  _init_properties_DispatchedContinuation_kt__tnmqc0();
  try {
    _this__u8e3s4.k1c(context, runnable);
  } catch ($p) {
    if ($p instanceof Error) {
      var e = $p;
      throw DispatchException.x1d(e, _this__u8e3s4, context);
    } else {
      throw $p;
    }
  }
}
function safeIsDispatchNeeded(_this__u8e3s4, context) {
  _init_properties_DispatchedContinuation_kt__tnmqc0();
  try {
    return _this__u8e3s4.j1c(context);
  } catch ($p) {
    if ($p instanceof Error) {
      var e = $p;
      throw DispatchException.x1d(e, _this__u8e3s4, context);
    } else {
      throw $p;
    }
  }
}
var properties_initialized_DispatchedContinuation_kt_2siadq;
function _init_properties_DispatchedContinuation_kt__tnmqc0() {
  if (!properties_initialized_DispatchedContinuation_kt_2siadq) {
    properties_initialized_DispatchedContinuation_kt_2siadq = true;
    UNDEFINED = new Symbol_0('UNDEFINED');
    REUSABLE_CLAIMED = new Symbol_0('REUSABLE_CLAIMED');
  }
}
function get_isReusableMode(_this__u8e3s4) {
  return _this__u8e3s4 === 2;
}
function get_isCancellableMode(_this__u8e3s4) {
  return _this__u8e3s4 === 1 || _this__u8e3s4 === 2;
}
function dispatch(_this__u8e3s4, mode) {
  // Inline function 'kotlinx.coroutines.assert' call
  var delegate = _this__u8e3s4.m1a();
  var undispatched = mode === 4;
  var tmp;
  var tmp_0;
  if (!undispatched) {
    tmp_0 = delegate instanceof DispatchedContinuation;
  } else {
    tmp_0 = false;
  }
  if (tmp_0) {
    tmp = get_isCancellableMode(mode) === get_isCancellableMode(_this__u8e3s4.t19_1);
  } else {
    tmp = false;
  }
  if (tmp) {
    var dispatcher = delegate.n19_1;
    var context = delegate.dc();
    if (safeIsDispatchNeeded(dispatcher, context)) {
      safeDispatch(dispatcher, context, _this__u8e3s4);
    } else {
      resumeUnconfined(_this__u8e3s4);
    }
  } else {
    resume(_this__u8e3s4, delegate, undispatched);
  }
}
function resumeUnconfined(_this__u8e3s4) {
  var eventLoop = ThreadLocalEventLoop_getInstance().b1d();
  if (eventLoop.v1c()) {
    eventLoop.u1c(_this__u8e3s4);
  } else {
    // Inline function 'kotlinx.coroutines.runUnconfinedEventLoop' call
    eventLoop.x1c(true);
    try {
      // Inline function 'kotlinx.coroutines.resumeUnconfined.<anonymous>' call
      resume(_this__u8e3s4, _this__u8e3s4.m1a(), true);
      $l$loop: while (eventLoop.t1c()) {
      }
    } catch ($p) {
      if ($p instanceof Error) {
        var e = $p;
        _this__u8e3s4.n1b(e);
      } else {
        throw $p;
      }
    }
    finally {
      eventLoop.y1c(true);
    }
  }
}
function resume(_this__u8e3s4, delegate, undispatched) {
  var state = _this__u8e3s4.q1a();
  var exception = _this__u8e3s4.l1b(state);
  var tmp;
  if (!(exception == null)) {
    // Inline function 'kotlin.Companion.failure' call
    tmp = _Result___init__impl__xyqfz8(createFailure(exception));
  } else {
    // Inline function 'kotlin.Companion.success' call
    var value = _this__u8e3s4.b1b(state);
    tmp = _Result___init__impl__xyqfz8(value);
  }
  var result = tmp;
  if (undispatched) {
    // Inline function 'kotlinx.coroutines.internal.DispatchedContinuation.resumeUndispatchedWith' call
    var this_0 = delegate instanceof DispatchedContinuation ? delegate : THROW_CCE();
    this_0.o19_1;
    // Inline function 'kotlinx.coroutines.withContinuationContext' call
    this_0.q19_1;
    // Inline function 'kotlinx.coroutines.internal.DispatchedContinuation.resumeUndispatchedWith.<anonymous>' call
    this_0.o19_1.d1b(result);
  } else {
    delegate.d1b(result);
  }
}
var counter;
function get_DEBUG() {
  return DEBUG;
}
var DEBUG;
function get_classSimpleName(_this__u8e3s4) {
  var tmp0_elvis_lhs = getKClassFromExpression(_this__u8e3s4).td();
  return tmp0_elvis_lhs == null ? 'Unknown' : tmp0_elvis_lhs;
}
function get_hexAddress(_this__u8e3s4) {
  // Inline function 'kotlin.js.asDynamic' call
  var result = _this__u8e3s4.__debug_counter;
  if (!(typeof result === 'number')) {
    counter = counter + 1 | 0;
    result = counter;
    // Inline function 'kotlin.js.asDynamic' call
    _this__u8e3s4.__debug_counter = result;
  }
  return ((!(result == null) ? typeof result === 'number' : false) ? result : THROW_CCE()).toString();
}
function propagateExceptionFinalResort(exception) {
  console.error(exception.toString());
}
function createEventLoop() {
  return new UnconfinedEventLoop();
}
function unsupported() {
  throw UnsupportedOperationException.t9('runBlocking event loop is not supported');
}
function toDebugString(_this__u8e3s4) {
  return toString_1(_this__u8e3s4);
}
function get_platformExceptionHandlers_() {
  _init_properties_CoroutineExceptionHandlerImpl_kt__37d7wf();
  return platformExceptionHandlers_;
}
var platformExceptionHandlers_;
function get_platformExceptionHandlers() {
  _init_properties_CoroutineExceptionHandlerImpl_kt__37d7wf();
  return get_platformExceptionHandlers_();
}
var properties_initialized_CoroutineExceptionHandlerImpl_kt_qhrgvx;
function _init_properties_CoroutineExceptionHandlerImpl_kt__37d7wf() {
  if (!properties_initialized_CoroutineExceptionHandlerImpl_kt_qhrgvx) {
    properties_initialized_CoroutineExceptionHandlerImpl_kt_qhrgvx = true;
    // Inline function 'kotlin.collections.mutableSetOf' call
    platformExceptionHandlers_ = LinkedHashSet.d1();
  }
}
function recoverStackTrace(exception, continuation) {
  return exception;
}
function threadContextElements(context) {
  return 0;
}
function commonThreadLocal(name) {
  return new CommonThreadLocal();
}
function getValueByIndex(target, index) {
  return target[index];
}
function unsafeCast(value) {
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return value;
}
function unsafeCast_0(value) {
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return value;
}
function copy(_this__u8e3s4, maxByteLength) {
  maxByteLength = maxByteLength === VOID ? VOID : maxByteLength;
  return Object.assign({}, _this__u8e3s4, {maxByteLength: maxByteLength});
}
function invoke(_this__u8e3s4, maxByteLength) {
  return {maxByteLength: maxByteLength};
}
function iteratorFromJsIterable(source) {
  // Inline function 'js.iterable.JsIterator.iterator' call
  var this_0 = source[Symbol.iterator]();
  return iteratorFromJsIteratorLike(this_0);
}
function iteratorFromJsIteratorLike(source) {
  var tmp = generateSequence(iteratorFromJsIteratorLike$lambda(source));
  return map(tmp, iteratorFromJsIteratorLike$lambda_0).x();
}
function iteratorFromJsIteratorLike$lambda($source) {
  return () => {
    var tmp = $source.next();
    return tmp instanceof constructor ? tmp : null;
  };
}
function iteratorFromJsIteratorLike$lambda_0(it) {
  return it.value;
}
function copy_0(_this__u8e3s4, enumerable, value, get, writable, set, configurable) {
  enumerable = enumerable === VOID ? VOID : enumerable;
  value = value === VOID ? VOID : value;
  get = get === VOID ? VOID : get;
  writable = writable === VOID ? VOID : writable;
  set = set === VOID ? VOID : set;
  configurable = configurable === VOID ? VOID : configurable;
  return Object.assign({}, _this__u8e3s4, {enumerable: enumerable, value: value, get: get, writable: writable, set: set, configurable: configurable});
}
function invoke_0(_this__u8e3s4, enumerable, value, get, writable, set, configurable) {
  enumerable = enumerable === VOID ? VOID : enumerable;
  value = value === VOID ? VOID : value;
  get = get === VOID ? VOID : get;
  writable = writable === VOID ? VOID : writable;
  set = set === VOID ? VOID : set;
  configurable = configurable === VOID ? VOID : configurable;
  return {enumerable: enumerable, value: value, get: get, writable: writable, set: set, configurable: configurable};
}
function awaitPromiseLike(promise, $completion) {
  // Inline function 'kotlinx.coroutines.suspendCancellableCoroutine.<anonymous>' call
  var cancellable = new CancellableContinuationImpl(intercepted($completion), 1);
  cancellable.o1a();
  // Inline function 'js.promise.internal.awaitPromiseLike.stub_for_inlining' call
  thenToContinuation(promise, cancellable);
  return cancellable.z1a();
}
function thenToContinuation(promise, continuation) {
  var tmp = thenToContinuation$lambda(continuation);
  promise.then(tmp, thenToContinuation$lambda_0(continuation));
}
function thenToContinuation$lambda($continuation) {
  return (it) => {
    // Inline function 'kotlin.coroutines.resume' call
    var this_0 = $continuation;
    // Inline function 'kotlin.Companion.success' call
    var tmp$ret$0 = _Result___init__impl__xyqfz8(it);
    this_0.d1b(tmp$ret$0);
    return Unit_instance;
  };
}
function thenToContinuation$lambda_0($continuation) {
  return (it) => {
    // Inline function 'js.errors.toThrowable' call
    // Inline function 'kotlin.coroutines.resumeWithException' call
    var this_0 = $continuation;
    // Inline function 'kotlin.Companion.failure' call
    var tmp$ret$1 = _Result___init__impl__xyqfz8(createFailure(it));
    this_0.d1b(tmp$ret$1);
    return Unit_instance;
  };
}
function copy_1(_this__u8e3s4, hourCycle, second, timeZone, calendar, era, dateStyle, formatMatcher, day, localeMatcher, hour12, fractionalSecondDigits, month, hour, dayPeriod, weekday, minute, timeStyle, timeZoneName, year, numberingSystem) {
  hourCycle = hourCycle === VOID ? VOID : hourCycle;
  second = second === VOID ? VOID : second;
  timeZone = timeZone === VOID ? VOID : timeZone;
  calendar = calendar === VOID ? VOID : calendar;
  era = era === VOID ? VOID : era;
  dateStyle = dateStyle === VOID ? VOID : dateStyle;
  formatMatcher = formatMatcher === VOID ? VOID : formatMatcher;
  day = day === VOID ? VOID : day;
  localeMatcher = localeMatcher === VOID ? VOID : localeMatcher;
  hour12 = hour12 === VOID ? VOID : hour12;
  fractionalSecondDigits = fractionalSecondDigits === VOID ? VOID : fractionalSecondDigits;
  month = month === VOID ? VOID : month;
  hour = hour === VOID ? VOID : hour;
  dayPeriod = dayPeriod === VOID ? VOID : dayPeriod;
  weekday = weekday === VOID ? VOID : weekday;
  minute = minute === VOID ? VOID : minute;
  timeStyle = timeStyle === VOID ? VOID : timeStyle;
  timeZoneName = timeZoneName === VOID ? VOID : timeZoneName;
  year = year === VOID ? VOID : year;
  numberingSystem = numberingSystem === VOID ? VOID : numberingSystem;
  return Object.assign({}, _this__u8e3s4, {hourCycle: hourCycle, second: second, timeZone: timeZone, calendar: calendar, era: era, dateStyle: dateStyle, formatMatcher: formatMatcher, day: day, localeMatcher: localeMatcher, hour12: hour12, fractionalSecondDigits: fractionalSecondDigits, month: month, hour: hour, dayPeriod: dayPeriod, weekday: weekday, minute: minute, timeStyle: timeStyle, timeZoneName: timeZoneName, year: year, numberingSystem: numberingSystem});
}
function invoke_1(_this__u8e3s4, hourCycle, second, timeZone, calendar, era, dateStyle, formatMatcher, day, localeMatcher, hour12, fractionalSecondDigits, month, hour, dayPeriod, weekday, minute, timeStyle, timeZoneName, year, numberingSystem) {
  hourCycle = hourCycle === VOID ? VOID : hourCycle;
  second = second === VOID ? VOID : second;
  timeZone = timeZone === VOID ? VOID : timeZone;
  calendar = calendar === VOID ? VOID : calendar;
  era = era === VOID ? VOID : era;
  dateStyle = dateStyle === VOID ? VOID : dateStyle;
  formatMatcher = formatMatcher === VOID ? VOID : formatMatcher;
  day = day === VOID ? VOID : day;
  localeMatcher = localeMatcher === VOID ? VOID : localeMatcher;
  hour12 = hour12 === VOID ? VOID : hour12;
  fractionalSecondDigits = fractionalSecondDigits === VOID ? VOID : fractionalSecondDigits;
  month = month === VOID ? VOID : month;
  hour = hour === VOID ? VOID : hour;
  dayPeriod = dayPeriod === VOID ? VOID : dayPeriod;
  weekday = weekday === VOID ? VOID : weekday;
  minute = minute === VOID ? VOID : minute;
  timeStyle = timeStyle === VOID ? VOID : timeStyle;
  timeZoneName = timeZoneName === VOID ? VOID : timeZoneName;
  year = year === VOID ? VOID : year;
  numberingSystem = numberingSystem === VOID ? VOID : numberingSystem;
  return {hourCycle: hourCycle, second: second, timeZone: timeZone, calendar: calendar, era: era, dateStyle: dateStyle, formatMatcher: formatMatcher, day: day, localeMatcher: localeMatcher, hour12: hour12, fractionalSecondDigits: fractionalSecondDigits, month: month, hour: hour, dayPeriod: dayPeriod, weekday: weekday, minute: minute, timeStyle: timeStyle, timeZoneName: timeZoneName, year: year, numberingSystem: numberingSystem};
}
function get_POW() {
  _init_properties_BigInt_kt__agomkx();
  return POW;
}
var POW;
function get_n(_this__u8e3s4) {
  _init_properties_BigInt_kt__agomkx();
  return BigInt(_this__u8e3s4);
}
var properties_initialized_BigInt_kt_nhzooh;
function _init_properties_BigInt_kt__agomkx() {
  if (!properties_initialized_BigInt_kt_nhzooh) {
    properties_initialized_BigInt_kt_nhzooh = true;
    POW = Function('base', 'exponent', 'return base ** exponent');
  }
}
function invoke_2(_this__u8e3s4, p1, p2) {
  // Inline function 'js.reflect.unsafeCast' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return _this__u8e3s4(p1, p2);
}
function copy_2(_this__u8e3s4, overflow) {
  overflow = overflow === VOID ? VOID : overflow;
  return Object.assign({}, _this__u8e3s4, {overflow: overflow});
}
function invoke_3(_this__u8e3s4, overflow) {
  overflow = overflow === VOID ? VOID : overflow;
  return {overflow: overflow};
}
function copy_3(_this__u8e3s4, overflow) {
  overflow = overflow === VOID ? VOID : overflow;
  return Object.assign({}, _this__u8e3s4, {overflow: overflow});
}
function invoke_4(_this__u8e3s4, overflow) {
  overflow = overflow === VOID ? VOID : overflow;
  return {overflow: overflow};
}
function copy_4(_this__u8e3s4, era, eraYear, year, month, monthCode, day) {
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  year = year === VOID ? VOID : year;
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  day = day === VOID ? VOID : day;
  return Object.assign({}, _this__u8e3s4, {era: era, eraYear: eraYear, year: year, month: month, monthCode: monthCode, day: day});
}
function invoke_5(_this__u8e3s4, era, eraYear, year, month, monthCode, day) {
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  year = year === VOID ? VOID : year;
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  return {era: era, eraYear: eraYear, year: year, month: month, monthCode: monthCode, day: day};
}
function copy_5(_this__u8e3s4, era, eraYear, year, month, monthCode) {
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  year = year === VOID ? VOID : year;
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  return Object.assign({}, _this__u8e3s4, {era: era, eraYear: eraYear, year: year, month: month, monthCode: monthCode});
}
function invoke_6(_this__u8e3s4, era, eraYear, year, month, monthCode) {
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  year = year === VOID ? VOID : year;
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  return {era: era, eraYear: eraYear, year: year, month: month, monthCode: monthCode};
}
function copy_6(_this__u8e3s4, era, eraYear, year, month, monthCode, day) {
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  year = year === VOID ? VOID : year;
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  day = day === VOID ? VOID : day;
  return Object.assign({}, _this__u8e3s4, {era: era, eraYear: eraYear, year: year, month: month, monthCode: monthCode, day: day});
}
function invoke_7(_this__u8e3s4, era, eraYear, year, month, monthCode, day) {
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  year = year === VOID ? VOID : year;
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  return {era: era, eraYear: eraYear, year: year, month: month, monthCode: monthCode, day: day};
}
function copy_7(_this__u8e3s4, smallestUnit, roundingMode, fractionalSecondDigits, calendarName) {
  smallestUnit = smallestUnit === VOID ? VOID : smallestUnit;
  roundingMode = roundingMode === VOID ? VOID : roundingMode;
  fractionalSecondDigits = fractionalSecondDigits === VOID ? VOID : fractionalSecondDigits;
  calendarName = calendarName === VOID ? VOID : calendarName;
  return Object.assign({}, _this__u8e3s4, {smallestUnit: smallestUnit, roundingMode: roundingMode, fractionalSecondDigits: fractionalSecondDigits, calendarName: calendarName});
}
function invoke_8(_this__u8e3s4, smallestUnit, roundingMode, fractionalSecondDigits, calendarName) {
  smallestUnit = smallestUnit === VOID ? VOID : smallestUnit;
  roundingMode = roundingMode === VOID ? VOID : roundingMode;
  fractionalSecondDigits = fractionalSecondDigits === VOID ? VOID : fractionalSecondDigits;
  calendarName = calendarName === VOID ? VOID : calendarName;
  return {smallestUnit: smallestUnit, roundingMode: roundingMode, fractionalSecondDigits: fractionalSecondDigits, calendarName: calendarName};
}
function copy_8(_this__u8e3s4, roundingIncrement, smallestUnit, roundingMode, largestUnit) {
  roundingIncrement = roundingIncrement === VOID ? VOID : roundingIncrement;
  smallestUnit = smallestUnit === VOID ? VOID : smallestUnit;
  roundingMode = roundingMode === VOID ? VOID : roundingMode;
  largestUnit = largestUnit === VOID ? VOID : largestUnit;
  return Object.assign({}, _this__u8e3s4, {roundingIncrement: roundingIncrement, smallestUnit: smallestUnit, roundingMode: roundingMode, largestUnit: largestUnit});
}
function invoke_9(_this__u8e3s4, roundingIncrement, smallestUnit, roundingMode, largestUnit) {
  roundingIncrement = roundingIncrement === VOID ? VOID : roundingIncrement;
  smallestUnit = smallestUnit === VOID ? VOID : smallestUnit;
  roundingMode = roundingMode === VOID ? VOID : roundingMode;
  largestUnit = largestUnit === VOID ? VOID : largestUnit;
  return {roundingIncrement: roundingIncrement, smallestUnit: smallestUnit, roundingMode: roundingMode, largestUnit: largestUnit};
}
function copy_9(_this__u8e3s4, relativeTo) {
  relativeTo = relativeTo === VOID ? VOID : relativeTo;
  return Object.assign({}, _this__u8e3s4, {relativeTo: relativeTo});
}
function invoke_10(_this__u8e3s4, relativeTo) {
  relativeTo = relativeTo === VOID ? VOID : relativeTo;
  return {relativeTo: relativeTo};
}
function copy_10(_this__u8e3s4, microseconds, milliseconds, days, nanoseconds, months, hours, minutes, years, seconds, weeks) {
  microseconds = microseconds === VOID ? VOID : microseconds;
  milliseconds = milliseconds === VOID ? VOID : milliseconds;
  days = days === VOID ? VOID : days;
  nanoseconds = nanoseconds === VOID ? VOID : nanoseconds;
  months = months === VOID ? VOID : months;
  hours = hours === VOID ? VOID : hours;
  minutes = minutes === VOID ? VOID : minutes;
  years = years === VOID ? VOID : years;
  seconds = seconds === VOID ? VOID : seconds;
  weeks = weeks === VOID ? VOID : weeks;
  return Object.assign({}, _this__u8e3s4, {microseconds: microseconds, milliseconds: milliseconds, days: days, nanoseconds: nanoseconds, months: months, hours: hours, minutes: minutes, years: years, seconds: seconds, weeks: weeks});
}
function invoke_11(_this__u8e3s4, microseconds, milliseconds, days, nanoseconds, months, hours, minutes, years, seconds, weeks) {
  microseconds = microseconds === VOID ? VOID : microseconds;
  milliseconds = milliseconds === VOID ? VOID : milliseconds;
  days = days === VOID ? VOID : days;
  nanoseconds = nanoseconds === VOID ? VOID : nanoseconds;
  months = months === VOID ? VOID : months;
  hours = hours === VOID ? VOID : hours;
  minutes = minutes === VOID ? VOID : minutes;
  years = years === VOID ? VOID : years;
  seconds = seconds === VOID ? VOID : seconds;
  weeks = weeks === VOID ? VOID : weeks;
  return {microseconds: microseconds, milliseconds: milliseconds, days: days, nanoseconds: nanoseconds, months: months, hours: hours, minutes: minutes, years: years, seconds: seconds, weeks: weeks};
}
function copy_11(_this__u8e3s4, smallestUnit, roundingMode, fractionalSecondDigits, timeZone) {
  smallestUnit = smallestUnit === VOID ? VOID : smallestUnit;
  roundingMode = roundingMode === VOID ? VOID : roundingMode;
  fractionalSecondDigits = fractionalSecondDigits === VOID ? VOID : fractionalSecondDigits;
  timeZone = timeZone === VOID ? VOID : timeZone;
  return Object.assign({}, _this__u8e3s4, {smallestUnit: smallestUnit, roundingMode: roundingMode, fractionalSecondDigits: fractionalSecondDigits, timeZone: timeZone});
}
function invoke_12(_this__u8e3s4, smallestUnit, roundingMode, fractionalSecondDigits, timeZone) {
  smallestUnit = smallestUnit === VOID ? VOID : smallestUnit;
  roundingMode = roundingMode === VOID ? VOID : roundingMode;
  fractionalSecondDigits = fractionalSecondDigits === VOID ? VOID : fractionalSecondDigits;
  return {smallestUnit: smallestUnit, roundingMode: roundingMode, fractionalSecondDigits: fractionalSecondDigits, timeZone: timeZone};
}
function copy_12(_this__u8e3s4, era, eraYear, year, month, monthCode) {
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  year = year === VOID ? VOID : year;
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  return Object.assign({}, _this__u8e3s4, {era: era, eraYear: eraYear, year: year, month: month, monthCode: monthCode});
}
function invoke_13(_this__u8e3s4, era, eraYear, year, month, monthCode) {
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  year = year === VOID ? VOID : year;
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  return {era: era, eraYear: eraYear, year: year, month: month, monthCode: monthCode};
}
function copy_13(_this__u8e3s4, month, monthCode) {
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  return Object.assign({}, _this__u8e3s4, {month: month, monthCode: monthCode});
}
function invoke_14(_this__u8e3s4, month, monthCode) {
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  return {month: month, monthCode: monthCode};
}
function copy_14(_this__u8e3s4, offset) {
  offset = offset === VOID ? VOID : offset;
  return Object.assign({}, _this__u8e3s4, {offset: offset});
}
function invoke_15(_this__u8e3s4, offset) {
  offset = offset === VOID ? VOID : offset;
  return {offset: offset};
}
function copy_15(_this__u8e3s4, isoDay, calendar, isoMonth, isoYear) {
  isoDay = isoDay === VOID ? VOID : isoDay;
  calendar = calendar === VOID ? VOID : calendar;
  isoMonth = isoMonth === VOID ? VOID : isoMonth;
  isoYear = isoYear === VOID ? VOID : isoYear;
  return Object.assign({}, _this__u8e3s4, {isoDay: isoDay, calendar: calendar, isoMonth: isoMonth, isoYear: isoYear});
}
function invoke_16(_this__u8e3s4, isoDay, calendar, isoMonth, isoYear) {
  return {isoDay: isoDay, calendar: calendar, isoMonth: isoMonth, isoYear: isoYear};
}
function copy_16(_this__u8e3s4, month, monthCode, calendar, era, eraYear, day, year) {
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  calendar = calendar === VOID ? VOID : calendar;
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  day = day === VOID ? VOID : day;
  year = year === VOID ? VOID : year;
  return Object.assign({}, _this__u8e3s4, {month: month, monthCode: monthCode, calendar: calendar, era: era, eraYear: eraYear, day: day, year: year});
}
function invoke_17(_this__u8e3s4, month, monthCode, calendar, era, eraYear, day, year) {
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  calendar = calendar === VOID ? VOID : calendar;
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  day = day === VOID ? VOID : day;
  year = year === VOID ? VOID : year;
  return {month: month, monthCode: monthCode, calendar: calendar, era: era, eraYear: eraYear, day: day, year: year};
}
function copy_17(_this__u8e3s4, isoDay, isoSecond, calendar, isoMonth, isoMinute, isoMicrosecond, isoNanosecond, isoYear, isoHour, isoMillisecond) {
  isoDay = isoDay === VOID ? VOID : isoDay;
  isoSecond = isoSecond === VOID ? VOID : isoSecond;
  calendar = calendar === VOID ? VOID : calendar;
  isoMonth = isoMonth === VOID ? VOID : isoMonth;
  isoMinute = isoMinute === VOID ? VOID : isoMinute;
  isoMicrosecond = isoMicrosecond === VOID ? VOID : isoMicrosecond;
  isoNanosecond = isoNanosecond === VOID ? VOID : isoNanosecond;
  isoYear = isoYear === VOID ? VOID : isoYear;
  isoHour = isoHour === VOID ? VOID : isoHour;
  isoMillisecond = isoMillisecond === VOID ? VOID : isoMillisecond;
  return Object.assign({}, _this__u8e3s4, {isoDay: isoDay, isoSecond: isoSecond, calendar: calendar, isoMonth: isoMonth, isoMinute: isoMinute, isoMicrosecond: isoMicrosecond, isoNanosecond: isoNanosecond, isoYear: isoYear, isoHour: isoHour, isoMillisecond: isoMillisecond});
}
function invoke_18(_this__u8e3s4, isoDay, isoSecond, calendar, isoMonth, isoMinute, isoMicrosecond, isoNanosecond, isoYear, isoHour, isoMillisecond) {
  return {isoDay: isoDay, isoSecond: isoSecond, calendar: calendar, isoMonth: isoMonth, isoMinute: isoMinute, isoMicrosecond: isoMicrosecond, isoNanosecond: isoNanosecond, isoYear: isoYear, isoHour: isoHour, isoMillisecond: isoMillisecond};
}
function copy_18(_this__u8e3s4, second, calendar, era, microsecond, nanosecond, day, millisecond, month, hour, monthCode, minute, eraYear, year) {
  second = second === VOID ? VOID : second;
  calendar = calendar === VOID ? VOID : calendar;
  era = era === VOID ? VOID : era;
  microsecond = microsecond === VOID ? VOID : microsecond;
  nanosecond = nanosecond === VOID ? VOID : nanosecond;
  day = day === VOID ? VOID : day;
  millisecond = millisecond === VOID ? VOID : millisecond;
  month = month === VOID ? VOID : month;
  hour = hour === VOID ? VOID : hour;
  monthCode = monthCode === VOID ? VOID : monthCode;
  minute = minute === VOID ? VOID : minute;
  eraYear = eraYear === VOID ? VOID : eraYear;
  year = year === VOID ? VOID : year;
  return Object.assign({}, _this__u8e3s4, {second: second, calendar: calendar, era: era, microsecond: microsecond, nanosecond: nanosecond, day: day, millisecond: millisecond, month: month, hour: hour, monthCode: monthCode, minute: minute, eraYear: eraYear, year: year});
}
function invoke_19(_this__u8e3s4, second, calendar, era, microsecond, nanosecond, day, millisecond, month, hour, monthCode, minute, eraYear, year) {
  second = second === VOID ? VOID : second;
  calendar = calendar === VOID ? VOID : calendar;
  era = era === VOID ? VOID : era;
  microsecond = microsecond === VOID ? VOID : microsecond;
  nanosecond = nanosecond === VOID ? VOID : nanosecond;
  day = day === VOID ? VOID : day;
  millisecond = millisecond === VOID ? VOID : millisecond;
  month = month === VOID ? VOID : month;
  hour = hour === VOID ? VOID : hour;
  monthCode = monthCode === VOID ? VOID : monthCode;
  minute = minute === VOID ? VOID : minute;
  eraYear = eraYear === VOID ? VOID : eraYear;
  year = year === VOID ? VOID : year;
  return {second: second, calendar: calendar, era: era, microsecond: microsecond, nanosecond: nanosecond, day: day, millisecond: millisecond, month: month, hour: hour, monthCode: monthCode, minute: minute, eraYear: eraYear, year: year};
}
function copy_19(_this__u8e3s4, month, monthCode, calendar, era, eraYear, day, year) {
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  calendar = calendar === VOID ? VOID : calendar;
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  day = day === VOID ? VOID : day;
  year = year === VOID ? VOID : year;
  return Object.assign({}, _this__u8e3s4, {month: month, monthCode: monthCode, calendar: calendar, era: era, eraYear: eraYear, day: day, year: year});
}
function invoke_20(_this__u8e3s4, month, monthCode, calendar, era, eraYear, day, year) {
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  calendar = calendar === VOID ? VOID : calendar;
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  day = day === VOID ? VOID : day;
  year = year === VOID ? VOID : year;
  return {month: month, monthCode: monthCode, calendar: calendar, era: era, eraYear: eraYear, day: day, year: year};
}
function copy_20(_this__u8e3s4, isoSecond, isoMinute, isoMicrosecond, isoNanosecond, isoHour, isoMillisecond) {
  isoSecond = isoSecond === VOID ? VOID : isoSecond;
  isoMinute = isoMinute === VOID ? VOID : isoMinute;
  isoMicrosecond = isoMicrosecond === VOID ? VOID : isoMicrosecond;
  isoNanosecond = isoNanosecond === VOID ? VOID : isoNanosecond;
  isoHour = isoHour === VOID ? VOID : isoHour;
  isoMillisecond = isoMillisecond === VOID ? VOID : isoMillisecond;
  return Object.assign({}, _this__u8e3s4, {isoSecond: isoSecond, isoMinute: isoMinute, isoMicrosecond: isoMicrosecond, isoNanosecond: isoNanosecond, isoHour: isoHour, isoMillisecond: isoMillisecond});
}
function invoke_21(_this__u8e3s4, isoSecond, isoMinute, isoMicrosecond, isoNanosecond, isoHour, isoMillisecond) {
  return {isoSecond: isoSecond, isoMinute: isoMinute, isoMicrosecond: isoMicrosecond, isoNanosecond: isoNanosecond, isoHour: isoHour, isoMillisecond: isoMillisecond};
}
function copy_21(_this__u8e3s4, hour, second, minute, microsecond, nanosecond, millisecond) {
  hour = hour === VOID ? VOID : hour;
  second = second === VOID ? VOID : second;
  minute = minute === VOID ? VOID : minute;
  microsecond = microsecond === VOID ? VOID : microsecond;
  nanosecond = nanosecond === VOID ? VOID : nanosecond;
  millisecond = millisecond === VOID ? VOID : millisecond;
  return Object.assign({}, _this__u8e3s4, {hour: hour, second: second, minute: minute, microsecond: microsecond, nanosecond: nanosecond, millisecond: millisecond});
}
function invoke_22(_this__u8e3s4, hour, second, minute, microsecond, nanosecond, millisecond) {
  hour = hour === VOID ? VOID : hour;
  second = second === VOID ? VOID : second;
  minute = minute === VOID ? VOID : minute;
  microsecond = microsecond === VOID ? VOID : microsecond;
  nanosecond = nanosecond === VOID ? VOID : nanosecond;
  millisecond = millisecond === VOID ? VOID : millisecond;
  return {hour: hour, second: second, minute: minute, microsecond: microsecond, nanosecond: nanosecond, millisecond: millisecond};
}
function copy_22(_this__u8e3s4, month, monthCode, calendar, era, eraYear, year) {
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  calendar = calendar === VOID ? VOID : calendar;
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  year = year === VOID ? VOID : year;
  return Object.assign({}, _this__u8e3s4, {month: month, monthCode: monthCode, calendar: calendar, era: era, eraYear: eraYear, year: year});
}
function invoke_23(_this__u8e3s4, month, monthCode, calendar, era, eraYear, year) {
  month = month === VOID ? VOID : month;
  monthCode = monthCode === VOID ? VOID : monthCode;
  calendar = calendar === VOID ? VOID : calendar;
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  year = year === VOID ? VOID : year;
  return {month: month, monthCode: monthCode, calendar: calendar, era: era, eraYear: eraYear, year: year};
}
function copy_23(_this__u8e3s4, roundingIncrement, smallestUnit, roundingMode) {
  roundingIncrement = roundingIncrement === VOID ? VOID : roundingIncrement;
  smallestUnit = smallestUnit === VOID ? VOID : smallestUnit;
  roundingMode = roundingMode === VOID ? VOID : roundingMode;
  return Object.assign({}, _this__u8e3s4, {roundingIncrement: roundingIncrement, smallestUnit: smallestUnit, roundingMode: roundingMode});
}
function invoke_24(_this__u8e3s4, roundingIncrement, smallestUnit, roundingMode) {
  roundingIncrement = roundingIncrement === VOID ? VOID : roundingIncrement;
  roundingMode = roundingMode === VOID ? VOID : roundingMode;
  return {roundingIncrement: roundingIncrement, smallestUnit: smallestUnit, roundingMode: roundingMode};
}
function copy_24(_this__u8e3s4, calendarName) {
  calendarName = calendarName === VOID ? VOID : calendarName;
  return Object.assign({}, _this__u8e3s4, {calendarName: calendarName});
}
function invoke_25(_this__u8e3s4, calendarName) {
  calendarName = calendarName === VOID ? VOID : calendarName;
  return {calendarName: calendarName};
}
function copy_25(_this__u8e3s4, getPlainDateTimeFor, id, toString, getOffsetNanosecondsFor, getPreviousTransition, getPossibleInstantsFor, toJSON, getOffsetStringFor, getInstantFor, getNextTransition) {
  getPlainDateTimeFor = getPlainDateTimeFor === VOID ? VOID : getPlainDateTimeFor;
  id = id === VOID ? VOID : id;
  toString = toString === VOID ? VOID : toString;
  getOffsetNanosecondsFor = getOffsetNanosecondsFor === VOID ? VOID : getOffsetNanosecondsFor;
  getPreviousTransition = getPreviousTransition === VOID ? VOID : getPreviousTransition;
  getPossibleInstantsFor = getPossibleInstantsFor === VOID ? VOID : getPossibleInstantsFor;
  toJSON = toJSON === VOID ? VOID : toJSON;
  getOffsetStringFor = getOffsetStringFor === VOID ? VOID : getOffsetStringFor;
  getInstantFor = getInstantFor === VOID ? VOID : getInstantFor;
  getNextTransition = getNextTransition === VOID ? VOID : getNextTransition;
  return Object.assign({}, _this__u8e3s4, {getPlainDateTimeFor: getPlainDateTimeFor, id: id, toString: toString, getOffsetNanosecondsFor: getOffsetNanosecondsFor, getPreviousTransition: getPreviousTransition, getPossibleInstantsFor: getPossibleInstantsFor, toJSON: toJSON, getOffsetStringFor: getOffsetStringFor, getInstantFor: getInstantFor, getNextTransition: getNextTransition});
}
function invoke_26(_this__u8e3s4, getPlainDateTimeFor, id, toString, getOffsetNanosecondsFor, getPreviousTransition, getPossibleInstantsFor, toJSON, getOffsetStringFor, getInstantFor, getNextTransition) {
  getPlainDateTimeFor = getPlainDateTimeFor === VOID ? VOID : getPlainDateTimeFor;
  toString = toString === VOID ? VOID : toString;
  getPreviousTransition = getPreviousTransition === VOID ? VOID : getPreviousTransition;
  toJSON = toJSON === VOID ? VOID : toJSON;
  getOffsetStringFor = getOffsetStringFor === VOID ? VOID : getOffsetStringFor;
  getInstantFor = getInstantFor === VOID ? VOID : getInstantFor;
  getNextTransition = getNextTransition === VOID ? VOID : getNextTransition;
  return {getPlainDateTimeFor: getPlainDateTimeFor, id: id, toString: toString, getOffsetNanosecondsFor: getOffsetNanosecondsFor, getPreviousTransition: getPreviousTransition, getPossibleInstantsFor: getPossibleInstantsFor, toJSON: toJSON, getOffsetStringFor: getOffsetStringFor, getInstantFor: getInstantFor, getNextTransition: getNextTransition};
}
function copy_26(_this__u8e3s4, disambiguation) {
  disambiguation = disambiguation === VOID ? VOID : disambiguation;
  return Object.assign({}, _this__u8e3s4, {disambiguation: disambiguation});
}
function invoke_27(_this__u8e3s4, disambiguation) {
  disambiguation = disambiguation === VOID ? VOID : disambiguation;
  return {disambiguation: disambiguation};
}
function copy_27(_this__u8e3s4, smallestUnit, roundingMode, fractionalSecondDigits) {
  smallestUnit = smallestUnit === VOID ? VOID : smallestUnit;
  roundingMode = roundingMode === VOID ? VOID : roundingMode;
  fractionalSecondDigits = fractionalSecondDigits === VOID ? VOID : fractionalSecondDigits;
  return Object.assign({}, _this__u8e3s4, {smallestUnit: smallestUnit, roundingMode: roundingMode, fractionalSecondDigits: fractionalSecondDigits});
}
function invoke_28(_this__u8e3s4, smallestUnit, roundingMode, fractionalSecondDigits) {
  smallestUnit = smallestUnit === VOID ? VOID : smallestUnit;
  roundingMode = roundingMode === VOID ? VOID : roundingMode;
  fractionalSecondDigits = fractionalSecondDigits === VOID ? VOID : fractionalSecondDigits;
  return {smallestUnit: smallestUnit, roundingMode: roundingMode, fractionalSecondDigits: fractionalSecondDigits};
}
function copy_28(_this__u8e3s4, era, eraYear, year) {
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  year = year === VOID ? VOID : year;
  return Object.assign({}, _this__u8e3s4, {era: era, eraYear: eraYear, year: year});
}
function invoke_29(_this__u8e3s4, era, eraYear, year) {
  era = era === VOID ? VOID : era;
  eraYear = eraYear === VOID ? VOID : eraYear;
  year = year === VOID ? VOID : year;
  return {era: era, eraYear: eraYear, year: year};
}
function copy_29(_this__u8e3s4, overflow, disambiguation, offset) {
  overflow = overflow === VOID ? VOID : overflow;
  disambiguation = disambiguation === VOID ? VOID : disambiguation;
  offset = offset === VOID ? VOID : offset;
  return Object.assign({}, _this__u8e3s4, {overflow: overflow, disambiguation: disambiguation, offset: offset});
}
function invoke_30(_this__u8e3s4, overflow, disambiguation, offset) {
  overflow = overflow === VOID ? VOID : overflow;
  disambiguation = disambiguation === VOID ? VOID : disambiguation;
  offset = offset === VOID ? VOID : offset;
  return {overflow: overflow, disambiguation: disambiguation, offset: offset};
}
function copy_30(_this__u8e3s4, isoDay, timeZone, isoSecond, calendar, isoMonth, isoNanosecond, isoHour, isoMillisecond, isoMinute, isoMicrosecond, offset, isoYear) {
  isoDay = isoDay === VOID ? VOID : isoDay;
  timeZone = timeZone === VOID ? VOID : timeZone;
  isoSecond = isoSecond === VOID ? VOID : isoSecond;
  calendar = calendar === VOID ? VOID : calendar;
  isoMonth = isoMonth === VOID ? VOID : isoMonth;
  isoNanosecond = isoNanosecond === VOID ? VOID : isoNanosecond;
  isoHour = isoHour === VOID ? VOID : isoHour;
  isoMillisecond = isoMillisecond === VOID ? VOID : isoMillisecond;
  isoMinute = isoMinute === VOID ? VOID : isoMinute;
  isoMicrosecond = isoMicrosecond === VOID ? VOID : isoMicrosecond;
  offset = offset === VOID ? VOID : offset;
  isoYear = isoYear === VOID ? VOID : isoYear;
  return Object.assign({}, _this__u8e3s4, {isoDay: isoDay, timeZone: timeZone, isoSecond: isoSecond, calendar: calendar, isoMonth: isoMonth, isoNanosecond: isoNanosecond, isoHour: isoHour, isoMillisecond: isoMillisecond, isoMinute: isoMinute, isoMicrosecond: isoMicrosecond, offset: offset, isoYear: isoYear});
}
function invoke_31(_this__u8e3s4, isoDay, timeZone, isoSecond, calendar, isoMonth, isoNanosecond, isoHour, isoMillisecond, isoMinute, isoMicrosecond, offset, isoYear) {
  return {isoDay: isoDay, timeZone: timeZone, isoSecond: isoSecond, calendar: calendar, isoMonth: isoMonth, isoNanosecond: isoNanosecond, isoHour: isoHour, isoMillisecond: isoMillisecond, isoMinute: isoMinute, isoMicrosecond: isoMicrosecond, offset: offset, isoYear: isoYear};
}
function copy_31(_this__u8e3s4, second, timeZone, calendar, era, microsecond, nanosecond, day, millisecond, month, hour, monthCode, minute, eraYear, offset, year) {
  second = second === VOID ? VOID : second;
  timeZone = timeZone === VOID ? VOID : timeZone;
  calendar = calendar === VOID ? VOID : calendar;
  era = era === VOID ? VOID : era;
  microsecond = microsecond === VOID ? VOID : microsecond;
  nanosecond = nanosecond === VOID ? VOID : nanosecond;
  day = day === VOID ? VOID : day;
  millisecond = millisecond === VOID ? VOID : millisecond;
  month = month === VOID ? VOID : month;
  hour = hour === VOID ? VOID : hour;
  monthCode = monthCode === VOID ? VOID : monthCode;
  minute = minute === VOID ? VOID : minute;
  eraYear = eraYear === VOID ? VOID : eraYear;
  offset = offset === VOID ? VOID : offset;
  year = year === VOID ? VOID : year;
  return Object.assign({}, _this__u8e3s4, {second: second, timeZone: timeZone, calendar: calendar, era: era, microsecond: microsecond, nanosecond: nanosecond, day: day, millisecond: millisecond, month: month, hour: hour, monthCode: monthCode, minute: minute, eraYear: eraYear, offset: offset, year: year});
}
function invoke_32(_this__u8e3s4, second, timeZone, calendar, era, microsecond, nanosecond, day, millisecond, month, hour, monthCode, minute, eraYear, offset, year) {
  second = second === VOID ? VOID : second;
  timeZone = timeZone === VOID ? VOID : timeZone;
  calendar = calendar === VOID ? VOID : calendar;
  era = era === VOID ? VOID : era;
  microsecond = microsecond === VOID ? VOID : microsecond;
  nanosecond = nanosecond === VOID ? VOID : nanosecond;
  day = day === VOID ? VOID : day;
  millisecond = millisecond === VOID ? VOID : millisecond;
  month = month === VOID ? VOID : month;
  hour = hour === VOID ? VOID : hour;
  monthCode = monthCode === VOID ? VOID : monthCode;
  minute = minute === VOID ? VOID : minute;
  eraYear = eraYear === VOID ? VOID : eraYear;
  offset = offset === VOID ? VOID : offset;
  year = year === VOID ? VOID : year;
  return {second: second, timeZone: timeZone, calendar: calendar, era: era, microsecond: microsecond, nanosecond: nanosecond, day: day, millisecond: millisecond, month: month, hour: hour, monthCode: monthCode, minute: minute, eraYear: eraYear, offset: offset, year: year};
}
function copy_32(_this__u8e3s4, smallestUnit, roundingMode, fractionalSecondDigits, calendarName, offset, timeZoneName) {
  smallestUnit = smallestUnit === VOID ? VOID : smallestUnit;
  roundingMode = roundingMode === VOID ? VOID : roundingMode;
  fractionalSecondDigits = fractionalSecondDigits === VOID ? VOID : fractionalSecondDigits;
  calendarName = calendarName === VOID ? VOID : calendarName;
  offset = offset === VOID ? VOID : offset;
  timeZoneName = timeZoneName === VOID ? VOID : timeZoneName;
  return Object.assign({}, _this__u8e3s4, {smallestUnit: smallestUnit, roundingMode: roundingMode, fractionalSecondDigits: fractionalSecondDigits, calendarName: calendarName, offset: offset, timeZoneName: timeZoneName});
}
function invoke_33(_this__u8e3s4, smallestUnit, roundingMode, fractionalSecondDigits, calendarName, offset, timeZoneName) {
  smallestUnit = smallestUnit === VOID ? VOID : smallestUnit;
  roundingMode = roundingMode === VOID ? VOID : roundingMode;
  fractionalSecondDigits = fractionalSecondDigits === VOID ? VOID : fractionalSecondDigits;
  calendarName = calendarName === VOID ? VOID : calendarName;
  offset = offset === VOID ? VOID : offset;
  timeZoneName = timeZoneName === VOID ? VOID : timeZoneName;
  return {smallestUnit: smallestUnit, roundingMode: roundingMode, fractionalSecondDigits: fractionalSecondDigits, calendarName: calendarName, offset: offset, timeZoneName: timeZoneName};
}
function copy_33(_this__u8e3s4, lastChunkHandling, alphabet) {
  lastChunkHandling = lastChunkHandling === VOID ? VOID : lastChunkHandling;
  alphabet = alphabet === VOID ? VOID : alphabet;
  return Object.assign({}, _this__u8e3s4, {lastChunkHandling: lastChunkHandling, alphabet: alphabet});
}
function invoke_34(_this__u8e3s4, lastChunkHandling, alphabet) {
  lastChunkHandling = lastChunkHandling === VOID ? VOID : lastChunkHandling;
  alphabet = alphabet === VOID ? VOID : alphabet;
  return {lastChunkHandling: lastChunkHandling, alphabet: alphabet};
}
function copy_34(_this__u8e3s4, written, read) {
  written = written === VOID ? VOID : written;
  read = read === VOID ? VOID : read;
  return Object.assign({}, _this__u8e3s4, {written: written, read: read});
}
function invoke_35(_this__u8e3s4, written, read) {
  return {written: written, read: read};
}
function copy_35(_this__u8e3s4, omitPadding, alphabet) {
  omitPadding = omitPadding === VOID ? VOID : omitPadding;
  alphabet = alphabet === VOID ? VOID : alphabet;
  return Object.assign({}, _this__u8e3s4, {omitPadding: omitPadding, alphabet: alphabet});
}
function invoke_36(_this__u8e3s4, omitPadding, alphabet) {
  omitPadding = omitPadding === VOID ? VOID : omitPadding;
  alphabet = alphabet === VOID ? VOID : alphabet;
  return {omitPadding: omitPadding, alphabet: alphabet};
}
function copy_36(_this__u8e3s4, signal) {
  signal = signal === VOID ? VOID : signal;
  return Object.assign({}, _this__u8e3s4, {signal: signal});
}
function copy_37(_this__u8e3s4, endings, type) {
  endings = endings === VOID ? VOID : endings;
  type = type === VOID ? VOID : type;
  return Object.assign({}, _this__u8e3s4, {endings: endings, type: type});
}
function invoke_37(_this__u8e3s4, endings, type) {
  endings = endings === VOID ? VOID : endings;
  type = type === VOID ? VOID : type;
  return {endings: endings, type: type};
}
function copy_38(_this__u8e3s4, capture, signal, once, signal_0, passive) {
  capture = capture === VOID ? VOID : capture;
  signal = signal === VOID ? VOID : signal;
  once = once === VOID ? VOID : once;
  signal_0 = signal_0 === VOID ? VOID : signal_0;
  passive = passive === VOID ? VOID : passive;
  return Object.assign({}, _this__u8e3s4, {capture: capture, signal: signal_0, once: once, signal: signal_0, passive: passive});
}
function invoke_38(_this__u8e3s4, capture, signal, once, signal_0, passive) {
  capture = capture === VOID ? VOID : capture;
  signal = signal === VOID ? VOID : signal;
  once = once === VOID ? VOID : once;
  signal_0 = signal_0 === VOID ? VOID : signal_0;
  passive = passive === VOID ? VOID : passive;
  return {capture: capture, signal: signal_0, once: once, signal: signal_0, passive: passive};
}
function copy_39(_this__u8e3s4, bubbles, cancelable, composed) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed});
}
function invoke_39(_this__u8e3s4, bubbles, cancelable, composed) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed};
}
function copy_40(_this__u8e3s4, capture) {
  capture = capture === VOID ? VOID : capture;
  return Object.assign({}, _this__u8e3s4, {capture: capture});
}
function invoke_40(_this__u8e3s4, capture) {
  capture = capture === VOID ? VOID : capture;
  return {capture: capture};
}
function addEventHandler(_this__u8e3s4, type, handler) {
  return addEventHandler_0(_this__u8e3s4, type, undefined, handler);
}
function removeEventListener(_this__u8e3s4, type, handler, options) {
  options = options === VOID ? undefined : options;
  _this__u8e3s4.removeEventListener(type, handler, options);
}
function addEventHandler_0(_this__u8e3s4, type, options, handler) {
  _this__u8e3s4.addEventListener(type, handler, options);
  return addEventHandler$lambda(_this__u8e3s4, type, handler, options);
}
function addEventHandler_1(_this__u8e3s4, type, handler) {
  return addEventHandler_2(_this__u8e3s4, type, undefined, handler);
}
function addEventHandler_2(_this__u8e3s4, type, options, handler) {
  _this__u8e3s4.addEventListener(type, handler, options);
  return addEventHandler$lambda_0(_this__u8e3s4, type, handler, options);
}
function addEventHandler$lambda($this_addEventHandler, $type, $handler, $options) {
  return () => {
    $this_addEventHandler.removeEventListener($type, $handler, $options);
    return Unit_instance;
  };
}
function addEventHandler$lambda_0($this_addEventHandler, $type, $handler, $options) {
  return () => {
    $this_addEventHandler.removeEventListener($type, $handler, $options);
    return Unit_instance;
  };
}
function copy_41(_this__u8e3s4, bubbles, cancelable, composed, total, loaded, lengthComputable) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  total = total === VOID ? VOID : total;
  loaded = loaded === VOID ? VOID : loaded;
  lengthComputable = lengthComputable === VOID ? VOID : lengthComputable;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, total: total, loaded: loaded, lengthComputable: lengthComputable});
}
function invoke_41(_this__u8e3s4, bubbles, cancelable, composed, total, loaded, lengthComputable) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  total = total === VOID ? VOID : total;
  loaded = loaded === VOID ? VOID : loaded;
  lengthComputable = lengthComputable === VOID ? VOID : lengthComputable;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, total: total, loaded: loaded, lengthComputable: lengthComputable};
}
function copy_42(_this__u8e3s4, endings, type, lastModified) {
  endings = endings === VOID ? VOID : endings;
  type = type === VOID ? VOID : type;
  lastModified = lastModified === VOID ? VOID : lastModified;
  return Object.assign({}, _this__u8e3s4, {endings: endings, type: type, lastModified: lastModified});
}
function invoke_42(_this__u8e3s4, endings, type, lastModified) {
  endings = endings === VOID ? VOID : endings;
  type = type === VOID ? VOID : type;
  lastModified = lastModified === VOID ? VOID : lastModified;
  return {endings: endings, type: type, lastModified: lastModified};
}
function copy_43(_this__u8e3s4, colorSpace) {
  colorSpace = colorSpace === VOID ? VOID : colorSpace;
  return Object.assign({}, _this__u8e3s4, {colorSpace: colorSpace});
}
function invoke_43(_this__u8e3s4, colorSpace) {
  colorSpace = colorSpace === VOID ? VOID : colorSpace;
  return {colorSpace: colorSpace};
}
function copy_44(_this__u8e3s4, bubbles, cancelable, composed, lastEventId, data, source, origin, ports) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  lastEventId = lastEventId === VOID ? VOID : lastEventId;
  data = data === VOID ? VOID : data;
  source = source === VOID ? VOID : source;
  origin = origin === VOID ? VOID : origin;
  ports = ports === VOID ? VOID : ports;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, lastEventId: lastEventId, data: data, source: source, origin: origin, ports: ports});
}
function invoke_44(_this__u8e3s4, bubbles, cancelable, composed, lastEventId, data, source, origin, ports) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  lastEventId = lastEventId === VOID ? VOID : lastEventId;
  data = data === VOID ? VOID : data;
  source = source === VOID ? VOID : source;
  origin = origin === VOID ? VOID : origin;
  ports = ports === VOID ? VOID : ports;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, lastEventId: lastEventId, data: data, source: source, origin: origin, ports: ports};
}
function copy_45(_this__u8e3s4, bubbles, cancelable, composed, promise, reason) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  promise = promise === VOID ? VOID : promise;
  reason = reason === VOID ? VOID : reason;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, promise: promise, reason: reason});
}
function invoke_45(_this__u8e3s4, bubbles, cancelable, composed, promise, reason) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  reason = reason === VOID ? VOID : reason;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, promise: promise, reason: reason};
}
function copy_46(_this__u8e3s4, transfer) {
  transfer = transfer === VOID ? VOID : transfer;
  return Object.assign({}, _this__u8e3s4, {transfer: transfer});
}
function invoke_46(_this__u8e3s4, transfer) {
  transfer = transfer === VOID ? VOID : transfer;
  return {transfer: transfer};
}
function copy_47(_this__u8e3s4, mode) {
  mode = mode === VOID ? VOID : mode;
  return Object.assign({}, _this__u8e3s4, {mode: mode});
}
function invoke_47(_this__u8e3s4, mode) {
  mode = mode === VOID ? VOID : mode;
  return {mode: mode};
}
function copy_48(_this__u8e3s4, readable, writable) {
  readable = readable === VOID ? VOID : readable;
  writable = writable === VOID ? VOID : writable;
  return Object.assign({}, _this__u8e3s4, {readable: readable, writable: writable});
}
function invoke_48(_this__u8e3s4, readable, writable) {
  return {readable: readable, writable: writable};
}
function copy_49(_this__u8e3s4, signal, signal_0, preventCancel, preventClose, preventAbort) {
  signal = signal === VOID ? VOID : signal;
  signal_0 = signal_0 === VOID ? VOID : signal_0;
  preventCancel = preventCancel === VOID ? VOID : preventCancel;
  preventClose = preventClose === VOID ? VOID : preventClose;
  preventAbort = preventAbort === VOID ? VOID : preventAbort;
  return Object.assign({}, _this__u8e3s4, {signal: signal_0, signal: signal_0, preventCancel: preventCancel, preventClose: preventClose, preventAbort: preventAbort});
}
function invoke_49(_this__u8e3s4, signal, signal_0, preventCancel, preventClose, preventAbort) {
  signal = signal === VOID ? VOID : signal;
  signal_0 = signal_0 === VOID ? VOID : signal_0;
  preventCancel = preventCancel === VOID ? VOID : preventCancel;
  preventClose = preventClose === VOID ? VOID : preventClose;
  preventAbort = preventAbort === VOID ? VOID : preventAbort;
  return {signal: signal_0, signal: signal_0, preventCancel: preventCancel, preventClose: preventClose, preventAbort: preventAbort};
}
function copy_50(_this__u8e3s4, start, write, close, type, abort) {
  start = start === VOID ? VOID : start;
  write = write === VOID ? VOID : write;
  close = close === VOID ? VOID : close;
  type = type === VOID ? VOID : type;
  abort = abort === VOID ? VOID : abort;
  return Object.assign({}, _this__u8e3s4, {start: start, write: write, close: close, type: type, abort: abort});
}
function invoke_50(_this__u8e3s4, start, write, close, type, abort) {
  start = start === VOID ? VOID : start;
  write = write === VOID ? VOID : write;
  close = close === VOID ? VOID : close;
  type = type === VOID ? VOID : type;
  abort = abort === VOID ? VOID : abort;
  return {start: start, write: write, close: close, type: type, abort: abort};
}
function copy_51(_this__u8e3s4, start, autoAllocateChunkSize, pull, cancel, type) {
  start = start === VOID ? VOID : start;
  autoAllocateChunkSize = autoAllocateChunkSize === VOID ? VOID : autoAllocateChunkSize;
  pull = pull === VOID ? VOID : pull;
  cancel = cancel === VOID ? VOID : cancel;
  type = type === VOID ? VOID : type;
  return Object.assign({}, _this__u8e3s4, {start: start, autoAllocateChunkSize: autoAllocateChunkSize, pull: pull, cancel: cancel, type: type});
}
function invoke_51(_this__u8e3s4, start, autoAllocateChunkSize, pull, cancel, type) {
  start = start === VOID ? VOID : start;
  autoAllocateChunkSize = autoAllocateChunkSize === VOID ? VOID : autoAllocateChunkSize;
  pull = pull === VOID ? VOID : pull;
  cancel = cancel === VOID ? VOID : cancel;
  type = type === VOID ? VOID : type;
  return {start: start, autoAllocateChunkSize: autoAllocateChunkSize, pull: pull, cancel: cancel, type: type};
}
function safeAny(signal1, signal2) {
  if (signal1 == null)
    return signal2;
  if (signal1.aborted)
    return signal1;
  if (signal2.aborted)
    return signal2;
  var controller = new AbortController();
  // Inline function 'kotlin.collections.mutableListOf' call
  var handlers = ArrayList.e1();
  // Inline function 'web.events.EventHandler' call
  // Inline function 'js.reflect.unsafeCast' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  var abortHandler = safeAny$lambda(handlers, controller);
  // Inline function 'kotlin.sequences.mapTo' call
  var _iterator__ex2g4s = sequenceOf([signal1, signal2]).x();
  while (_iterator__ex2g4s.y()) {
    var item = _iterator__ex2g4s.z();
    // Inline function 'web.abort.internal.safeAny.<anonymous>' call
    // Inline function 'web.events.Event.Companion.ABORT' call
    var tmp$ret$6 = addEventHandler_1(item, 'abort', abortHandler);
    handlers.o(tmp$ret$6);
  }
  return controller.signal;
}
function safeAny$lambda($handlers, $controller) {
  return (event) => {
    var _iterator__ex2g4s = $handlers.x();
    while (_iterator__ex2g4s.y()) {
      var element = _iterator__ex2g4s.z();
      // Inline function 'web.abort.internal.safeAny.<anonymous>.<anonymous>' call
      element();
    }
    $controller.abort(event.currentTarget.reason);
    return Unit_instance;
  };
}
function patchAbortOptions(options, controller) {
  // Inline function 'web.abort.Abortable.Companion.invoke' call
  // Inline function 'web.abort.invoke' call
  var abortOptions = {signal: safeAny(options == null ? null : options.signal, controller.signal)};
  var tmp = Object;
  // Inline function 'js.objects.jso' call
  var tmp$ret$2 = {};
  return tmp.assign(tmp$ret$2, options, abortOptions);
}
function awaitPromiseLike$lambda($controller) {
  return (it) => {
    $controller.abort();
    return Unit_instance;
  };
}
function copy_52(_this__u8e3s4, bubbles, cancelable, composed, pseudoElement, animationName, elapsedTime) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  pseudoElement = pseudoElement === VOID ? VOID : pseudoElement;
  animationName = animationName === VOID ? VOID : animationName;
  elapsedTime = elapsedTime === VOID ? VOID : elapsedTime;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, pseudoElement: pseudoElement, animationName: animationName, elapsedTime: elapsedTime});
}
function invoke_52(_this__u8e3s4, bubbles, cancelable, composed, pseudoElement, animationName, elapsedTime) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  pseudoElement = pseudoElement === VOID ? VOID : pseudoElement;
  animationName = animationName === VOID ? VOID : animationName;
  elapsedTime = elapsedTime === VOID ? VOID : elapsedTime;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, pseudoElement: pseudoElement, animationName: animationName, elapsedTime: elapsedTime};
}
function copy_53(_this__u8e3s4, bubbles, cancelable, composed, timelineTime, currentTime) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  timelineTime = timelineTime === VOID ? VOID : timelineTime;
  currentTime = currentTime === VOID ? VOID : currentTime;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, timelineTime: timelineTime, currentTime: currentTime});
}
function invoke_53(_this__u8e3s4, bubbles, cancelable, composed, timelineTime, currentTime) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  timelineTime = timelineTime === VOID ? VOID : timelineTime;
  currentTime = currentTime === VOID ? VOID : currentTime;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, timelineTime: timelineTime, currentTime: currentTime};
}
function copy_54(_this__u8e3s4, direction, endDelay, fill, easing, iterationStart, duration, delay, playbackRate, iterations, progress, endTime, activeDuration, currentIteration, startTime, localTime) {
  direction = direction === VOID ? VOID : direction;
  endDelay = endDelay === VOID ? VOID : endDelay;
  fill = fill === VOID ? VOID : fill;
  easing = easing === VOID ? VOID : easing;
  iterationStart = iterationStart === VOID ? VOID : iterationStart;
  duration = duration === VOID ? VOID : duration;
  delay = delay === VOID ? VOID : delay;
  playbackRate = playbackRate === VOID ? VOID : playbackRate;
  iterations = iterations === VOID ? VOID : iterations;
  progress = progress === VOID ? VOID : progress;
  endTime = endTime === VOID ? VOID : endTime;
  activeDuration = activeDuration === VOID ? VOID : activeDuration;
  currentIteration = currentIteration === VOID ? VOID : currentIteration;
  startTime = startTime === VOID ? VOID : startTime;
  localTime = localTime === VOID ? VOID : localTime;
  return Object.assign({}, _this__u8e3s4, {direction: direction, endDelay: endDelay, fill: fill, easing: easing, iterationStart: iterationStart, duration: duration, delay: delay, playbackRate: playbackRate, iterations: iterations, progress: progress, endTime: endTime, activeDuration: activeDuration, currentIteration: currentIteration, startTime: startTime, localTime: localTime});
}
function invoke_54(_this__u8e3s4, direction, endDelay, fill, easing, iterationStart, duration, delay, playbackRate, iterations, progress, endTime, activeDuration, currentIteration, startTime, localTime) {
  direction = direction === VOID ? VOID : direction;
  endDelay = endDelay === VOID ? VOID : endDelay;
  fill = fill === VOID ? VOID : fill;
  easing = easing === VOID ? VOID : easing;
  iterationStart = iterationStart === VOID ? VOID : iterationStart;
  duration = duration === VOID ? VOID : duration;
  delay = delay === VOID ? VOID : delay;
  playbackRate = playbackRate === VOID ? VOID : playbackRate;
  iterations = iterations === VOID ? VOID : iterations;
  progress = progress === VOID ? VOID : progress;
  endTime = endTime === VOID ? VOID : endTime;
  activeDuration = activeDuration === VOID ? VOID : activeDuration;
  currentIteration = currentIteration === VOID ? VOID : currentIteration;
  startTime = startTime === VOID ? VOID : startTime;
  localTime = localTime === VOID ? VOID : localTime;
  return {direction: direction, endDelay: endDelay, fill: fill, easing: easing, iterationStart: iterationStart, duration: duration, delay: delay, playbackRate: playbackRate, iterations: iterations, progress: progress, endTime: endTime, activeDuration: activeDuration, currentIteration: currentIteration, startTime: startTime, localTime: localTime};
}
function copy_55(_this__u8e3s4, originTime) {
  originTime = originTime === VOID ? VOID : originTime;
  return Object.assign({}, _this__u8e3s4, {originTime: originTime});
}
function invoke_55(_this__u8e3s4, originTime) {
  originTime = originTime === VOID ? VOID : originTime;
  return {originTime: originTime};
}
function copy_56(_this__u8e3s4, direction, endDelay, fill, easing, iterationStart, duration, delay, playbackRate, iterations) {
  direction = direction === VOID ? VOID : direction;
  endDelay = endDelay === VOID ? VOID : endDelay;
  fill = fill === VOID ? VOID : fill;
  easing = easing === VOID ? VOID : easing;
  iterationStart = iterationStart === VOID ? VOID : iterationStart;
  duration = duration === VOID ? VOID : duration;
  delay = delay === VOID ? VOID : delay;
  playbackRate = playbackRate === VOID ? VOID : playbackRate;
  iterations = iterations === VOID ? VOID : iterations;
  return Object.assign({}, _this__u8e3s4, {direction: direction, endDelay: endDelay, fill: fill, easing: easing, iterationStart: iterationStart, duration: duration, delay: delay, playbackRate: playbackRate, iterations: iterations});
}
function invoke_56(_this__u8e3s4, direction, endDelay, fill, easing, iterationStart, duration, delay, playbackRate, iterations) {
  direction = direction === VOID ? VOID : direction;
  endDelay = endDelay === VOID ? VOID : endDelay;
  fill = fill === VOID ? VOID : fill;
  easing = easing === VOID ? VOID : easing;
  iterationStart = iterationStart === VOID ? VOID : iterationStart;
  duration = duration === VOID ? VOID : duration;
  delay = delay === VOID ? VOID : delay;
  playbackRate = playbackRate === VOID ? VOID : playbackRate;
  iterations = iterations === VOID ? VOID : iterations;
  return {direction: direction, endDelay: endDelay, fill: fill, easing: easing, iterationStart: iterationStart, duration: duration, delay: delay, playbackRate: playbackRate, iterations: iterations};
}
function copy_57(_this__u8e3s4, direction, endDelay, fill, easing, iterationStart, duration, delay, playbackRate, iterations, composite, pseudoElement, iterationComposite, id, timeline) {
  direction = direction === VOID ? VOID : direction;
  endDelay = endDelay === VOID ? VOID : endDelay;
  fill = fill === VOID ? VOID : fill;
  easing = easing === VOID ? VOID : easing;
  iterationStart = iterationStart === VOID ? VOID : iterationStart;
  duration = duration === VOID ? VOID : duration;
  delay = delay === VOID ? VOID : delay;
  playbackRate = playbackRate === VOID ? VOID : playbackRate;
  iterations = iterations === VOID ? VOID : iterations;
  composite = composite === VOID ? VOID : composite;
  pseudoElement = pseudoElement === VOID ? VOID : pseudoElement;
  iterationComposite = iterationComposite === VOID ? VOID : iterationComposite;
  id = id === VOID ? VOID : id;
  timeline = timeline === VOID ? VOID : timeline;
  return Object.assign({}, _this__u8e3s4, {direction: direction, endDelay: endDelay, fill: fill, easing: easing, iterationStart: iterationStart, duration: duration, delay: delay, playbackRate: playbackRate, iterations: iterations, composite: composite, pseudoElement: pseudoElement, iterationComposite: iterationComposite, id: id, timeline: timeline});
}
function invoke_57(_this__u8e3s4, direction, endDelay, fill, easing, iterationStart, duration, delay, playbackRate, iterations, composite, pseudoElement, iterationComposite, id, timeline) {
  direction = direction === VOID ? VOID : direction;
  endDelay = endDelay === VOID ? VOID : endDelay;
  fill = fill === VOID ? VOID : fill;
  easing = easing === VOID ? VOID : easing;
  iterationStart = iterationStart === VOID ? VOID : iterationStart;
  duration = duration === VOID ? VOID : duration;
  delay = delay === VOID ? VOID : delay;
  playbackRate = playbackRate === VOID ? VOID : playbackRate;
  iterations = iterations === VOID ? VOID : iterations;
  composite = composite === VOID ? VOID : composite;
  pseudoElement = pseudoElement === VOID ? VOID : pseudoElement;
  iterationComposite = iterationComposite === VOID ? VOID : iterationComposite;
  id = id === VOID ? VOID : id;
  timeline = timeline === VOID ? VOID : timeline;
  return {direction: direction, endDelay: endDelay, fill: fill, easing: easing, iterationStart: iterationStart, duration: duration, delay: delay, playbackRate: playbackRate, iterations: iterations, composite: composite, pseudoElement: pseudoElement, iterationComposite: iterationComposite, id: id, timeline: timeline};
}
function copy_58(_this__u8e3s4, direction, endDelay, fill, easing, iterationStart, duration, delay, playbackRate, iterations, composite, pseudoElement, iterationComposite) {
  direction = direction === VOID ? VOID : direction;
  endDelay = endDelay === VOID ? VOID : endDelay;
  fill = fill === VOID ? VOID : fill;
  easing = easing === VOID ? VOID : easing;
  iterationStart = iterationStart === VOID ? VOID : iterationStart;
  duration = duration === VOID ? VOID : duration;
  delay = delay === VOID ? VOID : delay;
  playbackRate = playbackRate === VOID ? VOID : playbackRate;
  iterations = iterations === VOID ? VOID : iterations;
  composite = composite === VOID ? VOID : composite;
  pseudoElement = pseudoElement === VOID ? VOID : pseudoElement;
  iterationComposite = iterationComposite === VOID ? VOID : iterationComposite;
  return Object.assign({}, _this__u8e3s4, {direction: direction, endDelay: endDelay, fill: fill, easing: easing, iterationStart: iterationStart, duration: duration, delay: delay, playbackRate: playbackRate, iterations: iterations, composite: composite, pseudoElement: pseudoElement, iterationComposite: iterationComposite});
}
function invoke_58(_this__u8e3s4, direction, endDelay, fill, easing, iterationStart, duration, delay, playbackRate, iterations, composite, pseudoElement, iterationComposite) {
  direction = direction === VOID ? VOID : direction;
  endDelay = endDelay === VOID ? VOID : endDelay;
  fill = fill === VOID ? VOID : fill;
  easing = easing === VOID ? VOID : easing;
  iterationStart = iterationStart === VOID ? VOID : iterationStart;
  duration = duration === VOID ? VOID : duration;
  delay = delay === VOID ? VOID : delay;
  playbackRate = playbackRate === VOID ? VOID : playbackRate;
  iterations = iterations === VOID ? VOID : iterations;
  composite = composite === VOID ? VOID : composite;
  pseudoElement = pseudoElement === VOID ? VOID : pseudoElement;
  iterationComposite = iterationComposite === VOID ? VOID : iterationComposite;
  return {direction: direction, endDelay: endDelay, fill: fill, easing: easing, iterationStart: iterationStart, duration: duration, delay: delay, playbackRate: playbackRate, iterations: iterations, composite: composite, pseudoElement: pseudoElement, iterationComposite: iterationComposite};
}
function copy_59(_this__u8e3s4, direction, endDelay, fill, easing, iterationStart, duration, delay, playbackRate, iterations) {
  direction = direction === VOID ? VOID : direction;
  endDelay = endDelay === VOID ? VOID : endDelay;
  fill = fill === VOID ? VOID : fill;
  easing = easing === VOID ? VOID : easing;
  iterationStart = iterationStart === VOID ? VOID : iterationStart;
  duration = duration === VOID ? VOID : duration;
  delay = delay === VOID ? VOID : delay;
  playbackRate = playbackRate === VOID ? VOID : playbackRate;
  iterations = iterations === VOID ? VOID : iterations;
  return Object.assign({}, _this__u8e3s4, {direction: direction, endDelay: endDelay, fill: fill, easing: easing, iterationStart: iterationStart, duration: duration, delay: delay, playbackRate: playbackRate, iterations: iterations});
}
function invoke_59(_this__u8e3s4, direction, endDelay, fill, easing, iterationStart, duration, delay, playbackRate, iterations) {
  direction = direction === VOID ? VOID : direction;
  endDelay = endDelay === VOID ? VOID : endDelay;
  fill = fill === VOID ? VOID : fill;
  easing = easing === VOID ? VOID : easing;
  iterationStart = iterationStart === VOID ? VOID : iterationStart;
  duration = duration === VOID ? VOID : duration;
  delay = delay === VOID ? VOID : delay;
  playbackRate = playbackRate === VOID ? VOID : playbackRate;
  iterations = iterations === VOID ? VOID : iterations;
  return {direction: direction, endDelay: endDelay, fill: fill, easing: easing, iterationStart: iterationStart, duration: duration, delay: delay, playbackRate: playbackRate, iterations: iterations};
}
function copy_60(_this__u8e3s4, colorSpace, desynchronized, willReadFrequently, alpha) {
  colorSpace = colorSpace === VOID ? VOID : colorSpace;
  desynchronized = desynchronized === VOID ? VOID : desynchronized;
  willReadFrequently = willReadFrequently === VOID ? VOID : willReadFrequently;
  alpha = alpha === VOID ? VOID : alpha;
  return Object.assign({}, _this__u8e3s4, {colorSpace: colorSpace, desynchronized: desynchronized, willReadFrequently: willReadFrequently, alpha: alpha});
}
function invoke_60(_this__u8e3s4, colorSpace, desynchronized, willReadFrequently, alpha) {
  colorSpace = colorSpace === VOID ? VOID : colorSpace;
  desynchronized = desynchronized === VOID ? VOID : desynchronized;
  willReadFrequently = willReadFrequently === VOID ? VOID : willReadFrequently;
  alpha = alpha === VOID ? VOID : alpha;
  return {colorSpace: colorSpace, desynchronized: desynchronized, willReadFrequently: willReadFrequently, alpha: alpha};
}
function copy_61(_this__u8e3s4, quality, type) {
  quality = quality === VOID ? VOID : quality;
  type = type === VOID ? VOID : type;
  return Object.assign({}, _this__u8e3s4, {quality: quality, type: type});
}
function invoke_61(_this__u8e3s4, quality, type) {
  quality = quality === VOID ? VOID : quality;
  type = type === VOID ? VOID : type;
  return {quality: quality, type: type};
}
function copy_62(_this__u8e3s4, bubbles, cancelable, composed, clipboardData) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  clipboardData = clipboardData === VOID ? VOID : clipboardData;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, clipboardData: clipboardData});
}
function invoke_62(_this__u8e3s4, bubbles, cancelable, composed, clipboardData) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  clipboardData = clipboardData === VOID ? VOID : clipboardData;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, clipboardData: clipboardData};
}
function copy_63(_this__u8e3s4, flatten) {
  flatten = flatten === VOID ? VOID : flatten;
  return Object.assign({}, _this__u8e3s4, {flatten: flatten});
}
function invoke_63(_this__u8e3s4, flatten) {
  flatten = flatten === VOID ? VOID : flatten;
  return {flatten: flatten};
}
function copy_64(_this__u8e3s4, delegatesFocus, serializable, slotAssignment, clonable, mode) {
  delegatesFocus = delegatesFocus === VOID ? VOID : delegatesFocus;
  serializable = serializable === VOID ? VOID : serializable;
  slotAssignment = slotAssignment === VOID ? VOID : slotAssignment;
  clonable = clonable === VOID ? VOID : clonable;
  mode = mode === VOID ? VOID : mode;
  return Object.assign({}, _this__u8e3s4, {delegatesFocus: delegatesFocus, serializable: serializable, slotAssignment: slotAssignment, clonable: clonable, mode: mode});
}
function invoke_64(_this__u8e3s4, delegatesFocus, serializable, slotAssignment, clonable, mode) {
  delegatesFocus = delegatesFocus === VOID ? VOID : delegatesFocus;
  serializable = serializable === VOID ? VOID : serializable;
  slotAssignment = slotAssignment === VOID ? VOID : slotAssignment;
  clonable = clonable === VOID ? VOID : clonable;
  return {delegatesFocus: delegatesFocus, serializable: serializable, slotAssignment: slotAssignment, clonable: clonable, mode: mode};
}
function copy_65(_this__u8e3s4, bubbles, cancelable, composed, changed, deleted) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  changed = changed === VOID ? VOID : changed;
  deleted = deleted === VOID ? VOID : deleted;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, changed: changed, deleted: deleted});
}
function invoke_65(_this__u8e3s4, bubbles, cancelable, composed, changed, deleted) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  changed = changed === VOID ? VOID : changed;
  deleted = deleted === VOID ? VOID : deleted;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, changed: changed, deleted: deleted};
}
function copy_66(_this__u8e3s4, sameSite, expires, path, partitioned, domain, value, name) {
  sameSite = sameSite === VOID ? VOID : sameSite;
  expires = expires === VOID ? VOID : expires;
  path = path === VOID ? VOID : path;
  partitioned = partitioned === VOID ? VOID : partitioned;
  domain = domain === VOID ? VOID : domain;
  value = value === VOID ? VOID : value;
  name = name === VOID ? VOID : name;
  return Object.assign({}, _this__u8e3s4, {sameSite: sameSite, expires: expires, path: path, partitioned: partitioned, domain: domain, value: value, name: name});
}
function invoke_66(_this__u8e3s4, sameSite, expires, path, partitioned, domain, value, name) {
  sameSite = sameSite === VOID ? VOID : sameSite;
  expires = expires === VOID ? VOID : expires;
  path = path === VOID ? VOID : path;
  partitioned = partitioned === VOID ? VOID : partitioned;
  domain = domain === VOID ? VOID : domain;
  return {sameSite: sameSite, expires: expires, path: path, partitioned: partitioned, domain: domain, value: value, name: name};
}
function copy_67(_this__u8e3s4, value, name) {
  value = value === VOID ? VOID : value;
  name = name === VOID ? VOID : name;
  return Object.assign({}, _this__u8e3s4, {value: value, name: name});
}
function invoke_67(_this__u8e3s4, value, name) {
  value = value === VOID ? VOID : value;
  name = name === VOID ? VOID : name;
  return {value: value, name: name};
}
function copy_68(_this__u8e3s4, path, partitioned, domain, name) {
  path = path === VOID ? VOID : path;
  partitioned = partitioned === VOID ? VOID : partitioned;
  domain = domain === VOID ? VOID : domain;
  name = name === VOID ? VOID : name;
  return Object.assign({}, _this__u8e3s4, {path: path, partitioned: partitioned, domain: domain, name: name});
}
function invoke_68(_this__u8e3s4, path, partitioned, domain, name) {
  path = path === VOID ? VOID : path;
  partitioned = partitioned === VOID ? VOID : partitioned;
  domain = domain === VOID ? VOID : domain;
  return {path: path, partitioned: partitioned, domain: domain, name: name};
}
function copy_69(_this__u8e3s4, url, name) {
  url = url === VOID ? VOID : url;
  name = name === VOID ? VOID : name;
  return Object.assign({}, _this__u8e3s4, {url: url, name: name});
}
function invoke_69(_this__u8e3s4, url, name) {
  url = url === VOID ? VOID : url;
  name = name === VOID ? VOID : name;
  return {url: url, name: name};
}
function copy_70(_this__u8e3s4, bubbles, cancelable, composed, referrer, effectiveDirective, blockedURI, sourceFile, sample, violatedDirective, statusCode, lineNumber, disposition, originalPolicy, columnNumber, documentURI) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  referrer = referrer === VOID ? VOID : referrer;
  effectiveDirective = effectiveDirective === VOID ? VOID : effectiveDirective;
  blockedURI = blockedURI === VOID ? VOID : blockedURI;
  sourceFile = sourceFile === VOID ? VOID : sourceFile;
  sample = sample === VOID ? VOID : sample;
  violatedDirective = violatedDirective === VOID ? VOID : violatedDirective;
  statusCode = statusCode === VOID ? VOID : statusCode;
  lineNumber = lineNumber === VOID ? VOID : lineNumber;
  disposition = disposition === VOID ? VOID : disposition;
  originalPolicy = originalPolicy === VOID ? VOID : originalPolicy;
  columnNumber = columnNumber === VOID ? VOID : columnNumber;
  documentURI = documentURI === VOID ? VOID : documentURI;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, referrer: referrer, effectiveDirective: effectiveDirective, blockedURI: blockedURI, sourceFile: sourceFile, sample: sample, violatedDirective: violatedDirective, statusCode: statusCode, lineNumber: lineNumber, disposition: disposition, originalPolicy: originalPolicy, columnNumber: columnNumber, documentURI: documentURI});
}
function invoke_70(_this__u8e3s4, bubbles, cancelable, composed, referrer, effectiveDirective, blockedURI, sourceFile, sample, violatedDirective, statusCode, lineNumber, disposition, originalPolicy, columnNumber, documentURI) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  referrer = referrer === VOID ? VOID : referrer;
  effectiveDirective = effectiveDirective === VOID ? VOID : effectiveDirective;
  blockedURI = blockedURI === VOID ? VOID : blockedURI;
  sourceFile = sourceFile === VOID ? VOID : sourceFile;
  sample = sample === VOID ? VOID : sample;
  violatedDirective = violatedDirective === VOID ? VOID : violatedDirective;
  statusCode = statusCode === VOID ? VOID : statusCode;
  lineNumber = lineNumber === VOID ? VOID : lineNumber;
  disposition = disposition === VOID ? VOID : disposition;
  originalPolicy = originalPolicy === VOID ? VOID : originalPolicy;
  columnNumber = columnNumber === VOID ? VOID : columnNumber;
  documentURI = documentURI === VOID ? VOID : documentURI;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, referrer: referrer, effectiveDirective: effectiveDirective, blockedURI: blockedURI, sourceFile: sourceFile, sample: sample, violatedDirective: violatedDirective, statusCode: statusCode, lineNumber: lineNumber, disposition: disposition, originalPolicy: originalPolicy, columnNumber: columnNumber, documentURI: documentURI};
}
function copy_71(_this__u8e3s4, media, disabled, baseURL) {
  media = media === VOID ? VOID : media;
  disabled = disabled === VOID ? VOID : disabled;
  baseURL = baseURL === VOID ? VOID : baseURL;
  return Object.assign({}, _this__u8e3s4, {media: media, disabled: disabled, baseURL: baseURL});
}
function invoke_71(_this__u8e3s4, media, disabled, baseURL) {
  media = media === VOID ? VOID : media;
  disabled = disabled === VOID ? VOID : disabled;
  baseURL = baseURL === VOID ? VOID : baseURL;
  return {media: media, disabled: disabled, baseURL: baseURL};
}
function copy_72(_this__u8e3s4, bubbles, cancelable, composed, propertyName, pseudoElement, elapsedTime) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  propertyName = propertyName === VOID ? VOID : propertyName;
  pseudoElement = pseudoElement === VOID ? VOID : pseudoElement;
  elapsedTime = elapsedTime === VOID ? VOID : elapsedTime;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, propertyName: propertyName, pseudoElement: pseudoElement, elapsedTime: elapsedTime});
}
function invoke_72(_this__u8e3s4, bubbles, cancelable, composed, propertyName, pseudoElement, elapsedTime) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  propertyName = propertyName === VOID ? VOID : propertyName;
  pseudoElement = pseudoElement === VOID ? VOID : pseudoElement;
  elapsedTime = elapsedTime === VOID ? VOID : elapsedTime;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, propertyName: propertyName, pseudoElement: pseudoElement, elapsedTime: elapsedTime};
}
function copy_73(_this__u8e3s4, z, y, x) {
  z = z === VOID ? VOID : z;
  y = y === VOID ? VOID : y;
  x = x === VOID ? VOID : x;
  return Object.assign({}, _this__u8e3s4, {z: z, y: y, x: x});
}
function invoke_73(_this__u8e3s4, z, y, x) {
  z = z === VOID ? VOID : z;
  y = y === VOID ? VOID : y;
  x = x === VOID ? VOID : x;
  return {z: z, y: y, x: x};
}
function copy_74(_this__u8e3s4, bubbles, cancelable, composed, accelerationIncludingGravity, interval, acceleration, rotationRate) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  accelerationIncludingGravity = accelerationIncludingGravity === VOID ? VOID : accelerationIncludingGravity;
  interval = interval === VOID ? VOID : interval;
  acceleration = acceleration === VOID ? VOID : acceleration;
  rotationRate = rotationRate === VOID ? VOID : rotationRate;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, accelerationIncludingGravity: accelerationIncludingGravity, interval: interval, acceleration: acceleration, rotationRate: rotationRate});
}
function invoke_74(_this__u8e3s4, bubbles, cancelable, composed, accelerationIncludingGravity, interval, acceleration, rotationRate) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  accelerationIncludingGravity = accelerationIncludingGravity === VOID ? VOID : accelerationIncludingGravity;
  interval = interval === VOID ? VOID : interval;
  acceleration = acceleration === VOID ? VOID : acceleration;
  rotationRate = rotationRate === VOID ? VOID : rotationRate;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, accelerationIncludingGravity: accelerationIncludingGravity, interval: interval, acceleration: acceleration, rotationRate: rotationRate};
}
function copy_75(_this__u8e3s4, beta, gamma, alpha) {
  beta = beta === VOID ? VOID : beta;
  gamma = gamma === VOID ? VOID : gamma;
  alpha = alpha === VOID ? VOID : alpha;
  return Object.assign({}, _this__u8e3s4, {beta: beta, gamma: gamma, alpha: alpha});
}
function invoke_75(_this__u8e3s4, beta, gamma, alpha) {
  beta = beta === VOID ? VOID : beta;
  gamma = gamma === VOID ? VOID : gamma;
  alpha = alpha === VOID ? VOID : alpha;
  return {beta: beta, gamma: gamma, alpha: alpha};
}
function copy_76(_this__u8e3s4, bubbles, cancelable, composed, beta, gamma, absolute, alpha) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  beta = beta === VOID ? VOID : beta;
  gamma = gamma === VOID ? VOID : gamma;
  absolute = absolute === VOID ? VOID : absolute;
  alpha = alpha === VOID ? VOID : alpha;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, beta: beta, gamma: gamma, absolute: absolute, alpha: alpha});
}
function invoke_76(_this__u8e3s4, bubbles, cancelable, composed, beta, gamma, absolute, alpha) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  beta = beta === VOID ? VOID : beta;
  gamma = gamma === VOID ? VOID : gamma;
  absolute = absolute === VOID ? VOID : absolute;
  alpha = alpha === VOID ? VOID : alpha;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, beta: beta, gamma: gamma, absolute: absolute, alpha: alpha};
}
function copy_77(_this__u8e3s4, shadowRoots) {
  shadowRoots = shadowRoots === VOID ? VOID : shadowRoots;
  return Object.assign({}, _this__u8e3s4, {shadowRoots: shadowRoots});
}
function invoke_77(_this__u8e3s4, shadowRoots) {
  shadowRoots = shadowRoots === VOID ? VOID : shadowRoots;
  return {shadowRoots: shadowRoots};
}
function copy_78(_this__u8e3s4, contentVisibilityAuto, opacityProperty, visibilityProperty, checkVisibilityCSS, checkOpacity) {
  contentVisibilityAuto = contentVisibilityAuto === VOID ? VOID : contentVisibilityAuto;
  opacityProperty = opacityProperty === VOID ? VOID : opacityProperty;
  visibilityProperty = visibilityProperty === VOID ? VOID : visibilityProperty;
  checkVisibilityCSS = checkVisibilityCSS === VOID ? VOID : checkVisibilityCSS;
  checkOpacity = checkOpacity === VOID ? VOID : checkOpacity;
  return Object.assign({}, _this__u8e3s4, {contentVisibilityAuto: contentVisibilityAuto, opacityProperty: opacityProperty, visibilityProperty: visibilityProperty, checkVisibilityCSS: checkVisibilityCSS, checkOpacity: checkOpacity});
}
function invoke_78(_this__u8e3s4, contentVisibilityAuto, opacityProperty, visibilityProperty, checkVisibilityCSS, checkOpacity) {
  contentVisibilityAuto = contentVisibilityAuto === VOID ? VOID : contentVisibilityAuto;
  opacityProperty = opacityProperty === VOID ? VOID : opacityProperty;
  visibilityProperty = visibilityProperty === VOID ? VOID : visibilityProperty;
  checkVisibilityCSS = checkVisibilityCSS === VOID ? VOID : checkVisibilityCSS;
  checkOpacity = checkOpacity === VOID ? VOID : checkOpacity;
  return {contentVisibilityAuto: contentVisibilityAuto, opacityProperty: opacityProperty, visibilityProperty: visibilityProperty, checkVisibilityCSS: checkVisibilityCSS, checkOpacity: checkOpacity};
}
function copy_79(_this__u8e3s4, is) {
  is = is === VOID ? VOID : is;
  return Object.assign({}, _this__u8e3s4, {is: is});
}
function invoke_79(_this__u8e3s4, is) {
  is = is === VOID ? VOID : is;
  return {is: is};
}
function copy_80(_this__u8e3s4, preventScroll) {
  preventScroll = preventScroll === VOID ? VOID : preventScroll;
  return Object.assign({}, _this__u8e3s4, {preventScroll: preventScroll});
}
function invoke_80(_this__u8e3s4, preventScroll) {
  preventScroll = preventScroll === VOID ? VOID : preventScroll;
  return {preventScroll: preventScroll};
}
function copy_81(_this__u8e3s4, subtree) {
  subtree = subtree === VOID ? VOID : subtree;
  return Object.assign({}, _this__u8e3s4, {subtree: subtree});
}
function invoke_81(_this__u8e3s4, subtree) {
  subtree = subtree === VOID ? VOID : subtree;
  return {subtree: subtree};
}
function copy_82(_this__u8e3s4, shadowRoots, serializableShadowRoots) {
  shadowRoots = shadowRoots === VOID ? VOID : shadowRoots;
  serializableShadowRoots = serializableShadowRoots === VOID ? VOID : serializableShadowRoots;
  return Object.assign({}, _this__u8e3s4, {shadowRoots: shadowRoots, serializableShadowRoots: serializableShadowRoots});
}
function invoke_82(_this__u8e3s4, shadowRoots, serializableShadowRoots) {
  shadowRoots = shadowRoots === VOID ? VOID : shadowRoots;
  serializableShadowRoots = serializableShadowRoots === VOID ? VOID : serializableShadowRoots;
  return {shadowRoots: shadowRoots, serializableShadowRoots: serializableShadowRoots};
}
function copy_83(_this__u8e3s4, composed) {
  composed = composed === VOID ? VOID : composed;
  return Object.assign({}, _this__u8e3s4, {composed: composed});
}
function invoke_83(_this__u8e3s4, composed) {
  composed = composed === VOID ? VOID : composed;
  return {composed: composed};
}
function copy_84(_this__u8e3s4, unadjustedMovement) {
  unadjustedMovement = unadjustedMovement === VOID ? VOID : unadjustedMovement;
  return Object.assign({}, _this__u8e3s4, {unadjustedMovement: unadjustedMovement});
}
function invoke_84(_this__u8e3s4, unadjustedMovement) {
  unadjustedMovement = unadjustedMovement === VOID ? VOID : unadjustedMovement;
  return {unadjustedMovement: unadjustedMovement};
}
function copy_85(_this__u8e3s4, lineGapOverride, descentOverride, display, featureSettings, style, unicodeRange, ascentOverride, stretch, weight) {
  lineGapOverride = lineGapOverride === VOID ? VOID : lineGapOverride;
  descentOverride = descentOverride === VOID ? VOID : descentOverride;
  display = display === VOID ? VOID : display;
  featureSettings = featureSettings === VOID ? VOID : featureSettings;
  style = style === VOID ? VOID : style;
  unicodeRange = unicodeRange === VOID ? VOID : unicodeRange;
  ascentOverride = ascentOverride === VOID ? VOID : ascentOverride;
  stretch = stretch === VOID ? VOID : stretch;
  weight = weight === VOID ? VOID : weight;
  return Object.assign({}, _this__u8e3s4, {lineGapOverride: lineGapOverride, descentOverride: descentOverride, display: display, featureSettings: featureSettings, style: style, unicodeRange: unicodeRange, ascentOverride: ascentOverride, stretch: stretch, weight: weight});
}
function invoke_85(_this__u8e3s4, lineGapOverride, descentOverride, display, featureSettings, style, unicodeRange, ascentOverride, stretch, weight) {
  lineGapOverride = lineGapOverride === VOID ? VOID : lineGapOverride;
  descentOverride = descentOverride === VOID ? VOID : descentOverride;
  display = display === VOID ? VOID : display;
  featureSettings = featureSettings === VOID ? VOID : featureSettings;
  style = style === VOID ? VOID : style;
  unicodeRange = unicodeRange === VOID ? VOID : unicodeRange;
  ascentOverride = ascentOverride === VOID ? VOID : ascentOverride;
  stretch = stretch === VOID ? VOID : stretch;
  weight = weight === VOID ? VOID : weight;
  return {lineGapOverride: lineGapOverride, descentOverride: descentOverride, display: display, featureSettings: featureSettings, style: style, unicodeRange: unicodeRange, ascentOverride: ascentOverride, stretch: stretch, weight: weight};
}
function copy_86(_this__u8e3s4, bubbles, cancelable, composed, fontfaces) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  fontfaces = fontfaces === VOID ? VOID : fontfaces;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, fontfaces: fontfaces});
}
function invoke_86(_this__u8e3s4, bubbles, cancelable, composed, fontfaces) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  fontfaces = fontfaces === VOID ? VOID : fontfaces;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, fontfaces: fontfaces};
}
function copy_87(_this__u8e3s4, bubbles, cancelable, composed, formData) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  formData = formData === VOID ? VOID : formData;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, formData: formData});
}
function invoke_87(_this__u8e3s4, bubbles, cancelable, composed, formData) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, formData: formData};
}
function copy_88(_this__u8e3s4, bubbles, cancelable, composed, submitter) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  submitter = submitter === VOID ? VOID : submitter;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, submitter: submitter});
}
function invoke_88(_this__u8e3s4, bubbles, cancelable, composed, submitter) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  submitter = submitter === VOID ? VOID : submitter;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, submitter: submitter};
}
function copy_89(_this__u8e3s4, exclusive, create) {
  exclusive = exclusive === VOID ? VOID : exclusive;
  create = create === VOID ? VOID : create;
  return Object.assign({}, _this__u8e3s4, {exclusive: exclusive, create: create});
}
function invoke_89(_this__u8e3s4, exclusive, create) {
  exclusive = exclusive === VOID ? VOID : exclusive;
  create = create === VOID ? VOID : create;
  return {exclusive: exclusive, create: create};
}
function copy_90(_this__u8e3s4, navigationUI) {
  navigationUI = navigationUI === VOID ? VOID : navigationUI;
  return Object.assign({}, _this__u8e3s4, {navigationUI: navigationUI});
}
function invoke_90(_this__u8e3s4, navigationUI) {
  navigationUI = navigationUI === VOID ? VOID : navigationUI;
  return {navigationUI: navigationUI};
}
function copy_91(_this__u8e3s4, strongMagnitude, rightTrigger, duration, startDelay, weakMagnitude, leftTrigger) {
  strongMagnitude = strongMagnitude === VOID ? VOID : strongMagnitude;
  rightTrigger = rightTrigger === VOID ? VOID : rightTrigger;
  duration = duration === VOID ? VOID : duration;
  startDelay = startDelay === VOID ? VOID : startDelay;
  weakMagnitude = weakMagnitude === VOID ? VOID : weakMagnitude;
  leftTrigger = leftTrigger === VOID ? VOID : leftTrigger;
  return Object.assign({}, _this__u8e3s4, {strongMagnitude: strongMagnitude, rightTrigger: rightTrigger, duration: duration, startDelay: startDelay, weakMagnitude: weakMagnitude, leftTrigger: leftTrigger});
}
function invoke_91(_this__u8e3s4, strongMagnitude, rightTrigger, duration, startDelay, weakMagnitude, leftTrigger) {
  strongMagnitude = strongMagnitude === VOID ? VOID : strongMagnitude;
  rightTrigger = rightTrigger === VOID ? VOID : rightTrigger;
  duration = duration === VOID ? VOID : duration;
  startDelay = startDelay === VOID ? VOID : startDelay;
  weakMagnitude = weakMagnitude === VOID ? VOID : weakMagnitude;
  leftTrigger = leftTrigger === VOID ? VOID : leftTrigger;
  return {strongMagnitude: strongMagnitude, rightTrigger: rightTrigger, duration: duration, startDelay: startDelay, weakMagnitude: weakMagnitude, leftTrigger: leftTrigger};
}
function copy_92(_this__u8e3s4, bubbles, cancelable, composed, gamepad) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  gamepad = gamepad === VOID ? VOID : gamepad;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, gamepad: gamepad});
}
function invoke_92(_this__u8e3s4, bubbles, cancelable, composed, gamepad) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, gamepad: gamepad};
}
function copy_93(_this__u8e3s4, bubbles, cancelable, composed, oldURL, newURL) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  oldURL = oldURL === VOID ? VOID : oldURL;
  newURL = newURL === VOID ? VOID : newURL;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, oldURL: oldURL, newURL: newURL});
}
function invoke_93(_this__u8e3s4, bubbles, cancelable, composed, oldURL, newURL) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  oldURL = oldURL === VOID ? VOID : oldURL;
  newURL = newURL === VOID ? VOID : newURL;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, oldURL: oldURL, newURL: newURL};
}
function copy_94(_this__u8e3s4, bubbles, cancelable, composed, persisted) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  persisted = persisted === VOID ? VOID : persisted;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, persisted: persisted});
}
function invoke_94(_this__u8e3s4, bubbles, cancelable, composed, persisted) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  persisted = persisted === VOID ? VOID : persisted;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, persisted: persisted};
}
function copy_95(_this__u8e3s4, bubbles, cancelable, composed, state) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  state = state === VOID ? VOID : state;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, state: state});
}
function invoke_95(_this__u8e3s4, bubbles, cancelable, composed, state) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  state = state === VOID ? VOID : state;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, state: state};
}
function copy_96(_this__u8e3s4, bubbles, cancelable, composed, initDataType, initData) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  initDataType = initDataType === VOID ? VOID : initDataType;
  initData = initData === VOID ? VOID : initData;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, initDataType: initDataType, initData: initData});
}
function invoke_96(_this__u8e3s4, bubbles, cancelable, composed, initDataType, initData) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  initDataType = initDataType === VOID ? VOID : initDataType;
  initData = initData === VOID ? VOID : initData;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, initDataType: initDataType, initData: initData};
}
function copy_97(_this__u8e3s4, height, mediaTime, presentedFrames, receiveTime, presentationTime, captureTime, rtpTimestamp, expectedDisplayTime, processingDuration, width) {
  height = height === VOID ? VOID : height;
  mediaTime = mediaTime === VOID ? VOID : mediaTime;
  presentedFrames = presentedFrames === VOID ? VOID : presentedFrames;
  receiveTime = receiveTime === VOID ? VOID : receiveTime;
  presentationTime = presentationTime === VOID ? VOID : presentationTime;
  captureTime = captureTime === VOID ? VOID : captureTime;
  rtpTimestamp = rtpTimestamp === VOID ? VOID : rtpTimestamp;
  expectedDisplayTime = expectedDisplayTime === VOID ? VOID : expectedDisplayTime;
  processingDuration = processingDuration === VOID ? VOID : processingDuration;
  width = width === VOID ? VOID : width;
  return Object.assign({}, _this__u8e3s4, {height: height, mediaTime: mediaTime, presentedFrames: presentedFrames, receiveTime: receiveTime, presentationTime: presentationTime, captureTime: captureTime, rtpTimestamp: rtpTimestamp, expectedDisplayTime: expectedDisplayTime, processingDuration: processingDuration, width: width});
}
function invoke_97(_this__u8e3s4, height, mediaTime, presentedFrames, receiveTime, presentationTime, captureTime, rtpTimestamp, expectedDisplayTime, processingDuration, width) {
  receiveTime = receiveTime === VOID ? VOID : receiveTime;
  captureTime = captureTime === VOID ? VOID : captureTime;
  rtpTimestamp = rtpTimestamp === VOID ? VOID : rtpTimestamp;
  processingDuration = processingDuration === VOID ? VOID : processingDuration;
  return {height: height, mediaTime: mediaTime, presentedFrames: presentedFrames, receiveTime: receiveTime, presentationTime: presentationTime, captureTime: captureTime, rtpTimestamp: rtpTimestamp, expectedDisplayTime: expectedDisplayTime, processingDuration: processingDuration, width: width};
}
function copy_98(_this__u8e3s4, bubbles, cancelable, composed, messageType, message) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  messageType = messageType === VOID ? VOID : messageType;
  message = message === VOID ? VOID : message;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, messageType: messageType, message: message});
}
function invoke_98(_this__u8e3s4, bubbles, cancelable, composed, messageType, message) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, messageType: messageType, message: message};
}
function copy_99(_this__u8e3s4, minHdcpVersion) {
  minHdcpVersion = minHdcpVersion === VOID ? VOID : minHdcpVersion;
  return Object.assign({}, _this__u8e3s4, {minHdcpVersion: minHdcpVersion});
}
function invoke_99(_this__u8e3s4, minHdcpVersion) {
  minHdcpVersion = minHdcpVersion === VOID ? VOID : minHdcpVersion;
  return {minHdcpVersion: minHdcpVersion};
}
function copy_100(_this__u8e3s4, min, max) {
  min = min === VOID ? VOID : min;
  max = max === VOID ? VOID : max;
  return Object.assign({}, _this__u8e3s4, {min: min, max: max});
}
function invoke_100(_this__u8e3s4, min, max) {
  min = min === VOID ? VOID : min;
  max = max === VOID ? VOID : max;
  return {min: min, max: max};
}
function copy_101(_this__u8e3s4, bubbles, cancelable, composed, track) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  track = track === VOID ? VOID : track;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, track: track});
}
function invoke_101(_this__u8e3s4, bubbles, cancelable, composed, track) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, track: track};
}
function copy_102(_this__u8e3s4, channelCount, height, sampleSize, aspectRatio, displaySurface, echoCancellation, backgroundBlur, facingMode, groupId, autoGainControl, deviceId, frameRate, sampleRate, noiseSuppression, width) {
  channelCount = channelCount === VOID ? VOID : channelCount;
  height = height === VOID ? VOID : height;
  sampleSize = sampleSize === VOID ? VOID : sampleSize;
  aspectRatio = aspectRatio === VOID ? VOID : aspectRatio;
  displaySurface = displaySurface === VOID ? VOID : displaySurface;
  echoCancellation = echoCancellation === VOID ? VOID : echoCancellation;
  backgroundBlur = backgroundBlur === VOID ? VOID : backgroundBlur;
  facingMode = facingMode === VOID ? VOID : facingMode;
  groupId = groupId === VOID ? VOID : groupId;
  autoGainControl = autoGainControl === VOID ? VOID : autoGainControl;
  deviceId = deviceId === VOID ? VOID : deviceId;
  frameRate = frameRate === VOID ? VOID : frameRate;
  sampleRate = sampleRate === VOID ? VOID : sampleRate;
  noiseSuppression = noiseSuppression === VOID ? VOID : noiseSuppression;
  width = width === VOID ? VOID : width;
  return Object.assign({}, _this__u8e3s4, {channelCount: channelCount, height: height, sampleSize: sampleSize, aspectRatio: aspectRatio, displaySurface: displaySurface, echoCancellation: echoCancellation, backgroundBlur: backgroundBlur, facingMode: facingMode, groupId: groupId, autoGainControl: autoGainControl, deviceId: deviceId, frameRate: frameRate, sampleRate: sampleRate, noiseSuppression: noiseSuppression, width: width});
}
function invoke_102(_this__u8e3s4, channelCount, height, sampleSize, aspectRatio, displaySurface, echoCancellation, backgroundBlur, facingMode, groupId, autoGainControl, deviceId, frameRate, sampleRate, noiseSuppression, width) {
  channelCount = channelCount === VOID ? VOID : channelCount;
  height = height === VOID ? VOID : height;
  sampleSize = sampleSize === VOID ? VOID : sampleSize;
  aspectRatio = aspectRatio === VOID ? VOID : aspectRatio;
  displaySurface = displaySurface === VOID ? VOID : displaySurface;
  echoCancellation = echoCancellation === VOID ? VOID : echoCancellation;
  backgroundBlur = backgroundBlur === VOID ? VOID : backgroundBlur;
  facingMode = facingMode === VOID ? VOID : facingMode;
  groupId = groupId === VOID ? VOID : groupId;
  autoGainControl = autoGainControl === VOID ? VOID : autoGainControl;
  deviceId = deviceId === VOID ? VOID : deviceId;
  frameRate = frameRate === VOID ? VOID : frameRate;
  sampleRate = sampleRate === VOID ? VOID : sampleRate;
  noiseSuppression = noiseSuppression === VOID ? VOID : noiseSuppression;
  width = width === VOID ? VOID : width;
  return {channelCount: channelCount, height: height, sampleSize: sampleSize, aspectRatio: aspectRatio, displaySurface: displaySurface, echoCancellation: echoCancellation, backgroundBlur: backgroundBlur, facingMode: facingMode, groupId: groupId, autoGainControl: autoGainControl, deviceId: deviceId, frameRate: frameRate, sampleRate: sampleRate, noiseSuppression: noiseSuppression, width: width};
}
function copy_103(_this__u8e3s4, channelCount, height, sampleSize, aspectRatio, displaySurface, echoCancellation, backgroundBlur, facingMode, groupId, autoGainControl, deviceId, frameRate, sampleRate, noiseSuppression, width) {
  channelCount = channelCount === VOID ? VOID : channelCount;
  height = height === VOID ? VOID : height;
  sampleSize = sampleSize === VOID ? VOID : sampleSize;
  aspectRatio = aspectRatio === VOID ? VOID : aspectRatio;
  displaySurface = displaySurface === VOID ? VOID : displaySurface;
  echoCancellation = echoCancellation === VOID ? VOID : echoCancellation;
  backgroundBlur = backgroundBlur === VOID ? VOID : backgroundBlur;
  facingMode = facingMode === VOID ? VOID : facingMode;
  groupId = groupId === VOID ? VOID : groupId;
  autoGainControl = autoGainControl === VOID ? VOID : autoGainControl;
  deviceId = deviceId === VOID ? VOID : deviceId;
  frameRate = frameRate === VOID ? VOID : frameRate;
  sampleRate = sampleRate === VOID ? VOID : sampleRate;
  noiseSuppression = noiseSuppression === VOID ? VOID : noiseSuppression;
  width = width === VOID ? VOID : width;
  return Object.assign({}, _this__u8e3s4, {channelCount: channelCount, height: height, sampleSize: sampleSize, aspectRatio: aspectRatio, displaySurface: displaySurface, echoCancellation: echoCancellation, backgroundBlur: backgroundBlur, facingMode: facingMode, groupId: groupId, autoGainControl: autoGainControl, deviceId: deviceId, frameRate: frameRate, sampleRate: sampleRate, noiseSuppression: noiseSuppression, width: width});
}
function invoke_103(_this__u8e3s4, channelCount, height, sampleSize, aspectRatio, displaySurface, echoCancellation, backgroundBlur, facingMode, groupId, autoGainControl, deviceId, frameRate, sampleRate, noiseSuppression, width) {
  channelCount = channelCount === VOID ? VOID : channelCount;
  height = height === VOID ? VOID : height;
  sampleSize = sampleSize === VOID ? VOID : sampleSize;
  aspectRatio = aspectRatio === VOID ? VOID : aspectRatio;
  displaySurface = displaySurface === VOID ? VOID : displaySurface;
  echoCancellation = echoCancellation === VOID ? VOID : echoCancellation;
  backgroundBlur = backgroundBlur === VOID ? VOID : backgroundBlur;
  facingMode = facingMode === VOID ? VOID : facingMode;
  groupId = groupId === VOID ? VOID : groupId;
  autoGainControl = autoGainControl === VOID ? VOID : autoGainControl;
  deviceId = deviceId === VOID ? VOID : deviceId;
  frameRate = frameRate === VOID ? VOID : frameRate;
  sampleRate = sampleRate === VOID ? VOID : sampleRate;
  noiseSuppression = noiseSuppression === VOID ? VOID : noiseSuppression;
  width = width === VOID ? VOID : width;
  return {channelCount: channelCount, height: height, sampleSize: sampleSize, aspectRatio: aspectRatio, displaySurface: displaySurface, echoCancellation: echoCancellation, backgroundBlur: backgroundBlur, facingMode: facingMode, groupId: groupId, autoGainControl: autoGainControl, deviceId: deviceId, frameRate: frameRate, sampleRate: sampleRate, noiseSuppression: noiseSuppression, width: width};
}
function copy_104(_this__u8e3s4, channelCount, height, sampleSize, aspectRatio, displaySurface, echoCancellation, backgroundBlur, facingMode, groupId, autoGainControl, deviceId, frameRate, sampleRate, noiseSuppression, width, advanced) {
  channelCount = channelCount === VOID ? VOID : channelCount;
  height = height === VOID ? VOID : height;
  sampleSize = sampleSize === VOID ? VOID : sampleSize;
  aspectRatio = aspectRatio === VOID ? VOID : aspectRatio;
  displaySurface = displaySurface === VOID ? VOID : displaySurface;
  echoCancellation = echoCancellation === VOID ? VOID : echoCancellation;
  backgroundBlur = backgroundBlur === VOID ? VOID : backgroundBlur;
  facingMode = facingMode === VOID ? VOID : facingMode;
  groupId = groupId === VOID ? VOID : groupId;
  autoGainControl = autoGainControl === VOID ? VOID : autoGainControl;
  deviceId = deviceId === VOID ? VOID : deviceId;
  frameRate = frameRate === VOID ? VOID : frameRate;
  sampleRate = sampleRate === VOID ? VOID : sampleRate;
  noiseSuppression = noiseSuppression === VOID ? VOID : noiseSuppression;
  width = width === VOID ? VOID : width;
  advanced = advanced === VOID ? VOID : advanced;
  return Object.assign({}, _this__u8e3s4, {channelCount: channelCount, height: height, sampleSize: sampleSize, aspectRatio: aspectRatio, displaySurface: displaySurface, echoCancellation: echoCancellation, backgroundBlur: backgroundBlur, facingMode: facingMode, groupId: groupId, autoGainControl: autoGainControl, deviceId: deviceId, frameRate: frameRate, sampleRate: sampleRate, noiseSuppression: noiseSuppression, width: width, advanced: advanced});
}
function invoke_104(_this__u8e3s4, channelCount, height, sampleSize, aspectRatio, displaySurface, echoCancellation, backgroundBlur, facingMode, groupId, autoGainControl, deviceId, frameRate, sampleRate, noiseSuppression, width, advanced) {
  channelCount = channelCount === VOID ? VOID : channelCount;
  height = height === VOID ? VOID : height;
  sampleSize = sampleSize === VOID ? VOID : sampleSize;
  aspectRatio = aspectRatio === VOID ? VOID : aspectRatio;
  displaySurface = displaySurface === VOID ? VOID : displaySurface;
  echoCancellation = echoCancellation === VOID ? VOID : echoCancellation;
  backgroundBlur = backgroundBlur === VOID ? VOID : backgroundBlur;
  facingMode = facingMode === VOID ? VOID : facingMode;
  groupId = groupId === VOID ? VOID : groupId;
  autoGainControl = autoGainControl === VOID ? VOID : autoGainControl;
  deviceId = deviceId === VOID ? VOID : deviceId;
  frameRate = frameRate === VOID ? VOID : frameRate;
  sampleRate = sampleRate === VOID ? VOID : sampleRate;
  noiseSuppression = noiseSuppression === VOID ? VOID : noiseSuppression;
  width = width === VOID ? VOID : width;
  advanced = advanced === VOID ? VOID : advanced;
  return {channelCount: channelCount, height: height, sampleSize: sampleSize, aspectRatio: aspectRatio, displaySurface: displaySurface, echoCancellation: echoCancellation, backgroundBlur: backgroundBlur, facingMode: facingMode, groupId: groupId, autoGainControl: autoGainControl, deviceId: deviceId, frameRate: frameRate, sampleRate: sampleRate, noiseSuppression: noiseSuppression, width: width, advanced: advanced};
}
function copy_105(_this__u8e3s4, channelCount, height, sampleSize, aspectRatio, displaySurface, echoCancellation, backgroundBlur, facingMode, groupId, autoGainControl, deviceId, frameRate, sampleRate, noiseSuppression, width) {
  channelCount = channelCount === VOID ? VOID : channelCount;
  height = height === VOID ? VOID : height;
  sampleSize = sampleSize === VOID ? VOID : sampleSize;
  aspectRatio = aspectRatio === VOID ? VOID : aspectRatio;
  displaySurface = displaySurface === VOID ? VOID : displaySurface;
  echoCancellation = echoCancellation === VOID ? VOID : echoCancellation;
  backgroundBlur = backgroundBlur === VOID ? VOID : backgroundBlur;
  facingMode = facingMode === VOID ? VOID : facingMode;
  groupId = groupId === VOID ? VOID : groupId;
  autoGainControl = autoGainControl === VOID ? VOID : autoGainControl;
  deviceId = deviceId === VOID ? VOID : deviceId;
  frameRate = frameRate === VOID ? VOID : frameRate;
  sampleRate = sampleRate === VOID ? VOID : sampleRate;
  noiseSuppression = noiseSuppression === VOID ? VOID : noiseSuppression;
  width = width === VOID ? VOID : width;
  return Object.assign({}, _this__u8e3s4, {channelCount: channelCount, height: height, sampleSize: sampleSize, aspectRatio: aspectRatio, displaySurface: displaySurface, echoCancellation: echoCancellation, backgroundBlur: backgroundBlur, facingMode: facingMode, groupId: groupId, autoGainControl: autoGainControl, deviceId: deviceId, frameRate: frameRate, sampleRate: sampleRate, noiseSuppression: noiseSuppression, width: width});
}
function invoke_105(_this__u8e3s4, channelCount, height, sampleSize, aspectRatio, displaySurface, echoCancellation, backgroundBlur, facingMode, groupId, autoGainControl, deviceId, frameRate, sampleRate, noiseSuppression, width) {
  channelCount = channelCount === VOID ? VOID : channelCount;
  height = height === VOID ? VOID : height;
  sampleSize = sampleSize === VOID ? VOID : sampleSize;
  aspectRatio = aspectRatio === VOID ? VOID : aspectRatio;
  displaySurface = displaySurface === VOID ? VOID : displaySurface;
  echoCancellation = echoCancellation === VOID ? VOID : echoCancellation;
  backgroundBlur = backgroundBlur === VOID ? VOID : backgroundBlur;
  facingMode = facingMode === VOID ? VOID : facingMode;
  groupId = groupId === VOID ? VOID : groupId;
  autoGainControl = autoGainControl === VOID ? VOID : autoGainControl;
  deviceId = deviceId === VOID ? VOID : deviceId;
  frameRate = frameRate === VOID ? VOID : frameRate;
  sampleRate = sampleRate === VOID ? VOID : sampleRate;
  noiseSuppression = noiseSuppression === VOID ? VOID : noiseSuppression;
  width = width === VOID ? VOID : width;
  return {channelCount: channelCount, height: height, sampleSize: sampleSize, aspectRatio: aspectRatio, displaySurface: displaySurface, echoCancellation: echoCancellation, backgroundBlur: backgroundBlur, facingMode: facingMode, groupId: groupId, autoGainControl: autoGainControl, deviceId: deviceId, frameRate: frameRate, sampleRate: sampleRate, noiseSuppression: noiseSuppression, width: width};
}
function copy_106(_this__u8e3s4, min, max) {
  min = min === VOID ? VOID : min;
  max = max === VOID ? VOID : max;
  return Object.assign({}, _this__u8e3s4, {min: min, max: max});
}
function invoke_106(_this__u8e3s4, min, max) {
  min = min === VOID ? VOID : min;
  max = max === VOID ? VOID : max;
  return {min: min, max: max};
}
function copy_107(_this__u8e3s4, bubbles, cancelable, composed, pictureInPictureWindow) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  pictureInPictureWindow = pictureInPictureWindow === VOID ? VOID : pictureInPictureWindow;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, pictureInPictureWindow: pictureInPictureWindow});
}
function invoke_107(_this__u8e3s4, bubbles, cancelable, composed, pictureInPictureWindow) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, pictureInPictureWindow: pictureInPictureWindow};
}
function copy_108(_this__u8e3s4, bubbles, cancelable, composed, newState, oldState) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  newState = newState === VOID ? VOID : newState;
  oldState = oldState === VOID ? VOID : oldState;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, newState: newState, oldState: oldState});
}
function invoke_108(_this__u8e3s4, bubbles, cancelable, composed, newState, oldState) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  newState = newState === VOID ? VOID : newState;
  oldState = oldState === VOID ? VOID : oldState;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, newState: newState, oldState: oldState};
}
function copy_109(_this__u8e3s4, endOffset, startOffset, endContainer, startContainer) {
  endOffset = endOffset === VOID ? VOID : endOffset;
  startOffset = startOffset === VOID ? VOID : startOffset;
  endContainer = endContainer === VOID ? VOID : endContainer;
  startContainer = startContainer === VOID ? VOID : startContainer;
  return Object.assign({}, _this__u8e3s4, {endOffset: endOffset, startOffset: startOffset, endContainer: endContainer, startContainer: startContainer});
}
function invoke_109(_this__u8e3s4, endOffset, startOffset, endContainer, startContainer) {
  return {endOffset: endOffset, startOffset: startOffset, endContainer: endContainer, startContainer: startContainer};
}
function copy_110(_this__u8e3s4, behavior, inline, block) {
  behavior = behavior === VOID ? VOID : behavior;
  inline = inline === VOID ? VOID : inline;
  block = block === VOID ? VOID : block;
  return Object.assign({}, _this__u8e3s4, {behavior: behavior, inline: inline, block: block});
}
function invoke_110(_this__u8e3s4, behavior, inline, block) {
  behavior = behavior === VOID ? VOID : behavior;
  inline = inline === VOID ? VOID : inline;
  block = block === VOID ? VOID : block;
  return {behavior: behavior, inline: inline, block: block};
}
function copy_111(_this__u8e3s4, behavior) {
  behavior = behavior === VOID ? VOID : behavior;
  return Object.assign({}, _this__u8e3s4, {behavior: behavior});
}
function invoke_111(_this__u8e3s4, behavior) {
  behavior = behavior === VOID ? VOID : behavior;
  return {behavior: behavior};
}
function copy_112(_this__u8e3s4, behavior, left, top) {
  behavior = behavior === VOID ? VOID : behavior;
  left = left === VOID ? VOID : left;
  top = top === VOID ? VOID : top;
  return Object.assign({}, _this__u8e3s4, {behavior: behavior, left: left, top: top});
}
function invoke_112(_this__u8e3s4, behavior, left, top) {
  behavior = behavior === VOID ? VOID : behavior;
  left = left === VOID ? VOID : left;
  top = top === VOID ? VOID : top;
  return {behavior: behavior, left: left, top: top};
}
function copy_113(_this__u8e3s4, bubbles, cancelable, composed, newValue, oldValue, key, url, storageArea) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  newValue = newValue === VOID ? VOID : newValue;
  oldValue = oldValue === VOID ? VOID : oldValue;
  key = key === VOID ? VOID : key;
  url = url === VOID ? VOID : url;
  storageArea = storageArea === VOID ? VOID : storageArea;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, newValue: newValue, oldValue: oldValue, key: key, url: url, storageArea: storageArea});
}
function invoke_113(_this__u8e3s4, bubbles, cancelable, composed, newValue, oldValue, key, url, storageArea) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  newValue = newValue === VOID ? VOID : newValue;
  oldValue = oldValue === VOID ? VOID : oldValue;
  key = key === VOID ? VOID : key;
  url = url === VOID ? VOID : url;
  storageArea = storageArea === VOID ? VOID : storageArea;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, newValue: newValue, oldValue: oldValue, key: key, url: url, storageArea: storageArea};
}
function copy_114(_this__u8e3s4, clipped, stroke, fill, markers) {
  clipped = clipped === VOID ? VOID : clipped;
  stroke = stroke === VOID ? VOID : stroke;
  fill = fill === VOID ? VOID : fill;
  markers = markers === VOID ? VOID : markers;
  return Object.assign({}, _this__u8e3s4, {clipped: clipped, stroke: stroke, fill: fill, markers: markers});
}
function invoke_114(_this__u8e3s4, clipped, stroke, fill, markers) {
  clipped = clipped === VOID ? VOID : clipped;
  stroke = stroke === VOID ? VOID : stroke;
  fill = fill === VOID ? VOID : fill;
  markers = markers === VOID ? VOID : markers;
  return {clipped: clipped, stroke: stroke, fill: fill, markers: markers};
}
function copy_115(_this__u8e3s4, bubbles, cancelable, composed, detail, view, data) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  data = data === VOID ? VOID : data;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, data: data});
}
function invoke_115(_this__u8e3s4, bubbles, cancelable, composed, detail, view, data) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  data = data === VOID ? VOID : data;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, data: data};
}
function copy_116(_this__u8e3s4, bubbles, cancelable, composed, detail, view, altKey, metaKey, modifierFnLock, modifierSymbol, modifierSymbolLock, modifierCapsLock, ctrlKey, modifierAltGraph, modifierScrollLock, modifierSuper, modifierHyper, modifierNumLock, shiftKey, modifierFn, movementY, movementX, screenX, screenY, clientX, clientY, relatedTarget, buttons, button, dataTransfer) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  altKey = altKey === VOID ? VOID : altKey;
  metaKey = metaKey === VOID ? VOID : metaKey;
  modifierFnLock = modifierFnLock === VOID ? VOID : modifierFnLock;
  modifierSymbol = modifierSymbol === VOID ? VOID : modifierSymbol;
  modifierSymbolLock = modifierSymbolLock === VOID ? VOID : modifierSymbolLock;
  modifierCapsLock = modifierCapsLock === VOID ? VOID : modifierCapsLock;
  ctrlKey = ctrlKey === VOID ? VOID : ctrlKey;
  modifierAltGraph = modifierAltGraph === VOID ? VOID : modifierAltGraph;
  modifierScrollLock = modifierScrollLock === VOID ? VOID : modifierScrollLock;
  modifierSuper = modifierSuper === VOID ? VOID : modifierSuper;
  modifierHyper = modifierHyper === VOID ? VOID : modifierHyper;
  modifierNumLock = modifierNumLock === VOID ? VOID : modifierNumLock;
  shiftKey = shiftKey === VOID ? VOID : shiftKey;
  modifierFn = modifierFn === VOID ? VOID : modifierFn;
  movementY = movementY === VOID ? VOID : movementY;
  movementX = movementX === VOID ? VOID : movementX;
  screenX = screenX === VOID ? VOID : screenX;
  screenY = screenY === VOID ? VOID : screenY;
  clientX = clientX === VOID ? VOID : clientX;
  clientY = clientY === VOID ? VOID : clientY;
  relatedTarget = relatedTarget === VOID ? VOID : relatedTarget;
  buttons = buttons === VOID ? VOID : buttons;
  button = button === VOID ? VOID : button;
  dataTransfer = dataTransfer === VOID ? VOID : dataTransfer;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, altKey: altKey, metaKey: metaKey, modifierFnLock: modifierFnLock, modifierSymbol: modifierSymbol, modifierSymbolLock: modifierSymbolLock, modifierCapsLock: modifierCapsLock, ctrlKey: ctrlKey, modifierAltGraph: modifierAltGraph, modifierScrollLock: modifierScrollLock, modifierSuper: modifierSuper, modifierHyper: modifierHyper, modifierNumLock: modifierNumLock, shiftKey: shiftKey, modifierFn: modifierFn, movementY: movementY, movementX: movementX, screenX: screenX, screenY: screenY, clientX: clientX, clientY: clientY, relatedTarget: relatedTarget, buttons: buttons, button: button, dataTransfer: dataTransfer});
}
function invoke_116(_this__u8e3s4, bubbles, cancelable, composed, detail, view, altKey, metaKey, modifierFnLock, modifierSymbol, modifierSymbolLock, modifierCapsLock, ctrlKey, modifierAltGraph, modifierScrollLock, modifierSuper, modifierHyper, modifierNumLock, shiftKey, modifierFn, movementY, movementX, screenX, screenY, clientX, clientY, relatedTarget, buttons, button, dataTransfer) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  altKey = altKey === VOID ? VOID : altKey;
  metaKey = metaKey === VOID ? VOID : metaKey;
  modifierFnLock = modifierFnLock === VOID ? VOID : modifierFnLock;
  modifierSymbol = modifierSymbol === VOID ? VOID : modifierSymbol;
  modifierSymbolLock = modifierSymbolLock === VOID ? VOID : modifierSymbolLock;
  modifierCapsLock = modifierCapsLock === VOID ? VOID : modifierCapsLock;
  ctrlKey = ctrlKey === VOID ? VOID : ctrlKey;
  modifierAltGraph = modifierAltGraph === VOID ? VOID : modifierAltGraph;
  modifierScrollLock = modifierScrollLock === VOID ? VOID : modifierScrollLock;
  modifierSuper = modifierSuper === VOID ? VOID : modifierSuper;
  modifierHyper = modifierHyper === VOID ? VOID : modifierHyper;
  modifierNumLock = modifierNumLock === VOID ? VOID : modifierNumLock;
  shiftKey = shiftKey === VOID ? VOID : shiftKey;
  modifierFn = modifierFn === VOID ? VOID : modifierFn;
  movementY = movementY === VOID ? VOID : movementY;
  movementX = movementX === VOID ? VOID : movementX;
  screenX = screenX === VOID ? VOID : screenX;
  screenY = screenY === VOID ? VOID : screenY;
  clientX = clientX === VOID ? VOID : clientX;
  clientY = clientY === VOID ? VOID : clientY;
  relatedTarget = relatedTarget === VOID ? VOID : relatedTarget;
  buttons = buttons === VOID ? VOID : buttons;
  button = button === VOID ? VOID : button;
  dataTransfer = dataTransfer === VOID ? VOID : dataTransfer;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, altKey: altKey, metaKey: metaKey, modifierFnLock: modifierFnLock, modifierSymbol: modifierSymbol, modifierSymbolLock: modifierSymbolLock, modifierCapsLock: modifierCapsLock, ctrlKey: ctrlKey, modifierAltGraph: modifierAltGraph, modifierScrollLock: modifierScrollLock, modifierSuper: modifierSuper, modifierHyper: modifierHyper, modifierNumLock: modifierNumLock, shiftKey: shiftKey, modifierFn: modifierFn, movementY: movementY, movementX: movementX, screenX: screenX, screenY: screenY, clientX: clientX, clientY: clientY, relatedTarget: relatedTarget, buttons: buttons, button: button, dataTransfer: dataTransfer};
}
function copy_117(_this__u8e3s4, bubbles, cancelable, composed, detail, view, altKey, metaKey, modifierFnLock, modifierSymbol, modifierSymbolLock, modifierCapsLock, ctrlKey, modifierAltGraph, modifierScrollLock, modifierSuper, modifierHyper, modifierNumLock, shiftKey, modifierFn) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  altKey = altKey === VOID ? VOID : altKey;
  metaKey = metaKey === VOID ? VOID : metaKey;
  modifierFnLock = modifierFnLock === VOID ? VOID : modifierFnLock;
  modifierSymbol = modifierSymbol === VOID ? VOID : modifierSymbol;
  modifierSymbolLock = modifierSymbolLock === VOID ? VOID : modifierSymbolLock;
  modifierCapsLock = modifierCapsLock === VOID ? VOID : modifierCapsLock;
  ctrlKey = ctrlKey === VOID ? VOID : ctrlKey;
  modifierAltGraph = modifierAltGraph === VOID ? VOID : modifierAltGraph;
  modifierScrollLock = modifierScrollLock === VOID ? VOID : modifierScrollLock;
  modifierSuper = modifierSuper === VOID ? VOID : modifierSuper;
  modifierHyper = modifierHyper === VOID ? VOID : modifierHyper;
  modifierNumLock = modifierNumLock === VOID ? VOID : modifierNumLock;
  shiftKey = shiftKey === VOID ? VOID : shiftKey;
  modifierFn = modifierFn === VOID ? VOID : modifierFn;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, altKey: altKey, metaKey: metaKey, modifierFnLock: modifierFnLock, modifierSymbol: modifierSymbol, modifierSymbolLock: modifierSymbolLock, modifierCapsLock: modifierCapsLock, ctrlKey: ctrlKey, modifierAltGraph: modifierAltGraph, modifierScrollLock: modifierScrollLock, modifierSuper: modifierSuper, modifierHyper: modifierHyper, modifierNumLock: modifierNumLock, shiftKey: shiftKey, modifierFn: modifierFn});
}
function invoke_117(_this__u8e3s4, bubbles, cancelable, composed, detail, view, altKey, metaKey, modifierFnLock, modifierSymbol, modifierSymbolLock, modifierCapsLock, ctrlKey, modifierAltGraph, modifierScrollLock, modifierSuper, modifierHyper, modifierNumLock, shiftKey, modifierFn) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  altKey = altKey === VOID ? VOID : altKey;
  metaKey = metaKey === VOID ? VOID : metaKey;
  modifierFnLock = modifierFnLock === VOID ? VOID : modifierFnLock;
  modifierSymbol = modifierSymbol === VOID ? VOID : modifierSymbol;
  modifierSymbolLock = modifierSymbolLock === VOID ? VOID : modifierSymbolLock;
  modifierCapsLock = modifierCapsLock === VOID ? VOID : modifierCapsLock;
  ctrlKey = ctrlKey === VOID ? VOID : ctrlKey;
  modifierAltGraph = modifierAltGraph === VOID ? VOID : modifierAltGraph;
  modifierScrollLock = modifierScrollLock === VOID ? VOID : modifierScrollLock;
  modifierSuper = modifierSuper === VOID ? VOID : modifierSuper;
  modifierHyper = modifierHyper === VOID ? VOID : modifierHyper;
  modifierNumLock = modifierNumLock === VOID ? VOID : modifierNumLock;
  shiftKey = shiftKey === VOID ? VOID : shiftKey;
  modifierFn = modifierFn === VOID ? VOID : modifierFn;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, altKey: altKey, metaKey: metaKey, modifierFnLock: modifierFnLock, modifierSymbol: modifierSymbol, modifierSymbolLock: modifierSymbolLock, modifierCapsLock: modifierCapsLock, ctrlKey: ctrlKey, modifierAltGraph: modifierAltGraph, modifierScrollLock: modifierScrollLock, modifierSuper: modifierSuper, modifierHyper: modifierHyper, modifierNumLock: modifierNumLock, shiftKey: shiftKey, modifierFn: modifierFn};
}
function copy_118(_this__u8e3s4, bubbles, cancelable, composed, detail, view, relatedTarget) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  relatedTarget = relatedTarget === VOID ? VOID : relatedTarget;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, relatedTarget: relatedTarget});
}
function invoke_118(_this__u8e3s4, bubbles, cancelable, composed, detail, view, relatedTarget) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  relatedTarget = relatedTarget === VOID ? VOID : relatedTarget;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, relatedTarget: relatedTarget};
}
function copy_119(_this__u8e3s4, bubbles, cancelable, composed, detail, view, inputType, targetRanges, dataTransfer, data, isComposing) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  inputType = inputType === VOID ? VOID : inputType;
  targetRanges = targetRanges === VOID ? VOID : targetRanges;
  dataTransfer = dataTransfer === VOID ? VOID : dataTransfer;
  data = data === VOID ? VOID : data;
  isComposing = isComposing === VOID ? VOID : isComposing;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, inputType: inputType, targetRanges: targetRanges, dataTransfer: dataTransfer, data: data, isComposing: isComposing});
}
function invoke_119(_this__u8e3s4, bubbles, cancelable, composed, detail, view, inputType, targetRanges, dataTransfer, data, isComposing) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  inputType = inputType === VOID ? VOID : inputType;
  targetRanges = targetRanges === VOID ? VOID : targetRanges;
  dataTransfer = dataTransfer === VOID ? VOID : dataTransfer;
  data = data === VOID ? VOID : data;
  isComposing = isComposing === VOID ? VOID : isComposing;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, inputType: inputType, targetRanges: targetRanges, dataTransfer: dataTransfer, data: data, isComposing: isComposing};
}
function copy_120(_this__u8e3s4, bubbles, cancelable, composed, detail, view, altKey, metaKey, modifierFnLock, modifierSymbol, modifierSymbolLock, modifierCapsLock, ctrlKey, modifierAltGraph, modifierScrollLock, modifierSuper, modifierHyper, modifierNumLock, shiftKey, modifierFn, key, code, isComposing, repeat, location) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  altKey = altKey === VOID ? VOID : altKey;
  metaKey = metaKey === VOID ? VOID : metaKey;
  modifierFnLock = modifierFnLock === VOID ? VOID : modifierFnLock;
  modifierSymbol = modifierSymbol === VOID ? VOID : modifierSymbol;
  modifierSymbolLock = modifierSymbolLock === VOID ? VOID : modifierSymbolLock;
  modifierCapsLock = modifierCapsLock === VOID ? VOID : modifierCapsLock;
  ctrlKey = ctrlKey === VOID ? VOID : ctrlKey;
  modifierAltGraph = modifierAltGraph === VOID ? VOID : modifierAltGraph;
  modifierScrollLock = modifierScrollLock === VOID ? VOID : modifierScrollLock;
  modifierSuper = modifierSuper === VOID ? VOID : modifierSuper;
  modifierHyper = modifierHyper === VOID ? VOID : modifierHyper;
  modifierNumLock = modifierNumLock === VOID ? VOID : modifierNumLock;
  shiftKey = shiftKey === VOID ? VOID : shiftKey;
  modifierFn = modifierFn === VOID ? VOID : modifierFn;
  key = key === VOID ? VOID : key;
  code = code === VOID ? VOID : code;
  isComposing = isComposing === VOID ? VOID : isComposing;
  repeat = repeat === VOID ? VOID : repeat;
  location = location === VOID ? VOID : location;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, altKey: altKey, metaKey: metaKey, modifierFnLock: modifierFnLock, modifierSymbol: modifierSymbol, modifierSymbolLock: modifierSymbolLock, modifierCapsLock: modifierCapsLock, ctrlKey: ctrlKey, modifierAltGraph: modifierAltGraph, modifierScrollLock: modifierScrollLock, modifierSuper: modifierSuper, modifierHyper: modifierHyper, modifierNumLock: modifierNumLock, shiftKey: shiftKey, modifierFn: modifierFn, key: key, code: code, isComposing: isComposing, repeat: repeat, location: location});
}
function invoke_120(_this__u8e3s4, bubbles, cancelable, composed, detail, view, altKey, metaKey, modifierFnLock, modifierSymbol, modifierSymbolLock, modifierCapsLock, ctrlKey, modifierAltGraph, modifierScrollLock, modifierSuper, modifierHyper, modifierNumLock, shiftKey, modifierFn, key, code, isComposing, repeat, location) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  altKey = altKey === VOID ? VOID : altKey;
  metaKey = metaKey === VOID ? VOID : metaKey;
  modifierFnLock = modifierFnLock === VOID ? VOID : modifierFnLock;
  modifierSymbol = modifierSymbol === VOID ? VOID : modifierSymbol;
  modifierSymbolLock = modifierSymbolLock === VOID ? VOID : modifierSymbolLock;
  modifierCapsLock = modifierCapsLock === VOID ? VOID : modifierCapsLock;
  ctrlKey = ctrlKey === VOID ? VOID : ctrlKey;
  modifierAltGraph = modifierAltGraph === VOID ? VOID : modifierAltGraph;
  modifierScrollLock = modifierScrollLock === VOID ? VOID : modifierScrollLock;
  modifierSuper = modifierSuper === VOID ? VOID : modifierSuper;
  modifierHyper = modifierHyper === VOID ? VOID : modifierHyper;
  modifierNumLock = modifierNumLock === VOID ? VOID : modifierNumLock;
  shiftKey = shiftKey === VOID ? VOID : shiftKey;
  modifierFn = modifierFn === VOID ? VOID : modifierFn;
  key = key === VOID ? VOID : key;
  code = code === VOID ? VOID : code;
  isComposing = isComposing === VOID ? VOID : isComposing;
  repeat = repeat === VOID ? VOID : repeat;
  location = location === VOID ? VOID : location;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, altKey: altKey, metaKey: metaKey, modifierFnLock: modifierFnLock, modifierSymbol: modifierSymbol, modifierSymbolLock: modifierSymbolLock, modifierCapsLock: modifierCapsLock, ctrlKey: ctrlKey, modifierAltGraph: modifierAltGraph, modifierScrollLock: modifierScrollLock, modifierSuper: modifierSuper, modifierHyper: modifierHyper, modifierNumLock: modifierNumLock, shiftKey: shiftKey, modifierFn: modifierFn, key: key, code: code, isComposing: isComposing, repeat: repeat, location: location};
}
function copy_121(_this__u8e3s4, bubbles, cancelable, composed, detail, view, altKey, metaKey, modifierFnLock, modifierSymbol, modifierSymbolLock, modifierCapsLock, ctrlKey, modifierAltGraph, modifierScrollLock, modifierSuper, modifierHyper, modifierNumLock, shiftKey, modifierFn, movementY, movementX, screenX, screenY, clientX, clientY, relatedTarget, buttons, button) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  altKey = altKey === VOID ? VOID : altKey;
  metaKey = metaKey === VOID ? VOID : metaKey;
  modifierFnLock = modifierFnLock === VOID ? VOID : modifierFnLock;
  modifierSymbol = modifierSymbol === VOID ? VOID : modifierSymbol;
  modifierSymbolLock = modifierSymbolLock === VOID ? VOID : modifierSymbolLock;
  modifierCapsLock = modifierCapsLock === VOID ? VOID : modifierCapsLock;
  ctrlKey = ctrlKey === VOID ? VOID : ctrlKey;
  modifierAltGraph = modifierAltGraph === VOID ? VOID : modifierAltGraph;
  modifierScrollLock = modifierScrollLock === VOID ? VOID : modifierScrollLock;
  modifierSuper = modifierSuper === VOID ? VOID : modifierSuper;
  modifierHyper = modifierHyper === VOID ? VOID : modifierHyper;
  modifierNumLock = modifierNumLock === VOID ? VOID : modifierNumLock;
  shiftKey = shiftKey === VOID ? VOID : shiftKey;
  modifierFn = modifierFn === VOID ? VOID : modifierFn;
  movementY = movementY === VOID ? VOID : movementY;
  movementX = movementX === VOID ? VOID : movementX;
  screenX = screenX === VOID ? VOID : screenX;
  screenY = screenY === VOID ? VOID : screenY;
  clientX = clientX === VOID ? VOID : clientX;
  clientY = clientY === VOID ? VOID : clientY;
  relatedTarget = relatedTarget === VOID ? VOID : relatedTarget;
  buttons = buttons === VOID ? VOID : buttons;
  button = button === VOID ? VOID : button;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, altKey: altKey, metaKey: metaKey, modifierFnLock: modifierFnLock, modifierSymbol: modifierSymbol, modifierSymbolLock: modifierSymbolLock, modifierCapsLock: modifierCapsLock, ctrlKey: ctrlKey, modifierAltGraph: modifierAltGraph, modifierScrollLock: modifierScrollLock, modifierSuper: modifierSuper, modifierHyper: modifierHyper, modifierNumLock: modifierNumLock, shiftKey: shiftKey, modifierFn: modifierFn, movementY: movementY, movementX: movementX, screenX: screenX, screenY: screenY, clientX: clientX, clientY: clientY, relatedTarget: relatedTarget, buttons: buttons, button: button});
}
function invoke_121(_this__u8e3s4, bubbles, cancelable, composed, detail, view, altKey, metaKey, modifierFnLock, modifierSymbol, modifierSymbolLock, modifierCapsLock, ctrlKey, modifierAltGraph, modifierScrollLock, modifierSuper, modifierHyper, modifierNumLock, shiftKey, modifierFn, movementY, movementX, screenX, screenY, clientX, clientY, relatedTarget, buttons, button) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  altKey = altKey === VOID ? VOID : altKey;
  metaKey = metaKey === VOID ? VOID : metaKey;
  modifierFnLock = modifierFnLock === VOID ? VOID : modifierFnLock;
  modifierSymbol = modifierSymbol === VOID ? VOID : modifierSymbol;
  modifierSymbolLock = modifierSymbolLock === VOID ? VOID : modifierSymbolLock;
  modifierCapsLock = modifierCapsLock === VOID ? VOID : modifierCapsLock;
  ctrlKey = ctrlKey === VOID ? VOID : ctrlKey;
  modifierAltGraph = modifierAltGraph === VOID ? VOID : modifierAltGraph;
  modifierScrollLock = modifierScrollLock === VOID ? VOID : modifierScrollLock;
  modifierSuper = modifierSuper === VOID ? VOID : modifierSuper;
  modifierHyper = modifierHyper === VOID ? VOID : modifierHyper;
  modifierNumLock = modifierNumLock === VOID ? VOID : modifierNumLock;
  shiftKey = shiftKey === VOID ? VOID : shiftKey;
  modifierFn = modifierFn === VOID ? VOID : modifierFn;
  movementY = movementY === VOID ? VOID : movementY;
  movementX = movementX === VOID ? VOID : movementX;
  screenX = screenX === VOID ? VOID : screenX;
  screenY = screenY === VOID ? VOID : screenY;
  clientX = clientX === VOID ? VOID : clientX;
  clientY = clientY === VOID ? VOID : clientY;
  relatedTarget = relatedTarget === VOID ? VOID : relatedTarget;
  buttons = buttons === VOID ? VOID : buttons;
  button = button === VOID ? VOID : button;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, altKey: altKey, metaKey: metaKey, modifierFnLock: modifierFnLock, modifierSymbol: modifierSymbol, modifierSymbolLock: modifierSymbolLock, modifierCapsLock: modifierCapsLock, ctrlKey: ctrlKey, modifierAltGraph: modifierAltGraph, modifierScrollLock: modifierScrollLock, modifierSuper: modifierSuper, modifierHyper: modifierHyper, modifierNumLock: modifierNumLock, shiftKey: shiftKey, modifierFn: modifierFn, movementY: movementY, movementX: movementX, screenX: screenX, screenY: screenY, clientX: clientX, clientY: clientY, relatedTarget: relatedTarget, buttons: buttons, button: button};
}
function copy_122(_this__u8e3s4, bubbles, cancelable, composed, detail, view, altKey, metaKey, modifierFnLock, modifierSymbol, modifierSymbolLock, modifierCapsLock, ctrlKey, modifierAltGraph, modifierScrollLock, modifierSuper, modifierHyper, modifierNumLock, shiftKey, modifierFn, movementY, movementX, screenX, screenY, clientX, clientY, relatedTarget, buttons, button, height, tangentialPressure, predictedEvents, pointerId, tiltY, tiltX, twist, pointerType, pressure, altitudeAngle, isPrimary, azimuthAngle, coalescedEvents, width) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  altKey = altKey === VOID ? VOID : altKey;
  metaKey = metaKey === VOID ? VOID : metaKey;
  modifierFnLock = modifierFnLock === VOID ? VOID : modifierFnLock;
  modifierSymbol = modifierSymbol === VOID ? VOID : modifierSymbol;
  modifierSymbolLock = modifierSymbolLock === VOID ? VOID : modifierSymbolLock;
  modifierCapsLock = modifierCapsLock === VOID ? VOID : modifierCapsLock;
  ctrlKey = ctrlKey === VOID ? VOID : ctrlKey;
  modifierAltGraph = modifierAltGraph === VOID ? VOID : modifierAltGraph;
  modifierScrollLock = modifierScrollLock === VOID ? VOID : modifierScrollLock;
  modifierSuper = modifierSuper === VOID ? VOID : modifierSuper;
  modifierHyper = modifierHyper === VOID ? VOID : modifierHyper;
  modifierNumLock = modifierNumLock === VOID ? VOID : modifierNumLock;
  shiftKey = shiftKey === VOID ? VOID : shiftKey;
  modifierFn = modifierFn === VOID ? VOID : modifierFn;
  movementY = movementY === VOID ? VOID : movementY;
  movementX = movementX === VOID ? VOID : movementX;
  screenX = screenX === VOID ? VOID : screenX;
  screenY = screenY === VOID ? VOID : screenY;
  clientX = clientX === VOID ? VOID : clientX;
  clientY = clientY === VOID ? VOID : clientY;
  relatedTarget = relatedTarget === VOID ? VOID : relatedTarget;
  buttons = buttons === VOID ? VOID : buttons;
  button = button === VOID ? VOID : button;
  height = height === VOID ? VOID : height;
  tangentialPressure = tangentialPressure === VOID ? VOID : tangentialPressure;
  predictedEvents = predictedEvents === VOID ? VOID : predictedEvents;
  pointerId = pointerId === VOID ? VOID : pointerId;
  tiltY = tiltY === VOID ? VOID : tiltY;
  tiltX = tiltX === VOID ? VOID : tiltX;
  twist = twist === VOID ? VOID : twist;
  pointerType = pointerType === VOID ? VOID : pointerType;
  pressure = pressure === VOID ? VOID : pressure;
  altitudeAngle = altitudeAngle === VOID ? VOID : altitudeAngle;
  isPrimary = isPrimary === VOID ? VOID : isPrimary;
  azimuthAngle = azimuthAngle === VOID ? VOID : azimuthAngle;
  coalescedEvents = coalescedEvents === VOID ? VOID : coalescedEvents;
  width = width === VOID ? VOID : width;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, altKey: altKey, metaKey: metaKey, modifierFnLock: modifierFnLock, modifierSymbol: modifierSymbol, modifierSymbolLock: modifierSymbolLock, modifierCapsLock: modifierCapsLock, ctrlKey: ctrlKey, modifierAltGraph: modifierAltGraph, modifierScrollLock: modifierScrollLock, modifierSuper: modifierSuper, modifierHyper: modifierHyper, modifierNumLock: modifierNumLock, shiftKey: shiftKey, modifierFn: modifierFn, movementY: movementY, movementX: movementX, screenX: screenX, screenY: screenY, clientX: clientX, clientY: clientY, relatedTarget: relatedTarget, buttons: buttons, button: button, height: height, tangentialPressure: tangentialPressure, predictedEvents: predictedEvents, pointerId: pointerId, tiltY: tiltY, tiltX: tiltX, twist: twist, pointerType: pointerType, pressure: pressure, altitudeAngle: altitudeAngle, isPrimary: isPrimary, azimuthAngle: azimuthAngle, coalescedEvents: coalescedEvents, width: width});
}
function invoke_122(_this__u8e3s4, bubbles, cancelable, composed, detail, view, altKey, metaKey, modifierFnLock, modifierSymbol, modifierSymbolLock, modifierCapsLock, ctrlKey, modifierAltGraph, modifierScrollLock, modifierSuper, modifierHyper, modifierNumLock, shiftKey, modifierFn, movementY, movementX, screenX, screenY, clientX, clientY, relatedTarget, buttons, button, height, tangentialPressure, predictedEvents, pointerId, tiltY, tiltX, twist, pointerType, pressure, altitudeAngle, isPrimary, azimuthAngle, coalescedEvents, width) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  altKey = altKey === VOID ? VOID : altKey;
  metaKey = metaKey === VOID ? VOID : metaKey;
  modifierFnLock = modifierFnLock === VOID ? VOID : modifierFnLock;
  modifierSymbol = modifierSymbol === VOID ? VOID : modifierSymbol;
  modifierSymbolLock = modifierSymbolLock === VOID ? VOID : modifierSymbolLock;
  modifierCapsLock = modifierCapsLock === VOID ? VOID : modifierCapsLock;
  ctrlKey = ctrlKey === VOID ? VOID : ctrlKey;
  modifierAltGraph = modifierAltGraph === VOID ? VOID : modifierAltGraph;
  modifierScrollLock = modifierScrollLock === VOID ? VOID : modifierScrollLock;
  modifierSuper = modifierSuper === VOID ? VOID : modifierSuper;
  modifierHyper = modifierHyper === VOID ? VOID : modifierHyper;
  modifierNumLock = modifierNumLock === VOID ? VOID : modifierNumLock;
  shiftKey = shiftKey === VOID ? VOID : shiftKey;
  modifierFn = modifierFn === VOID ? VOID : modifierFn;
  movementY = movementY === VOID ? VOID : movementY;
  movementX = movementX === VOID ? VOID : movementX;
  screenX = screenX === VOID ? VOID : screenX;
  screenY = screenY === VOID ? VOID : screenY;
  clientX = clientX === VOID ? VOID : clientX;
  clientY = clientY === VOID ? VOID : clientY;
  relatedTarget = relatedTarget === VOID ? VOID : relatedTarget;
  buttons = buttons === VOID ? VOID : buttons;
  button = button === VOID ? VOID : button;
  height = height === VOID ? VOID : height;
  tangentialPressure = tangentialPressure === VOID ? VOID : tangentialPressure;
  predictedEvents = predictedEvents === VOID ? VOID : predictedEvents;
  pointerId = pointerId === VOID ? VOID : pointerId;
  tiltY = tiltY === VOID ? VOID : tiltY;
  tiltX = tiltX === VOID ? VOID : tiltX;
  twist = twist === VOID ? VOID : twist;
  pointerType = pointerType === VOID ? VOID : pointerType;
  pressure = pressure === VOID ? VOID : pressure;
  altitudeAngle = altitudeAngle === VOID ? VOID : altitudeAngle;
  isPrimary = isPrimary === VOID ? VOID : isPrimary;
  azimuthAngle = azimuthAngle === VOID ? VOID : azimuthAngle;
  coalescedEvents = coalescedEvents === VOID ? VOID : coalescedEvents;
  width = width === VOID ? VOID : width;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, altKey: altKey, metaKey: metaKey, modifierFnLock: modifierFnLock, modifierSymbol: modifierSymbol, modifierSymbolLock: modifierSymbolLock, modifierCapsLock: modifierCapsLock, ctrlKey: ctrlKey, modifierAltGraph: modifierAltGraph, modifierScrollLock: modifierScrollLock, modifierSuper: modifierSuper, modifierHyper: modifierHyper, modifierNumLock: modifierNumLock, shiftKey: shiftKey, modifierFn: modifierFn, movementY: movementY, movementX: movementX, screenX: screenX, screenY: screenY, clientX: clientX, clientY: clientY, relatedTarget: relatedTarget, buttons: buttons, button: button, height: height, tangentialPressure: tangentialPressure, predictedEvents: predictedEvents, pointerId: pointerId, tiltY: tiltY, tiltX: tiltX, twist: twist, pointerType: pointerType, pressure: pressure, altitudeAngle: altitudeAngle, isPrimary: isPrimary, azimuthAngle: azimuthAngle, coalescedEvents: coalescedEvents, width: width};
}
function copy_123(_this__u8e3s4, bubbles, cancelable, composed, detail, view, altKey, metaKey, modifierFnLock, modifierSymbol, modifierSymbolLock, modifierCapsLock, ctrlKey, modifierAltGraph, modifierScrollLock, modifierSuper, modifierHyper, modifierNumLock, shiftKey, modifierFn, targetTouches, touches, changedTouches) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  altKey = altKey === VOID ? VOID : altKey;
  metaKey = metaKey === VOID ? VOID : metaKey;
  modifierFnLock = modifierFnLock === VOID ? VOID : modifierFnLock;
  modifierSymbol = modifierSymbol === VOID ? VOID : modifierSymbol;
  modifierSymbolLock = modifierSymbolLock === VOID ? VOID : modifierSymbolLock;
  modifierCapsLock = modifierCapsLock === VOID ? VOID : modifierCapsLock;
  ctrlKey = ctrlKey === VOID ? VOID : ctrlKey;
  modifierAltGraph = modifierAltGraph === VOID ? VOID : modifierAltGraph;
  modifierScrollLock = modifierScrollLock === VOID ? VOID : modifierScrollLock;
  modifierSuper = modifierSuper === VOID ? VOID : modifierSuper;
  modifierHyper = modifierHyper === VOID ? VOID : modifierHyper;
  modifierNumLock = modifierNumLock === VOID ? VOID : modifierNumLock;
  shiftKey = shiftKey === VOID ? VOID : shiftKey;
  modifierFn = modifierFn === VOID ? VOID : modifierFn;
  targetTouches = targetTouches === VOID ? VOID : targetTouches;
  touches = touches === VOID ? VOID : touches;
  changedTouches = changedTouches === VOID ? VOID : changedTouches;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, altKey: altKey, metaKey: metaKey, modifierFnLock: modifierFnLock, modifierSymbol: modifierSymbol, modifierSymbolLock: modifierSymbolLock, modifierCapsLock: modifierCapsLock, ctrlKey: ctrlKey, modifierAltGraph: modifierAltGraph, modifierScrollLock: modifierScrollLock, modifierSuper: modifierSuper, modifierHyper: modifierHyper, modifierNumLock: modifierNumLock, shiftKey: shiftKey, modifierFn: modifierFn, targetTouches: targetTouches, touches: touches, changedTouches: changedTouches});
}
function invoke_123(_this__u8e3s4, bubbles, cancelable, composed, detail, view, altKey, metaKey, modifierFnLock, modifierSymbol, modifierSymbolLock, modifierCapsLock, ctrlKey, modifierAltGraph, modifierScrollLock, modifierSuper, modifierHyper, modifierNumLock, shiftKey, modifierFn, targetTouches, touches, changedTouches) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  altKey = altKey === VOID ? VOID : altKey;
  metaKey = metaKey === VOID ? VOID : metaKey;
  modifierFnLock = modifierFnLock === VOID ? VOID : modifierFnLock;
  modifierSymbol = modifierSymbol === VOID ? VOID : modifierSymbol;
  modifierSymbolLock = modifierSymbolLock === VOID ? VOID : modifierSymbolLock;
  modifierCapsLock = modifierCapsLock === VOID ? VOID : modifierCapsLock;
  ctrlKey = ctrlKey === VOID ? VOID : ctrlKey;
  modifierAltGraph = modifierAltGraph === VOID ? VOID : modifierAltGraph;
  modifierScrollLock = modifierScrollLock === VOID ? VOID : modifierScrollLock;
  modifierSuper = modifierSuper === VOID ? VOID : modifierSuper;
  modifierHyper = modifierHyper === VOID ? VOID : modifierHyper;
  modifierNumLock = modifierNumLock === VOID ? VOID : modifierNumLock;
  shiftKey = shiftKey === VOID ? VOID : shiftKey;
  modifierFn = modifierFn === VOID ? VOID : modifierFn;
  targetTouches = targetTouches === VOID ? VOID : targetTouches;
  touches = touches === VOID ? VOID : touches;
  changedTouches = changedTouches === VOID ? VOID : changedTouches;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, altKey: altKey, metaKey: metaKey, modifierFnLock: modifierFnLock, modifierSymbol: modifierSymbol, modifierSymbolLock: modifierSymbolLock, modifierCapsLock: modifierCapsLock, ctrlKey: ctrlKey, modifierAltGraph: modifierAltGraph, modifierScrollLock: modifierScrollLock, modifierSuper: modifierSuper, modifierHyper: modifierHyper, modifierNumLock: modifierNumLock, shiftKey: shiftKey, modifierFn: modifierFn, targetTouches: targetTouches, touches: touches, changedTouches: changedTouches};
}
function copy_124(_this__u8e3s4, target, screenX, screenY, rotationAngle, force, pageY, altitudeAngle, pageX, touchType, clientX, clientY, azimuthAngle, identifier, radiusY, radiusX) {
  target = target === VOID ? VOID : target;
  screenX = screenX === VOID ? VOID : screenX;
  screenY = screenY === VOID ? VOID : screenY;
  rotationAngle = rotationAngle === VOID ? VOID : rotationAngle;
  force = force === VOID ? VOID : force;
  pageY = pageY === VOID ? VOID : pageY;
  altitudeAngle = altitudeAngle === VOID ? VOID : altitudeAngle;
  pageX = pageX === VOID ? VOID : pageX;
  touchType = touchType === VOID ? VOID : touchType;
  clientX = clientX === VOID ? VOID : clientX;
  clientY = clientY === VOID ? VOID : clientY;
  azimuthAngle = azimuthAngle === VOID ? VOID : azimuthAngle;
  identifier = identifier === VOID ? VOID : identifier;
  radiusY = radiusY === VOID ? VOID : radiusY;
  radiusX = radiusX === VOID ? VOID : radiusX;
  return Object.assign({}, _this__u8e3s4, {target: target, screenX: screenX, screenY: screenY, rotationAngle: rotationAngle, force: force, pageY: pageY, altitudeAngle: altitudeAngle, pageX: pageX, touchType: touchType, clientX: clientX, clientY: clientY, azimuthAngle: azimuthAngle, identifier: identifier, radiusY: radiusY, radiusX: radiusX});
}
function invoke_124(_this__u8e3s4, target, screenX, screenY, rotationAngle, force, pageY, altitudeAngle, pageX, touchType, clientX, clientY, azimuthAngle, identifier, radiusY, radiusX) {
  screenX = screenX === VOID ? VOID : screenX;
  screenY = screenY === VOID ? VOID : screenY;
  rotationAngle = rotationAngle === VOID ? VOID : rotationAngle;
  force = force === VOID ? VOID : force;
  pageY = pageY === VOID ? VOID : pageY;
  altitudeAngle = altitudeAngle === VOID ? VOID : altitudeAngle;
  pageX = pageX === VOID ? VOID : pageX;
  touchType = touchType === VOID ? VOID : touchType;
  clientX = clientX === VOID ? VOID : clientX;
  clientY = clientY === VOID ? VOID : clientY;
  azimuthAngle = azimuthAngle === VOID ? VOID : azimuthAngle;
  radiusY = radiusY === VOID ? VOID : radiusY;
  radiusX = radiusX === VOID ? VOID : radiusX;
  return {target: target, screenX: screenX, screenY: screenY, rotationAngle: rotationAngle, force: force, pageY: pageY, altitudeAngle: altitudeAngle, pageX: pageX, touchType: touchType, clientX: clientX, clientY: clientY, azimuthAngle: azimuthAngle, identifier: identifier, radiusY: radiusY, radiusX: radiusX};
}
function copy_125(_this__u8e3s4, bubbles, cancelable, composed, detail, view) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view});
}
function invoke_125(_this__u8e3s4, bubbles, cancelable, composed, detail, view) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view};
}
function copy_126(_this__u8e3s4, bubbles, cancelable, composed, detail, view, altKey, metaKey, modifierFnLock, modifierSymbol, modifierSymbolLock, modifierCapsLock, ctrlKey, modifierAltGraph, modifierScrollLock, modifierSuper, modifierHyper, modifierNumLock, shiftKey, modifierFn, movementY, movementX, screenX, screenY, clientX, clientY, relatedTarget, buttons, button, deltaX, deltaMode, deltaZ, deltaY) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  altKey = altKey === VOID ? VOID : altKey;
  metaKey = metaKey === VOID ? VOID : metaKey;
  modifierFnLock = modifierFnLock === VOID ? VOID : modifierFnLock;
  modifierSymbol = modifierSymbol === VOID ? VOID : modifierSymbol;
  modifierSymbolLock = modifierSymbolLock === VOID ? VOID : modifierSymbolLock;
  modifierCapsLock = modifierCapsLock === VOID ? VOID : modifierCapsLock;
  ctrlKey = ctrlKey === VOID ? VOID : ctrlKey;
  modifierAltGraph = modifierAltGraph === VOID ? VOID : modifierAltGraph;
  modifierScrollLock = modifierScrollLock === VOID ? VOID : modifierScrollLock;
  modifierSuper = modifierSuper === VOID ? VOID : modifierSuper;
  modifierHyper = modifierHyper === VOID ? VOID : modifierHyper;
  modifierNumLock = modifierNumLock === VOID ? VOID : modifierNumLock;
  shiftKey = shiftKey === VOID ? VOID : shiftKey;
  modifierFn = modifierFn === VOID ? VOID : modifierFn;
  movementY = movementY === VOID ? VOID : movementY;
  movementX = movementX === VOID ? VOID : movementX;
  screenX = screenX === VOID ? VOID : screenX;
  screenY = screenY === VOID ? VOID : screenY;
  clientX = clientX === VOID ? VOID : clientX;
  clientY = clientY === VOID ? VOID : clientY;
  relatedTarget = relatedTarget === VOID ? VOID : relatedTarget;
  buttons = buttons === VOID ? VOID : buttons;
  button = button === VOID ? VOID : button;
  deltaX = deltaX === VOID ? VOID : deltaX;
  deltaMode = deltaMode === VOID ? VOID : deltaMode;
  deltaZ = deltaZ === VOID ? VOID : deltaZ;
  deltaY = deltaY === VOID ? VOID : deltaY;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, altKey: altKey, metaKey: metaKey, modifierFnLock: modifierFnLock, modifierSymbol: modifierSymbol, modifierSymbolLock: modifierSymbolLock, modifierCapsLock: modifierCapsLock, ctrlKey: ctrlKey, modifierAltGraph: modifierAltGraph, modifierScrollLock: modifierScrollLock, modifierSuper: modifierSuper, modifierHyper: modifierHyper, modifierNumLock: modifierNumLock, shiftKey: shiftKey, modifierFn: modifierFn, movementY: movementY, movementX: movementX, screenX: screenX, screenY: screenY, clientX: clientX, clientY: clientY, relatedTarget: relatedTarget, buttons: buttons, button: button, deltaX: deltaX, deltaMode: deltaMode, deltaZ: deltaZ, deltaY: deltaY});
}
function invoke_126(_this__u8e3s4, bubbles, cancelable, composed, detail, view, altKey, metaKey, modifierFnLock, modifierSymbol, modifierSymbolLock, modifierCapsLock, ctrlKey, modifierAltGraph, modifierScrollLock, modifierSuper, modifierHyper, modifierNumLock, shiftKey, modifierFn, movementY, movementX, screenX, screenY, clientX, clientY, relatedTarget, buttons, button, deltaX, deltaMode, deltaZ, deltaY) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  detail = detail === VOID ? VOID : detail;
  view = view === VOID ? VOID : view;
  altKey = altKey === VOID ? VOID : altKey;
  metaKey = metaKey === VOID ? VOID : metaKey;
  modifierFnLock = modifierFnLock === VOID ? VOID : modifierFnLock;
  modifierSymbol = modifierSymbol === VOID ? VOID : modifierSymbol;
  modifierSymbolLock = modifierSymbolLock === VOID ? VOID : modifierSymbolLock;
  modifierCapsLock = modifierCapsLock === VOID ? VOID : modifierCapsLock;
  ctrlKey = ctrlKey === VOID ? VOID : ctrlKey;
  modifierAltGraph = modifierAltGraph === VOID ? VOID : modifierAltGraph;
  modifierScrollLock = modifierScrollLock === VOID ? VOID : modifierScrollLock;
  modifierSuper = modifierSuper === VOID ? VOID : modifierSuper;
  modifierHyper = modifierHyper === VOID ? VOID : modifierHyper;
  modifierNumLock = modifierNumLock === VOID ? VOID : modifierNumLock;
  shiftKey = shiftKey === VOID ? VOID : shiftKey;
  modifierFn = modifierFn === VOID ? VOID : modifierFn;
  movementY = movementY === VOID ? VOID : movementY;
  movementX = movementX === VOID ? VOID : movementX;
  screenX = screenX === VOID ? VOID : screenX;
  screenY = screenY === VOID ? VOID : screenY;
  clientX = clientX === VOID ? VOID : clientX;
  clientY = clientY === VOID ? VOID : clientY;
  relatedTarget = relatedTarget === VOID ? VOID : relatedTarget;
  buttons = buttons === VOID ? VOID : buttons;
  button = button === VOID ? VOID : button;
  deltaX = deltaX === VOID ? VOID : deltaX;
  deltaMode = deltaMode === VOID ? VOID : deltaMode;
  deltaZ = deltaZ === VOID ? VOID : deltaZ;
  deltaY = deltaY === VOID ? VOID : deltaY;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, detail: detail, view: view, altKey: altKey, metaKey: metaKey, modifierFnLock: modifierFnLock, modifierSymbol: modifierSymbol, modifierSymbolLock: modifierSymbolLock, modifierCapsLock: modifierCapsLock, ctrlKey: ctrlKey, modifierAltGraph: modifierAltGraph, modifierScrollLock: modifierScrollLock, modifierSuper: modifierSuper, modifierHyper: modifierHyper, modifierNumLock: modifierNumLock, shiftKey: shiftKey, modifierFn: modifierFn, movementY: movementY, movementX: movementX, screenX: screenX, screenY: screenY, clientX: clientX, clientY: clientY, relatedTarget: relatedTarget, buttons: buttons, button: button, deltaX: deltaX, deltaMode: deltaMode, deltaZ: deltaZ, deltaY: deltaY};
}
function copy_127(_this__u8e3s4, tooShort, typeMismatch, badInput, rangeOverflow, customError, stepMismatch, valueMissing, tooLong, rangeUnderflow, patternMismatch) {
  tooShort = tooShort === VOID ? VOID : tooShort;
  typeMismatch = typeMismatch === VOID ? VOID : typeMismatch;
  badInput = badInput === VOID ? VOID : badInput;
  rangeOverflow = rangeOverflow === VOID ? VOID : rangeOverflow;
  customError = customError === VOID ? VOID : customError;
  stepMismatch = stepMismatch === VOID ? VOID : stepMismatch;
  valueMissing = valueMissing === VOID ? VOID : valueMissing;
  tooLong = tooLong === VOID ? VOID : tooLong;
  rangeUnderflow = rangeUnderflow === VOID ? VOID : rangeUnderflow;
  patternMismatch = patternMismatch === VOID ? VOID : patternMismatch;
  return Object.assign({}, _this__u8e3s4, {tooShort: tooShort, typeMismatch: typeMismatch, badInput: badInput, rangeOverflow: rangeOverflow, customError: customError, stepMismatch: stepMismatch, valueMissing: valueMissing, tooLong: tooLong, rangeUnderflow: rangeUnderflow, patternMismatch: patternMismatch});
}
function invoke_127(_this__u8e3s4, tooShort, typeMismatch, badInput, rangeOverflow, customError, stepMismatch, valueMissing, tooLong, rangeUnderflow, patternMismatch) {
  tooShort = tooShort === VOID ? VOID : tooShort;
  typeMismatch = typeMismatch === VOID ? VOID : typeMismatch;
  badInput = badInput === VOID ? VOID : badInput;
  rangeOverflow = rangeOverflow === VOID ? VOID : rangeOverflow;
  customError = customError === VOID ? VOID : customError;
  stepMismatch = stepMismatch === VOID ? VOID : stepMismatch;
  valueMissing = valueMissing === VOID ? VOID : valueMissing;
  tooLong = tooLong === VOID ? VOID : tooLong;
  rangeUnderflow = rangeUnderflow === VOID ? VOID : rangeUnderflow;
  patternMismatch = patternMismatch === VOID ? VOID : patternMismatch;
  return {tooShort: tooShort, typeMismatch: typeMismatch, badInput: badInput, rangeOverflow: rangeOverflow, customError: customError, stepMismatch: stepMismatch, valueMissing: valueMissing, tooLong: tooLong, rangeUnderflow: rangeUnderflow, patternMismatch: patternMismatch};
}
function copy_128(_this__u8e3s4, bubbles, cancelable, composed, viewTransition) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  viewTransition = viewTransition === VOID ? VOID : viewTransition;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, viewTransition: viewTransition});
}
function invoke_128(_this__u8e3s4, bubbles, cancelable, composed, viewTransition) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  viewTransition = viewTransition === VOID ? VOID : viewTransition;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, viewTransition: viewTransition};
}
function copy_129(_this__u8e3s4, bubbles, cancelable, composed, viewTransition, activation) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  viewTransition = viewTransition === VOID ? VOID : viewTransition;
  activation = activation === VOID ? VOID : activation;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, viewTransition: viewTransition, activation: activation});
}
function invoke_129(_this__u8e3s4, bubbles, cancelable, composed, viewTransition, activation) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  viewTransition = viewTransition === VOID ? VOID : viewTransition;
  activation = activation === VOID ? VOID : activation;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, viewTransition: viewTransition, activation: activation};
}
function copy_130(_this__u8e3s4, update, types) {
  update = update === VOID ? VOID : update;
  types = types === VOID ? VOID : types;
  return Object.assign({}, _this__u8e3s4, {update: update, types: types});
}
function invoke_130(_this__u8e3s4, update, types) {
  update = update === VOID ? VOID : update;
  types = types === VOID ? VOID : types;
  return {update: update, types: types};
}
function copy_131(_this__u8e3s4, bubbles, cancelable, composed, track) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  track = track === VOID ? VOID : track;
  return Object.assign({}, _this__u8e3s4, {bubbles: bubbles, cancelable: cancelable, composed: composed, track: track});
}
function invoke_131(_this__u8e3s4, bubbles, cancelable, composed, track) {
  bubbles = bubbles === VOID ? VOID : bubbles;
  cancelable = cancelable === VOID ? VOID : cancelable;
  composed = composed === VOID ? VOID : composed;
  track = track === VOID ? VOID : track;
  return {bubbles: bubbles, cancelable: cancelable, composed: composed, track: track};
}
function copy_132(_this__u8e3s4, transfer, targetOrigin) {
  transfer = transfer === VOID ? VOID : transfer;
  targetOrigin = targetOrigin === VOID ? VOID : targetOrigin;
  return Object.assign({}, _this__u8e3s4, {transfer: transfer, targetOrigin: targetOrigin});
}
function invoke_132(_this__u8e3s4, transfer, targetOrigin) {
  transfer = transfer === VOID ? VOID : transfer;
  targetOrigin = targetOrigin === VOID ? VOID : targetOrigin;
  return {transfer: transfer, targetOrigin: targetOrigin};
}
function get_CHILD_ARRAY() {
  _init_properties_ChildrenBuilder_kt__gexuom();
  return CHILD_ARRAY;
}
var CHILD_ARRAY;
function get_DEFAULT_KEY() {
  _init_properties_ChildrenBuilder_kt__gexuom();
  return DEFAULT_KEY;
}
var DEFAULT_KEY;
function addChildNode(_this__u8e3s4, node) {
  _init_properties_ChildrenBuilder_kt__gexuom();
  // Inline function 'react.childArray' call
  // Inline function 'kotlin.js.asDynamic' call
  if (!(_this__u8e3s4[get_CHILD_ARRAY()] == null)) {
    // Inline function 'react.childArray' call
    // Inline function 'kotlin.js.asDynamic' call
    // Inline function 'kotlin.js.asDynamic' call
    _this__u8e3s4[get_CHILD_ARRAY()].push(node);
  } else {
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    // Inline function 'react.childArray' call
    var value = [node];
    // Inline function 'kotlin.js.asDynamic' call
    _this__u8e3s4[get_CHILD_ARRAY()] = value;
  }
}
function addChild(_this__u8e3s4, type, props) {
  _init_properties_ChildrenBuilder_kt__gexuom();
  addChildElement(_this__u8e3s4, type, props, VOID, getDefaultKey(_this__u8e3s4));
}
function addChild_0(_this__u8e3s4, type) {
  _init_properties_ChildrenBuilder_kt__gexuom();
  addChildElement(_this__u8e3s4, type, VOID, VOID, getDefaultKey(_this__u8e3s4));
}
function addChild_1(_this__u8e3s4, type, block) {
  _init_properties_ChildrenBuilder_kt__gexuom();
  var defaultKey = getDefaultKey(_this__u8e3s4);
  // Inline function 'js.objects.jso' call
  // Inline function 'js.objects.jso' call
  // Inline function 'kotlin.apply' call
  var this_0 = {};
  block(this_0);
  var props = this_0;
  addChildElement(_this__u8e3s4, type, props, getChildArray(props), defaultKey);
}
function addChild_2(_this__u8e3s4, provider, value, block) {
  _init_properties_ChildrenBuilder_kt__gexuom();
  addChild_1(_this__u8e3s4, provider, addChild$lambda(value, block));
}
function addChildElement(_this__u8e3s4, type, props, children, defaultKey) {
  props = props === VOID ? null : props;
  children = children === VOID ? null : children;
  _init_properties_ChildrenBuilder_kt__gexuom();
  var childProps_0 = childProps(props, defaultKey);
  var tmp;
  if (!(children == null)) {
    tmp = createElement.apply(null, [type, childProps_0].concat([].slice.call(children.slice())));
  } else {
    tmp = createElement(type, childProps_0);
  }
  var element = tmp;
  addChildNode(_this__u8e3s4, element);
}
function getDefaultKey(_this__u8e3s4) {
  _init_properties_ChildrenBuilder_kt__gexuom();
  // Inline function 'kotlin.js.asDynamic' call
  var key = _this__u8e3s4[get_DEFAULT_KEY()];
  Reflect.deleteProperty(_this__u8e3s4, get_DEFAULT_KEY());
  return key;
}
function getChildArray(_this__u8e3s4) {
  _init_properties_ChildrenBuilder_kt__gexuom();
  // Inline function 'kotlin.js.asDynamic' call
  return _this__u8e3s4[get_CHILD_ARRAY()];
}
function childProps(props, defaultKey) {
  _init_properties_ChildrenBuilder_kt__gexuom();
  if (defaultKey == null)
    return props;
  if (props == null) {
    // Inline function 'js.objects.jso' call
    // Inline function 'js.objects.jso' call
    // Inline function 'kotlin.apply' call
    var this_0 = {};
    // Inline function 'react.childProps.<anonymous>' call
    this_0.key = defaultKey;
    return this_0;
  }
  if (!(props.key == null))
    return props;
  // Inline function 'js.objects.jso' call
  // Inline function 'js.objects.jso' call
  // Inline function 'kotlin.apply' call
  var this_1 = {};
  // Inline function 'react.childProps.<anonymous>' call
  // Inline function 'react.Props.unaryPlus' call
  Object.assign(this_1, props);
  this_1.key = defaultKey;
  return this_1;
}
function getChildArray_0(_this__u8e3s4) {
  _init_properties_ChildrenBuilder_kt__gexuom();
  // Inline function 'kotlin.js.asDynamic' call
  return _this__u8e3s4[get_CHILD_ARRAY()];
}
function addChild$lambda($value, $block) {
  return ($this$addChild) => {
    $this$addChild.value = $value;
    $block($this$addChild);
    return Unit_instance;
  };
}
var properties_initialized_ChildrenBuilder_kt_gby2z0;
function _init_properties_ChildrenBuilder_kt__gexuom() {
  if (!properties_initialized_ChildrenBuilder_kt_gby2z0) {
    properties_initialized_ChildrenBuilder_kt_gby2z0 = true;
    CHILD_ARRAY = Symbol('@@child-array');
    DEFAULT_KEY = Symbol('@@default-key');
  }
}
function copy_133(_this__u8e3s4, componentStack, digest) {
  componentStack = componentStack === VOID ? VOID : componentStack;
  digest = digest === VOID ? VOID : digest;
  return Object.assign({}, _this__u8e3s4, {componentStack: componentStack, digest: digest});
}
function invoke_133(_this__u8e3s4, componentStack, digest) {
  componentStack = componentStack === VOID ? VOID : componentStack;
  digest = digest === VOID ? VOID : digest;
  return {componentStack: componentStack, digest: digest};
}
function ReactNode(source) {
  // Inline function 'react.ReactNode' call
  // Inline function 'js.reflect.unsafeCast' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return toString(source);
}
function buildCleanup(cleanups) {
  // Inline function 'kotlin.collections.isEmpty' call
  if (cleanups.length === 0)
    return undefined;
  return buildCleanup$lambda(cleanups);
}
function buildCleanup$lambda($cleanups) {
  return () => {
    var indexedObject = $cleanups;
    var inductionVariable = 0;
    var last = indexedObject.length;
    while (inductionVariable < last) {
      var cleanup = indexedObject[inductionVariable];
      inductionVariable = inductionVariable + 1 | 0;
      cleanup();
    }
    return Unit_instance;
  };
}
function buildCleanupCallback(block) {
  return buildCleanupCallback$lambda(block);
}
function buildCleanupCallback$lambda($block) {
  return () => {
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var cleanups = [];
    // Inline function 'js.reflect.unsafeCast' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    $block(cleanups);
    return buildCleanup(cleanups);
  };
}
function useEffectWithCleanup(effect) {
  var callback = buildCleanupCallback(effect);
  useEffect(callback);
}
var index_0;
function FC(block) {
  // Inline function 'js.reflect.unsafeCast' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return FC$lambda(block);
}
function FC$lambda$lambda($block, $props) {
  return ($this$createElementOrNull) => {
    $block($this$createElementOrNull, $props);
    return Unit_instance;
  };
}
function FC$lambda($block) {
  return (props) => createElementOrNull(FC$lambda$lambda($block, props));
}
function create(_this__u8e3s4, block) {
  // Inline function 'js.objects.jso' call
  // Inline function 'js.objects.jso' call
  // Inline function 'kotlin.apply' call
  var this_0 = {};
  block(this_0);
  var props = this_0;
  var tmp0_elvis_lhs = getChildArray(props);
  var tmp;
  if (tmp0_elvis_lhs == null) {
    // Inline function 'kotlin.emptyArray' call
    tmp = [];
  } else {
    tmp = tmp0_elvis_lhs;
  }
  var children = tmp;
  return createElement.apply(null, [_this__u8e3s4, props].concat([].slice.call(children.slice())));
}
function createElementOrNull(block) {
  // Inline function 'js.objects.jso' call
  // Inline function 'js.objects.jso' call
  // Inline function 'kotlin.apply' call
  var this_0 = {};
  block(this_0);
  var tmp0_elvis_lhs = getChildArray_0(this_0);
  var tmp;
  if (tmp0_elvis_lhs == null) {
    return null;
  } else {
    tmp = tmp0_elvis_lhs;
  }
  var children = tmp;
  return createElement.apply(null, [Fragment, VOID].concat([].slice.call(children.slice())));
}
var ReactHTML_instance;
function ReactHTML_getInstance() {
  return ReactHTML_instance;
}
function copy_134(_this__u8e3s4, componentStack, errorBoundary) {
  componentStack = componentStack === VOID ? VOID : componentStack;
  errorBoundary = errorBoundary === VOID ? VOID : errorBoundary;
  return Object.assign({}, _this__u8e3s4, {componentStack: componentStack, errorBoundary: errorBoundary});
}
function invoke_134(_this__u8e3s4, componentStack, errorBoundary) {
  componentStack = componentStack === VOID ? VOID : componentStack;
  errorBoundary = errorBoundary === VOID ? VOID : errorBoundary;
  return {componentStack: componentStack, errorBoundary: errorBoundary};
}
function copy_135(_this__u8e3s4, componentStack) {
  componentStack = componentStack === VOID ? VOID : componentStack;
  return Object.assign({}, _this__u8e3s4, {componentStack: componentStack});
}
function invoke_135(_this__u8e3s4, componentStack) {
  componentStack = componentStack === VOID ? VOID : componentStack;
  return {componentStack: componentStack};
}
function copy_136(_this__u8e3s4, componentStack) {
  componentStack = componentStack === VOID ? VOID : componentStack;
  return Object.assign({}, _this__u8e3s4, {componentStack: componentStack});
}
function invoke_136(_this__u8e3s4, componentStack) {
  componentStack = componentStack === VOID ? VOID : componentStack;
  return {componentStack: componentStack};
}
function copy_137(_this__u8e3s4, onRecoverableError, identifierPrefix, onCaughtError, onUncaughtError) {
  onRecoverableError = onRecoverableError === VOID ? VOID : onRecoverableError;
  identifierPrefix = identifierPrefix === VOID ? VOID : identifierPrefix;
  onCaughtError = onCaughtError === VOID ? VOID : onCaughtError;
  onUncaughtError = onUncaughtError === VOID ? VOID : onUncaughtError;
  return Object.assign({}, _this__u8e3s4, {onRecoverableError: onRecoverableError, identifierPrefix: identifierPrefix, onCaughtError: onCaughtError, onUncaughtError: onUncaughtError});
}
function invoke_137(_this__u8e3s4, onRecoverableError, identifierPrefix, onCaughtError, onUncaughtError) {
  onRecoverableError = onRecoverableError === VOID ? VOID : onRecoverableError;
  identifierPrefix = identifierPrefix === VOID ? VOID : identifierPrefix;
  onCaughtError = onCaughtError === VOID ? VOID : onCaughtError;
  onUncaughtError = onUncaughtError === VOID ? VOID : onUncaughtError;
  return {onRecoverableError: onRecoverableError, identifierPrefix: identifierPrefix, onCaughtError: onCaughtError, onUncaughtError: onUncaughtError};
}
function copy_138(_this__u8e3s4, componentStack) {
  componentStack = componentStack === VOID ? VOID : componentStack;
  return Object.assign({}, _this__u8e3s4, {componentStack: componentStack});
}
function invoke_138(_this__u8e3s4, componentStack) {
  componentStack = componentStack === VOID ? VOID : componentStack;
  return {componentStack: componentStack};
}
var org_mkui_canvas_AbstractAveragingLayer$stable;
var org_mkui_canvas_AbstractDensityLayer$stable;
function alpha(_this__u8e3s4, alpha) {
  var tmp = getURed(_this__u8e3s4);
  var tmp_0 = getUGreen(_this__u8e3s4);
  var tmp_1 = getUBlue(_this__u8e3s4);
  // Inline function 'kotlin.toUInt' call
  // Inline function 'kotlin.floatToUInt' call
  var value = 255 * alpha;
  // Inline function 'kotlin.UInt.toUByte' call
  var this_0 = doubleToUInt(value);
  // Inline function 'kotlin.toUByte' call
  var this_1 = _UInt___get_data__impl__f0vqqw(this_0);
  var tmp$ret$3 = _UByte___init__impl__g9hnc4(toByte(this_1));
  return colorOf_0(tmp, tmp_0, tmp_1, tmp$ret$3);
}
function darker(_this__u8e3s4) {
  var FACTOR = 0.7;
  // Inline function 'kotlin.UByte.toDouble' call
  // Inline function 'kotlin.UByte.toInt' call
  var this_0 = getURed(_this__u8e3s4);
  var tmp$ret$0 = _UByte___get_data__impl__jof9qr(this_0) & 255;
  var tmp$ret$1 = uintToDouble(tmp$ret$0);
  // Inline function 'kotlin.math.max' call
  var a = numberToInt(tmp$ret$1 * FACTOR);
  var tmp = Math.max(a, 0);
  // Inline function 'kotlin.UByte.toDouble' call
  // Inline function 'kotlin.UByte.toInt' call
  var this_1 = getUGreen(_this__u8e3s4);
  var tmp$ret$3 = _UByte___get_data__impl__jof9qr(this_1) & 255;
  var tmp$ret$4 = uintToDouble(tmp$ret$3);
  // Inline function 'kotlin.math.max' call
  var a_0 = numberToInt(tmp$ret$4 * FACTOR);
  var tmp_0 = Math.max(a_0, 0);
  // Inline function 'kotlin.UByte.toDouble' call
  // Inline function 'kotlin.UByte.toInt' call
  var this_2 = getUBlue(_this__u8e3s4);
  var tmp$ret$6 = _UByte___get_data__impl__jof9qr(this_2) & 255;
  var tmp$ret$7 = uintToDouble(tmp$ret$6);
  // Inline function 'kotlin.math.max' call
  var a_1 = numberToInt(tmp$ret$7 * FACTOR);
  var tmp_1 = Math.max(a_1, 0);
  // Inline function 'kotlin.UByte.toInt' call
  var this_3 = getUAlpha(_this__u8e3s4);
  var tmp$ret$9 = _UByte___get_data__impl__jof9qr(this_3) & 255;
  return colorOf(tmp, tmp_0, tmp_1, tmp$ret$9);
}
function brighter(_this__u8e3s4) {
  var FACTOR = 0.7;
  // Inline function 'kotlin.UByte.toInt' call
  var this_0 = getURed(_this__u8e3s4);
  var r = _UByte___get_data__impl__jof9qr(this_0) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_1 = getUGreen(_this__u8e3s4);
  var g = _UByte___get_data__impl__jof9qr(this_1) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_2 = getUBlue(_this__u8e3s4);
  var b = _UByte___get_data__impl__jof9qr(this_2) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_3 = getUAlpha(_this__u8e3s4);
  var alpha = _UByte___get_data__impl__jof9qr(this_3) & 255;
  var i = numberToInt(1.0 / (1.0 - FACTOR));
  if (r === 0 && g === 0 && b === 0) {
    return colorOf(i, i, i, alpha);
  }
  if (r > 0 && r < i)
    r = i;
  if (g > 0 && g < i)
    g = i;
  if (b > 0 && b < i)
    b = i;
  // Inline function 'kotlin.math.min' call
  var a = numberToInt(r / FACTOR);
  var tmp = Math.min(a, 255);
  // Inline function 'kotlin.math.min' call
  var a_0 = numberToInt(g / FACTOR);
  var tmp_0 = Math.min(a_0, 255);
  // Inline function 'kotlin.math.min' call
  var a_1 = numberToInt(b / FACTOR);
  var tmp$ret$6 = Math.min(a_1, 255);
  return colorOf(tmp, tmp_0, tmp$ret$6, alpha);
}
function brightenAndSaturate(_this__u8e3s4, brightness, saturation) {
  // Inline function 'kotlin.UByte.toInt' call
  var this_0 = getURed(_this__u8e3s4);
  var tmp = _UByte___get_data__impl__jof9qr(this_0) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_1 = getUGreen(_this__u8e3s4);
  var tmp_0 = _UByte___get_data__impl__jof9qr(this_1) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_2 = getUBlue(_this__u8e3s4);
  var tmp$ret$2 = _UByte___get_data__impl__jof9qr(this_2) & 255;
  var hsb = RGBtoHSB(tmp, tmp_0, tmp$ret$2, null);
  if (!(brightness === 0.0)) {
    // Inline function 'kotlin.math.min' call
    var b = hsb[2] + brightness;
    // Inline function 'kotlin.math.max' call
    var b_0 = Math.min(1.0, b);
    hsb[2] = Math.max(0.0, b_0);
  }
  if (!(saturation === 0.0)) {
    // Inline function 'kotlin.math.min' call
    var b_1 = hsb[1] + saturation;
    // Inline function 'kotlin.math.max' call
    var b_2 = Math.min(1.0, b_1);
    hsb[1] = Math.max(0.0, b_2);
  }
  return colorOf_3(HSBtoRGB(hsb[0], hsb[1], hsb[2]));
}
function RGBtoHSB(r, g, b, hsbvals) {
  var hsbvals_0 = hsbvals;
  var hue;
  var saturation;
  var brightness;
  if (hsbvals_0 == null) {
    hsbvals_0 = new Float32Array(3);
  }
  var cmax = r > g ? r : g;
  if (b > cmax)
    cmax = b;
  var cmin = r < g ? r : g;
  if (b < cmin)
    cmin = b;
  brightness = cmax / 255.0;
  saturation = !(cmax === 0) ? (cmax - cmin | 0) / cmax : 0.0;
  if (saturation === 0.0)
    hue = 0.0;
  else {
    var redc = (cmax - r | 0) / (cmax - cmin | 0);
    var greenc = (cmax - g | 0) / (cmax - cmin | 0);
    var bluec = (cmax - b | 0) / (cmax - cmin | 0);
    hue = r === cmax ? bluec - greenc : g === cmax ? 2.0 + redc - bluec : 4.0 + greenc - redc;
    hue = hue / 6.0;
    if (hue < 0)
      hue = hue + 1.0;
  }
  hsbvals_0[0] = hue;
  hsbvals_0[1] = saturation;
  hsbvals_0[2] = brightness;
  return hsbvals_0;
}
function HSBtoRGB(hue, saturation, brightness) {
  var r = 0;
  var g = 0;
  var b = 0;
  if (saturation === 0.0) {
    b = numberToInt(brightness * 255.0 + 0.5);
    g = b;
    r = g;
  } else {
    // Inline function 'kotlin.math.floor' call
    var h = (hue - Math.floor(hue)) * 6.0;
    // Inline function 'kotlin.math.floor' call
    var f = h - Math.floor(h);
    var p = brightness * (1.0 - saturation);
    var q = brightness * (1.0 - saturation * f);
    var t = brightness * (1.0 - saturation * (1.0 - f));
    switch (numberToInt(h)) {
      case 0:
        r = numberToInt(brightness * 255.0 + 0.5);
        g = numberToInt(t * 255.0 + 0.5);
        b = numberToInt(p * 255.0 + 0.5);
        break;
      case 1:
        r = numberToInt(q * 255.0 + 0.5);
        g = numberToInt(brightness * 255.0 + 0.5);
        b = numberToInt(p * 255.0 + 0.5);
        break;
      case 2:
        r = numberToInt(p * 255.0 + 0.5);
        g = numberToInt(brightness * 255.0 + 0.5);
        b = numberToInt(t * 255.0 + 0.5);
        break;
      case 3:
        r = numberToInt(p * 255.0 + 0.5);
        g = numberToInt(q * 255.0 + 0.5);
        b = numberToInt(brightness * 255.0 + 0.5);
        break;
      case 4:
        r = numberToInt(t * 255.0 + 0.5);
        g = numberToInt(p * 255.0 + 0.5);
        b = numberToInt(brightness * 255.0 + 0.5);
        break;
      case 5:
        r = numberToInt(brightness * 255.0 + 0.5);
        g = numberToInt(p * 255.0 + 0.5);
        b = numberToInt(q * 255.0 + 0.5);
        break;
    }
  }
  return -16777216 | r << 16 | g << 8 | b << 0;
}
var org_mkui_coloring_implementation_AbstractColoring$stable;
var org_mkui_coloring_implementation_SimpleColoring$stable;
var org_mkui_coloring_implementation_SimpleColoringEvent$stable;
var org_mkui_colormap_AbstractColorMap$stable;
var PropertyType_Inverval_instance;
var PropertyType_Palette_instance;
var PropertyType_Matching_instance;
var PropertyType_Assignments_instance;
var PropertyType_MissingValuesColor_instance;
var PropertyType_UnderflowColor_instance;
var PropertyType_OverflowColor_instance;
var PropertyType_Inverted_instance;
var PropertyType_NumberOfSteps_instance;
var PropertyType_Brightness_instance;
var PropertyType_Saturation_instance;
var PropertyType_Alpha_instance;
function values_0() {
  return [PropertyType_Inverval_getInstance(), PropertyType_Palette_getInstance(), PropertyType_Matching_getInstance(), PropertyType_Assignments_getInstance(), PropertyType_MissingValuesColor_getInstance(), PropertyType_UnderflowColor_getInstance(), PropertyType_OverflowColor_getInstance(), PropertyType_Inverted_getInstance(), PropertyType_NumberOfSteps_getInstance(), PropertyType_Brightness_getInstance(), PropertyType_Saturation_getInstance(), PropertyType_Alpha_getInstance()];
}
var PropertyType_entriesInitialized;
function PropertyType_initEntries() {
  if (PropertyType_entriesInitialized)
    return Unit_instance;
  PropertyType_entriesInitialized = true;
  PropertyType_Inverval_instance = new PropertyType('Inverval', 0);
  PropertyType_Palette_instance = new PropertyType('Palette', 1);
  PropertyType_Matching_instance = new PropertyType('Matching', 2);
  PropertyType_Assignments_instance = new PropertyType('Assignments', 3);
  PropertyType_MissingValuesColor_instance = new PropertyType('MissingValuesColor', 4);
  PropertyType_UnderflowColor_instance = new PropertyType('UnderflowColor', 5);
  PropertyType_OverflowColor_instance = new PropertyType('OverflowColor', 6);
  PropertyType_Inverted_instance = new PropertyType('Inverted', 7);
  PropertyType_NumberOfSteps_instance = new PropertyType('NumberOfSteps', 8);
  PropertyType_Brightness_instance = new PropertyType('Brightness', 9);
  PropertyType_Saturation_instance = new PropertyType('Saturation', 10);
  PropertyType_Alpha_instance = new PropertyType('Alpha', 11);
}
var Companion_instance_30;
function Companion_getInstance_30() {
  return Companion_instance_30;
}
function PropertyType_Inverval_getInstance() {
  PropertyType_initEntries();
  return PropertyType_Inverval_instance;
}
function PropertyType_Palette_getInstance() {
  PropertyType_initEntries();
  return PropertyType_Palette_instance;
}
function PropertyType_Matching_getInstance() {
  PropertyType_initEntries();
  return PropertyType_Matching_instance;
}
function PropertyType_Assignments_getInstance() {
  PropertyType_initEntries();
  return PropertyType_Assignments_instance;
}
function PropertyType_MissingValuesColor_getInstance() {
  PropertyType_initEntries();
  return PropertyType_MissingValuesColor_instance;
}
function PropertyType_UnderflowColor_getInstance() {
  PropertyType_initEntries();
  return PropertyType_UnderflowColor_instance;
}
function PropertyType_OverflowColor_getInstance() {
  PropertyType_initEntries();
  return PropertyType_OverflowColor_instance;
}
function PropertyType_Inverted_getInstance() {
  PropertyType_initEntries();
  return PropertyType_Inverted_instance;
}
function PropertyType_NumberOfSteps_getInstance() {
  PropertyType_initEntries();
  return PropertyType_NumberOfSteps_instance;
}
function PropertyType_Brightness_getInstance() {
  PropertyType_initEntries();
  return PropertyType_Brightness_instance;
}
function PropertyType_Saturation_getInstance() {
  PropertyType_initEntries();
  return PropertyType_Saturation_instance;
}
function PropertyType_Alpha_getInstance() {
  PropertyType_initEntries();
  return PropertyType_Alpha_instance;
}
var Assignments_STATIC_instance;
var Assignments_DYNAMIC_instance;
var Assignments_entriesInitialized;
function Assignments_initEntries() {
  if (Assignments_entriesInitialized)
    return Unit_instance;
  Assignments_entriesInitialized = true;
  Assignments_STATIC_instance = new Assignments('STATIC', 0);
  Assignments_DYNAMIC_instance = new Assignments('DYNAMIC', 1);
}
function Assignments_STATIC_getInstance() {
  Assignments_initEntries();
  return Assignments_STATIC_instance;
}
function Assignments_DYNAMIC_getInstance() {
  Assignments_initEntries();
  return Assignments_DYNAMIC_instance;
}
var org_mkui_colormap_ColorMapEvent$stable;
var org_mkui_colormap_ColorMapFactory$stable;
var Matching_EXACT_instance;
var Matching_CLOSEST_instance;
var Matching_entriesInitialized;
function Matching_initEntries() {
  if (Matching_entriesInitialized)
    return Unit_instance;
  Matching_entriesInitialized = true;
  Matching_EXACT_instance = new Matching('EXACT', 0);
  Matching_CLOSEST_instance = new Matching('CLOSEST', 1);
}
function Matching_EXACT_getInstance() {
  Matching_initEntries();
  return Matching_EXACT_instance;
}
var org_mkui_colormap_SetStoreMutableProperty$stable;
var org_mkui_colormap_SimpleColorMap$stable;
function arrayToString_0($this, array) {
  var str = '';
  var inductionVariable = 0;
  var last = array.length - 1 | 0;
  if (inductionVariable <= last)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      var v = array[i];
      if (!(v == null)) {
        str = str + toString_1(v);
      }
      if (i < (array.length - 1 | 0)) {
        str = str + '/';
      }
    }
     while (inductionVariable <= last);
  return str;
}
function palette$factory() {
  return getPropertyCallableRef('palette', 1, KMutableProperty1, (receiver) => receiver.r1f(), (receiver, value) => receiver.e1j(value));
}
function palette$factory_0() {
  return getPropertyCallableRef('palette', 1, KMutableProperty1, (receiver) => receiver.r1f(), (receiver, value) => receiver.e1j(value));
}
function nullColor$factory() {
  return getPropertyCallableRef('nullColor', 1, KMutableProperty1, (receiver) => receiver.s1f(), (receiver, value) => receiver.g1j(value));
}
function nullColor$factory_0() {
  return getPropertyCallableRef('nullColor', 1, KMutableProperty1, (receiver) => receiver.s1f(), (receiver, value) => receiver.g1j(value));
}
function isInverted$factory() {
  return getPropertyCallableRef('isInverted', 1, KMutableProperty1, (receiver) => receiver.an(), (receiver, value) => receiver.t1j(value));
}
function isInverted$factory_0() {
  return getPropertyCallableRef('isInverted', 1, KMutableProperty1, (receiver) => receiver.an(), (receiver, value) => receiver.t1j(value));
}
function colorCount$factory() {
  return getPropertyCallableRef('colorCount', 1, KMutableProperty1, (receiver) => receiver.x1f(), (receiver, value) => receiver.y1j(value));
}
function colorCount$factory_0() {
  return getPropertyCallableRef('colorCount', 1, KMutableProperty1, (receiver) => receiver.x1f(), (receiver, value) => receiver.y1j(value));
}
function brightness$factory() {
  return getPropertyCallableRef('brightness', 1, KMutableProperty1, (receiver) => receiver.n1f(), (receiver, value) => receiver.b1k(value));
}
function brightness$factory_0() {
  return getPropertyCallableRef('brightness', 1, KMutableProperty1, (receiver) => receiver.n1f(), (receiver, value) => receiver.b1k(value));
}
function saturation$factory() {
  return getPropertyCallableRef('saturation', 1, KMutableProperty1, (receiver) => receiver.o1f(), (receiver, value) => receiver.e1k(value));
}
function saturation$factory_0() {
  return getPropertyCallableRef('saturation', 1, KMutableProperty1, (receiver) => receiver.o1f(), (receiver, value) => receiver.e1k(value));
}
var org_mkui_colormap_editor_AbstractCategoricalColorMapEditor$stable;
var org_mkui_colormap_editor_AbstractColorMapPanel$stable;
var org_mkui_colormap_editor_AbstractCustomColorMapEditor$stable;
var org_mkui_colormap_editor_AbstractPredefinedColorMapEditor$stable;
var org_mkui_colormap_property_MutableColorMapOverrideProperty$stable;
var org_mkui_colormap_property_MutableColorMapProperty$stable;
var org_mkui_colormapping_AbstractColorMapping$stable;
var org_mkui_component_InteractiveComponentListeners$stable;
var org_mkui_component_VerticalPanelBuilder$stable;
var org_mkui_component_button_CPButtonProperties$stable;
var org_mkui_component_menu_ToggleGroup$stable;
var org_mkui_component_panel_Row$stable;
var Posture_REGULAR_instance;
var Posture_ITALIC_instance;
var Posture_entriesInitialized;
function Posture_initEntries() {
  if (Posture_entriesInitialized)
    return Unit_instance;
  Posture_entriesInitialized = true;
  Posture_REGULAR_instance = new Posture('REGULAR', 0);
  Posture_ITALIC_instance = new Posture('ITALIC', 1);
}
function Posture_REGULAR_getInstance() {
  Posture_initEntries();
  return Posture_REGULAR_instance;
}
function Posture_ITALIC_getInstance() {
  Posture_initEntries();
  return Posture_ITALIC_instance;
}
var Weight_NORMAL_instance;
var Weight_BOLD_instance;
var Weight_entriesInitialized;
function Weight_initEntries() {
  if (Weight_entriesInitialized)
    return Unit_instance;
  Weight_entriesInitialized = true;
  Weight_NORMAL_instance = new Weight('NORMAL', 0);
  Weight_BOLD_instance = new Weight('BOLD', 1);
}
function Weight_NORMAL_getInstance() {
  Weight_initEntries();
  return Weight_NORMAL_instance;
}
function Weight_BOLD_getInstance() {
  Weight_initEntries();
  return Weight_BOLD_instance;
}
var org_mkui_geom_AbstractRectangle2D$stable;
var Companion_instance_31;
function Companion_getInstance_31() {
  return Companion_instance_31;
}
var org_mkui_geom_AffineTransform$stable;
function _matround($this, matval) {
  return round(matval * 1.0E15) / 1.0E15;
}
function stateError($this) {
  throw UnsupportedOperationException.t9('missing case in transform state switch');
}
function rotate90($this) {
  var M0 = $this.w1m_1;
  $this.w1m_1 = $this.y1m_1;
  $this.y1m_1 = -M0;
  M0 = $this.x1m_1;
  $this.x1m_1 = $this.z1m_1;
  $this.z1m_1 = -M0;
  var state = Companion_getInstance_32().y1n_1[$this.c1n_1];
  if ((state & 6) === 2 && $this.w1m_1 === 1.0 && $this.z1m_1 === 1.0) {
    state = state - 2 | 0;
  }
  $this.c1n_1 = state;
  $this.d1n_1 = -1;
}
function rotate180($this) {
  $this.w1m_1 = -$this.w1m_1;
  $this.z1m_1 = -$this.z1m_1;
  var state = $this.c1n_1;
  if (!((state & 4) === 0)) {
    $this.y1m_1 = -$this.y1m_1;
    $this.x1m_1 = -$this.x1m_1;
  } else {
    if ($this.w1m_1 === 1.0 && $this.z1m_1 === 1.0) {
      $this.c1n_1 = state & -3;
    } else {
      $this.c1n_1 = state | 2;
    }
  }
  $this.d1n_1 = -1;
}
function rotate270($this) {
  var M0 = $this.w1m_1;
  $this.w1m_1 = -$this.y1m_1;
  $this.y1m_1 = M0;
  M0 = $this.x1m_1;
  $this.x1m_1 = -$this.z1m_1;
  $this.z1m_1 = M0;
  var state = Companion_getInstance_32().y1n_1[$this.c1n_1];
  if ((state & 6) === 2 && $this.w1m_1 === 1.0 && $this.z1m_1 === 1.0) {
    state = state - 2 | 0;
  }
  $this.c1n_1 = state;
  $this.d1n_1 = -1;
}
var Companion_instance_32;
function Companion_getInstance_32() {
  if (Companion_instance_32 === VOID)
    new Companion_32();
  return Companion_instance_32;
}
function init_org_mkui_geom_AffineTransform(_this__u8e3s4) {
  Companion_getInstance_32();
  _this__u8e3s4.x1m_1 = 0.0;
  _this__u8e3s4.y1m_1 = 0.0;
  _this__u8e3s4.a1n_1 = 0.0;
  _this__u8e3s4.b1n_1 = 0.0;
  _this__u8e3s4.c1n_1 = 0;
  _this__u8e3s4.d1n_1 = 0;
}
var org_mkui_geom_Arc2D_Double$stable;
var Companion_instance_33;
function Companion_getInstance_33() {
  return Companion_instance_33;
}
function init_org_mkui_geom_Arc2D_Double(_this__u8e3s4) {
}
var org_mkui_geom_ArcIterator$stable;
function btan($this, increment) {
  var increment_0 = increment;
  increment_0 = increment_0 / 2.0;
  var tmp = 4.0 / 3.0;
  // Inline function 'kotlin.math.sin' call
  var x = increment_0;
  var tmp_0 = tmp * Math.sin(x);
  // Inline function 'kotlin.math.cos' call
  var x_0 = increment_0;
  return tmp_0 / (1.0 + Math.cos(x_0));
}
var Companion_instance_34;
function Companion_getInstance_34() {
  return Companion_instance_34;
}
var corg_mkui_geom_Area_AreaIterator$stable;
var corg_mkui_geom_Area$stable;
function pathToCurves($this, pi) {
  var curves = ArrayList.e1();
  var windingRule = pi.g1q();
  var coords = new Float64Array(23);
  var movx = 0.0;
  var movy = 0.0;
  var curx = 0.0;
  var cury = 0.0;
  while (!pi.b17()) {
    var newy;
    var newx;
    switch (pi.i1q(coords)) {
      case 0:
        Companion_instance_38.n1q(curves, curx, cury, movx, movy);
        // Inline function 'kotlin.run' call

        // Inline function 'corg.mkui.geom.Companion.pathToCurves.<anonymous>' call

        movx = coords[0];
        curx = movx;
        // Inline function 'kotlin.run' call

        // Inline function 'corg.mkui.geom.Companion.pathToCurves.<anonymous>' call

        movy = coords[1];
        cury = movy;
        Companion_instance_38.o1q(curves, movx, movy);
        break;
      case 1:
        newx = coords[0];
        newy = coords[1];
        Companion_instance_38.n1q(curves, curx, cury, newx, newy);
        curx = newx;
        cury = newy;
        break;
      case 2:
        newx = coords[2];
        newy = coords[3];
        Companion_instance_38.p1q(curves, curx, cury, coords);
        curx = newx;
        cury = newy;
        break;
      case 3:
        newx = coords[4];
        newy = coords[5];
        Companion_instance_38.q1q(curves, curx, cury, coords);
        curx = newx;
        cury = newy;
        break;
      case 4:
        Companion_instance_38.n1q(curves, curx, cury, movx, movy);
        curx = movx;
        cury = movy;
        break;
    }
    pi.h1q();
  }
  Companion_instance_38.n1q(curves, curx, cury, movx, movy);
  var operator;
  if (windingRule === 0) {
    operator = new EOWindOp();
  } else {
    operator = new NZWindOp();
  }
  return operator.s1q(curves, $this.r1q_1);
}
function invalidateBounds($this) {
  $this.u1q_1 = null;
}
function getCachedBounds($this) {
  if (!($this.u1q_1 == null)) {
    return ensureNotNull($this.u1q_1);
  }
  var r = Double_3.p1m(0.0, 0.0, 0.0, 0.0);
  if (ensureNotNull($this.t1q_1).a1() > 0) {
    var c = ensureNotNull($this.t1q_1).b1(0);
    r = Double_3.p1m(c.w1q(), c.x1q(), 0.0, 0.0);
    var inductionVariable = 1;
    var last = ensureNotNull($this.t1q_1).a1();
    if (inductionVariable < last)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        r = ensureNotNull($this.t1q_1).b1(i).y1q(Double_3.p1m(r.w1l(), r.x1l(), r.cm(), r.dm()));
      }
       while (inductionVariable < last);
  }
  // Inline function 'kotlin.also' call
  var this_0 = Double_3.p1m(r.w1l(), r.x1l(), r.cm(), r.dm());
  // Inline function 'corg.mkui.geom.Area.getCachedBounds.<anonymous>' call
  $this.u1q_1 = this_0;
  return this_0;
}
var Companion_instance_35;
function Companion_getInstance_35() {
  if (Companion_instance_35 === VOID)
    new Companion_35();
  return Companion_instance_35;
}
function init_corg_mkui_geom_Area(_this__u8e3s4) {
  Companion_getInstance_35();
  _this__u8e3s4.t1q_1 = null;
  _this__u8e3s4.u1q_1 = null;
}
var org_mkui_geom_AreaOp_CAGOp$stable;
var org_mkui_geom_AreaOp_AddOp$stable;
var org_mkui_geom_AreaOp_SubOp$stable;
var org_mkui_geom_AreaOp_IntOp$stable;
var org_mkui_geom_AreaOp_XorOp$stable;
var org_mkui_geom_AreaOp_NZWindOp$stable;
var org_mkui_geom_AreaOp_EOWindOp$stable;
var org_mkui_geom_AreaOp$stable;
function addEdges($this, edges, curves, curvetag) {
  var _iterator__ex2g4s = curves.x();
  while (_iterator__ex2g4s.y()) {
    var c = _iterator__ex2g4s.z();
    if (c.e1r() > 0) {
      edges.o(new Edge(c, curvetag));
    }
  }
}
function AreaOp$Companion$YXTopComparator$lambda(o1, o2) {
  var c1 = o1.w1r_1;
  var c2 = o2.w1r_1;
  var v1;
  var v2;
  // Inline function 'kotlin.also' call
  var this_0 = c1.e1s();
  // Inline function 'org.mkui.geom.Companion.YXTopComparator.<anonymous>.<anonymous>' call
  v1 = this_0;
  var tmp = this_0;
  // Inline function 'kotlin.also' call
  var this_1 = c2.e1s();
  // Inline function 'org.mkui.geom.Companion.YXTopComparator.<anonymous>.<anonymous>' call
  v2 = this_1;
  if (tmp === this_1) {
    // Inline function 'kotlin.also' call
    var this_2 = c1.f1s();
    // Inline function 'org.mkui.geom.Companion.YXTopComparator.<anonymous>.<anonymous>' call
    v1 = this_2;
    var tmp_0 = this_2;
    // Inline function 'kotlin.also' call
    var this_3 = c2.f1s();
    // Inline function 'org.mkui.geom.Companion.YXTopComparator.<anonymous>.<anonymous>' call
    v2 = this_3;
    if (tmp_0 === this_3) {
      return 0;
    }
  }
  if (v1 < v2) {
    return -1;
  }
  return 1;
}
function pruneEdges($this, edges) {
  var numedges = edges.a1();
  if (numedges < 2) {
    return ArrayList.e1();
  }
  // Inline function 'kotlin.collections.toTypedArray' call
  var edgelist = copyToArray(edges);
  sortWith(edgelist, Companion_getInstance_36().n1s_1);
  if (false) {
    println('pruning: ');
    var inductionVariable = 0;
    if (inductionVariable < numedges)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        println('edgelist[' + i + '] = ' + edgelist[i].toString());
      }
       while (inductionVariable < numedges);
  }
  var left = 0;
  var right = 0;
  var cur;
  var next;
  var yrange = new Float64Array(2);
  var subcurves = ArrayList.e1();
  var chains = ArrayList.e1();
  var links = ArrayList.e1();
  $l$loop: while (left < numedges) {
    var y = yrange[0];
    var e;
    next = right - 1 | 0;
    cur = next;
    while (cur >= left) {
      e = edgelist[cur];
      if (e.w1r_1.q1s() > y) {
        if (next > cur) {
          edgelist[next] = e;
        }
        next = next - 1 | 0;
      }
      cur = cur - 1 | 0;
    }
    left = next + 1 | 0;
    if (left >= right) {
      if (right >= numedges) {
        break $l$loop;
      }
      y = edgelist[right].w1r_1.e1s();
      if (y > yrange[0]) {
        Companion_getInstance_36().r1s(subcurves, chains);
      }
      yrange[0] = y;
    }
    $l$loop_0: while (right < numedges) {
      e = edgelist[right];
      if (e.w1r_1.e1s() > y) {
        break $l$loop_0;
      }
      right = right + 1 | 0;
    }
    yrange[1] = edgelist[left].w1r_1.q1s();
    if (right < numedges) {
      y = edgelist[right].w1r_1.e1s();
      if (yrange[1] > y) {
        yrange[1] = y;
      }
    }
    if (false) {
      println('current line: y = [' + yrange[0] + ', ' + yrange[1] + toString(_Char___init__impl__6a9atx(93)));
      cur = left;
      while (cur < right) {
        println('  ' + edgelist[cur].toString());
        cur = cur + 1 | 0;
      }
    }
    var nexteq = 1;
    cur = left;
    while (cur < right) {
      e = edgelist[cur];
      e.a1s_1 = 0;
      next = cur;
      $l$loop_1: while (next > left) {
        var prevedge = edgelist[next - 1 | 0];
        var ordering = e.s1s(prevedge, yrange);
        if (yrange[1] <= yrange[0]) {
          throw UnsupportedOperationException.t9('backstepping to ' + yrange[1] + ' from ' + yrange[0]);
        }
        if (ordering >= 0) {
          if (ordering === 0) {
            var eq = prevedge.a1s_1;
            if (eq === 0) {
              var _unary__edvuaz = nexteq;
              nexteq = _unary__edvuaz + 1 | 0;
              eq = _unary__edvuaz;
              prevedge.a1s_1 = eq;
            }
            e.a1s_1 = eq;
          }
          break $l$loop_1;
        }
        edgelist[next] = prevedge;
        next = next - 1 | 0;
      }
      edgelist[next] = e;
      cur = cur + 1 | 0;
    }
    if (false) {
      println('current sorted line: y = [' + yrange[0] + ', ' + yrange[1] + toString(_Char___init__impl__6a9atx(93)));
      cur = left;
      while (cur < right) {
        println('  ' + edgelist[cur].toString());
        cur = cur + 1 | 0;
      }
    }
    $this.t1s();
    var ystart = yrange[0];
    var yend = yrange[1];
    cur = left;
    while (cur < right) {
      e = edgelist[cur];
      var etag;
      var eq_0 = e.a1s_1;
      if (!(eq_0 === 0)) {
        var origstate = $this.v1s();
        etag = origstate === 1 ? -1 : 1;
        var activematch = null;
        var longestmatch = e;
        var furthesty = yend;
        $l$1: do {
          $l$0: do {
            $this.u1s(e);
            if (activematch == null && e.w1s(ystart, etag)) {
              activematch = e;
            }
            y = e.w1r_1.q1s();
            if (y > furthesty) {
              longestmatch = e;
              furthesty = y;
            }
          }
           while (false);
          var tmp;
          cur = cur + 1 | 0;
          if (cur < right) {
            // Inline function 'kotlin.also' call
            var this_0 = edgelist[cur];
            // Inline function 'org.mkui.geom.AreaOp.pruneEdges.<anonymous>' call
            e = this_0;
            tmp = this_0.a1s_1 === eq_0;
          } else {
            tmp = false;
          }
        }
         while (tmp);
        cur = cur - 1 | 0;
        if ($this.v1s() === origstate) {
          etag = 0;
        } else {
          e = !(activematch == null) ? activematch : ensureNotNull(longestmatch);
        }
      } else {
        etag = $this.u1s(e);
      }
      if (!(etag === 0)) {
        e.x1s(yend, etag);
        links.o(new CurveLink(e.w1r_1, ystart, yend, etag));
      }
      cur = cur + 1 | 0;
    }
    if (!($this.v1s() === -1)) {
      println('Still inside at end of active edge list!');
      println('num curves = ' + (right - left | 0));
      println('num links = ' + links.a1());
      println('y top = ' + yrange[0]);
      if (right < numedges) {
        println('y top of next curve = ' + edgelist[right].w1r_1.e1s());
      } else {
        println('no more curves');
      }
      cur = left;
      while (cur < right) {
        e = edgelist[cur];
        println(e);
        var eq_1 = e.a1s_1;
        if (!(eq_1 === 0)) {
          println('  was equal to ' + eq_1 + '...');
        }
        cur = cur + 1 | 0;
      }
    }
    if (false) {
      println('new links:');
      var inductionVariable_0 = 0;
      var last = links.a1() - 1 | 0;
      if (inductionVariable_0 <= last)
        do {
          var i_0 = inductionVariable_0;
          inductionVariable_0 = inductionVariable_0 + 1 | 0;
          var link = ensureNotNull(links.b1(i_0));
          println('  ' + link.d1t().toString());
        }
         while (inductionVariable_0 <= last);
    }
    Companion_getInstance_36().e1t(subcurves, chains, links);
    links.o5();
    yrange[0] = yend;
  }
  Companion_getInstance_36().r1s(subcurves, chains);
  var ret = ArrayList.e1();
  var _iterator__ex2g4s = subcurves.x();
  while (_iterator__ex2g4s.y()) {
    var subcurve = _iterator__ex2g4s.z();
    var link_0 = subcurve;
    ret.o(ensureNotNull(link_0).f1t());
    var nextlink = link_0;
    $l$loop_2: while (true) {
      // Inline function 'kotlin.also' call
      var this_1 = ensureNotNull(nextlink).c1t_1;
      // Inline function 'org.mkui.geom.AreaOp.pruneEdges.<anonymous>' call
      nextlink = this_1;
      if (!!(this_1 == null)) {
        break $l$loop_2;
      }
      if (!ensureNotNull(link_0).g1t(ensureNotNull(nextlink))) {
        ret.o(link_0.d1t());
        link_0 = nextlink;
      }
    }
    ret.o(ensureNotNull(link_0).d1t());
  }
  return ret;
}
var Companion_instance_36;
function Companion_getInstance_36() {
  if (Companion_instance_36 === VOID)
    new Companion_36();
  return Companion_instance_36;
}
var org_mkui_geom_ChainEnd$stable;
var org_mkui_geom_Crossings_EvenOdd$stable;
var org_mkui_geom_Crossings_NonZero$stable;
var org_mkui_geom_Crossings$stable;
var Companion_instance_37;
function Companion_getInstance_37() {
  return Companion_instance_37;
}
var org_mkui_geom_CubicCurve2D$stable;
var org_mkui_geom_Curve$stable;
function fairlyClose($this, v1, v2) {
  // Inline function 'kotlin.math.abs' call
  var x = v1 - v2;
  var tmp = Math.abs(x);
  // Inline function 'kotlin.math.abs' call
  var tmp3 = Math.abs(v1);
  // Inline function 'kotlin.math.abs' call
  // Inline function 'kotlin.math.max' call
  var b = Math.abs(v2);
  return tmp < Math.max(tmp3, b) * 1.0E-10;
}
var Companion_instance_38;
function Companion_getInstance_38() {
  return Companion_instance_38;
}
var org_mkui_geom_CurveLink$stable;
var org_mkui_geom_Edge$stable;
var Companion_instance_39;
function Companion_getInstance_39() {
  return Companion_instance_39;
}
var org_mkui_geom_Ellipse$stable;
var org_mkui_geom_Ellipse2D_Double$stable;
var org_mkui_geom_EllipseIterator$stable;
var Companion_instance_40;
function Companion_getInstance_40() {
  if (Companion_instance_40 === VOID)
    new Companion_40();
  return Companion_instance_40;
}
var org_mkui_geom_FlatteningPathIterator$stable;
var org_mkui_geom_GeneralPath$stable;
var org_mkui_geom_Line2D_Double$stable;
var org_mkui_geom_Line2D$stable;
var Companion_instance_41;
function Companion_getInstance_41() {
  return Companion_instance_41;
}
var org_mkui_geom_LineIterator$stable;
var org_mkui_geom_NoninvertibleTransformException$stable;
var org_mkui_geom_Order0$stable;
var org_mkui_geom_Order1$stable;
var org_mkui_geom_Order2$stable;
var Companion_instance_42;
function Companion_getInstance_42() {
  return Companion_instance_42;
}
var org_mkui_geom_Order3$stable;
var Companion_instance_43;
function Companion_getInstance_43() {
  return Companion_instance_43;
}
var org_mkui_geom_Path$stable;
var org_mkui_geom_Path2D_Double_CopyIterator$stable;
var org_mkui_geom_Path2D_Double_TxIterator$stable;
var org_mkui_geom_Path2D_Double$stable;
var org_mkui_geom_Path2D_Iterator$stable;
var org_mkui_geom_Path2D$stable;
function init_org_mkui_geom_Path2D_Double(_this__u8e3s4) {
}
var Companion_instance_44;
function Companion_getInstance_44() {
  if (Companion_instance_44 === VOID)
    new Companion_44();
  return Companion_instance_44;
}
var Companion_instance_45;
function Companion_getInstance_45() {
  return Companion_instance_45;
}
function init_org_mkui_geom_Path2D(_this__u8e3s4) {
  _this__u8e3s4.x1y_1 = 0;
  _this__u8e3s4.y1y_1 = 0;
  _this__u8e3s4.z1y_1 = 0;
}
var org_mkui_geom_Point$stable;
var org_mkui_geom_Point2D_Double$stable;
var org_mkui_geom_Point2D_Float$stable;
function init_org_mkui_geom_Point2D_Double(_this__u8e3s4) {
  _this__u8e3s4.n1o_1 = 0.0;
  _this__u8e3s4.o1o_1 = 0.0;
}
function init_org_mkui_geom_Point2D_Float(_this__u8e3s4) {
  _this__u8e3s4.k1o_1 = 0.0;
  _this__u8e3s4.l1o_1 = 0.0;
}
var org_mkui_geom_Polygon_PolygonPathIterator$stable;
var org_mkui_geom_Polygon$stable;
var org_mkui_geom_QuadCurve2D_Double$stable;
var org_mkui_geom_QuadCurve2D$stable;
var Companion_instance_46;
function Companion_getInstance_46() {
  return Companion_instance_46;
}
var org_mkui_geom_QuadIterator$stable;
var org_mkui_geom_RectIterator$stable;
var org_mkui_geom_Rectangle$stable;
function _get_isNormalized__vs9aom($this) {
  return $this.cm() >= 0 && $this.dm() >= 0;
}
function init_org_mkui_geom_Rectangle(_this__u8e3s4) {
  _this__u8e3s4.q20_1 = 0;
  _this__u8e3s4.r20_1 = 0;
  _this__u8e3s4.s20_1 = 0;
  _this__u8e3s4.t20_1 = 0;
}
var org_mkui_geom_Rectangle2D_Double$stable;
function _get_isNormalized__vs9aom_0($this) {
  return $this.cm() >= 0 && $this.dm() >= 0;
}
var Companion_instance_47;
function Companion_getInstance_47() {
  return Companion_instance_47;
}
var org_mkui_geom_Rectangle2DHelper$stable;
var org_mkui_geom_RoundRectIterator$stable;
var Companion_instance_48;
function Companion_getInstance_48() {
  if (Companion_instance_48 === VOID)
    new Companion_48();
  return Companion_instance_48;
}
var org_mkui_geom_RoundRectangle2D_Double$stable;
var org_mkui_geom_RoundRectangle2D$stable;
function _get_isNormalized__vs9aom_1($this) {
  return $this.q21_1 >= 0 && $this.r21_1 >= 0;
}
function init_org_mkui_geom_RoundRectangle2D_Double(_this__u8e3s4) {
  _this__u8e3s4.o21_1 = 0.0;
  _this__u8e3s4.p21_1 = 0.0;
  _this__u8e3s4.q21_1 = 0.0;
  _this__u8e3s4.r21_1 = 0.0;
  _this__u8e3s4.s21_1 = 0.0;
  _this__u8e3s4.t21_1 = 0.0;
}
function classify($this, coord, left, right, arcsize) {
  var tmp;
  if (coord < left) {
    tmp = 0;
  } else if (coord < left + arcsize) {
    tmp = 1;
  } else if (coord < right - arcsize) {
    tmp = 2;
  } else if (coord < right) {
    tmp = 3;
  } else {
    tmp = 4;
  }
  return tmp;
}
var org_mkui_geom_ScreenTransformHelper$stable;
var ScreenTransformHelper_instance;
function ScreenTransformHelper_getInstance() {
  return ScreenTransformHelper_instance;
}
var org_mkui_geom_Segment$stable;
var org_mkui_geom_TextShape$stable;
var org_mkui_geom_curve_BSpline$stable;
var org_mkui_geom_curve_Bag$stable;
var org_mkui_geom_curve_BezierCurve$stable;
var org_mkui_geom_curve_BinaryCurveApproximationAlgorithm$stable;
var org_mkui_geom_curve_CardinalSpline$stable;
var org_mkui_geom_curve_CatmullRomSpline$stable;
var org_mkui_geom_curve_ControlPath$stable;
var org_mkui_geom_curve_CubicBSpline$stable;
var org_mkui_geom_curve_Curve$stable;
var org_mkui_geom_curve_Geom$stable;
var org_mkui_geom_curve_GroupIterator$stable;
var org_mkui_geom_curve_LagrangeCurve$stable;
var org_mkui_geom_curve_MultiPath$stable;
var org_mkui_geom_curve_NURBSpline$stable;
var org_mkui_geom_curve_NaturalCubicSpline$stable;
var org_mkui_geom_curve_ParametricCurve$stable;
var org_mkui_geom_curve_PascalsTriangle$stable;
var org_mkui_geom_curve_ShapeMultiPath$stable;
var org_mkui_geom_curve_ShapeMultiPathIterator$stable;
var org_mkui_geom_curve_ValueVector$stable;
var org_mkui_graphics_AbstractIDrawing$stable;
var org_mkui_graphics_AbstractIGraphics$stable;
var Companion_instance_49;
function Companion_getInstance_49() {
  return Companion_instance_49;
}
var org_mkui_graphics_Edge$stable;
var org_mkui_graphics_Insets$stable;
var org_mkui_graphics_colortheme_AbstractColorTheme$stable;
var org_mkui_graphics_colortheme_LightColorTheme$stable;
var org_mkui_graphics_line_BresenhamLineDrawer$stable;
var org_mkui_graphics_line_TwoStepLineDrawer$stable;
var org_mkui_graphics_pressure_LinearPressure$stable;
var org_mkui_graphics_pressure_LogPressure$stable;
var org_mkui_labeling_ContrastEnhancement_Off$stable;
var org_mkui_labeling_ContrastEnhancement_Brightness$stable;
var org_mkui_labeling_ContrastEnhancement_BlackWhite$stable;
var org_mkui_labeling_ContrastEnhancement_Complement$stable;
var org_mkui_labeling_ContrastEnhancement$stable;
var Companion_instance_50;
function Companion_getInstance_50() {
  if (Companion_instance_50 === VOID)
    new Companion_50();
  return Companion_instance_50;
}
var Off_instance;
function Off_getInstance() {
  if (Off_instance === VOID)
    new Off();
  return Off_instance;
}
var Brightness_instance;
function Brightness_getInstance() {
  if (Brightness_instance === VOID)
    new Brightness();
  return Brightness_instance;
}
var BlackWhite_instance;
function BlackWhite_getInstance() {
  if (BlackWhite_instance === VOID)
    new BlackWhite();
  return BlackWhite_instance;
}
var Complement_instance;
function Complement_getInstance() {
  if (Complement_instance === VOID)
    new Complement();
  return Complement_instance;
}
function get_Black() {
  _init_properties_EnhancedLabel_kt__o8kthw();
  return Black;
}
var Black;
function get_White() {
  _init_properties_EnhancedLabel_kt__o8kthw();
  return White;
}
var White;
var org_mkui_labeling_EnhancedLabel_Effect_Plain$stable;
var org_mkui_labeling_EnhancedLabel_Effect_Shadow$stable;
var org_mkui_labeling_EnhancedLabel_Effect_Glow$stable;
var org_mkui_labeling_EnhancedLabel_Effect_Outline$stable;
var org_mkui_labeling_EnhancedLabel_Effect_Emphasize$stable;
var org_mkui_labeling_EnhancedLabel_Effect$stable;
var org_mkui_labeling_EnhancedLabel$stable;
var Rendering_Truncate_instance;
var Rendering_Clip_instance;
var Rendering_WordWrap_instance;
function values_1() {
  return [Rendering_Truncate_getInstance(), Rendering_Clip_getInstance(), Rendering_WordWrap_getInstance()];
}
function valueOf_0(value) {
  switch (value) {
    case 'Truncate':
      return Rendering_Truncate_getInstance();
    case 'Clip':
      return Rendering_Clip_getInstance();
    case 'WordWrap':
      return Rendering_WordWrap_getInstance();
    default:
      Rendering_initEntries();
      THROW_IAE('No enum constant value.');
      break;
  }
}
var Rendering_entriesInitialized;
function Rendering_initEntries() {
  if (Rendering_entriesInitialized)
    return Unit_instance;
  Rendering_entriesInitialized = true;
  Rendering_Truncate_instance = new Rendering('Truncate', 0);
  Rendering_Clip_instance = new Rendering('Clip', 1);
  Rendering_WordWrap_instance = new Rendering('WordWrap', 2);
}
var Plain_instance;
function Plain_getInstance() {
  if (Plain_instance === VOID)
    new Plain();
  return Plain_instance;
}
var Shadow_instance;
function Shadow_getInstance() {
  if (Shadow_instance === VOID)
    new Shadow();
  return Shadow_instance;
}
var Glow_instance;
function Glow_getInstance() {
  if (Glow_instance === VOID)
    new Glow();
  return Glow_instance;
}
var Outline_instance;
function Outline_getInstance() {
  if (Outline_instance === VOID)
    new Outline();
  return Outline_instance;
}
var Emphasize_instance;
function Emphasize_getInstance() {
  if (Emphasize_instance === VOID)
    new Emphasize();
  return Emphasize_instance;
}
var Companion_instance_51;
function Companion_getInstance_51() {
  return Companion_instance_51;
}
function Rendering_Truncate_getInstance() {
  Rendering_initEntries();
  return Rendering_Truncate_instance;
}
function Rendering_Clip_getInstance() {
  Rendering_initEntries();
  return Rendering_Clip_instance;
}
function Rendering_WordWrap_getInstance() {
  Rendering_initEntries();
  return Rendering_WordWrap_instance;
}
function diff(_this__u8e3s4, background) {
  _init_properties_EnhancedLabel_kt__o8kthw();
  // Inline function 'kotlin.UByte.toInt' call
  var this_0 = getURed(_this__u8e3s4);
  var tmp = _UByte___get_data__impl__jof9qr(this_0) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_1 = getURed(background);
  var tmp$ret$1 = _UByte___get_data__impl__jof9qr(this_1) & 255;
  var r = abs_0(tmp - tmp$ret$1 | 0);
  // Inline function 'kotlin.UByte.toInt' call
  var this_2 = getUGreen(_this__u8e3s4);
  var tmp_0 = _UByte___get_data__impl__jof9qr(this_2) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_3 = getUGreen(background);
  var tmp$ret$3 = _UByte___get_data__impl__jof9qr(this_3) & 255;
  var g = abs_0(tmp_0 - tmp$ret$3 | 0);
  // Inline function 'kotlin.UByte.toInt' call
  var this_4 = getUBlue(_this__u8e3s4);
  var tmp_1 = _UByte___get_data__impl__jof9qr(this_4) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_5 = getUBlue(background);
  var tmp$ret$5 = _UByte___get_data__impl__jof9qr(this_5) & 255;
  var b = abs_0(tmp_1 - tmp$ret$5 | 0);
  // Inline function 'kotlin.math.max' call
  // Inline function 'kotlin.math.max' call
  var b_0 = Math.max(g, b);
  return Math.max(r, b_0) / 255.0;
}
function brightness(_this__u8e3s4) {
  _init_properties_EnhancedLabel_kt__o8kthw();
  // Inline function 'kotlin.UByte.toInt' call
  var this_0 = getURed(_this__u8e3s4);
  var tmp = _UByte___get_data__impl__jof9qr(this_0) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_1 = getUGreen(_this__u8e3s4);
  var tmp_0 = _UByte___get_data__impl__jof9qr(this_1) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_2 = getUBlue(_this__u8e3s4);
  var tmp$ret$2 = _UByte___get_data__impl__jof9qr(this_2) & 255;
  var hsb = RGBtoHSB(tmp, tmp_0, tmp$ret$2, null);
  return hsb[2];
}
function replaceBrightness(_this__u8e3s4, min) {
  _init_properties_EnhancedLabel_kt__o8kthw();
  // Inline function 'kotlin.UByte.toInt' call
  var this_0 = getURed(_this__u8e3s4);
  var tmp = _UByte___get_data__impl__jof9qr(this_0) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_1 = getUGreen(_this__u8e3s4);
  var tmp_0 = _UByte___get_data__impl__jof9qr(this_1) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_2 = getUBlue(_this__u8e3s4);
  var tmp$ret$2 = _UByte___get_data__impl__jof9qr(this_2) & 255;
  var hsb = RGBtoHSB(tmp, tmp_0, tmp$ret$2, null);
  return getHSBColor(hsb[0], hsb[1], min);
}
function luminance(_this__u8e3s4) {
  _init_properties_EnhancedLabel_kt__o8kthw();
  // Inline function 'kotlin.UByte.toInt' call
  var this_0 = getURed(_this__u8e3s4);
  var r = _UByte___get_data__impl__jof9qr(this_0) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_1 = getUGreen(_this__u8e3s4);
  var g = _UByte___get_data__impl__jof9qr(this_1) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_2 = getUBlue(_this__u8e3s4);
  var b = _UByte___get_data__impl__jof9qr(this_2) & 255;
  return (0.299 * r + 0.587 * g + 0.114 * b) / 255.0;
}
function lum(_this__u8e3s4) {
  _init_properties_EnhancedLabel_kt__o8kthw();
  // Inline function 'kotlin.UByte.toInt' call
  var this_0 = getURed(_this__u8e3s4);
  var r = _UByte___get_data__impl__jof9qr(this_0) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_1 = getUGreen(_this__u8e3s4);
  var g = _UByte___get_data__impl__jof9qr(this_1) & 255;
  // Inline function 'kotlin.UByte.toInt' call
  var this_2 = getUBlue(_this__u8e3s4);
  var b = _UByte___get_data__impl__jof9qr(this_2) & 255;
  return 0.299 * r + 0.587 * g + 0.114 * b;
}
function getHSBColor(h, s, b) {
  _init_properties_EnhancedLabel_kt__o8kthw();
  return colorOf_3(HSBtoRGB(h, s, b));
}
var properties_initialized_EnhancedLabel_kt_cq7ape;
function _init_properties_EnhancedLabel_kt__o8kthw() {
  if (!properties_initialized_EnhancedLabel_kt_cq7ape) {
    properties_initialized_EnhancedLabel_kt_cq7ape = true;
    Black = colorOf_0(_UByte___init__impl__g9hnc4(0), _UByte___init__impl__g9hnc4(0), _UByte___init__impl__g9hnc4(0), _UByte___init__impl__g9hnc4(-1));
    White = colorOf_0(_UByte___init__impl__g9hnc4(-1), _UByte___init__impl__g9hnc4(-1), _UByte___init__impl__g9hnc4(-1), _UByte___init__impl__g9hnc4(-1));
    org_mkui_labeling_EnhancedLabel_Effect_Plain$stable = 0;
    org_mkui_labeling_EnhancedLabel_Effect_Shadow$stable = 0;
    org_mkui_labeling_EnhancedLabel_Effect_Glow$stable = 0;
    org_mkui_labeling_EnhancedLabel_Effect_Outline$stable = 0;
    org_mkui_labeling_EnhancedLabel_Effect_Emphasize$stable = 0;
    org_mkui_labeling_EnhancedLabel_Effect$stable = 0;
    org_mkui_labeling_EnhancedLabel$stable = 8;
  }
}
var org_mkui_palette_AbstractMutablePalette$stable;
var org_mkui_palette_AbstractPalette$stable;
var org_mkui_palette_CustomPalette_Entry$stable;
var org_mkui_palette_CustomPalette$stable;
var Mode_Ramps_instance;
var Mode_Bands_instance;
var Mode_entriesInitialized;
function Mode_initEntries() {
  if (Mode_entriesInitialized)
    return Unit_instance;
  Mode_entriesInitialized = true;
  Mode_Ramps_instance = new Mode('Ramps', 0);
  Mode_Bands_instance = new Mode('Bands', 1);
}
function updateFixedColorGradient($this) {
  var colors = ArrayList.e1();
  var inductionVariable = 0;
  if (inductionVariable <= 255)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      var fraction = 1.0 * i / 255;
      var color = ensureNotNull(computeColor($this, fraction));
      colors.o(color);
    }
     while (inductionVariable <= 255);
  $this.a25_1 = colors;
  $this.y1j(colors.a1());
  $this.s24(new PaletteEvent());
}
function computeColor($this, fration) {
  if (!$this.v1g_1.c1()) {
    var previous = null;
    var _iterator__ex2g4s = $this.v1g_1.x();
    while (_iterator__ex2g4s.y()) {
      var current = _iterator__ex2g4s.z();
      if (!(previous == null)) {
        if (previous.l1k_1 <= fration && fration <= current.l1k_1) {
          var v = (fration - previous.l1k_1) / (current.l1k_1 - previous.l1k_1);
          return interpolate($this, ensureNotNull(previous.c25()), ensureNotNull(current.c25()), v);
        }
      }
      previous = current;
    }
    if (fration < first_0($this.v1g_1).l1k_1) {
      return first_0($this.v1g_1).c25();
    }
    if (fration > last_0($this.v1g_1).l1k_1) {
      return last_0($this.v1g_1).c25();
    }
  }
  return null;
}
function interpolate($this, c1, c2, p) {
  var tmp;
  switch ($this.u1g_1.r2().z2_1) {
    case 0:
      if (p === 0.0)
        return c1;
      var tmp_0;
      if (p === 1.0) {
        tmp_0 = c2;
      } else {
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_0 = getURed(c1);
        var tmp$ret$0 = _UByte___get_data__impl__jof9qr(this_0) & 255;
        var tmp_1 = uintToDouble(tmp$ret$0) * (1.0 - p);
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_1 = getURed(c2);
        var tmp$ret$2 = _UByte___get_data__impl__jof9qr(this_1) & 255;
        var tmp$ret$3 = uintToDouble(tmp$ret$2);
        var tmp_2 = numberToInt(tmp_1 + tmp$ret$3 * p);
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_2 = getUGreen(c1);
        var tmp$ret$4 = _UByte___get_data__impl__jof9qr(this_2) & 255;
        var tmp_3 = uintToDouble(tmp$ret$4) * (1.0 - p);
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_3 = getUGreen(c2);
        var tmp$ret$6 = _UByte___get_data__impl__jof9qr(this_3) & 255;
        var tmp$ret$7 = uintToDouble(tmp$ret$6);
        var tmp_4 = numberToInt(tmp_3 + tmp$ret$7 * p);
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_4 = getUBlue(c1);
        var tmp$ret$8 = _UByte___get_data__impl__jof9qr(this_4) & 255;
        var tmp_5 = uintToDouble(tmp$ret$8) * (1.0 - p);
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_5 = getUBlue(c2);
        var tmp$ret$10 = _UByte___get_data__impl__jof9qr(this_5) & 255;
        var tmp$ret$11 = uintToDouble(tmp$ret$10);
        var tmp_6 = numberToInt(tmp_5 + tmp$ret$11 * p);
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_6 = getUAlpha(c1);
        var tmp$ret$12 = _UByte___get_data__impl__jof9qr(this_6) & 255;
        var tmp_7 = uintToDouble(tmp$ret$12) * (1.0 - p);
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_7 = getUAlpha(c2);
        var tmp$ret$14 = _UByte___get_data__impl__jof9qr(this_7) & 255;
        var tmp$ret$15 = uintToDouble(tmp$ret$14);
        tmp_0 = colorOf(tmp_2, tmp_4, tmp_6, numberToInt(tmp_7 + tmp$ret$15 * p));
      }

      tmp = tmp_0;
      break;
    case 1:
      tmp = c1;
      break;
    default:
      noWhenBranchMatchedException();
      break;
  }
  return tmp;
}
function CustomPalette$_init_$lambda_rc1wld(a, b) {
  // Inline function 'kotlin.comparisons.compareValuesBy' call
  // Inline function 'org.mkui.palette.CustomPalette.<init>.<anonymous>' call
  var tmp = a.l1k_1;
  // Inline function 'org.mkui.palette.CustomPalette.<init>.<anonymous>' call
  var tmp$ret$1 = b.l1k_1;
  return compareValues(tmp, tmp$ret$1);
}
function Mode_Ramps_getInstance() {
  Mode_initEntries();
  return Mode_Ramps_instance;
}
var Cycle_NONE_instance;
var Cycle_REPEAT_instance;
var Cycle_REFLECT_instance;
var Cycle_entriesInitialized;
function Cycle_initEntries() {
  if (Cycle_entriesInitialized)
    return Unit_instance;
  Cycle_entriesInitialized = true;
  Cycle_NONE_instance = new Cycle('NONE', 0);
  Cycle_REPEAT_instance = new Cycle('REPEAT', 1);
  Cycle_REFLECT_instance = new Cycle('REFLECT', 2);
}
function Cycle_NONE_getInstance() {
  Cycle_initEntries();
  return Cycle_NONE_instance;
}
var org_mkui_palette_DynamicPalette$stable;
function init_org_mkui_palette_DynamicPalette(_this__u8e3s4) {
  _this__u8e3s4.b25_1 = false;
}
var org_mkui_palette_FixedPalette$stable;
function toCPColorList($this, colors) {
  var list = ArrayList.o7(colors.length);
  var inductionVariable = 0;
  var last = colors.length;
  while (inductionVariable < last) {
    var color = colors[inductionVariable];
    inductionVariable = inductionVariable + 1 | 0;
    list.o(colorOf_3(color));
  }
  return list;
}
var Companion_instance_52;
function Companion_getInstance_52() {
  return Companion_instance_52;
}
var org_mkui_palette_InterpolatedPalette_Entry$stable;
var org_mkui_palette_InterpolatedPalette$stable;
var Mode_Ramps_instance_0;
var Mode_Bands_instance_0;
function values_2() {
  return [Mode_Ramps_getInstance_0(), Mode_Bands_getInstance()];
}
function valueOf_1(value) {
  switch (value) {
    case 'Ramps':
      return Mode_Ramps_getInstance_0();
    case 'Bands':
      return Mode_Bands_getInstance();
    default:
      Mode_initEntries_0();
      THROW_IAE('No enum constant value.');
      break;
  }
}
function get_entries() {
  if ($ENTRIES == null)
    $ENTRIES = enumEntries(values_2());
  return $ENTRIES;
}
var Mode_entriesInitialized_0;
function Mode_initEntries_0() {
  if (Mode_entriesInitialized_0)
    return Unit_instance;
  Mode_entriesInitialized_0 = true;
  Mode_Ramps_instance_0 = new Mode_0('Ramps', 0);
  Mode_Bands_instance_0 = new Mode_0('Bands', 1);
}
var $ENTRIES;
function updateFixedColorGradient_0($this) {
  if (!$this.entries.c1()) {
    var colors = ArrayList.e1();
    var inductionVariable = 0;
    if (inductionVariable <= 255)
      do {
        var i = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var fraction = 1.0 * i / 255;
        var color = computeColor_0($this, fraction);
        if (!(color == null)) {
          colors.o(color);
        } else {
          throw IllegalStateException.n4('Null color ' + fraction + ', ' + toString_0(color));
        }
      }
       while (inductionVariable <= 255);
    $this.o25_1 = colors;
    $this.y1j(colors.a1());
  } else {
    $this.o25_1 = emptyList();
    $this.y1j(0);
  }
}
function computeColor_0($this, fraction) {
  if (!$this.entries.c1()) {
    var previous = null;
    var _iterator__ex2g4s = $this.entries.x();
    while (_iterator__ex2g4s.y()) {
      var current = _iterator__ex2g4s.z();
      if (!(previous == null)) {
        if (previous.fraction <= fraction && fraction <= current.fraction) {
          var v = (fraction - previous.fraction) / (current.fraction - previous.fraction);
          return interpolate_0($this, previous.getColor(), current.getColor(), v);
        }
      }
      previous = current;
    }
    if (fraction < first_0($this.entries).fraction) {
      return first_0($this.entries).getColor();
    }
    if (fraction > last_0($this.entries).fraction) {
      return last_0($this.entries).getColor();
    }
  }
  return null;
}
function interpolate_0($this, c1, c2, p) {
  var tmp;
  switch ($this.z25_1.r2().z2_1) {
    case 0:
      if (p === 0.0)
        return c1;
      var tmp_0;
      if (p === 1.0) {
        tmp_0 = c2;
      } else {
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_0 = getURed(c1);
        var tmp$ret$0 = _UByte___get_data__impl__jof9qr(this_0) & 255;
        var tmp_1 = uintToDouble(tmp$ret$0) * (1.0 - p);
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_1 = getURed(c2);
        var tmp$ret$2 = _UByte___get_data__impl__jof9qr(this_1) & 255;
        var tmp$ret$3 = uintToDouble(tmp$ret$2);
        var tmp_2 = numberToInt(tmp_1 + tmp$ret$3 * p);
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_2 = getUGreen(c1);
        var tmp$ret$4 = _UByte___get_data__impl__jof9qr(this_2) & 255;
        var tmp_3 = uintToDouble(tmp$ret$4) * (1.0 - p);
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_3 = getUGreen(c2);
        var tmp$ret$6 = _UByte___get_data__impl__jof9qr(this_3) & 255;
        var tmp$ret$7 = uintToDouble(tmp$ret$6);
        var tmp_4 = numberToInt(tmp_3 + tmp$ret$7 * p);
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_4 = getUBlue(c1);
        var tmp$ret$8 = _UByte___get_data__impl__jof9qr(this_4) & 255;
        var tmp_5 = uintToDouble(tmp$ret$8) * (1.0 - p);
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_5 = getUBlue(c2);
        var tmp$ret$10 = _UByte___get_data__impl__jof9qr(this_5) & 255;
        var tmp$ret$11 = uintToDouble(tmp$ret$10);
        var tmp_6 = numberToInt(tmp_5 + tmp$ret$11 * p);
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_6 = getUAlpha(c1);
        var tmp$ret$12 = _UByte___get_data__impl__jof9qr(this_6) & 255;
        var tmp_7 = uintToDouble(tmp$ret$12) * (1.0 - p);
        // Inline function 'kotlin.UByte.toDouble' call
        // Inline function 'kotlin.UByte.toInt' call
        var this_7 = getUAlpha(c2);
        var tmp$ret$14 = _UByte___get_data__impl__jof9qr(this_7) & 255;
        var tmp$ret$15 = uintToDouble(tmp$ret$14);
        tmp_0 = colorOf(tmp_2, tmp_4, tmp_6, numberToInt(tmp_7 + tmp$ret$15 * p));
      }

      tmp = tmp_0;
      break;
    case 1:
      tmp = c1;
      break;
    default:
      noWhenBranchMatchedException();
      break;
  }
  return tmp;
}
function InterpolatedPalette$_init_$lambda_qt4r8t(a, b) {
  // Inline function 'kotlin.comparisons.compareValuesBy' call
  // Inline function 'org.mkui.palette.InterpolatedPalette.<init>.<anonymous>' call
  var tmp = a.fraction;
  // Inline function 'org.mkui.palette.InterpolatedPalette.<init>.<anonymous>' call
  var tmp$ret$1 = b.fraction;
  return compareValues(tmp, tmp$ret$1);
}
function InterpolatedPalette$_init_$lambda_qt4r8t_0(a, b) {
  // Inline function 'kotlin.comparisons.compareValuesBy' call
  // Inline function 'org.mkui.palette.InterpolatedPalette.<init>.<anonymous>' call
  var tmp = a.fraction;
  // Inline function 'org.mkui.palette.InterpolatedPalette.<init>.<anonymous>' call
  var tmp$ret$1 = b.fraction;
  return compareValues(tmp, tmp$ret$1);
}
function Mode_Ramps_getInstance_0() {
  Mode_initEntries_0();
  return Mode_Ramps_instance_0;
}
function Mode_Bands_getInstance() {
  Mode_initEntries_0();
  return Mode_Bands_instance_0;
}
var org_mkui_palette_PaletteEvent$stable;
var org_mkui_palette_PaletteFactory_Entry$stable;
var org_mkui_palette_PaletteFactory$stable;
var Companion_instance_53;
function Companion_getInstance_53() {
  if (Companion_instance_53 === VOID)
    new Companion_53();
  return Companion_instance_53;
}
var PaletteType_SEQUENTIAL_instance;
var PaletteType_DIVERGING_instance;
var PaletteType_QUALITATIVE_instance;
var PaletteType_entriesInitialized;
function PaletteType_initEntries() {
  if (PaletteType_entriesInitialized)
    return Unit_instance;
  PaletteType_entriesInitialized = true;
  PaletteType_SEQUENTIAL_instance = new PaletteType('SEQUENTIAL', 0);
  PaletteType_DIVERGING_instance = new PaletteType('DIVERGING', 1);
  PaletteType_QUALITATIVE_instance = new PaletteType('QUALITATIVE', 2);
}
function PaletteType_SEQUENTIAL_getInstance() {
  PaletteType_initEntries();
  return PaletteType_SEQUENTIAL_instance;
}
function PaletteType_DIVERGING_getInstance() {
  PaletteType_initEntries();
  return PaletteType_DIVERGING_instance;
}
function PaletteType_QUALITATIVE_getInstance() {
  PaletteType_initEntries();
  return PaletteType_QUALITATIVE_instance;
}
var org_mkui_property_ObservableManager$stable;
var org_mkui_property_ObservableValue$stable;
var org_mkui_property_Observable$stable;
var org_mkui_rubberband_RubberbandDrawing$stable;
var org_mkui_rubberband_ScreenTransformRubberBand$stable;
var org_mkui_rubberband_SimpleRubberBand$stable;
var org_mkui_transform_AbstractMutableTwoDScreenTransform$stable;
var org_mkui_transform_AbstractTwoDScreenTransform$stable;
var org_mkui_transform_SimpleTwoDScreenTransform$stable;
function updateAspectRatio($this) {
  var width = $this.e29_1;
  var height = $this.f29_1 * $this.l29_1;
  if ($this.k29_1 && !(width === height)) {
    if (width < height) {
      $this.i29_1.n15(0);
      $this.j29_1.n15(numberToInt($this.f29_1 - $this.e29_1 / $this.l29_1));
    } else {
      $this.i29_1.n15(numberToInt($this.e29_1 - $this.f29_1 * $this.l29_1));
      $this.j29_1.n15(0);
    }
  }
}
function init_org_mkui_transform_SimpleTwoDScreenTransform(_this__u8e3s4) {
  _this__u8e3s4.k29_1 = false;
  var tmp = _this__u8e3s4;
  tmp.m29_1 = new SimpleTwoDScreenTransform$intervalListener$1(_this__u8e3s4);
}
var org_mkui_visual_AbstractVisual$stable;
var org_mkui_canvas_CPCanvas$stable;
var com_macrofocus_crossplatform_client_layer_ElementalAveragingGWTLayer$stable;
var org_mkui_canvas_ElementalBufferedGWTLayer$stable;
var org_mkui_canvas_ElementalCanvasHandler_ElementalMouseEvent$stable;
var org_mkui_canvas_ElementalCanvasHandler_ElementalKeyEvent$stable;
var org_mkui_canvas_ElementalCanvasHandler$stable;
var com_macrofocus_crossplatform_client_layer_ElementalDensityGWTLayer$stable;
var org_mkui_canvas_ElementalDirectGWTLayer$stable;
var org_mkui_canvas_ElementalFontMetrics$stable;
var org_mkui_canvas_ElementalIGraphics$stable;
var org_mkui_canvas_FunctionalCPCanvas$stable;
function prepare($this) {
  $this.a2a_1.y18();
  var width = $this.g2a_1;
  var height = $this.h2a_1;
  var dirtyLayers;
  // Inline function 'kotlin.run' call
  // Inline function 'org.mkui.canvas.FunctionalCPCanvas.prepare.<anonymous>' call
  dirtyLayers = ArrayList.l($this.y29_1);
  $this.y29_1.o5();
  var _iterator__ex2g4s = dirtyLayers.x();
  while (_iterator__ex2g4s.y()) {
    var layer = _iterator__ex2g4s.z();
    layer.y2a(width, height);
  }
  $this.a2a_1.z18();
  $this.z2a();
}
function _get_resizeObserver__wzddgf($this) {
  var tmp = $this.e2a_1;
  if (!(tmp == null))
    return tmp;
  else {
    throwUninitializedPropertyAccessException('resizeObserver');
  }
}
function paintTheCanvas($this) {
  $this.b2a_1.y18();
  var tmp0_safe_receiver = $this.m2a_1;
  if (tmp0_safe_receiver == null)
    null;
  else {
    // Inline function 'kotlin.apply' call
    // Inline function 'org.mkui.canvas.FunctionalCPCanvas.paintTheCanvas.<anonymous>' call
    $this.a2b(tmp0_safe_receiver);
    var _iterator__ex2g4s = $this.v29_1.x();
    while (_iterator__ex2g4s.y()) {
      var i = _iterator__ex2g4s.z();
      i.b2b(tmp0_safe_receiver);
    }
    $this.b2a_1.z18();
    if ($this.x29_1.r2()) {
      tmp0_safe_receiver.fillStyle = 'red';
      var y = $this.h2a_1;
      y = y - 12.0;
      tmp0_safe_receiver.fillText('Prepare: ' + $this.a2a_1.v18().toString() + ' ms', 5.0, y);
      y = y - 12;
      tmp0_safe_receiver.fillText('Render: ' + $this.b2a_1.v18().toString() + ' ms', 5.0, y);
      y = y - 12;
      tmp0_safe_receiver.fillText('Interact: ' + $this.c2a_1.v18().toString() + ' ms', 5.0, y);
    }
  }
}
function findDesiredScaleFactor($this) {
  return window.devicePixelRatio;
}
function publishData($this, canvasRef, canvas) {
  var width = canvas.clientWidth;
  var height = canvas.clientHeight;
  println('client=' + canvas.clientWidth + 'x' + canvas.clientHeight + ', offset=' + canvas.offsetWidth + 'x' + canvas.offsetHeight + ', offset=' + canvas.scrollWidth + 'x' + canvas.scrollHeight);
  println('publishData from ' + toString_1(canvasRef) + ' ' + width + 'x' + height);
  var scaleFactor = findDesiredScaleFactor($this);
  var dim = canvas.getBoundingClientRect();
  if ($this.f2b(width, height, scaleFactor)) {
    $this.c2b(canvasRef, width, height, scaleFactor);
    $this.d2b(width, height);
    $this.e2b();
  }
}
function FunctionalCPCanvas$redraw$lambda(this$0) {
  return (it) => {
    paintTheCanvas(this$0);
    return Unit_instance;
  };
}
function FunctionalCPCanvas$nativeComponent$lambda$lambda$lambda(this$0, $canvasRef, $targetContainer) {
  return (_unused_var__etf5q3, _unused_var__etf5q3_0) => {
    publishData(this$0, $canvasRef, $targetContainer);
    return Unit_instance;
  };
}
function FunctionalCPCanvas$nativeComponent$lambda$lambda$lambda_0($targetContainer, this$0) {
  return () => {
    println('Unmount ' + toString_1($targetContainer));
    _get_resizeObserver__wzddgf(this$0).disconnect();
    return Unit_instance;
  };
}
function FunctionalCPCanvas$nativeComponent$lambda$lambda($canvasRef, this$0) {
  return ($this$useEffectWithCleanup) => {
    var targetContainer = ensureNotNull($canvasRef.current);
    println('Mount ' + toString_1(targetContainer));
    var tmp = this$0;
    var tmp0_safe_receiver = $canvasRef.current;
    var tmp_0;
    if (tmp0_safe_receiver == null) {
      tmp_0 = null;
    } else {
      // Inline function 'web.canvas.CanvasRenderingContext2D.Companion.ID' call
      tmp_0 = tmp0_safe_receiver.getContext('2d');
    }
    tmp.m2a_1 = tmp_0;
    var tmp_1 = this$0;
    tmp_1.e2a_1 = new ResizeObserver(FunctionalCPCanvas$nativeComponent$lambda$lambda$lambda(this$0, $canvasRef, targetContainer));
    _get_resizeObserver__wzddgf(this$0).observe(targetContainer);
    new CPInteractiveHandler(targetContainer, this$0.f2a_1, this$0.c2a_1);
    $this$useEffectWithCleanup.push(FunctionalCPCanvas$nativeComponent$lambda$lambda$lambda_0(targetContainer, this$0));
    return Unit_instance;
  };
}
function FunctionalCPCanvas$nativeComponent$lambda$lambda_0($canvasRef) {
  return ($this$canvas) => {
    // Inline function 'web.cssom.ClassName' call
    // Inline function 'js.reflect.unsafeCast' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    $this$canvas.className = 'canvas';
    // Inline function 'js.objects.jso' call
    // Inline function 'js.objects.jso' call
    // Inline function 'kotlin.apply' call
    var this_0 = {};
    // Inline function 'org.mkui.canvas.FunctionalCPCanvas.nativeComponent.<anonymous>.<anonymous>.<anonymous>' call
    // Inline function 'web.cssom.pct' call
    // Inline function 'js.reflect.unsafeCast' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    this_0.width = toString_1(100) + '%';
    // Inline function 'web.cssom.pct' call
    // Inline function 'js.reflect.unsafeCast' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    this_0.height = toString_1(100) + '%';
    $this$canvas.style = this_0;
    $this$canvas.ref = $canvasRef;
    return Unit_instance;
  };
}
function FunctionalCPCanvas$nativeComponent$lambda(this$0) {
  return ($this$FC, it) => {
    var canvasRef = useRef();
    useEffectWithCleanup(FunctionalCPCanvas$nativeComponent$lambda$lambda(canvasRef, this$0));
    // Inline function 'react.dom.html.ReactHTML.canvas' call
    // Inline function 'react.IntrinsicType' call
    // Inline function 'js.reflect.unsafeCast' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    var block = FunctionalCPCanvas$nativeComponent$lambda$lambda_0(canvasRef);
    addChild_1($this$FC, 'canvas', block);
    return Unit_instance;
  };
}
var org_mkui_canvas_JSMouseEvent$stable;
var org_mkui_canvas_ResizeObserver$stable;
function colorOf(r, g, b, a) {
  return CPColor.x2b(r, g, b, a);
}
function colorOf_0(r, g, b, a) {
  return CPColor.y2b(r, g, b, a);
}
function getURed(_this__u8e3s4) {
  return _this__u8e3s4.s2b_1;
}
function getUGreen(_this__u8e3s4) {
  return _this__u8e3s4.t2b_1;
}
function getUBlue(_this__u8e3s4) {
  return _this__u8e3s4.u2b_1;
}
function getUAlpha(_this__u8e3s4) {
  return _this__u8e3s4.v2b_1;
}
function colorOf_1(r, g, b) {
  return CPColor.z2b(r, g, b);
}
function colorOf_2(r, g, b) {
  return CPColor.a2c(r, g, b);
}
function colorOf_3(rgba) {
  return CPColor.b2c(rgba);
}
function colorOf_4(r, g, b) {
  return CPColor.c2c(r, g, b);
}
var org_mkui_color_MkColorFactory$stable;
var Companion_instance_54;
function Companion_getInstance_54() {
  if (Companion_instance_54 === VOID)
    new Companion_54();
  return Companion_instance_54;
}
function MkColorFactory$white$delegate$lambda() {
  return colorOf_4(_UByte___init__impl__g9hnc4(-1), _UByte___init__impl__g9hnc4(-1), _UByte___init__impl__g9hnc4(-1));
}
function MkColorFactory$lightGray$delegate$lambda() {
  return colorOf_4(_UByte___init__impl__g9hnc4(-64), _UByte___init__impl__g9hnc4(-64), _UByte___init__impl__g9hnc4(-64));
}
function MkColorFactory$gray$delegate$lambda() {
  return colorOf_4(_UByte___init__impl__g9hnc4(-128), _UByte___init__impl__g9hnc4(-128), _UByte___init__impl__g9hnc4(-128));
}
function MkColorFactory$darkGray$delegate$lambda() {
  return colorOf_4(_UByte___init__impl__g9hnc4(64), _UByte___init__impl__g9hnc4(64), _UByte___init__impl__g9hnc4(64));
}
function MkColorFactory$black$delegate$lambda() {
  return colorOf_4(_UByte___init__impl__g9hnc4(0), _UByte___init__impl__g9hnc4(0), _UByte___init__impl__g9hnc4(0));
}
function white$factory() {
  return getPropertyCallableRef('white', 1, KProperty1, (receiver) => receiver.n1g(), null);
}
function lightGray$factory() {
  return getPropertyCallableRef('lightGray', 1, KProperty1, (receiver) => receiver.d2c(), null);
}
function gray$factory() {
  return getPropertyCallableRef('gray', 1, KProperty1, (receiver) => receiver.a1j(), null);
}
function darkGray$factory() {
  return getPropertyCallableRef('darkGray', 1, KProperty1, (receiver) => receiver.e2c(), null);
}
function black$factory() {
  return getPropertyCallableRef('black', 1, KProperty1, (receiver) => receiver.f2c(), null);
}
var org_mkui_color_crossplatform_CPColor$stable;
var org_mkui_component_CPComponentWrapper$stable;
var org_mkui_component_CPInteractiveHandler_ElementalMouseEvent$stable;
var org_mkui_component_CPInteractiveHandler_ElementalKeyEvent$stable;
var org_mkui_component_CPInteractiveHandler$stable;
function CPInteractiveHandler$onmousedrag$lambda(this$0) {
  return (it) => {
    var _iterator__ex2g4s = this$0.j2c_1.m1l_1.x();
    while (_iterator__ex2g4s.y()) {
      var mouseMotionListener = _iterator__ex2g4s.z();
      mouseMotionListener.q2c(new JSMouseEvent(it, 0));
    }
    it.stopPropagation();
    return Unit_instance;
  };
}
function CPInteractiveHandler$registerMouseListener$lambda(this$0) {
  return (it) => {
    var _iterator__ex2g4s = this$0.j2c_1.l1l_1.x();
    while (_iterator__ex2g4s.y()) {
      var l = _iterator__ex2g4s.z();
      l.r2c(new JSMouseEvent(it, 0));
      if (this$0.n2c_1) {
        this$0.s2c();
      }
      l.t2c(new JSMouseEvent(it, 0));
    }
    return Unit_instance;
  };
}
function CPInteractiveHandler$registerMouseListener$lambda_0(this$0) {
  return (it) => {
    var tmp;
    if (!this$0.n2c_1) {
      this$0.u2c();
      tmp = Unit_instance;
    }
    var _iterator__ex2g4s = this$0.j2c_1.l1l_1.x();
    while (_iterator__ex2g4s.y()) {
      var l = _iterator__ex2g4s.z();
      l.v2c(new JSMouseEvent(it, 1));
    }
    return Unit_instance;
  };
}
function CPInteractiveHandler$registerMouseListener$lambda_1(this$0) {
  return (it) => {
    var tmp;
    if (!this$0.m2c_1) {
      this$0.m2c_1 = true;
      var tmp_0;
      if (!this$0.n2c_1) {
        var _iterator__ex2g4s = this$0.j2c_1.l1l_1.x();
        while (_iterator__ex2g4s.y()) {
          var l = _iterator__ex2g4s.z();
          l.w2c(new JSMouseEvent(it, 0));
        }
        tmp_0 = Unit_instance;
      }
      tmp = tmp_0;
    }
    return Unit_instance;
  };
}
function CPInteractiveHandler$registerMouseListener$lambda_2(this$0) {
  return (it) => {
    this$0.m2c_1 = false;
    var tmp;
    if (!this$0.n2c_1) {
      var _iterator__ex2g4s = this$0.j2c_1.l1l_1.x();
      while (_iterator__ex2g4s.y()) {
        var l = _iterator__ex2g4s.z();
        l.x2c(new JSMouseEvent(it, 0));
      }
      tmp = Unit_instance;
    }
    return Unit_instance;
  };
}
function CPInteractiveHandler$registerMouseListener$lambda_3(this$0) {
  return (it) => {
    var _iterator__ex2g4s = this$0.j2c_1.l1l_1.x();
    while (_iterator__ex2g4s.y()) {
      var l = _iterator__ex2g4s.z();
      l.v2c(new JSMouseEvent(it, 2));
    }
    return Unit_instance;
  };
}
function CPInteractiveHandler$registerMouseMotionListener$lambda(this$0) {
  return (it) => {
    var tmp0_safe_receiver = this$0.k2c_1;
    if (tmp0_safe_receiver == null)
      null;
    else {
      tmp0_safe_receiver.y18();
    }
    var tmp;
    if (!this$0.n2c_1) {
      var _iterator__ex2g4s = this$0.j2c_1.m1l_1.x();
      while (_iterator__ex2g4s.y()) {
        var l = _iterator__ex2g4s.z();
        l.y2c(new JSMouseEvent(it, 0));
      }
      tmp = Unit_instance;
    }
    var tmp1_safe_receiver = this$0.k2c_1;
    var tmp_0;
    if (tmp1_safe_receiver == null) {
      tmp_0 = null;
    } else {
      tmp1_safe_receiver.z18();
      tmp_0 = Unit_instance;
    }
    return tmp_0;
  };
}
function CPInteractiveHandler$registerMouseWheelListener$lambda(this$0) {
  return (it) => {
    it.preventDefault();
    var _iterator__ex2g4s = this$0.j2c_1.n1l_1.x();
    while (_iterator__ex2g4s.y()) {
      var l = _iterator__ex2g4s.z();
      l.b2d(new CPInteractiveHandler$registerMouseWheelListener$1$1(it));
    }
    return Unit_instance;
  };
}
function CPInteractiveHandler$registerKeyListener$lambda(this$0) {
  return (it) => {
    var code = -1;
    var tmp;
    if (code >= 0) {
      var _iterator__ex2g4s = this$0.j2c_1.o1l_1.x();
      while (_iterator__ex2g4s.y()) {
        var l = _iterator__ex2g4s.z();
        l.c2d(new ElementalKeyEvent(get_keyCode(it)));
      }
      tmp = Unit_instance;
    }
    return Unit_instance;
  };
}
function CPInteractiveHandler$registerContextMenuListener$lambda(this$0) {
  return (it) => {
    it.preventDefault();
    it.stopPropagation();
    var _iterator__ex2g4s = this$0.j2c_1.p1l_1.x();
    while (_iterator__ex2g4s.y()) {
      var l = _iterator__ex2g4s.z();
      l.e2d(new CPInteractiveHandler$registerContextMenuListener$1$1(it));
    }
    return Unit_instance;
  };
}
var org_mkui_component_CPSeparator$stable;
var org_mkui_component_ReactComponent$stable;
var org_mkui_component_absolute_AbsoluteCPContainer$stable;
var org_mkui_component_button_CPButton$stable;
var org_mkui_component_button_CPCheckBox$stable;
var org_mkui_component_button_CPCollapseButton$stable;
var org_mkui_component_button_CPComboBox$stable;
var org_mkui_component_button_CPRadioButtons$stable;
var org_mkui_component_button_CPSplitMenuButton$stable;
var org_mkui_component_button_CPSwitch$stable;
var org_mkui_component_input_CPColorPicker$stable;
var org_mkui_component_input_CPFontPicker$stable;
var org_mkui_component_input_CPSlider$stable;
var org_mkui_component_input_CPSpinner$stable;
var org_mkui_component_label_CPLabel$stable;
var org_mkui_component_list_CPCheckBoxList$stable;
var org_mkui_component_menu_CPMenu$stable;
var org_mkui_component_menu_CPMenuBar$stable;
var org_mkui_component_menu_CPPopupMenu$stable;
var org_mkui_component_panel_CPCollapse$stable;
var org_mkui_component_panel_CPFillMiddlePanel$stable;
var org_mkui_component_panel_CPFormPanel$stable;
var org_mkui_component_panel_CPGridPanel$stable;
var org_mkui_component_panel_CPOverlayPanel$stable;
var org_mkui_component_panel_CPVerticalFlowPanel$stable;
var org_mkui_component_panel_CPVerticalPanel$stable;
var org_mkui_font_CPFontFactory$stable;
var Companion_instance_55;
function Companion_getInstance_55() {
  if (Companion_instance_55 === VOID)
    new Companion_55();
  return Companion_instance_55;
}
function getFontSize(_this__u8e3s4) {
  return _this__u8e3s4.t2d();
}
var org_mkui_font_crossplatform_CPFont$stable;
function _get_name__das4rk($this) {
  var tmp0 = $this.s2d_1;
  // Inline function 'kotlin.getValue' call
  name$factory();
  return tmp0.r2();
}
function CPFont$name$delegate$lambda(this$0) {
  return () => {
    var html = StringBuilder.u();
    if (this$0.q2d_1 === Weight_BOLD_getInstance()) {
      html.lb('bold ');
    } else if (this$0.r2d_1 === Posture_ITALIC_getInstance()) {
      html.lb('italic ');
    } else {
      html.lb('normal ');
    }
    html.lb((this$0.p2d_1 * 72 / 96).toString() + 'pt ');
    var tmp;
    if (!(this$0.o2d_1 == null)) {
      html.lb(this$0.o2d_1);
      tmp = Unit_instance;
    }
    return html.toString();
  };
}
function name$factory() {
  return getPropertyCallableRef('name', 1, KProperty1, (receiver) => _get_name__das4rk(receiver), null);
}
var org_mkui_graphics_CPGraphics$stable;
var org_mkui_graphics_CPGraphicsContext2D$stable;
var org_mkui_graphics_CPImage$stable;
function _get__nativeImage__47l87u($this) {
  return ensureNotNull($this.z2d_1);
}
var org_mkui_graphics_CPImageFactory$stable;
var CPImageFactory_instance;
function CPImageFactory_getInstance() {
  if (CPImageFactory_instance === VOID)
    new CPImageFactory();
  return CPImageFactory_instance;
}
var org_mkui_graphics_CanvasRenderingContext2DTextMetrics$stable;
var org_mkui_react_ReactStateInstance$stable;
var org_mkui_window_CPWindow$stable;
function get_keyCode(_this__u8e3s4) {
  // Inline function 'kotlin.js.asDynamic' call
  return _this__u8e3s4.keyCode;
}
var Companion_instance_56;
function Companion_getInstance_56() {
  return Companion_instance_56;
}
function get_2($this, path) {
  return new Dice(path.slice());
}
var Companion_instance_57;
function Companion_getInstance_57() {
  return Companion_instance_57;
}
function get_3($this, path) {
  return new Dimensions(path.slice());
}
var Companion_instance_58;
function Companion_getInstance_58() {
  return Companion_instance_58;
}
var GroupFactory_instance;
function GroupFactory_getInstance() {
  return GroupFactory_instance;
}
function init_org_molap_aggregates_cube_LinkedGroup(_this__u8e3s4) {
  _this__u8e3s4.r2f_1 = null;
}
var Companion_instance_59;
function Companion_getInstance_59() {
  if (Companion_instance_59 === VOID)
    new Companion_59();
  return Companion_instance_59;
}
var Companion_instance_60;
function Companion_getInstance_60() {
  return Companion_instance_60;
}
function run($this) {
  $this.u2h_1 = false;
  var groups = ArrayList.e1();
  var _iterator__ex2g4s = ensureNotNull(ensureNotNull($this.c2i()).b2h()).x();
  while (_iterator__ex2g4s.y()) {
    var group = _iterator__ex2g4s.z();
    groups.o(group);
  }
  $this.j2i_1 = groups;
}
function init_org_molap_aggregates_query_CuboidQuery(_this__u8e3s4) {
  _this__u8e3s4.f2i_1 = null;
  _this__u8e3s4.g2i_1 = null;
  _this__u8e3s4.h2i_1 = null;
  _this__u8e3s4.j2i_1 = null;
  var tmp = _this__u8e3s4;
  tmp.k2i_1 = new CuboidQuery$queryListener$1(_this__u8e3s4);
  var tmp_0 = _this__u8e3s4;
  tmp_0.l2i_1 = new CuboidQuery$dataFrameListener$1(_this__u8e3s4);
}
function _get_cacheRowIndex__mo0sbb($this) {
  if ($this.u2i_1 == null) {
    // Inline function 'kotlin.arrayOfNulls' call
    var size = ensureNotNull($this.s2i_1.b2h()).a1();
    var groups = fillArrayVal(Array(size), null);
    var i = 0;
    var _iterator__ex2g4s = ensureNotNull($this.s2i_1.b2h()).x();
    while (_iterator__ex2g4s.y()) {
      var g = _iterator__ex2g4s.z();
      var _unary__edvuaz = i;
      i = _unary__edvuaz + 1 | 0;
      groups[_unary__edvuaz] = isInterface(g, Group) ? g : THROW_CCE();
    }
    $this.u2i_1 = DefaultUniqueIndex.y2i(groups.slice());
  }
  return $this.u2i_1;
}
function _get_cacheColumnIndex__9igbhr($this) {
  if ($this.v2i_1 == null) {
    // Inline function 'kotlin.arrayOfNulls' call
    var size = $this.z2i();
    var names = fillArrayVal(Array(size), null);
    var inductionVariable = 0;
    var last = $this.z2i();
    if (inductionVariable < last)
      do {
        var c = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        names[c] = $this.a2j(c);
      }
       while (inductionVariable < last);
    $this.v2i_1 = DefaultUniqueIndex.y2i(names.slice());
  }
  return $this.v2i_1;
}
function get_4($this, path) {
  return new Structure(taggedArrayCopy(path));
}
var Companion_instance_61;
function Companion_getInstance_61() {
  return Companion_instance_61;
}
var Companion_instance_62;
function Companion_getInstance_62() {
  return Companion_instance_62;
}
function AbstractDataFrame$cube$delegate$lambda(this$0) {
  return () => new InMemoryCube(isInterface(this$0, DataFrame) ? this$0 : THROW_CCE());
}
function cube$factory() {
  return getPropertyCallableRef('cube', 1, KProperty1, (receiver) => receiver.w2g(), null);
}
var DataFrameHelper_instance;
function DataFrameHelper_getInstance() {
  return DataFrameHelper_instance;
}
function createSeries($this, dataFrame, column) {
  var columnClass = dataFrame.h2j(column);
  if (columnClass.equals(PrimitiveClasses_getInstance().je())) {
    var values = new Int32Array(dataFrame.g2k());
    var available = booleanArray(dataFrame.g2k());
    var inductionVariable = 0;
    var last = dataFrame.g2k();
    if (inductionVariable < last)
      do {
        var r = inductionVariable;
        inductionVariable = inductionVariable + 1 | 0;
        var tmp = dataFrame.y2j(dataFrame.d2k(r), column);
        var valueAt = (tmp == null ? true : typeof tmp === 'number') ? tmp : THROW_CCE();
        if (!(valueAt == null)) {
          available[r] = true;
          values[r] = valueAt;
        } else {
          available[r] = false;
        }
      }
       while (inductionVariable < last);
    var tmp_0 = Companion_getInstance_64().n2l(values, available);
    return isInterface(tmp_0, MutableSeries) ? tmp_0 : THROW_CCE();
  } else if (columnClass.equals(getKClass(Long))) {
    var values_0 = longArray(dataFrame.g2k());
    var available_0 = booleanArray(dataFrame.g2k());
    var inductionVariable_0 = 0;
    var last_0 = dataFrame.g2k();
    if (inductionVariable_0 < last_0)
      do {
        var r_0 = inductionVariable_0;
        inductionVariable_0 = inductionVariable_0 + 1 | 0;
        var tmp_1 = dataFrame.y2j(dataFrame.d2k(r_0), column);
        var valueAt_0 = (tmp_1 == null ? true : tmp_1 instanceof Long) ? tmp_1 : THROW_CCE();
        if (!(valueAt_0 == null)) {
          available_0[r_0] = true;
          values_0[r_0] = valueAt_0;
        } else {
          available_0[r_0] = false;
        }
      }
       while (inductionVariable_0 < last_0);
    var tmp_2 = Companion_getInstance_64().m2l(values_0, available_0);
    return isInterface(tmp_2, MutableSeries) ? tmp_2 : THROW_CCE();
  } else if (columnClass.equals(PrimitiveClasses_getInstance().ke())) {
    var values_1 = new Float32Array(dataFrame.g2k());
    var available_1 = booleanArray(dataFrame.g2k());
    var inductionVariable_1 = 0;
    var last_1 = dataFrame.g2k();
    if (inductionVariable_1 < last_1)
      do {
        var r_1 = inductionVariable_1;
        inductionVariable_1 = inductionVariable_1 + 1 | 0;
        var tmp_3 = dataFrame.y2j(dataFrame.d2k(r_1), column);
        var valueAt_1 = (tmp_3 == null ? true : typeof tmp_3 === 'number') ? tmp_3 : THROW_CCE();
        if (!(valueAt_1 == null)) {
          available_1[r_1] = true;
          values_1[r_1] = valueAt_1;
        } else {
          available_1[r_1] = false;
        }
      }
       while (inductionVariable_1 < last_1);
    var tmp_4 = Companion_getInstance_64().l2l(values_1, available_1);
    return isInterface(tmp_4, MutableSeries) ? tmp_4 : THROW_CCE();
  } else if (columnClass.equals(PrimitiveClasses_getInstance().le())) {
    var values_2 = new Float64Array(dataFrame.g2k());
    var available_2 = booleanArray(dataFrame.g2k());
    var inductionVariable_2 = 0;
    var last_2 = dataFrame.g2k();
    if (inductionVariable_2 < last_2)
      do {
        var r_2 = inductionVariable_2;
        inductionVariable_2 = inductionVariable_2 + 1 | 0;
        var tmp_5 = dataFrame.y2j(dataFrame.d2k(r_2), column);
        var valueAt_2 = (tmp_5 == null ? true : typeof tmp_5 === 'number') ? tmp_5 : THROW_CCE();
        if (!(valueAt_2 == null)) {
          available_2[r_2] = true;
          values_2[r_2] = valueAt_2;
        } else {
          available_2[r_2] = false;
        }
      }
       while (inductionVariable_2 < last_2);
    var tmp_6 = Companion_getInstance_64().k2l(values_2, available_2);
    return isInterface(tmp_6, Series) ? tmp_6 : THROW_CCE();
  } else {
    var tmp_7 = 0;
    var tmp_8 = dataFrame.g2k();
    // Inline function 'kotlin.arrayOfNulls' call
    var tmp_9 = fillArrayVal(Array(tmp_8), null);
    while (tmp_7 < tmp_8) {
      var tmp_10 = tmp_7;
      var tmp_11 = dataFrame.y2j(dataFrame.d2k(tmp_10), column);
      var valueAt_3 = (tmp_11 == null ? true : !(tmp_11 == null)) ? tmp_11 : THROW_CCE();
      var tmp_12;
      if (!(valueAt_3 === Companion_getInstance_59().q2h_1)) {
        tmp_12 = valueAt_3;
      } else {
        tmp_12 = null;
      }
      tmp_9[tmp_10] = tmp_12;
      tmp_7 = tmp_7 + 1 | 0;
    }
    var values_3 = tmp_9;
    var tmp_13 = Companion_getInstance_64().j2l(values_3, columnClass);
    return isInterface(tmp_13, Series) ? tmp_13 : THROW_CCE();
  }
}
function DefaultUniqueIndex$Lazy$indexDelegate$lambda(this$0) {
  return () => this$0.m2m();
}
function DefaultUniqueIndex$Lazy$listDelegate$lambda(this$0) {
  return () => this$0.n2m();
}
var Companion_instance_63;
function Companion_getInstance_63() {
  return Companion_instance_63;
}
function init_org_molap_index_DefaultUniqueIndex(_this__u8e3s4) {
}
function index$factory() {
  return getPropertyCallableRef('index', 1, KProperty1, (receiver) => receiver.o2m(), null);
}
function list$factory() {
  return getPropertyCallableRef('list', 1, KProperty1, (receiver) => receiver.b1c(), null);
}
var Duplicate_RemoveFirst_instance;
var Duplicate_RemoveLast_instance;
var Duplicate_UseFirst_instance;
var Duplicate_UseFirstWarn_instance;
var Duplicate_UseLast_instance;
var Duplicate_ThrowException_instance;
var Duplicate_entriesInitialized;
function Duplicate_initEntries() {
  if (Duplicate_entriesInitialized)
    return Unit_instance;
  Duplicate_entriesInitialized = true;
  Duplicate_RemoveFirst_instance = new Duplicate('RemoveFirst', 0);
  Duplicate_RemoveLast_instance = new Duplicate('RemoveLast', 1);
  Duplicate_UseFirst_instance = new Duplicate('UseFirst', 2);
  Duplicate_UseFirstWarn_instance = new Duplicate('UseFirstWarn', 3);
  Duplicate_UseLast_instance = new Duplicate('UseLast', 4);
  Duplicate_ThrowException_instance = new Duplicate('ThrowException', 5);
}
function Duplicate_UseFirstWarn_getInstance() {
  Duplicate_initEntries();
  return Duplicate_UseFirstWarn_instance;
}
function init_org_molap_series_DefaultSeries(_this__u8e3s4) {
}
function init_org_molap_series_DoubleSeries(_this__u8e3s4) {
}
function init_org_molap_series_FloatSeries(_this__u8e3s4) {
}
function init_org_molap_series_IntegerSeries(_this__u8e3s4) {
}
function init_org_molap_series_LongSeries(_this__u8e3s4) {
}
function buildInteger($this, values, available) {
  return IntegerSeries.z2n(values, available);
}
function buildLong($this, values, available) {
  return LongSeries.e2o(values, available);
}
function buildFloat($this, values, available) {
  return FloatSeries.u2n(values, available);
}
function buildDouble($this, values, available) {
  return DoubleSeries.o2n(values, available);
}
function build($this, values, type) {
  return DefaultSeries.j2n(values, VOID, type);
}
var Companion_instance_64;
function Companion_getInstance_64() {
  if (Companion_instance_64 === VOID)
    new Companion_64();
  return Companion_instance_64;
}
function getObject($this, value) {
  var tmp;
  if (!(value == null)) {
    var tmp_0;
    if (!(value == null) ? typeof value === 'string' : false) {
      tmp_0 = typeof value === 'string' ? value : THROW_CCE();
    } else {
      if (isNumber(value)) {
        tmp_0 = isNumber(value) ? value : THROW_CCE();
      } else {
        if (!(value == null) ? typeof value === 'boolean' : false) {
          tmp_0 = typeof value === 'boolean' ? value : THROW_CCE();
        } else {
          if (!(value == null) ? isArray(value) : false) {
            var array = isArray(value) ? value : THROW_CCE();
            // Inline function 'kotlin.arrayOfNulls' call
            var size = array.length;
            var a = fillArrayVal(Array(size), null);
            var inductionVariable = 0;
            var last = array.length;
            if (inductionVariable < last)
              do {
                var i = inductionVariable;
                inductionVariable = inductionVariable + 1 | 0;
                a[i] = getObject($this, array[i]);
              }
               while (inductionVariable < last);
            tmp_0 = a;
          } else {
            if (!(value == null) ? isInterface(value, KtMap) : false) {
              tmp_0 = isInterface(value, KtMap) ? value : THROW_CCE();
            } else {
              if (value == null) {
                tmp_0 = null;
              } else {
                tmp_0 = toString_1(value);
              }
            }
          }
        }
      }
    }
    tmp = tmp_0;
  } else {
    tmp = null;
  }
  return tmp;
}
function getClass($this, value) {
  var tmp;
  if (value == null) {
    tmp = null;
  } else {
    if (!(value == null) ? typeof value === 'string' : false) {
      tmp = PrimitiveClasses_getInstance().ne();
    } else {
      if (!(value == null) ? typeof value === 'number' : false) {
        tmp = PrimitiveClasses_getInstance().le();
      } else {
        if (!(value == null) ? typeof value === 'boolean' : false) {
          tmp = PrimitiveClasses_getInstance().ge();
        } else {
          if (!(value == null) ? isArray(value) : false) {
            tmp = PrimitiveClasses_getInstance().me();
          } else {
            if (!(value == null) ? isInterface(value, KtMap) : false) {
              tmp = getKClass(KtMap);
            } else {
              tmp = PrimitiveClasses_getInstance().ne();
            }
          }
        }
      }
    }
  }
  return tmp;
}
function JsonDataFrame$rowIndex$delegate$lambda(this$0) {
  return () => IntegerRangeUniqueIndex.v2l(0, this$0.h2o_1.length - 1 | 0);
}
function JsonDataFrame$columnIndex$delegate$lambda(this$0) {
  return () => {
    // Inline function 'kotlin.collections.copyOf' call
    // Inline function 'kotlin.js.asDynamic' call
    var tmp$ret$1 = this$0.i2o_1.slice();
    return DefaultUniqueIndex.y2i(tmp$ret$1.slice());
  };
}
function rowIndex$factory() {
  return getPropertyCallableRef('rowIndex', 1, KProperty1, (receiver) => receiver.t2j(), null);
}
function columnIndex$factory() {
  return getPropertyCallableRef('columnIndex', 1, KProperty1, (receiver) => receiver.u2j(), null);
}
var com_treemap_AbsScale$stable;
var com_treemap_AbstractAlgorithm$stable;
var com_treemap_AbstractLabeling$stable;
function calcSignedPolygonArea($this, points) {
  var N = points.length;
  var i;
  var j;
  var area = 0.0;
  i = 0;
  while (i < N) {
    j = (i + 1 | 0) % N | 0;
    area = area + points[i].w1l() * points[j].x1l();
    area = area - points[i].x1l() * points[j].w1l();
    i = i + 1 | 0;
  }
  area = area / 2.0;
  return area;
}
var Companion_instance_65;
function Companion_getInstance_65() {
  return Companion_instance_65;
}
var com_treemap_AbstractNesting$stable;
var Companion_instance_66;
function Companion_getInstance_66() {
  return Companion_instance_66;
}
var com_treemap_AbstractNodeRenderer$stable;
var com_treemap_AbstractRendering$stable;
var Companion_instance_67;
function Companion_getInstance_67() {
  return Companion_instance_67;
}
function computeBounds($this, shape) {
  var tmp;
  if (isInterface(shape, Rectangle2D)) {
    var bounds = shape.y1l();
    tmp = Rectangle.from(numberToInt(bounds.w1l()), numberToInt(bounds.x1l()), numberToInt(bounds.cm()), numberToInt(bounds.dm()));
  } else {
    var bounds_0 = shape.y1l();
    var tmp_0 = bounds_0.cm();
    // Inline function 'kotlin.math.sqrt' call
    var tmp$ret$0 = Math.sqrt(2.0);
    var halfWidth = numberToInt(tmp_0 / tmp$ret$0);
    var tmp_1 = bounds_0.dm();
    // Inline function 'kotlin.math.sqrt' call
    var tmp$ret$1 = Math.sqrt(2.0);
    var halfHeight = numberToInt(tmp_1 / tmp$ret$1);
    tmp = Rectangle.from(numberToInt(bounds_0.w1l() + (bounds_0.cm() - halfWidth) / 2), numberToInt(bounds_0.x1l() + (bounds_0.dm() - halfHeight) / 2), halfWidth, halfHeight);
  }
  return tmp;
}
var com_treemap_AbstractTreeMap$stable;
var Companion_instance_68;
function Companion_getInstance_68() {
  return Companion_instance_68;
}
var com_treemap_AbstractTreeMapColumnSettings$stable;
var Companion_instance_69;
function Companion_getInstance_69() {
  return Companion_instance_69;
}
var com_treemap_AbstractTreeMapController$stable;
var Mode_Selection_instance;
var Mode_Zooming_instance;
var Mode_Panning_instance;
var Mode_entriesInitialized_1;
function Mode_initEntries_1() {
  if (Mode_entriesInitialized_1)
    return Unit_instance;
  Mode_entriesInitialized_1 = true;
  Mode_Selection_instance = new Mode_1('Selection', 0);
  Mode_Zooming_instance = new Mode_1('Zooming', 1);
  Mode_Panning_instance = new Mode_1('Panning', 2);
}
function setSelection($this, observation) {
  if (!(observation == null)) {
    ensureNotNull(ensureNotNull($this.x2t_1.k2t_1).j2p()).selection.i13([observation]);
  } else {
    ensureNotNull(ensureNotNull($this.x2t_1.k2t_1).j2p()).selection.e13();
  }
}
function addToSelection($this, observation) {
  ensureNotNull(ensureNotNull($this.x2t_1.k2t_1).j2p()).selection.g13(observation, true);
}
function addToSelection_0($this, newSelection) {
  ensureNotNull(ensureNotNull($this.x2t_1.k2t_1).j2p()).selection.h13(newSelection, true);
}
function zoom($this, amount, xCenter, yCenter) {
  var xCenter_0 = xCenter;
  var yCenter_0 = yCenter;
  if ($this.o2t_1) {
    var viewport = ensureNotNull($this.k2t_1).y2t();
    var world = ensureNotNull($this.k2t_1).z2t();
    if (!(yCenter_0 == null)) {
      yCenter_0 = world.j1m() - yCenter_0;
    }
    if ($this.p2t_1) {
      var normalizedXCenter = normalize($this, xCenter_0, world.f1m(), world.i1m());
      var normalizedYCenter = normalize($this, yCenter_0, world.h1m(), world.j1m());
      xCenter_0 = denormalize($this, $this.a2u(normalizedXCenter), world.f1m(), world.i1m());
      yCenter_0 = denormalize($this, $this.a2u(normalizedYCenter), world.h1m(), world.j1m());
    }
    var xRange = (new Range($this, amount, xCenter_0, viewport.f1m(), viewport.cm(), world.f1m(), world.i1m(), ensureNotNull($this.k2t_1).a1().cm())).l2u();
    var xMin = xRange.m2u();
    var xMax = xRange.n2u();
    var yRange = (new Range($this, amount, yCenter_0, viewport.h1m(), viewport.dm(), world.h1m(), world.j1m(), ensureNotNull($this.k2t_1).a1().dm())).l2u();
    var yMin = yRange.m2u();
    var yMax = yRange.n2u();
    if (xMin < xMax && yMin < yMax) {
      ensureNotNull($this.k2t_1).o2u(false, xMin, xMax, yMin, yMax);
    }
  }
}
function normalize($this, center, min, extent) {
  return (center - min) / extent * 2.0 - 1.0;
}
function denormalize($this, x, min, extent) {
  return min + extent * ((x + 1.0) / 2.0);
}
function openPopupMenu($this, e) {
  var popupMenu = new CPPopupMenu();
  var x = e.w1l();
  var y = e.x1l();
  var drillDownCommand = AbstractTreeMapController$openPopupMenu$drillDownCommand$1.x2u($this, x, y);
  var drillUpCommand = AbstractTreeMapController$openPopupMenu$drillUpCommand$1.e2v($this);
  var zoomInCommand = AbstractTreeMapController$openPopupMenu$zoomInCommand$1.l2v($this);
  var zoomOutCommand = AbstractTreeMapController$openPopupMenu$zoomOutCommand$1.s2v($this);
  popupMenu.l2d(drillDownCommand);
  popupMenu.l2d(drillUpCommand);
  popupMenu.l2d(zoomInCommand);
  popupMenu.l2d(zoomOutCommand);
  popupMenu.m2d(ensureNotNull($this.k2t_1).r2r(), x, y);
}
function Mode_Selection_getInstance() {
  Mode_initEntries_1();
  return Mode_Selection_instance;
}
function Mode_Zooming_getInstance() {
  Mode_initEntries_1();
  return Mode_Zooming_instance;
}
function Mode_Panning_getInstance() {
  Mode_initEntries_1();
  return Mode_Panning_instance;
}
var com_treemap_AbstractTreeMapModel$stable;
function cancelDoUpdate($this) {
  if ($this.d2x_1) {
    if (!($this.worker == null)) {
      ensureNotNull($this.worker).c18();
    }
    if (!($this.workerFuture == null)) {
      ensureNotNull($this.workerFuture).c17(true);
    }
  } else {
    if (!($this.worker == null)) {
      ensureNotNull($this.worker).c18();
    }
  }
}
function getValues($this, node, column) {
  var count = 0;
  var _iterator__ex2g4s = $this.preorderEnumeration(node).x();
  while (_iterator__ex2g4s.y()) {
    var child = _iterator__ex2g4s.z();
    if ($this.c2y(child) && !$this.filter.ol(child) && !$this.search.ol(child)) {
      var tmp = $this.getValueAt(child, column);
      var value = (tmp == null ? true : isNumber(tmp)) ? tmp : THROW_CCE();
      if (!(value == null)) {
        count = count + 1 | 0;
      }
    }
  }
  var sizes = new Float64Array(count);
  var i = 0;
  var _iterator__ex2g4s_0 = $this.preorderEnumeration(node).x();
  while (_iterator__ex2g4s_0.y()) {
    var child_0 = _iterator__ex2g4s_0.z();
    if ($this.c2y(child_0) && !$this.filter.ol(child_0) && !$this.search.ol(child_0)) {
      var tmp_0 = $this.getValueAt(child_0, column);
      var value_0 = (tmp_0 == null ? true : isNumber(tmp_0)) ? tmp_0 : THROW_CCE();
      if (!(value_0 == null) && i < sizes.length) {
        sizes[i] = numberToDouble(value_0);
        i = i + 1 | 0;
      }
    }
  }
  return sizes;
}
function getSizeWeightedValues($this, node, column) {
  var count = 0;
  var _iterator__ex2g4s = $this.preorderEnumeration(node).x();
  while (_iterator__ex2g4s.y()) {
    var child = _iterator__ex2g4s.z();
    if ($this.c2y(child) && !$this.filter.ol(child)) {
      var tmp = $this.getValueAt(child, column);
      var value = (tmp == null ? true : isNumber(tmp)) ? tmp : THROW_CCE();
      if (!(value == null)) {
        count = count + 1 | 0;
      }
    }
  }
  var sizes = new Float64Array(count);
  var i = 0;
  var sumSize = $this.getSumSize(node);
  var _iterator__ex2g4s_0 = $this.preorderEnumeration(node).x();
  while (_iterator__ex2g4s_0.y()) {
    var child_0 = _iterator__ex2g4s_0.z();
    if ($this.c2y(child_0) && !$this.filter.ol(child_0)) {
      var tmp_0 = $this.getValueAt(child_0, column);
      var value_0 = (tmp_0 == null ? true : isNumber(tmp_0)) ? tmp_0 : THROW_CCE();
      if (!(value_0 == null) && i < sizes.length) {
        sizes[i] = numberToDouble(value_0) * child_0.a1() / sumSize;
        i = i + 1 | 0;
      }
    }
  }
  return sizes;
}
function visit($this, node, p) {
  var _iterator__ex2g4s = $this.getChildren(node).x();
  while (_iterator__ex2g4s.y()) {
    var child = _iterator__ex2g4s.z();
    var shape = $this.l2y(child);
    if (shape == null && !$this.c2y(node)) {
      var visit_0 = visit($this, child, p);
      if (!(visit_0 === child)) {
        return visit_0;
      }
    } else if (contains_3($this, p, ensureNotNull(shape))) {
      return visit($this, child, p);
    }
  }
  return node;
}
function contains_3($this, p, shape) {
  var tmp;
  if (shape instanceof TextShape) {
    tmp = shape.y1l().z1l(Double_2.s1p(p.w1l(), p.x1l()));
  } else {
    tmp = shape.z1l(Double_2.s1p(p.w1l(), p.x1l()));
  }
  return tmp;
}
function getSelf($this) {
  return $this;
}
var Companion_instance_70;
function Companion_getInstance_70() {
  return Companion_instance_70;
}
var com_treemap_AbstractTreeMapNode$stable;
function createCushionImage($this) {
  if ($this.e33() == null)
    return null;
  var bounds;
  var tmp = $this.e33();
  if (tmp instanceof Rectangle) {
    var tmp_0 = $this.e33();
    bounds = tmp_0 instanceof Rectangle ? tmp_0 : THROW_CCE();
  } else {
    var b = ensureNotNull($this.e33()).y1l();
    bounds = Rectangle.from(numberToInt(b.w1l()), numberToInt(b.x1l()), numberToInt(b.cm()), numberToInt(b.dm()));
  }
  // Inline function 'kotlin.math.max' call
  var b_0 = bounds.s20_1;
  var width = Math.max(1, b_0);
  // Inline function 'kotlin.math.max' call
  var b_1 = bounds.t20_1;
  var height = Math.max(1, b_1);
  var image = new CPImage(width, height);
  ensureNotNull($this.q33()).s33($this.f2y_1, $this.e2z(), bounds.q20_1, bounds.r20_1, width, height, image);
  return image;
}
var com_treemap_AbstractTreeMapSettings$stable;
var Companion_instance_71;
function Companion_getInstance_71() {
  return Companion_instance_71;
}
var com_treemap_AbstractTreeMapToolTip$stable;
var Companion_instance_72;
function Companion_getInstance_72() {
  return Companion_instance_72;
}
var com_treemap_AbstractTreeMapView$stable;
function getXCoordinateAxis($this) {
  return $this.r37_1.w1l();
}
function getYCoordinateAxis($this) {
  return $this.r37_1.x1l();
}
function visit_0($this, model, node, p) {
  var _iterator__ex2g4s = model.getChildren(node).x();
  while (_iterator__ex2g4s.y()) {
    var child = _iterator__ex2g4s.z();
    if (!model.filter.ol(child)) {
      var shape = $this.l37(child);
      var depth = model.getLevel(node) - model.getLevel(ensureNotNull(model.currentRoot)) | 0;
      var algorithm = model.settings.getColumnSettings(model.getGroupByColumn(node)).getAlgorithm();
      if (ensureNotNull(model.settings.getDepth()).p2q(depth + 1 | 0) && algorithm.y2o(model.getShape(node))) {
        if (shape == null && !model.hasNoChildren(node)) {
          var visit = visit_0($this, model, child, p);
          if (!(visit === child)) {
            return visit;
          }
        } else if ($this.p38(p, shape)) {
          return visit_0($this, model, child, p);
        } else if (!model.settings.getColumnSettings(model.getGroupByColumn(node)).getAlgorithm().v2o()) {
          if ($this.p38(p, shape)) {
            return child;
          } else {
            var visit_1 = visit_0($this, model, child, p);
            if (!(visit_1 === child)) {
              return visit_1;
            }
          }
        }
      }
    }
  }
  return node;
}
function visit_1($this, model, node, rect, list) {
  var _iterator__ex2g4s = model.getChildren(node).x();
  while (_iterator__ex2g4s.y()) {
    var child = _iterator__ex2g4s.z();
    var shape = $this.l37(child);
    if (!(shape == null) && shape.b1m(rect)) {
      if (model.hasNoChildren(child)) {
        list.o(child);
      }
      visit_1($this, model, child, rect, list);
    }
  }
  return node;
}
var com_treemap_AggregationFactory$stable;
var Companion_instance_73;
function Companion_getInstance_73() {
  if (Companion_instance_73 === VOID)
    new Companion_73();
  return Companion_instance_73;
}
var com_treemap_AlgorithmFactory$stable;
var Companion_instance_74;
function Companion_getInstance_74() {
  if (Companion_instance_74 === VOID)
    new Companion_74();
  return Companion_instance_74;
}
var com_treemap_AverageAggregation$stable;
var com_treemap_BackgroundParentNodeRenderer$stable;
var com_treemap_BackgroundRootNodeTreeMapRenderer$stable;
var com_treemap_BarAlgorithm$stable;
var Orientation_Vertical_instance;
var Orientation_Horizontal_instance;
var Orientation_entriesInitialized;
function Orientation_initEntries() {
  if (Orientation_entriesInitialized)
    return Unit_instance;
  Orientation_entriesInitialized = true;
  Orientation_Vertical_instance = new Orientation('Vertical', 0);
  Orientation_Horizontal_instance = new Orientation('Horizontal', 1);
}
function Orientation_Horizontal_getInstance() {
  Orientation_initEntries();
  return Orientation_Horizontal_instance;
}
var com_treemap_BinaryTreeAlgorithm$stable;
var com_treemap_BorderParentNodeRenderer$stable;
var com_treemap_BreadthFirstIterator$stable;
var com_treemap_CirclePackingAlgorithm_Circle$stable;
var com_treemap_CirclePackingAlgorithm$stable;
function init_com_treemap_CirclePackingAlgorithm_Circle(_this__u8e3s4) {
  _this__u8e3s4.j3e_1 = 0.0;
  _this__u8e3s4.k3e_1 = 0.0;
  _this__u8e3s4.l3e_1 = 0.0;
}
function distance($this, circle1, circle2) {
  var x1 = circle1.j3e_1;
  var y1 = circle1.k3e_1;
  var r1 = circle1.l3e_1;
  var x2 = circle2.j3e_1;
  var y2 = circle2.k3e_1;
  var r2 = circle2.l3e_1;
  var x = x2 - x1;
  var y = y2 - y1;
  // Inline function 'kotlin.math.sqrt' call
  var x_0 = x * x + y * y;
  return Math.sqrt(x_0) - r1 - r2;
}
function get_hole_degree($this, candidate, placed_circles, pc1, pc2) {
  var lsq = 0.0;
  var _iterator__ex2g4s = placed_circles.x();
  $l$loop_0: while (_iterator__ex2g4s.y()) {
    var pc = _iterator__ex2g4s.z();
    if (!(pc1 == null) && equals(pc1, pc)) {
      continue $l$loop_0;
    }
    if (!(pc2 == null) && equals(pc2, pc)) {
      continue $l$loop_0;
    }
    var tmp = lsq;
    // Inline function 'kotlin.math.pow' call
    var this_0 = candidate.k3e_1 - pc.k3e_1;
    var tmp_0 = Math.pow(this_0, 2.0);
    // Inline function 'kotlin.math.pow' call
    var this_1 = candidate.j3e_1 - pc.j3e_1;
    // Inline function 'kotlin.math.sqrt' call
    var x = tmp_0 + Math.pow(this_1, 2.0);
    lsq = tmp + Math.sqrt(x);
  }
  // Inline function 'kotlin.math.sqrt' call
  var x_0 = lsq;
  return -Math.sqrt(x_0);
}
function get_placement_candidates($this, radius, c1, c2, margin) {
  var ic1;
  var ic2;
  ic1 = Circle.m3e(ensureNotNull(c1).j3e_1, c1.k3e_1, c1.l3e_1 + (radius + margin));
  ic2 = Circle.m3e(ensureNotNull(c2).j3e_1, c2.k3e_1, c2.l3e_1 + (radius + margin));
  var i = get_intersection($this, ic1, ic2);
  var i1 = i[0];
  var i2 = i[1];
  if (i1 == null) {
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    return [null, null];
  }
  var i1_x = i1.w1l();
  var i1_y = i1.x1l();
  var candidate1;
  candidate1 = Circle.m3e(i1_x, i1_y, radius);
  if (i2 == null) {
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    return [candidate1, null];
  }
  var i2_x = i2.w1l();
  var i2_y = i2.x1l();
  var candidate2;
  candidate2 = Circle.m3e(i2_x, i2_y, radius);
  // Inline function 'kotlin.arrayOf' call
  // Inline function 'kotlin.js.unsafeCast' call
  // Inline function 'kotlin.js.asDynamic' call
  return [candidate1, candidate2];
}
function get_intersection($this, circle1, circle2) {
  var x1 = ensureNotNull(circle1).j3e_1;
  var y1 = circle1.k3e_1;
  var r1 = circle1.l3e_1;
  var x2 = ensureNotNull(circle2).j3e_1;
  var y2 = circle2.k3e_1;
  var r2 = circle2.l3e_1;
  var dx = x2 - x1;
  var dy = y2 - y1;
  // Inline function 'kotlin.math.sqrt' call
  var x = dx * dx + dy * dy;
  var d = Math.sqrt(x);
  if (d > r1 + r2) {
    println('no solution, the circles are separate: ' + toString_0(circle1) + ', ' + toString_0(circle2));
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    return [null, null];
  }
  // Inline function 'kotlin.math.abs' call
  var x_0 = r1 - r2;
  if (d < Math.abs(x_0)) {
    println('no solution, circles contained within each other: ' + toString_0(circle1) + ', ' + toString_0(circle2));
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    return [null, null];
  }
  if (d === 0.0 && r1 === r2) {
    println('no solution, circles are coincident: ' + toString_0(circle1) + ', ' + toString_0(circle2));
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    return [null, null];
  }
  var a = (r1 * r1 - r2 * r2 + d * d) / (2 * d);
  // Inline function 'kotlin.math.sqrt' call
  var x_1 = r1 * r1 - a * a;
  var h = Math.sqrt(x_1);
  var xm = x1 + a * dx / d;
  var ym = y1 + a * dy / d;
  var xs1 = xm + h * dy / d;
  var xs2 = xm - h * dy / d;
  var ys1 = ym - h * dx / d;
  var ys2 = ym + h * dx / d;
  var tmp;
  if (xs1 === xs2 && ys1 === ys2) {
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp = [Double_2.s1p(xs1, ys1), null];
  } else {
    // Inline function 'kotlin.arrayOf' call
    // Inline function 'kotlin.js.unsafeCast' call
    // Inline function 'kotlin.js.asDynamic' call
    tmp = [Double_2.s1p(xs1, ys1), Double_2.s1p(xs2, ys2)];
  }
  return tmp;
}
function outerSoddyCircle($this, circleA, circleB, circleC) {
  var ra = circleA.l3e_1;
  var rb = circleB.l3e_1;
  var rc = circleC.l3e_1;
  var k1;
  var k2;
  var k3;
  var k4;
  k1 = 1 / ra;
  k2 = 1 / rb;
  k3 = 1 / rc;
  var tmp = k1 + k2 + k3;
  // Inline function 'kotlin.math.sqrt' call
  var x = k1 * k2 + k2 * k3 + k3 * k1;
  // Inline function 'kotlin.math.abs' call
  var x_0 = tmp - 2 * Math.sqrt(x);
  k4 = Math.abs(x_0);
  var q1;
  var q2;
  var q3;
  var q4;
  q1 = (new Complex(k1, 0.0)).p3e(new Complex(circleA.j3e_1, circleA.k3e_1));
  q2 = (new Complex(k2, 0.0)).p3e(new Complex(circleB.j3e_1, circleB.k3e_1));
  q3 = (new Complex(k3, 0.0)).p3e(new Complex(circleC.j3e_1, circleC.k3e_1));
  q4 = q1.q3e(q2).q3e(q3).r3e((new Complex(2.0, 0.0)).p3e(q1.p3e(q2).q3e(q2.p3e(q3)).q3e(q3.p3e(q1)).xv()));
  var z = q4.s3e(new Complex(k4, 0.0));
  var tmp_0;
  if (z.w3e() || isNaN_3(1 / k4)) {
    tmp_0 = Circle.v3e();
  } else {
    tmp_0 = Circle.m3e(-z.t3e(), -z.u3e(), 1 / k4);
  }
  return tmp_0;
}
function boundingCircle($this, circles) {
  var outerSoddy = null;
  if (circles.a1() >= 3) {
    outerSoddy = outerSoddyCircle($this, circles.b1(0), circles.b1(1), circles.b1(2));
    var _iterator__ex2g4s = circles.x();
    while (_iterator__ex2g4s.y()) {
      var c = _iterator__ex2g4s.z();
      // Inline function 'kotlin.math.sqrt' call
      var x = (outerSoddy.j3e_1 - c.j3e_1) * (outerSoddy.j3e_1 - c.j3e_1) + (outerSoddy.k3e_1 - c.k3e_1) * (outerSoddy.k3e_1 - c.k3e_1);
      var dist = Math.sqrt(x);
      var tmp = outerSoddy;
      var tmp1 = outerSoddy.l3e_1;
      // Inline function 'kotlin.math.max' call
      var b = dist + c.l3e_1;
      tmp.l3e_1 = Math.max(tmp1, b);
    }
  }
  var bbox = boundingBox($this, circles);
  var tmp_0 = bbox.a1m();
  var tmp_1 = bbox.c1m();
  var tmp3 = bbox.cm();
  // Inline function 'kotlin.math.max' call
  var b_0 = bbox.dm();
  var tmp$ret$2 = Math.max(tmp3, b_0);
  var bc = Circle.m3e(tmp_0, tmp_1, tmp$ret$2 / 2);
  var _iterator__ex2g4s_0 = circles.x();
  while (_iterator__ex2g4s_0.y()) {
    var c_0 = _iterator__ex2g4s_0.z();
    // Inline function 'kotlin.math.sqrt' call
    var x_0 = (bc.j3e_1 - c_0.j3e_1) * (bc.j3e_1 - c_0.j3e_1) + (bc.k3e_1 - c_0.k3e_1) * (bc.k3e_1 - c_0.k3e_1);
    var dist_0 = Math.sqrt(x_0);
    var tmp_2 = bc;
    var tmp6 = bc.l3e_1;
    // Inline function 'kotlin.math.max' call
    var b_1 = dist_0 + c_0.l3e_1;
    tmp_2.l3e_1 = Math.max(tmp6, b_1);
  }
  return outerSoddy == null || bc.l3e_1 < outerSoddy.l3e_1 ? bc : outerSoddy;
}
function boundingBox($this, circles) {
  var minx = 1.7976931348623157E308;
  var maxx = 4.9E-324;
  var miny = 1.7976931348623157E308;
  var maxy = 4.9E-324;
  var _iterator__ex2g4s = circles.x();
  while (_iterator__ex2g4s.y()) {
    var c = _iterator__ex2g4s.z();
    var tmp0 = minx;
    // Inline function 'kotlin.math.min' call
    var b = c.j3e_1 - c.l3e_1;
    minx = Math.min(tmp0, b);
    var tmp2 = maxx;
    // Inline function 'kotlin.math.max' call
    var b_0 = c.j3e_1 + c.l3e_1;
    maxx = Math.max(tmp2, b_0);
    var tmp4 = miny;
    // Inline function 'kotlin.math.min' call
    var b_1 = c.k3e_1 - c.l3e_1;
    miny = Math.min(tmp4, b_1);
    var tmp6 = maxy;
    // Inline function 'kotlin.math.max' call
    var b_2 = c.k3e_1 + c.l3e_1;
    maxy = Math.max(tmp6, b_2);
  }
  return Double_3.p1m(minx, miny, maxx - minx, maxy - miny);
}
function computeBoundingBox($this, children, accessor) {
  var circles = ArrayList.e1();
  var inductionVariable = 0;
  var last = children.length;
  while (inductionVariable < last) {
    var child = children[inductionVariable];
    inductionVariable = inductionVariable + 1 | 0;
    var shape = accessor.getShape(child);
    var tmp;
    if (!(shape == null)) {
      tmp = !(shape == null) ? isInterface(shape, Ellipse2D) : false;
    } else {
      tmp = false;
    }
    if (tmp) {
      var ellipse2D = shape;
      var circle = Circle.m3e(ellipse2D.a1m(), ellipse2D.c1m(), ellipse2D.cm() / 2);
      circles.o(circle);
    }
  }
  var tmp_0;
  if (circles.a1() > 0) {
    var circle_0 = boundingCircle(Companion_instance_75, circles);
    var b = circle_0.x3e();
    tmp_0 = Double_3.p1m(b.w1l(), b.x1l(), b.cm(), b.dm()).y1l();
  } else {
    tmp_0 = null;
  }
  return tmp_0;
}
var Companion_instance_75;
function Companion_getInstance_75() {
  return Companion_instance_75;
}
var com_treemap_CircularAlgorithm$stable;
function init_com_treemap_CircularAlgorithm_Pair(_this__u8e3s4) {
  _this__u8e3s4.n3f_1 = 1.7976931348623157E308;
}
function init_com_treemap_CircularAlgorithm_Circle(_this__u8e3s4) {
  _this__u8e3s4.o3f_1 = 0.0;
  _this__u8e3s4.p3f_1 = 0.0;
  _this__u8e3s4.q3f_1 = 0.0;
}
function pairPack($this, circles) {
  var error = 0.01;
  switch (circles.a1()) {
    case 0:
      break;
    case 1:
      var circle = circles.b1(0);
      circle.o3f_1 = 0.0;
      circle.p3f_1 = 0.0;
      break;
    case 2:
      var c0 = circles.b1(0);
      var c1 = circles.b1(1);
      var radius = c0.q3f_1 + c1.q3f_1;
      c0.o3f_1 = c0.q3f_1 - radius;
      c1.o3f_1 = radius - c1.q3f_1;
      c1.p3f_1 = 0.0;
      c0.p3f_1 = c1.p3f_1;
      break;
    case 4:
      // Inline function 'kotlin.run' call

      // Inline function 'com.treemap.Companion.pairPack.<anonymous>' call

      var sorted = ArrayList.l(circles);
      sort(sorted);
      if (sorted.b1(0).q3f_1 / sorted.b1(3).q3f_1 < 1.3) {
        var c0_0 = sorted.b1(0);
        var c1_0 = sorted.b1(1);
        var c2 = sorted.b1(2);
        var c3 = sorted.b1(3);
        c0_0.p3f_1 = -c0_0.q3f_1;
        c0_0.o3f_1 = c0_0.p3f_1;
        c1_0.p3f_1 = c1_0.q3f_1;
        c1_0.o3f_1 = c1_0.p3f_1;
        c2.o3f_1 = c2.q3f_1;
        c2.p3f_1 = -c2.q3f_1;
        c3.o3f_1 = -c3.q3f_1;
        c3.p3f_1 = c3.q3f_1;
      } else {
        doDefault($this, circles, error);
      }

      // Inline function 'kotlin.run' call

      // Inline function 'com.treemap.Companion.pairPack.<anonymous>' call

      doDefault($this, circles, error);
      break;
    default:
      doDefault($this, circles, error);
      break;
  }
}
function doDefault($this, circles, error) {
  var sorted = ArrayList.l(circles);
  sort(sorted);
  var ca = sorted.b1(0);
  var cb = sorted.b1(1);
  var cc = sorted.b1(2);
  var b = ca.q3f_1 + cc.q3f_1;
  var c = ca.q3f_1 + cb.q3f_1;
  // Inline function 'kotlin.math.sqrt' call
  var x = ca.q3f_1 * cb.q3f_1 * cc.q3f_1 * (ca.q3f_1 + cb.q3f_1 + cc.q3f_1);
  var area = Math.sqrt(x);
  var hc = 2 * area / c;
  ca.o3f_1 = -ca.q3f_1;
  ca.p3f_1 = 0.0;
  cb.o3f_1 = cb.q3f_1;
  cb.p3f_1 = 0.0;
  var tmp = cc;
  var tmp_0 = ca.o3f_1;
  // Inline function 'kotlin.math.sqrt' call
  var x_0 = b * b - hc * hc;
  tmp.o3f_1 = tmp_0 + Math.sqrt(x_0);
  cc.p3f_1 = hc;
  var cp = Double_2.p1o();
  var transform = AffineTransform.z1n();
  var shift = ca.q3f_1 - cb.q3f_1;
  var _receiver__tnumb7 = ca;
  _receiver__tnumb7.o3f_1 = _receiver__tnumb7.o3f_1 + shift;
  var _receiver__tnumb7_0 = cb;
  _receiver__tnumb7_0.o3f_1 = _receiver__tnumb7_0.o3f_1 + shift;
  var _receiver__tnumb7_1 = cc;
  _receiver__tnumb7_1.o3f_1 = _receiver__tnumb7_1.o3f_1 + shift;
  if (sorted.a1() > 3) {
    var smallestRadius = sorted.b1(sorted.a1() - 1 | 0).q3f_1;
    var pairs = ArrayList.e1();
    pairs.o(Pair_0.r3f(cb, ca));
    pairs.o(Pair_0.r3f(ca, cc));
    pairs.o(Pair_0.r3f(cc, cb));
    var innerSoddyRadius_0 = innerSoddyRadius($this, ca.q3f_1, cb.q3f_1, cc.q3f_1);
    if (innerSoddyRadius_0 >= smallestRadius) {
      pairs.o(Pair_0.s3f(ca, cb, innerSoddyRadius_0));
      pairs.o(Pair_0.s3f(cc, ca, innerSoddyRadius_0));
      pairs.o(Pair_0.s3f(cb, cc, innerSoddyRadius_0));
    }
    var closestPoint = Double_2.p1o();
    var closestEdgeIndex;
    var i = 3;
    while (i < sorted.a1()) {
      cc = sorted.b1(i);
      closestPoint.n1o_1 = 1.7976931348623157E308;
      closestPoint.o1o_1 = 1.7976931348623157E308;
      closestEdgeIndex = -1;
      var pairIndex = 0;
      while (pairIndex < pairs.a1()) {
        var intersects;
        var pair = pairs.b1(pairIndex);
        if (pair.n3f_1 < cc.q3f_1 - error) {
          intersects = true;
        } else {
          ca = pair.l3f_1;
          cb = pair.m3f_1;
          b = ca.q3f_1 + cc.q3f_1;
          c = ca.q3f_1 + cb.q3f_1;
          // Inline function 'kotlin.math.sqrt' call
          var x_1 = ca.q3f_1 * cb.q3f_1 * cc.q3f_1 * (ca.q3f_1 + cb.q3f_1 + cc.q3f_1);
          area = Math.sqrt(x_1);
          hc = 2 * area / c;
          var tmp_1 = cp;
          // Inline function 'kotlin.math.sqrt' call
          var x_2 = b * b - hc * hc;
          tmp_1.n1o_1 = Math.sqrt(x_2);
          cp.o1o_1 = hc;
          var tmp4 = cb.p3f_1 - ca.p3f_1;
          // Inline function 'kotlin.math.atan2' call
          var x_3 = cb.o3f_1 - ca.o3f_1;
          var theta = Math.atan2(tmp4, x_3);
          transform.g1o();
          transform.e1o(ca.o3f_1, ca.p3f_1);
          transform.f1o(theta);
          transform.j1o(cp, cp);
          if (cp.n1o_1 * cp.n1o_1 + cp.o1o_1 * cp.o1o_1 >= closestPoint.n1o_1 * closestPoint.n1o_1 + closestPoint.o1o_1 * closestPoint.o1o_1) {
            intersects = true;
          } else {
            intersects = false;
            cc.o3f_1 = cp.n1o_1;
            cc.p3f_1 = cp.o1o_1;
            var j = 0;
            $l$loop: while (j < i) {
              if (cc.u3f(sorted.b1(j), error)) {
                pair.n3f_1 = cc.t3f(sorted.b1(j));
                intersects = true;
                break $l$loop;
              }
              j = j + 1 | 0;
            }
          }
        }
        if (!intersects) {
          if (cc.o3f_1 * cc.o3f_1 + cc.p3f_1 * cc.p3f_1 < closestPoint.n1o_1 * closestPoint.n1o_1 + closestPoint.o1o_1 * closestPoint.o1o_1) {
            closestPoint.n1o_1 = cc.o3f_1;
            closestPoint.o1o_1 = cc.p3f_1;
            closestEdgeIndex = pairIndex;
          }
        }
        pairIndex = pairIndex + 1 | 0;
      }
      if (closestEdgeIndex >= 0) {
        cc.o3f_1 = closestPoint.n1o_1;
        cc.p3f_1 = closestPoint.o1o_1;
        ca = pairs.b1(closestEdgeIndex).l3f_1;
        cb = pairs.b1(closestEdgeIndex).m3f_1;
        innerSoddyRadius_0 = innerSoddyRadius($this, ca.q3f_1, cb.q3f_1, cc.q3f_1);
        if (innerSoddyRadius_0 >= smallestRadius) {
          pairs.b1(closestEdgeIndex).n3f_1 = innerSoddyRadius_0;
          pairs.o(Pair_0.s3f(cc, ca, innerSoddyRadius_0));
          pairs.o(Pair_0.s3f(cb, cc, innerSoddyRadius_0));
        } else {
          pairs.u5(closestEdgeIndex);
        }
        pairs.o(Pair_0.r3f(ca, cc));
        pairs.o(Pair_0.r3f(cc, cb));
      }
      i = i + 1 | 0;
    }
  }
}
function innerSoddyRadius($this, ra, rb, rc) {
  var tmp = ra * rb * rc;
  var tmp_0 = ra * rc + ra * rb + rb * rc;
  // Inline function 'kotlin.math.sqrt' call
  var x = 4 * ra * rb * rc * (ra + rb + rc);
  return tmp / (tmp_0 + Math.sqrt(x));
}
function outerSoddyCircle_0($this, circleA, circleB, circleC) {
  var ra = circleA.q3f_1;
  var rb = circleB.q3f_1;
  var rc = circleC.q3f_1;
  var k1;
  var k2;
  var k3;
  var k4;
  k1 = 1 / ra;
  k2 = 1 / rb;
  k3 = 1 / rc;
  var tmp = k1 + k2 + k3;
  // Inline function 'kotlin.math.sqrt' call
  var x = k1 * k2 + k2 * k3 + k3 * k1;
  // Inline function 'kotlin.math.abs' call
  var x_0 = tmp - 2 * Math.sqrt(x);
  k4 = Math.abs(x_0);
  var q1;
  var q2;
  var q3;
  var q4;
  q1 = (new Complex_0(k1, 0.0)).x3f(new Complex_0(circleA.o3f_1, circleA.p3f_1));
  q2 = (new Complex_0(k2, 0.0)).x3f(new Complex_0(circleB.o3f_1, circleB.p3f_1));
  q3 = (new Complex_0(k3, 0.0)).x3f(new Complex_0(circleC.o3f_1, circleC.p3f_1));
  q4 = q1.y3f(q2).y3f(q3).z3f((new Complex_0(2.0, 0.0)).x3f(q1.x3f(q2).y3f(q2.x3f(q3)).y3f(q3.x3f(q1)).xv()));
  var z = q4.a3g(new Complex_0(k4, 0.0));
  var tmp_0;
  if (z.w3e() || isNaN_3(1 / k4)) {
    tmp_0 = Circle_0.c3g();
  } else {
    tmp_0 = Circle_0.b3g(-z.t3e(), -z.u3e(), 1 / k4);
  }
  return tmp_0;
}
function boundingCircle_0($this, circles) {
  var outerSoddy = null;
  if (circles.a1() >= 3) {
    outerSoddy = outerSoddyCircle_0($this, circles.b1(0), circles.b1(1), circles.b1(2));
    var _iterator__ex2g4s = circles.x();
    while (_iterator__ex2g4s.y()) {
      var c = _iterator__ex2g4s.z();
      // Inline function 'kotlin.math.sqrt' call
      var x = (outerSoddy.o3f_1 - c.o3f_1) * (outerSoddy.o3f_1 - c.o3f_1) + (outerSoddy.p3f_1 - c.p3f_1) * (outerSoddy.p3f_1 - c.p3f_1);
      var dist = Math.sqrt(x);
      var tmp = outerSoddy;
      var tmp1 = outerSoddy.q3f_1;
      // Inline function 'kotlin.math.max' call
      var b = dist + c.q3f_1;
      tmp.q3f_1 = Math.max(tmp1, b);
    }
  }
  var bbox = boundingBox_0($this, circles);
  var tmp_0 = bbox.a1m();
  var tmp_1 = bbox.c1m();
  var tmp3 = bbox.cm();
  // Inline function 'kotlin.math.max' call
  var b_0 = bbox.dm();
  var tmp$ret$2 = Math.max(tmp3, b_0);
  var bc = Circle_0.b3g(tmp_0, tmp_1, tmp$ret$2 / 2);
  var _iterator__ex2g4s_0 = circles.x();
  while (_iterator__ex2g4s_0.y()) {
    var c_0 = _iterator__ex2g4s_0.z();
    // Inline function 'kotlin.math.sqrt' call
    var x_0 = (bc.o3f_1 - c_0.o3f_1) * (bc.o3f_1 - c_0.o3f_1) + (bc.p3f_1 - c_0.p3f_1) * (bc.p3f_1 - c_0.p3f_1);
    var dist_0 = Math.sqrt(x_0);
    var tmp_2 = bc;
    var tmp6 = bc.q3f_1;
    // Inline function 'kotlin.math.max' call
    var b_1 = dist_0 + c_0.q3f_1;
    tmp_2.q3f_1 = Math.max(tmp6, b_1);
  }
  return outerSoddy == null || bc.q3f_1 < outerSoddy.q3f_1 ? bc : outerSoddy;
}
function boundingBox_0($this, circles) {
  var minx = 1.7976931348623157E308;
  var maxx = 4.9E-324;
  var miny = 1.7976931348623157E308;
  var maxy = 4.9E-324;
  var _iterator__ex2g4s = circles.x();
  while (_iterator__ex2g4s.y()) {
    var c = _iterator__ex2g4s.z();
    var tmp0 = minx;
    // Inline function 'kotlin.math.min' call
    var b = c.o3f_1 - c.q3f_1;
    minx = Math.min(tmp0, b);
    var tmp2 = maxx;
    // Inline function 'kotlin.math.max' call
    var b_0 = c.o3f_1 + c.q3f_1;
    maxx = Math.max(tmp2, b_0);
    var tmp4 = miny;
    // Inline function 'kotlin.math.min' call
    var b_1 = c.p3f_1 - c.q3f_1;
    miny = Math.min(tmp4, b_1);
    var tmp6 = maxy;
    // Inline function 'kotlin.math.max' call
    var b_2 = c.p3f_1 + c.q3f_1;
    maxy = Math.max(tmp6, b_2);
  }
  return Double_3.p1m(minx, miny, maxx - minx, maxy - miny);
}
function computeBoundingBox_0($this, children, accessor) {
  var circles = ArrayList.e1();
  var inductionVariable = 0;
  var last = children.length;
  while (inductionVariable < last) {
    var child = children[inductionVariable];
    inductionVariable = inductionVariable + 1 | 0;
    var shape = accessor.getShape(child);
    var tmp;
    if (!(shape == null)) {
      tmp = !(shape == null) ? isInterface(shape, Ellipse2D) : false;
    } else {
      tmp = false;
    }
    if (tmp) {
      var ellipse2D = shape;
      var circle = Circle_0.b3g(ellipse2D.a1m(), ellipse2D.c1m(), ellipse2D.cm() / 2);
      circles.o(circle);
    }
  }
  var tmp_0;
  if (circles.a1() > 0) {
    var circle_0 = boundingCircle_0(Companion_instance_76, circles);
    var b = circle_0.x3e();
    tmp_0 = (new Double_0(b.w1l(), b.x1l(), b.cm(), b.dm())).y1l();
  } else {
    tmp_0 = null;
  }
  return tmp_0;
}
var Companion_instance_76;
function Companion_getInstance_76() {
  return Companion_instance_76;
}
var com_treemap_ColorOrdering$stable;
var Companion_instance_77;
function Companion_getInstance_77() {
  return Companion_instance_77;
}
var com_treemap_ColoredSurroundLabeling$stable;
var com_treemap_CombinationGenerator$stable;
var CombinationGenerator_instance;
function CombinationGenerator_getInstance() {
  return CombinationGenerator_instance;
}
var com_treemap_CountAggregation$stable;
var com_treemap_Cushion$stable;
function init_com_treemap_Cushion(_this__u8e3s4) {
  _this__u8e3s4.r33_1 = new Float64Array(4);
}
var com_treemap_CushionRendering$stable;
function paintCushion($this, g, view, image, bounds, shape) {
  var completed = true;
  if (isInterface(shape, Rectangle2D)) {
    if (bounds.cm() > image.x2d_1 || bounds.dm() > image.y2d_1) {
      var bilinear = g.a3h();
      g.b3h(true);
      completed = g.c3h(image, bounds.q20_1, bounds.r20_1, bounds.s20_1, bounds.t20_1);
      g.b3h(bilinear);
    } else {
      completed = g.c3h(image, bounds.q20_1, bounds.r20_1, bounds.s20_1, bounds.t20_1);
    }
  } else {
    var tmp0 = bounds.s20_1;
    // Inline function 'kotlin.math.min' call
    var b = view.a1().yl_1;
    var width = Math.min(tmp0, b);
    var tmp2 = bounds.t20_1;
    // Inline function 'kotlin.math.min' call
    var b_0 = view.a1().zl_1;
    var height = Math.min(tmp2, b_0);
    if (bounds.cm() > image.x2d_1 || bounds.dm() > image.y2d_1) {
      var bilinear_0 = g.a3h();
      g.b3h(true);
      completed = g.z3g(image, bounds.q20_1, bounds.r20_1, bounds.s20_1, bounds.t20_1, width, height, bounds, shape);
      g.b3h(bilinear_0);
    } else {
      completed = g.z3g(image, bounds.q20_1, bounds.r20_1, bounds.s20_1, bounds.t20_1, width, height, bounds, shape);
    }
  }
  return completed;
}
var com_treemap_DefaultAlgorithmFactory$stable;
var DefaultAlgorithmFactory_instance;
function DefaultAlgorithmFactory_getInstance() {
  return DefaultAlgorithmFactory_instance;
}
var com_treemap_DefaultTreeMap$stable;
var com_treemap_DefaultTreeMapColumnSettings$stable;
function findFont($this, families, style, size, defaultFont, fontFactory) {
  // Inline function 'kotlin.collections.toTypedArray' call
  var this_0 = split(families, [',']);
  var indexedObject = copyToArray(this_0);
  var inductionVariable = 0;
  var last = indexedObject.length;
  while (inductionVariable < last) {
    var family = indexedObject[inductionVariable];
    inductionVariable = inductionVariable + 1 | 0;
    var font = fontFactory.n2d(family);
    if (!(font == null)) {
      return font.u2d(size);
    }
  }
  return defaultFont.u2d(size);
}
var Companion_instance_78;
function Companion_getInstance_78() {
  return Companion_instance_78;
}
var com_treemap_DefaultTreeMapController$stable;
var com_treemap_DefaultTreeMapHeaderRenderer$stable;
var Companion_instance_79;
function Companion_getInstance_79() {
  if (Companion_instance_79 === VOID)
    new Companion_79();
  return Companion_instance_79;
}
var com_treemap_DefaultTreeMapLabelRenderer$stable;
var Companion_instance_80;
function Companion_getInstance_80() {
  if (Companion_instance_80 === VOID)
    new Companion_80();
  return Companion_instance_80;
}
var com_treemap_DefaultTreeMapModel$stable;
var com_treemap_DefaultTreeMapPopup$stable;
var com_treemap_DefaultTreeMapSettings$stable;
function scheduleUpdateGroupBy($this) {
  $this.j35(new TreeMapSettingsEvent(true, true, true));
}
function scheduleUpdateLayout($this) {
  $this.j35(new TreeMapSettingsEvent(false, true, true));
}
function scheduleUpdateColors($this) {
  $this.j35(new TreeMapSettingsEvent(false, false, true));
}
function scheduleUpdate($this) {
  $this.j35(new TreeMapSettingsEvent(false, false, false));
}
function groupByColumns$factory() {
  return getPropertyCallableRef('groupByColumns', 1, KMutableProperty1, (receiver) => receiver.groupByColumns, (receiver, value) => receiver.groupByColumns = value);
}
function groupByColumns$factory_0() {
  return getPropertyCallableRef('groupByColumns', 1, KMutableProperty1, (receiver) => receiver.groupByColumns, (receiver, value) => receiver.groupByColumns = value);
}
function labelsColumns$factory() {
  return getPropertyCallableRef('labelsColumns', 1, KMutableProperty1, (receiver) => receiver.labelsColumns, (receiver, value) => receiver.labelsColumns = value);
}
function labelsColumns$factory_0() {
  return getPropertyCallableRef('labelsColumns', 1, KMutableProperty1, (receiver) => receiver.labelsColumns, (receiver, value) => receiver.labelsColumns = value);
}
function toolTipColumns$factory() {
  return getPropertyCallableRef('toolTipColumns', 1, KMutableProperty1, (receiver) => receiver.toolTipColumns, (receiver, value) => receiver.toolTipColumns = value);
}
function toolTipColumns$factory_0() {
  return getPropertyCallableRef('toolTipColumns', 1, KMutableProperty1, (receiver) => receiver.toolTipColumns, (receiver, value) => receiver.toolTipColumns = value);
}
function sizeColumn$factory() {
  return getPropertyCallableRef('sizeColumn', 1, KMutableProperty1, (receiver) => receiver.sizeColumn, (receiver, value) => receiver.sizeColumn = value);
}
function sizeColumn$factory_0() {
  return getPropertyCallableRef('sizeColumn', 1, KMutableProperty1, (receiver) => receiver.sizeColumn, (receiver, value) => receiver.sizeColumn = value);
}
function colorColumn$factory() {
  return getPropertyCallableRef('colorColumn', 1, KMutableProperty1, (receiver) => receiver.colorColumn, (receiver, value) => receiver.colorColumn = value);
}
function colorColumn$factory_0() {
  return getPropertyCallableRef('colorColumn', 1, KMutableProperty1, (receiver) => receiver.colorColumn, (receiver, value) => receiver.colorColumn = value);
}
function backgroundColumn$factory() {
  return getPropertyCallableRef('backgroundColumn', 1, KMutableProperty1, (receiver) => receiver.backgroundColumn, (receiver, value) => receiver.backgroundColumn = value);
}
function backgroundColumn$factory_0() {
  return getPropertyCallableRef('backgroundColumn', 1, KMutableProperty1, (receiver) => receiver.backgroundColumn, (receiver, value) => receiver.backgroundColumn = value);
}
function heightColumn$factory() {
  return getPropertyCallableRef('heightColumn', 1, KMutableProperty1, (receiver) => receiver.heightColumn, (receiver, value) => receiver.heightColumn = value);
}
function heightColumn$factory_0() {
  return getPropertyCallableRef('heightColumn', 1, KMutableProperty1, (receiver) => receiver.heightColumn, (receiver, value) => receiver.heightColumn = value);
}
function rendering$factory() {
  return getPropertyCallableRef('rendering', 1, KMutableProperty1, (receiver) => receiver.rendering, (receiver, value) => receiver.rendering = value);
}
function rendering$factory_0() {
  return getPropertyCallableRef('rendering', 1, KMutableProperty1, (receiver) => receiver.rendering, (receiver, value) => receiver.rendering = value);
}
var com_treemap_DefaultTreeMapToolTip$stable;
var com_treemap_DefaultTreeMapTooltipRenderer$stable;
var Companion_instance_81;
function Companion_getInstance_81() {
  if (Companion_instance_81 === VOID)
    new Companion_81();
  return Companion_instance_81;
}
var com_treemap_DefaultTreeMapView$stable;
function DefaultTreeMapView$component$delegate$lambda(this$0) {
  return () => new TreeMapCanvas(this$0);
}
function DefaultTreeMapView$timer$delegate$lambda(this$0) {
  return () => {
    var tmp = Companion_getInstance_28().h17_1;
    return tmp.m17('TreeMapViewUpdater', 40, false, new DefaultTreeMapView$timer$2$1(this$0));
  };
}
function component$factory() {
  return getPropertyCallableRef('component', 1, KProperty1, (receiver) => receiver.r2r(), null);
}
function timer$factory() {
  return getPropertyCallableRef('timer', 1, KProperty1, (receiver) => receiver.b3v(), null);
}
var com_treemap_DepthFactory$stable;
var Companion_instance_82;
function Companion_getInstance_82() {
  if (Companion_instance_82 === VOID)
    new Companion_82();
  return Companion_instance_82;
}
var com_treemap_EqualCirclesInCircle$stable;
var EqualCirclesInCircle_instance;
function EqualCirclesInCircle_getInstance() {
  if (EqualCirclesInCircle_instance === VOID)
    new EqualCirclesInCircle();
  return EqualCirclesInCircle_instance;
}
var com_treemap_Exp10Scale$stable;
var com_treemap_ExpScale$stable;
var com_treemap_ExpandLabeling$stable;
var com_treemap_FieldOrdering$stable;
var com_treemap_FixedNesting$stable;
var com_treemap_FlatNoBorderRendering$stable;
var com_treemap_FlatRendering$stable;
var com_treemap_HeightOrdering$stable;
var com_treemap_HighlightParentNodeRenderer$stable;
var com_treemap_IcicleAlgorithm$stable;
function getMaxDepthToLeaf($this, model, root) {
  var maxDepth = 0;
  var it = model.depthFirstIterator(root).x();
  while (it.y()) {
    var o = ensureNotNull(it.z());
    if (model.hasNoChildren(o)) {
      var curDepth = model.getLevel(o);
      if (curDepth > maxDepth)
        maxDepth = curDepth;
    }
  }
  return maxDepth;
}
var com_treemap_InfiniteDepth$stable;
var com_treemap_InverseScale$stable;
var com_treemap_Itertools$stable;
var Itertools_instance;
function Itertools_getInstance() {
  return Itertools_instance;
}
var com_treemap_LabelingFactory$stable;
var Companion_instance_83;
function Companion_getInstance_83() {
  if (Companion_instance_83 === VOID)
    new Companion_83();
  return Companion_instance_83;
}
var com_treemap_LeafNodeRenderer$stable;
var com_treemap_LeafTreeMapNode$stable;
var com_treemap_Log1pScale$stable;
var com_treemap_LogScale$stable;
var com_treemap_MatrixAlgorithm$stable;
function getName($this) {
  return 'Matrix';
}
var Companion_instance_84;
function Companion_getInstance_84() {
  return Companion_instance_84;
}
var com_treemap_MaxAggregation$stable;
var com_treemap_MaxScale$stable;
var com_treemap_MinAggregation$stable;
var com_treemap_MinScale$stable;
var com_treemap_MutableAlgorithmOverrideProperty$stable;
var com_treemap_MutableAlgorithmProperty$stable;
var com_treemap_NestingFactory$stable;
var Companion_instance_85;
function Companion_getInstance_85() {
  if (Companion_instance_85 === VOID)
    new Companion_85();
  return Companion_instance_85;
}
var com_treemap_NodesTreeMapRenderer$stable;
function paint($this, g2, view, model, root, pass, passes, progress) {
  var completed = true;
  var screenBounds = Double_3.p1m(0.0, 0.0, view.a2w().w1l().m15(), view.a2w().x1l().m15());
  g2.x3w(screenBounds);
  var _iterator__ex2g4s = $this.g3c_1.b2q(view, root, pass).x();
  while (_iterator__ex2g4s.y()) {
    var node = _iterator__ex2g4s.z();
    if (progress == null || !progress.d17()) {
      if (!model.isRoot(node) && $this.g3c_1.e2q(view, node)) {
        var depth = model.getLevel(node) - model.getLevel(root) | 0;
        if (ensureNotNull(model.settings.getDepth()).p2q(depth)) {
          var shape = view.l2q(node);
          if (!(shape == null)) {
            var bounds = shape.v1l();
            var hitClip = g2.y3w(bounds);
            if (hitClip) {
              completed = !!(completed & $this.g3c_1.f2q(g2, view, node, pass, passes, bounds, shape));
            }
          }
        }
      }
    } else {
      return Unit_instance;
    }
  }
  if (!completed) {
    view.j37();
  }
}
var Companion_instance_86;
function Companion_getInstance_86() {
  return Companion_instance_86;
}
var com_treemap_NoneAggregation$stable;
var com_treemap_NoneLabeling$stable;
var com_treemap_NoneNesting$stable;
var com_treemap_NumericTransformScale$stable;
var com_treemap_OneLevelIterator$stable;
var SortOrder_Ascending_instance;
var SortOrder_Descending_instance;
var SortOrder_entriesInitialized;
function SortOrder_initEntries() {
  if (SortOrder_entriesInitialized)
    return Unit_instance;
  SortOrder_entriesInitialized = true;
  SortOrder_Ascending_instance = new SortOrder('Ascending', 0);
  SortOrder_Descending_instance = new SortOrder('Descending', 1);
}
function SortOrder_Descending_getInstance() {
  SortOrder_initEntries();
  return SortOrder_Descending_instance;
}
var com_treemap_OrderingFactory$stable;
var Companion_instance_87;
function Companion_getInstance_87() {
  if (Companion_instance_87 === VOID)
    new Companion_87();
  return Companion_instance_87;
}
var com_treemap_OriginalOrdering$stable;
var Companion_instance_88;
function Companion_getInstance_88() {
  return Companion_instance_88;
}
var com_treemap_OriginalScale$stable;
var com_treemap_OverlayLabeling$stable;
var com_treemap_OverridingTreeMapColumnSettings$stable;
var com_treemap_Pair$stable;
var com_treemap_ParentPreorderIterator$stable;
var com_treemap_ParentTreeMapNode$stable;
var com_treemap_PermutationGenerator$stable;
var com_treemap_PieAlgorithm$stable;
var com_treemap_PivotByAlgorithm_Biggest$stable;
var com_treemap_PivotByAlgorithm_Middle$stable;
var com_treemap_PivotByAlgorithm_SplitSize$stable;
var com_treemap_PivotByAlgorithm$stable;
function tryLayout3($this, children, bounds, accessor) {
  // Inline function 'kotlin.arrayOfNulls' call
  var newRectangles = fillArrayVal(Array(3), null);
  var sumSize = accessor.getSize(ensureNotNull(children[0])) + accessor.getSize(ensureNotNull(children[1])) + accessor.getSize(ensureNotNull(children[2]));
  var ratio1 = accessor.getSize(ensureNotNull(children[0])) / sumSize;
  var ratio2 = accessor.getSize(ensureNotNull(children[1])) / sumSize;
  var ratio3 = accessor.getSize(ensureNotNull(children[2])) / sumSize;
  var aspectRatio = bounds.cm() / bounds.dm();
  if (aspectRatio >= 1) {
    var w1 = ratio1 * bounds.cm();
    var w2 = ratio2 * bounds.cm();
    var w3 = ratio3 * bounds.cm();
    newRectangles[0] = Double_3.p1m(bounds.w1l(), bounds.x1l(), w1, bounds.dm());
    newRectangles[1] = Double_3.p1m(bounds.w1l() + w1, bounds.x1l(), w2, bounds.dm());
    newRectangles[2] = Double_3.p1m(bounds.w1l() + w1 + w2, bounds.x1l(), w3, bounds.dm());
  } else {
    var h1 = ratio1 * bounds.dm();
    var h2 = ratio2 * bounds.dm();
    var h3 = ratio3 * bounds.dm();
    newRectangles[0] = Double_3.p1m(bounds.w1l(), bounds.x1l(), bounds.cm(), h1);
    newRectangles[1] = Double_3.p1m(bounds.w1l(), bounds.x1l() + h1, bounds.cm(), h2);
    newRectangles[2] = Double_3.p1m(bounds.w1l(), bounds.x1l() + h1 + h2, bounds.cm(), h3);
  }
  return newRectangles;
}
function tryLayout4Quad($this, children, bounds, accessor) {
  // Inline function 'kotlin.arrayOfNulls' call
  var newRectangles = fillArrayVal(Array(4), null);
  var sumSize = accessor.getSize(ensureNotNull(children[0])) + accessor.getSize(ensureNotNull(children[1])) + accessor.getSize(ensureNotNull(children[2])) + accessor.getSize(ensureNotNull(children[3]));
  var ratio1 = (accessor.getSize(ensureNotNull(children[0])) + accessor.getSize(ensureNotNull(children[1]))) / sumSize;
  var aspectRatio = bounds.cm() / bounds.dm();
  if (aspectRatio >= 1) {
    var w = ratio1 * bounds.cm();
    var ratio2 = accessor.getSize(ensureNotNull(children[0])) / (accessor.getSize(ensureNotNull(children[0])) + accessor.getSize(ensureNotNull(children[1])));
    var h = ratio2 * bounds.dm();
    newRectangles[0] = Double_3.p1m(bounds.w1l(), bounds.x1l(), w, h);
    newRectangles[1] = Double_3.p1m(bounds.w1l(), bounds.x1l() + h, w, bounds.dm() - h);
    ratio2 = accessor.getSize(ensureNotNull(children[2])) / (accessor.getSize(ensureNotNull(children[2])) + accessor.getSize(ensureNotNull(children[3])));
    h = ratio2 * bounds.dm();
    newRectangles[2] = Double_3.p1m(bounds.w1l() + w, bounds.x1l(), bounds.cm() - w, h);
    newRectangles[3] = Double_3.p1m(bounds.w1l() + w, bounds.x1l() + h, bounds.cm() - w, bounds.dm() - h);
  } else {
    var h_0 = ratio1 * bounds.dm();
    var ratio2_0 = accessor.getSize(ensureNotNull(children[0])) / (accessor.getSize(ensureNotNull(children[0])) + accessor.getSize(ensureNotNull(children[1])));
    var w_0 = ratio2_0 * bounds.cm();
    newRectangles[0] = Double_3.p1m(bounds.w1l(), bounds.x1l(), w_0, h_0);
    newRectangles[1] = Double_3.p1m(bounds.w1l(), bounds.x1l() + h_0, w_0, bounds.dm() - h_0);
    ratio2_0 = accessor.getSize(ensureNotNull(children[2])) / (accessor.getSize(ensureNotNull(children[2])) + accessor.getSize(ensureNotNull(children[3])));
    h_0 = ratio2_0 * bounds.dm();
    newRectangles[2] = Double_3.p1m(bounds.w1l() + w_0, bounds.x1l(), bounds.cm() - w_0, h_0);
    newRectangles[3] = Double_3.p1m(bounds.w1l() + w_0, bounds.x1l() + h_0, bounds.cm() - w_0, bounds.dm() - h_0);
  }
  return newRectangles;
}
function tryLayout4Snake($this, children, bounds, accessor) {
  // Inline function 'kotlin.arrayOfNulls' call
  var newRectangles = fillArrayVal(Array(4), null);
  var sumSize = accessor.getSize(ensureNotNull(children[0])) + accessor.getSize(ensureNotNull(children[1])) + accessor.getSize(ensureNotNull(children[2])) + accessor.getSize(ensureNotNull(children[3]));
  var ratio1 = accessor.getSize(ensureNotNull(children[0])) / sumSize;
  var ratio2 = accessor.getSize(ensureNotNull(children[1])) / sumSize;
  var ratio3 = accessor.getSize(ensureNotNull(children[2])) / sumSize;
  var ratio4 = accessor.getSize(ensureNotNull(children[3])) / sumSize;
  var aspectRatio = bounds.cm() / bounds.dm();
  if (aspectRatio >= 1) {
    var w1 = ratio1 * bounds.cm();
    var w2 = ratio2 * bounds.cm();
    var w3 = ratio3 * bounds.cm();
    var w4 = ratio4 * bounds.cm();
    newRectangles[0] = Double_3.p1m(bounds.w1l(), bounds.x1l(), w1, bounds.dm());
    newRectangles[1] = Double_3.p1m(bounds.w1l() + w1, bounds.x1l(), w2, bounds.dm());
    newRectangles[2] = Double_3.p1m(bounds.w1l() + w1 + w2, bounds.x1l(), w3, bounds.dm());
    newRectangles[3] = Double_3.p1m(bounds.w1l() + w1 + w2 + w3, bounds.x1l(), w4, bounds.dm());
  } else {
    var h1 = ratio1 * bounds.dm();
    var h2 = ratio2 * bounds.dm();
    var h3 = ratio3 * bounds.dm();
    var h4 = ratio4 * bounds.dm();
    newRectangles[0] = Double_3.p1m(bounds.w1l(), bounds.x1l(), bounds.cm(), h1);
    newRectangles[1] = Double_3.p1m(bounds.w1l(), bounds.x1l() + h1, bounds.cm(), h2);
    newRectangles[2] = Double_3.p1m(bounds.w1l(), bounds.x1l() + h1 + h2, bounds.cm(), h3);
    newRectangles[3] = Double_3.p1m(bounds.w1l(), bounds.x1l() + h1 + h2 + h3, bounds.cm(), h4);
  }
  return newRectangles;
}
function tryLayout5($this, children, bounds, accessor) {
  // Inline function 'kotlin.arrayOfNulls' call
  var newRectangles = fillArrayVal(Array(5), null);
  var sumSize = accessor.getSize(ensureNotNull(children[0])) + accessor.getSize(ensureNotNull(children[1])) + accessor.getSize(ensureNotNull(children[2])) + accessor.getSize(ensureNotNull(children[3])) + accessor.getSize(ensureNotNull(children[4]));
  var ratio1 = accessor.getSize(ensureNotNull(children[0])) / sumSize;
  var ratio2 = accessor.getSize(ensureNotNull(children[1])) / sumSize;
  var ratio3 = accessor.getSize(ensureNotNull(children[2])) / sumSize;
  var ratio4 = accessor.getSize(ensureNotNull(children[3])) / sumSize;
  var ratio5 = accessor.getSize(ensureNotNull(children[4])) / sumSize;
  var aspectRatio = bounds.cm() / bounds.dm();
  if (aspectRatio >= 1) {
    var w1 = ratio1 * bounds.cm();
    var w2 = ratio2 * bounds.cm();
    var w3 = ratio3 * bounds.cm();
    var w4 = ratio4 * bounds.cm();
    var w5 = ratio5 * bounds.cm();
    newRectangles[0] = Double_3.p1m(bounds.w1l(), bounds.x1l(), w1, bounds.dm());
    newRectangles[1] = Double_3.p1m(bounds.w1l() + w1, bounds.x1l(), w2, bounds.dm());
    newRectangles[2] = Double_3.p1m(bounds.w1l() + w1 + w2, bounds.x1l(), w3, bounds.dm());
    newRectangles[3] = Double_3.p1m(bounds.w1l() + w1 + w2 + w3, bounds.x1l(), w4, bounds.dm());
    newRectangles[4] = Double_3.p1m(bounds.w1l() + w1 + w2 + w3 + w4, bounds.x1l(), w5, bounds.dm());
  } else {
    var h1 = ratio1 * bounds.dm();
    var h2 = ratio2 * bounds.dm();
    var h3 = ratio3 * bounds.dm();
    var h4 = ratio4 * bounds.dm();
    var h5 = ratio5 * bounds.dm();
    newRectangles[0] = Double_3.p1m(bounds.w1l(), bounds.x1l(), bounds.cm(), h1);
    newRectangles[1] = Double_3.p1m(bounds.w1l(), bounds.x1l() + h1, bounds.cm(), h2);
    newRectangles[2] = Double_3.p1m(bounds.w1l(), bounds.x1l() + h1 + h2, bounds.cm(), h3);
    newRectangles[3] = Double_3.p1m(bounds.w1l(), bounds.x1l() + h1 + h2 + h3, bounds.cm(), h4);
    newRectangles[4] = Double_3.p1m(bounds.w1l(), bounds.x1l() + h1 + h2 + h3 + h4, bounds.cm(), h5);
  }
  return newRectangles;
}
function copyFromSize(_this__u8e3s4, from, size) {
  return copyOfRange_0(_this__u8e3s4, from, from + size | 0);
}
var com_treemap_PostorderIterator$stable;
var com_treemap_PreorderIterator$stable;
var Progressive_Disabled_instance;
var Progressive_Incremental_instance;
var Progressive_Iterative_instance;
var Progressive_entriesInitialized;
function Progressive_initEntries() {
  if (Progressive_entriesInitialized)
    return Unit_instance;
  Progressive_entriesInitialized = true;
  Progressive_Disabled_instance = new Progressive('Disabled', 0);
  Progressive_Incremental_instance = new Progressive('Incremental', 1);
  Progressive_Iterative_instance = new Progressive('Iterative', 2);
}
function Progressive_Disabled_getInstance() {
  Progressive_initEntries();
  return Progressive_Disabled_instance;
}
var com_treemap_ProportionalNesting$stable;
var Type_Raw_instance;
var Type_KeepAspectRatio_instance;
var Type_EqualBorderWidth_instance;
var Type_entriesInitialized;
function Type_initEntries() {
  if (Type_entriesInitialized)
    return Unit_instance;
  Type_entriesInitialized = true;
  Type_Raw_instance = new Type('Raw', 0);
  Type_KeepAspectRatio_instance = new Type('KeepAspectRatio', 1);
  Type_EqualBorderWidth_instance = new Type('EqualBorderWidth', 2);
}
var Companion_instance_89;
function Companion_getInstance_89() {
  if (Companion_instance_89 === VOID)
    new Companion_89();
  return Companion_instance_89;
}
function Type_EqualBorderWidth_getInstance() {
  Type_initEntries();
  return Type_EqualBorderWidth_instance;
}
var com_treemap_RectangularTransform$stable;
var Companion_instance_90;
function Companion_getInstance_90() {
  return Companion_instance_90;
}
function init_com_treemap_RectangularTransform(_this__u8e3s4) {
  _this__u8e3s4.q2q_1 = 0.0;
  _this__u8e3s4.r2q_1 = 0.0;
  _this__u8e3s4.s2q_1 = 1.0;
  _this__u8e3s4.t2q_1 = 1.0;
}
var com_treemap_RenderingFactory$stable;
var Companion_instance_91;
function Companion_getInstance_91() {
  if (Companion_instance_91 === VOID)
    new Companion_91();
  return Companion_instance_91;
}
var com_treemap_ScaleFactory$stable;
var Companion_instance_92;
function Companion_getInstance_92() {
  if (Companion_instance_92 === VOID)
    new Companion_92();
  return Companion_instance_92;
}
var com_treemap_SelectionNodeRenderer$stable;
var com_treemap_SizeOrColorOrdering$stable;
var com_treemap_SizeOrdering$stable;
var com_treemap_SizeWeightedAggregation$stable;
var com_treemap_SliceAndDiceAlgorithm_VerticalOrientationStrategy$stable;
var com_treemap_SliceAndDiceAlgorithm_HoritzonalOrientationStrategy$stable;
var com_treemap_SliceAndDiceAlgorithm_BestOrientationStrategy$stable;
var com_treemap_SliceAndDiceAlgorithm_AlternateOrientationStrategy$stable;
var com_treemap_SliceAndDiceAlgorithm$stable;
var com_treemap_SplitAlgorithm$stable;
function getName_0($this) {
  return 'Split';
}
function splitLayout($this, items, r, accessor) {
  if (items.a1() === 0) {
    return true;
  }
  if (items.a1() === 1) {
    accessor.setShape(items.b1(0), r);
    return true;
  }
  var l1 = ArrayList.e1();
  var l2 = ArrayList.e1();
  var r1;
  var r2;
  var halfSize = w($this, items, accessor) / 2;
  var w1 = 0.0;
  var tmp = 0.0;
  var iterator = items.n2();
  $l$loop: while (iterator.y()) {
    var front = iterator.z();
    tmp = w1 + accessor.getSize(front);
    var tmp_0;
    // Inline function 'kotlin.math.abs' call
    var x = halfSize - tmp;
    var tmp_1 = Math.abs(x);
    // Inline function 'kotlin.math.abs' call
    var x_0 = halfSize - w1;
    if (tmp_1 > Math.abs(x_0)) {
      tmp_0 = true;
    } else {
      tmp_0 = !iterator.y();
    }
    if (tmp_0) {
      break $l$loop;
    }
    iterator.n5();
    l1.o(front);
    w1 = tmp;
  }
  l2 = items;
  if (r.cm() > r.dm()) {
    r1 = Double_3.p1m(r.w1l(), r.x1l(), r.cm() * (w($this, l1, accessor) / (w($this, l1, accessor) + w($this, l2, accessor))), r.dm());
    r2 = Double_3.p1m(r.w1l() + r1.cm(), r.x1l(), r.cm() - r1.cm(), r.dm());
  } else {
    r1 = Double_3.p1m(r.w1l(), r.x1l(), r.cm(), r.dm() * (w($this, l1, accessor) / (w($this, l1, accessor) + w($this, l2, accessor))));
    r2 = Double_3.p1m(r.w1l(), r.x1l() + r1.dm(), r.cm(), r.dm() - r1.dm());
  }
  splitLayout($this, l1, r1, accessor);
  splitLayout($this, l2, r2, accessor);
  return false;
}
function w($this, list, accessor) {
  var sum = 0.0;
  var _iterator__ex2g4s = list.x();
  while (_iterator__ex2g4s.y()) {
    var node = _iterator__ex2g4s.z();
    sum = sum + accessor.getSize(node);
  }
  return sum;
}
var Companion_instance_93;
function Companion_getInstance_93() {
  return Companion_instance_93;
}
var com_treemap_SquarifiedAlgorithm$stable;
function getName_1($this) {
  return 'Squarified';
}
function computeAspectRatio($this, area, width) {
  var aspectRatio = area / (width * width * $this.b3z_1.r2());
  if (aspectRatio < 1.0) {
    aspectRatio = 1.0 / aspectRatio;
  }
  return aspectRatio;
}
var Companion_instance_94;
function Companion_getInstance_94() {
  return Companion_instance_94;
}
var com_treemap_SquarifiedPlusAlgorithm$stable;
function getName_2($this) {
  return 'Squarified+';
}
function bestAspectRatio($this, nodes, current, last, side, sizeFactor, accessor) {
  if (nodes == null || nodes.length === 0) {
    return 1.7976931348623157E308;
  }
  var max = 0.0;
  var inductionVariable = current;
  if (inductionVariable <= last)
    do {
      var i = inductionVariable;
      inductionVariable = inductionVariable + 1 | 0;
      var node = nodes[i];
      var m = computeAspectRatio_0($this, accessor.getSize(node) * sizeFactor, side);
      if (m > max) {
        max = m;
      }
    }
     while (!(i === last));
  return max;
}
function computeAspectRatio_0($this, area, width) {
  var aspectRatio = area / (width * width * $this.e3z_1.r2());
  if (aspectRatio < 1.0) {
    aspectRatio = 1.0 / aspectRatio;
  }
  return aspectRatio;
}
function willImprove($this, actualAR, expandedAR) {
  if (actualAR === 0.0) {
    return true;
  }
  if (expandedAR === 0.0) {
    return false;
  }
  // Inline function 'kotlin.math.abs' call
  var x = actualAR - $this.e3z_1.r2();
  var v1 = Math.abs(x);
  // Inline function 'kotlin.math.abs' call
  var x_0 = expandedAR - $this.e3z_1.r2();
  var v2 = Math.abs(x_0);
  return v1 > v2;
}
var Companion_instance_95;
function Companion_getInstance_95() {
  return Companion_instance_95;
}
var com_treemap_StdDevAggregation$stable;
var com_treemap_StripAlgorithm$stable;
var com_treemap_SumAggregation$stable;
var com_treemap_SunburstAlgorithm$stable;
function getMaxDepthToLeaf_0($this, model, root) {
  var maxDepth = 0;
  var it = model.depthFirstIterator(root).x();
  while (it.y()) {
    var o = ensureNotNull(it.z());
    if (model.hasNoChildren(o)) {
      var curDepth = model.getLevel(o);
      if (curDepth > maxDepth)
        maxDepth = curDepth;
    }
  }
  return maxDepth;
}
var com_treemap_SurroundLabeling$stable;
function computeAllocatedHeight($this, preferredHeight, rectangle) {
  // Inline function 'kotlin.math.min' call
  var a = rectangle.dm() / 5;
  return Math.min(a, preferredHeight);
}
function computeThickness($this, model, rectangle, node) {
  var thickness = rectangle.cm() * rectangle.dm() * 5.0E-4;
  var tmp2 = $this.u3g_1;
  // Inline function 'kotlin.math.min' call
  var a = $this.v3g_1;
  // Inline function 'kotlin.math.max' call
  var b = Math.min(a, thickness);
  return Math.max(tmp2, b);
}
var Companion_instance_96;
function Companion_getInstance_96() {
  return Companion_instance_96;
}
var com_treemap_TextParentNodeRenderer$stable;
var com_treemap_ThresholdDepth$stable;
var Companion_instance_97;
function Companion_getInstance_97() {
  return Companion_instance_97;
}
var com_treemap_TreeMapColorMapPanelModel$stable;
var com_treemap_TreeMapEvent$stable;
var com_treemap_TreeMapFilterCoordinator$stable;
var com_treemap_TreeMapProbingCoordinator$stable;
var com_treemap_TreeMapSelectionCoordinator$stable;
var com_treemap_TreeMapSettingsEvent$stable;
var ToolTipType_Heavyweight_instance;
var ToolTipType_Lightweight_instance;
var ToolTipType_Painted_instance;
var ToolTipType_entriesInitialized;
function ToolTipType_initEntries() {
  if (ToolTipType_entriesInitialized)
    return Unit_instance;
  ToolTipType_entriesInitialized = true;
  ToolTipType_Heavyweight_instance = new ToolTipType('Heavyweight', 0);
  ToolTipType_Lightweight_instance = new ToolTipType('Lightweight', 1);
  ToolTipType_Painted_instance = new ToolTipType('Painted', 2);
}
function ToolTipType_Painted_getInstance() {
  ToolTipType_initEntries();
  return ToolTipType_Painted_instance;
}
var com_treemap_XPlus1Scale$stable;
var com_treemap_colormap_DataFrameColorMapFactory$stable;
var DataFrameColorMapFactory_instance;
function DataFrameColorMapFactory_getInstance() {
  return DataFrameColorMapFactory_instance;
}
var com_treemap_crossplatform_AbstractTGraphics$stable;
var Companion_instance_98;
function Companion_getInstance_98() {
  return Companion_instance_98;
}
var com_treemap_details_DetailsDataFrame$stable;
var com_treemap_legacy_SingleSelectionSettingsCoordinator$stable;
function init_com_treemap_legacy_SingleSelectionSettingsCoordinator(_this__u8e3s4) {
}
var com_treemap_tagcloud_AbstractTagCloudAlgorithm$stable;
var com_treemap_tagcloud_ArchimedeanSpiral$stable;
var com_treemap_tagcloud_DefaultWord$stable;
var com_treemap_tagcloud_HierarchicalBoundingBox$stable;
var com_treemap_tagcloud_HierarchicalBoundingBoxPair$stable;
var com_treemap_tagcloud_HierarchicalBoundingBoxes$stable;
var com_treemap_tagcloud_Interpolator$stable;
var com_treemap_tagcloud_LinearizedPathIterator$stable;
var com_treemap_tagcloud_Point2d$stable;
var com_treemap_tagcloud_PointPlusAccumulatedDistance$stable;
var com_treemap_tagcloud_PositionIterator$stable;
var com_treemap_tagcloud_RectangularTextShape$stable;
var com_treemap_tagcloud_Tuple2d$stable;
var com_treemap_tagcloud_Vector2d$stable;
var com_treemap_treeplot_Spoint$stable;
var com_treemap_JsTreeMap$stable;
function JsTreeMap$lambda($model) {
  return ($this$create) => {
    $this$create.model = $model;
    return Unit_instance;
  };
}
function get_TreeMapComponent() {
  _init_properties_TreeMap_kt__gvwl04();
  return TreeMapComponent_0;
}
var TreeMapComponent_0;
function getTreeMapComponent() {
  _init_properties_TreeMap_kt__gvwl04();
  return get_TreeMapComponent();
}
function TreeMapComponent$lambda($this$FC, props) {
  _init_properties_TreeMap_kt__gvwl04();
  var treeMap = DefaultTreeMap.m3h();
  treeMap.model = props.model;
  // Inline function 'react.ChildrenBuilder.invoke' call
  var this_0 = treeMap.component.n2a();
  addChild_0($this$FC, this_0);
  return Unit_instance;
}
var properties_initialized_TreeMap_kt_89j11q;
function _init_properties_TreeMap_kt__gvwl04() {
  if (!properties_initialized_TreeMap_kt_89j11q) {
    properties_initialized_TreeMap_kt_89j11q = true;
    TreeMapComponent_0 = FC(TreeMapComponent$lambda);
  }
}
var com_treemap_crossplatform_CanvasRenderingContext2DFontMetrics$stable;
var com_treemap_crossplatform_CanvasRenderingContext2DIGraphics$stable;
var com_treemap_crossplatform_CanvasRenderingContext2DTGraphics$stable;
function paintWordWrapText($this, g, label, text, maxWidth, x, yStart, foreground, background, paint) {
  var maxWidth_0 = maxWidth;
  var x_0 = x;
  maxWidth_0 = maxWidth_0 - (label.getInsetLeft() + label.getInsetRight() | 0) | 0;
  var w = label.getInsetLeft() + label.getInsetRight();
  x_0 = x_0 + label.getInsetLeft() | 0;
  var y = yStart + label.getInsetTop() | 0;
  var tmp;
  if (maxWidth_0 > 0 && !(text == null)) {
    // Inline function 'kotlin.text.isNotEmpty' call
    tmp = charSequenceLength(text) > 0;
  } else {
    tmp = false;
  }
  if (tmp) {
    // Inline function 'kotlin.collections.toTypedArray' call
    var this_0 = split(text, [' ']);
    var tmp$ret$1 = copyToArray(this_0);
    var words = ArrayList.l(listOf_0(tmp$ret$1.slice()));
    var line = '';
    var lineCount = 0;
    var i;
    var test;
    var testMetrics = null;
    i = 0;
    while (i < words.a1()) {
      test = words.b1(i);
      testMetrics = $this.u40_1.measureText(test);
      while (ensureNotNull(testMetrics).width > maxWidth_0) {
        var tmp2 = test;
        // Inline function 'kotlin.text.substring' call
        var endIndex = test.length - 1 | 0;
        // Inline function 'kotlin.js.asDynamic' call
        test = tmp2.substring(0, endIndex);
        testMetrics = $this.u40_1.measureText(test);
      }
      if (!(words.b1(i) === test)) {
        var tmp_0 = i + 1 | 0;
        var tmp5 = words.b1(i);
        // Inline function 'kotlin.text.substring' call
        var startIndex = test.length;
        // Inline function 'kotlin.js.asDynamic' call
        var tmp$ret$5 = tmp5.substring(startIndex);
        words.j6(tmp_0, tmp$ret$5);
        words.j5(i, test);
      }
      test = line + words.b1(i) + toString(_Char___init__impl__6a9atx(32));
      var previousMetrics = testMetrics;
      testMetrics = $this.u40_1.measureText(test);
      if (testMetrics.width > maxWidth_0 && i > 0) {
        if (paint) {
          $this.c41(label, x_0, y, maxWidth_0, line);
        }
        line = words.b1(i) + toString(_Char___init__impl__6a9atx(32));
        y = y + $this.d41(label) | 0;
        lineCount = lineCount + 1 | 0;
        var tmp7 = w;
        // Inline function 'kotlin.math.max' call
        var b = ensureNotNull(previousMetrics).width;
        w = Math.max(tmp7, b);
      } else {
        line = test;
      }
      i = i + 1 | 0;
    }
    if (paint) {
      $this.c41(label, x_0, y, maxWidth_0, line);
    }
    if (!(testMetrics == null)) {
      var tmp9 = w;
      // Inline function 'kotlin.math.max' call
      var b_0 = testMetrics.width;
      w = Math.max(tmp9, b_0);
    }
    y = y + $this.d41(label) | 0;
  }
  // Inline function 'kotlin.math.ceil' call
  var x_1 = w;
  var tmp$ret$8 = Math.ceil(x_1);
  var tmp_1 = numberToInt(tmp$ret$8);
  // Inline function 'kotlin.math.ceil' call
  var x_2 = y;
  var tmp$ret$9 = Math.ceil(x_2);
  return Dimension.bm(tmp_1, numberToInt(tmp$ret$9) + label.getInsetBottom() | 0);
}
var com_treemap_crossplatform_Headless$stable;
var com_treemap_crossplatform_TreeMapCanvas$stable;
//region block: post-declaration
initMetadataForInterface(CharSequence, 'CharSequence');
initMetadataForInterface(Comparable, 'Comparable');
initMetadataForClass(Number_0, 'Number');
initMetadataForClass(asSequence$$inlined$Sequence$1);
initMetadataForInterface(Iterable, 'Iterable');
initMetadataForClass(asIterable$$inlined$Iterable$1, VOID, VOID, VOID, [Iterable]);
initMetadataForClass(Exception, 'Exception', Exception.nc);
initMetadataForClass(RuntimeException, 'RuntimeException', RuntimeException.u1);
initMetadataForClass(KotlinNothingValueException, 'KotlinNothingValueException', KotlinNothingValueException.r1);
initMetadataForCompanion(Companion);
initMetadataForClass(Char, 'Char', VOID, VOID, [Comparable]);
initMetadataForCompanion(Companion_0);
initMetadataForInterface(Collection, 'Collection', VOID, VOID, [Iterable]);
initMetadataForInterface(KtList_0, 'List', VOID, VOID, [Collection]);
initMetadataForCompanion(Companion_1);
initMetadataForInterface(KtSet_0, 'Set', VOID, VOID, [Collection]);
initMetadataForInterface(Entry, 'Entry');
initMetadataForInterface(KtMap, 'Map');
initMetadataForInterface(MutableIterable, 'MutableIterable', VOID, VOID, [Iterable]);
initMetadataForInterface(MutableCollection, 'MutableCollection', VOID, VOID, [Collection, MutableIterable]);
initMetadataForCompanion(Companion_2);
initMetadataForClass(Enum, 'Enum', VOID, VOID, [Comparable]);
initMetadataForCompanion(Companion_3);
initMetadataForClass(Long, 'Long', VOID, VOID, [Number_0, Comparable]);
initMetadataForInterface(FunctionAdapter, 'FunctionAdapter');
initMetadataForClass(arrayIterator$1);
initMetadataForClass(JsArrayView, 'JsArrayView');
initMetadataForClass(JsSetView, 'JsSetView', JsSetView);
initMetadataForObject(Digit, 'Digit');
initMetadataForInterface(Comparator, 'Comparator');
initMetadataForObject(Unit, 'Unit');
initMetadataForClass(AbstractCollection, 'AbstractCollection', VOID, VOID, [Collection]);
initMetadataForClass(AbstractMutableCollection, 'AbstractMutableCollection', VOID, VOID, [AbstractCollection, MutableCollection]);
initMetadataForClass(IteratorImpl, 'IteratorImpl');
initMetadataForClass(ListIteratorImpl, 'ListIteratorImpl');
protoOf(AbstractMutableList).asJsReadonlyArrayView = asJsReadonlyArrayView;
initMetadataForClass(AbstractMutableList, 'AbstractMutableList', VOID, VOID, [AbstractMutableCollection, MutableCollection, KtList_0]);
initMetadataForInterface(RandomAccess, 'RandomAccess');
initMetadataForClass(SubList, 'SubList', VOID, VOID, [AbstractMutableList, RandomAccess]);
initMetadataForClass(AbstractMap, 'AbstractMap', VOID, VOID, [KtMap]);
initMetadataForClass(AbstractMutableMap, 'AbstractMutableMap', VOID, VOID, [AbstractMap, KtMap]);
protoOf(AbstractMutableSet).asJsReadonlySetView = asJsReadonlySetView;
initMetadataForClass(AbstractMutableSet, 'AbstractMutableSet', VOID, VOID, [AbstractMutableCollection, KtSet_0, MutableCollection]);
initMetadataForCompanion(Companion_4);
initMetadataForClass(ArrayList, 'ArrayList', ArrayList.e1, VOID, [AbstractMutableList, MutableCollection, KtList_0, RandomAccess]);
initMetadataForClass(HashMap, 'HashMap', HashMap.d8, VOID, [AbstractMutableMap, KtMap]);
initMetadataForClass(HashMapKeys, 'HashMapKeys', VOID, VOID, [KtSet_0, MutableCollection, AbstractMutableSet]);
initMetadataForClass(HashMapValues, 'HashMapValues', VOID, VOID, [MutableCollection, AbstractMutableCollection]);
initMetadataForClass(HashMapEntrySetBase, 'HashMapEntrySetBase', VOID, VOID, [KtSet_0, MutableCollection, AbstractMutableSet]);
initMetadataForClass(HashMapEntrySet, 'HashMapEntrySet');
initMetadataForClass(HashMapKeysDefault$iterator$1);
initMetadataForClass(HashMapKeysDefault, 'HashMapKeysDefault');
initMetadataForClass(HashMapValuesDefault$iterator$1);
initMetadataForClass(HashMapValuesDefault, 'HashMapValuesDefault');
initMetadataForClass(HashSet, 'HashSet', HashSet.x9, VOID, [AbstractMutableSet, KtSet_0, MutableCollection]);
initMetadataForCompanion(Companion_5);
initMetadataForClass(Itr, 'Itr');
initMetadataForClass(KeysItr, 'KeysItr');
initMetadataForClass(ValuesItr, 'ValuesItr');
initMetadataForClass(EntriesItr, 'EntriesItr');
initMetadataForClass(EntryRef, 'EntryRef', VOID, VOID, [Entry]);
initMetadataForInterface(InternalMap, 'InternalMap');
protoOf(InternalHashMap).q9 = containsAllEntries;
initMetadataForClass(InternalHashMap, 'InternalHashMap', InternalHashMap.o8, VOID, [InternalMap]);
initMetadataForObject(EmptyHolder, 'EmptyHolder');
initMetadataForClass(LinkedHashSet, 'LinkedHashSet', LinkedHashSet.d1, VOID, [HashSet, KtSet_0, MutableCollection]);
initMetadataForClass(BaseOutput, 'BaseOutput');
initMetadataForClass(NodeJsOutput, 'NodeJsOutput');
initMetadataForClass(BufferedOutput, 'BufferedOutput', BufferedOutput);
initMetadataForClass(BufferedOutputToConsoleLog, 'BufferedOutputToConsoleLog', BufferedOutputToConsoleLog);
initMetadataForClass(InterceptedCoroutine, 'InterceptedCoroutine');
initMetadataForClass(IllegalStateException, 'IllegalStateException', IllegalStateException.lc);
initMetadataForClass(CancellationException, 'CancellationException', CancellationException.kc);
initMetadataForClass(IllegalArgumentException, 'IllegalArgumentException', IllegalArgumentException.qc);
initMetadataForClass(UnsupportedOperationException, 'UnsupportedOperationException', UnsupportedOperationException.h4);
initMetadataForClass(NoSuchElementException, 'NoSuchElementException', NoSuchElementException.s5);
initMetadataForClass(Error_0, 'Error', Error_0.uc);
initMetadataForClass(IndexOutOfBoundsException, 'IndexOutOfBoundsException', IndexOutOfBoundsException.ad);
initMetadataForClass(NumberFormatException, 'NumberFormatException', NumberFormatException.gd);
initMetadataForClass(ArithmeticException, 'ArithmeticException', ArithmeticException.ld);
initMetadataForClass(AssertionError, 'AssertionError', AssertionError.pd);
initMetadataForClass(ConcurrentModificationException, 'ConcurrentModificationException', ConcurrentModificationException.va);
initMetadataForClass(ClassCastException, 'ClassCastException', ClassCastException.z4);
initMetadataForClass(NullPointerException, 'NullPointerException', NullPointerException.r4);
initMetadataForClass(NoWhenBranchMatchedException, 'NoWhenBranchMatchedException', NoWhenBranchMatchedException.v4);
initMetadataForClass(UninitializedPropertyAccessException, 'UninitializedPropertyAccessException', UninitializedPropertyAccessException.sd);
initMetadataForInterface(KClass, 'KClass');
initMetadataForClass(KClassImpl, 'KClassImpl', VOID, VOID, [KClass]);
initMetadataForObject(NothingKClassImpl, 'NothingKClassImpl');
initMetadataForClass(ErrorKClass, 'ErrorKClass', ErrorKClass, VOID, [KClass]);
initMetadataForClass(PrimitiveKClassImpl, 'PrimitiveKClassImpl');
initMetadataForClass(SimpleKClassImpl, 'SimpleKClassImpl');
initMetadataForInterface(KProperty1, 'KProperty1');
initMetadataForInterface(KMutableProperty1, 'KMutableProperty1', VOID, VOID, [KProperty1]);
initMetadataForObject(PrimitiveClasses, 'PrimitiveClasses');
initMetadataForClass(ConstrainedOnceSequence, 'ConstrainedOnceSequence');
initMetadataForClass(StringBuilder, 'StringBuilder', StringBuilder.u, VOID, [CharSequence]);
initMetadataForCompanion(Companion_6);
initMetadataForClass(sam$kotlin_Comparator$0, 'sam$kotlin_Comparator$0', VOID, VOID, [Comparator, FunctionAdapter]);
initMetadataForClass(ExceptionTraceBuilder, 'ExceptionTraceBuilder', ExceptionTraceBuilder);
protoOf(AbstractList).asJsReadonlyArrayView = asJsReadonlyArrayView;
initMetadataForClass(AbstractList, 'AbstractList', VOID, VOID, [AbstractCollection, KtList_0]);
initMetadataForClass(SubList_0, 'SubList', VOID, VOID, [AbstractList, RandomAccess]);
initMetadataForClass(IteratorImpl_0, 'IteratorImpl');
initMetadataForClass(ListIteratorImpl_0, 'ListIteratorImpl');
initMetadataForCompanion(Companion_7);
initMetadataForCompanion(Companion_8);
initMetadataForCompanion(Companion_9);
initMetadataForCompanion(Companion_10);
initMetadataForClass(ArrayDeque, 'ArrayDeque', ArrayDeque.fg);
initMetadataForObject(EmptyIterator, 'EmptyIterator');
protoOf(EmptyList).asJsReadonlyArrayView = asJsReadonlyArrayView;
initMetadataForObject(EmptyList, 'EmptyList', VOID, VOID, [KtList_0, RandomAccess]);
initMetadataForClass(ArrayAsCollection, 'ArrayAsCollection', VOID, VOID, [Collection]);
initMetadataForClass(IntIterator, 'IntIterator');
initMetadataForClass(GeneratorSequence$iterator$1);
initMetadataForClass(GeneratorSequence, 'GeneratorSequence');
initMetadataForClass(TransformingSequence$iterator$1);
initMetadataForClass(TransformingSequence, 'TransformingSequence');
initMetadataForObject(EmptySequence, 'EmptySequence');
protoOf(EmptySet).asJsReadonlySetView = asJsReadonlySetView;
initMetadataForObject(EmptySet, 'EmptySet', VOID, VOID, [KtSet_0]);
initMetadataForObject(NaturalOrderComparator, 'NaturalOrderComparator', VOID, VOID, [Comparator]);
initMetadataForObject(Key, 'Key');
initMetadataForInterface(Element, 'Element');
initMetadataForInterface(ContinuationInterceptor, 'ContinuationInterceptor', VOID, VOID, [Element]);
initMetadataForClass(AbstractCoroutineContextKey, 'AbstractCoroutineContextKey');
protoOf(AbstractCoroutineContextElement).ec = get;
initMetadataForClass(AbstractCoroutineContextElement, 'AbstractCoroutineContextElement', VOID, VOID, [Element]);
initMetadataForClass(CoroutineSingletons, 'CoroutineSingletons');
initMetadataForClass(EnumEntriesList, 'EnumEntriesList', VOID, VOID, [KtList_0, AbstractList]);
initMetadataForObject(Delegates, 'Delegates');
initMetadataForClass(ObservableProperty, 'ObservableProperty');
initMetadataForClass(Random, 'Random');
initMetadataForObject(Default, 'Default');
initMetadataForCompanion(Companion_11);
initMetadataForClass(XorWowRandom, 'XorWowRandom');
initMetadataForCompanion(Companion_12);
initMetadataForClass(IntProgression, 'IntProgression', VOID, VOID, [Iterable]);
initMetadataForInterface(ClosedRange, 'ClosedRange');
initMetadataForClass(IntRange, 'IntRange', VOID, VOID, [IntProgression, ClosedRange]);
initMetadataForClass(IntProgressionIterator, 'IntProgressionIterator');
initMetadataForCompanion(Companion_13);
initMetadataForClass(DelimitedRangesSequence$iterator$1);
initMetadataForClass(DelimitedRangesSequence, 'DelimitedRangesSequence');
initMetadataForObject(State, 'State');
initMetadataForClass(LinesIterator, 'LinesIterator');
initMetadataForClass(lineSequence$$inlined$Sequence$1);
initMetadataForClass(UnsafeLazyImpl, 'UnsafeLazyImpl');
initMetadataForObject(UNINITIALIZED_VALUE, 'UNINITIALIZED_VALUE');
initMetadataForCompanion(Companion_14);
initMetadataForClass(Failure, 'Failure');
initMetadataForClass(NotImplementedError, 'NotImplementedError', NotImplementedError.bk);
initMetadataForClass(Pair, 'Pair');
initMetadataForClass(EnumMap, 'EnumMap', VOID, VOID, [KtMap]);
initMetadataForClass(ConcatenateIterator, 'ConcatenateIterator');
initMetadataForClass(EmptyIterator_0, 'EmptyIterator', EmptyIterator_0);
initMetadataForClass(ConcatenateIterable, 'ConcatenateIterable', VOID, VOID, [Iterable]);
initMetadataForObject(Iterables, 'Iterables');
initMetadataForClass(SortedSet, 'SortedSet');
initMetadataForClass(UniversalComparator, 'UniversalComparator', UniversalComparator, VOID, [Comparator]);
initMetadataForClass(WeakReference, 'WeakReference');
initMetadataForClass(AbstractUICommand, 'AbstractUICommand');
initMetadataForClass(HtmlString, 'HtmlString');
initMetadataForClass(WeakFilterListener, 'WeakFilterListener');
initMetadataForCompanion(Companion_15);
initMetadataForClass(AbstractFilter, 'AbstractFilter');
initMetadataForClass(AbstractMutableFilter, 'AbstractMutableFilter');
initMetadataForClass(SimpleFilter, 'SimpleFilter', SimpleFilter);
initMetadataForInterface(CPFormat, 'CPFormat');
initMetadataForClass(Dimension, 'Dimension', Dimension.am);
initMetadataForClass(AbstractIndex, 'AbstractIndex');
initMetadataForClass(AbstractMutableInterval, 'AbstractMutableInterval');
initMetadataForClass(AbstractBoundedInterval, 'AbstractBoundedInterval');
initMetadataForClass(WeakIntervalListener, 'WeakIntervalListener');
initMetadataForClass(BoundedIntervalEvent, 'BoundedIntervalEvent');
initMetadataForClass(ClosedInterval, 'ClosedInterval');
initMetadataForClass(IntervalEvent, 'IntervalEvent');
initMetadataForClass(PropertyClosedInterval, 'PropertyClosedInterval');
initMetadataForClass(OpenInterval, 'OpenInterval');
initMetadataForInterface(PropertyListener, 'PropertyListener');
initMetadataForClass(PropertyClosedInterval$1, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(PropertyClosedInterval$2, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(SimpleBoundedInterval$intervalListener$1);
initMetadataForClass(SimpleBoundedInterval, 'SimpleBoundedInterval');
initMetadataForCompanion(Companion_16);
initMetadataForInterface(BigDecimal_0, 'BigDecimal', VOID, VOID, [Comparable]);
initMetadataForCompanion(Companion_17);
initMetadataForInterface(BigInteger_0, 'BigInteger', VOID, VOID, [Comparable]);
initMetadataForClass(BigIntegerRange$iterator$1);
protoOf(BigIntegerRange).i1 = contains;
protoOf(BigIntegerRange).c1 = isEmpty;
initMetadataForClass(BigIntegerRange, 'BigIntegerRange', VOID, VOID, [ClosedRange, Iterable]);
initMetadataForCompanion(Companion_18);
initMetadataForClass(BitSieve, 'BitSieve');
initMetadataForCompanion(Companion_19);
initMetadataForObject(LongOverflow, 'LongOverflow');
initMetadataForClass(StringBuilderHelper, 'StringBuilderHelper', StringBuilderHelper);
initMetadataForCompanion(Companion_20);
protoOf(CommonBigDecimal).sqrt = sqrt;
initMetadataForClass(CommonBigDecimal, 'CommonBigDecimal', VOID, VOID, [BigDecimal_0]);
initMetadataForCompanion(Companion_21);
protoOf(CommonBigInteger).rangeTo = rangeTo;
protoOf(CommonBigInteger).rangeToInt = rangeToInt;
protoOf(CommonBigInteger).rangeToLong = rangeToLong;
protoOf(CommonBigInteger).plusInt = plusInt;
protoOf(CommonBigInteger).plusLong = plusLong;
protoOf(CommonBigInteger).minusInt = minusInt;
protoOf(CommonBigInteger).minusLong = minusLong;
protoOf(CommonBigInteger).timesInt = timesInt;
protoOf(CommonBigInteger).timesLong = timesLong;
protoOf(CommonBigInteger).divInt = divInt;
protoOf(CommonBigInteger).divLong = divLong;
protoOf(CommonBigInteger).divideAndRemainderInt = divideAndRemainderInt;
protoOf(CommonBigInteger).divideAndRemainderLong = divideAndRemainderLong;
protoOf(CommonBigInteger).reminderInt = reminderInt;
protoOf(CommonBigInteger).reminderLong = reminderLong;
protoOf(CommonBigInteger).gcdInt = gcdInt;
protoOf(CommonBigInteger).gcdLong = gcdLong;
protoOf(CommonBigInteger).remInt = remInt;
protoOf(CommonBigInteger).remLong = remLong;
protoOf(CommonBigInteger).modInverseInt = modInverseInt;
protoOf(CommonBigInteger).modInverseLong = modInverseLong;
protoOf(CommonBigInteger).andInt = andInt;
protoOf(CommonBigInteger).andLong = andLong;
protoOf(CommonBigInteger).orInt = orInt;
protoOf(CommonBigInteger).orLong = orLong;
protoOf(CommonBigInteger).xorInt = xorInt;
protoOf(CommonBigInteger).xorLong = xorLong;
protoOf(CommonBigInteger).andNotInt = andNotInt;
protoOf(CommonBigInteger).andNotLong = andNotLong;
initMetadataForClass(CommonBigInteger, 'CommonBigInteger', VOID, VOID, [BigInteger_0]);
initMetadataForCompanion(Companion_22);
initMetadataForClass(MathContext, 'MathContext', MathContext);
initMetadataForCompanion(Companion_23);
initMetadataForClass(MutableBigInteger, 'MutableBigInteger', MutableBigInteger.lr);
initMetadataForCompanion(Companion_24);
initMetadataForClass(RoundingMode, 'RoundingMode');
initMetadataForClass(SignedMutableBigInteger, 'SignedMutableBigInteger', SignedMutableBigInteger.xw);
initMetadataForClass(AbstractProperty, 'AbstractProperty');
initMetadataForInterface(MutableProperty, 'MutableProperty');
protoOf(AbstractMutableProperty).sh = getValue;
protoOf(AbstractMutableProperty).wx = setValue;
initMetadataForClass(AbstractMutableProperty, 'AbstractMutableProperty', VOID, VOID, [AbstractProperty, MutableProperty]);
initMetadataForClass(WeakPropertiesListener, 'WeakPropertiesListener');
initMetadataForClass(AbstractProperties, 'AbstractProperties', VOID, VOID, [Iterable]);
initMetadataForClass(WeakPropertyListener, 'WeakPropertyListener', VOID, VOID, [PropertyListener]);
initMetadataForClass(EnumProperties$ExposedProperty$listener$1, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(NamedPropertyListener, 'NamedPropertyListener', VOID, VOID, [PropertyListener]);
initMetadataForClass(ExposedProperty, 'ExposedProperty', VOID, VOID, [AbstractMutableProperty, MutableProperty]);
initMetadataForClass(EnumProperties, 'EnumProperties', VOID, VOID, [AbstractProperties, Iterable]);
initMetadataForClass(KReadWriteProperty, 'KReadWriteProperty');
initMetadataForCompanion(Companion_25);
initMetadataForClass(OverrideProperties$registerPropertyListener$1, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(OverrideProperties, 'OverrideProperties', VOID, VOID, [AbstractProperties, Iterable]);
initMetadataForClass(OverrideProperty$overridePropertyListener$1, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(OverrideProperty$1, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(OverrideProperty$2, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(OverrideProperty, 'OverrideProperty');
initMetadataForClass(PropertyDelegates$mutable$1);
initMetadataForObject(PropertyDelegates, 'PropertyDelegates');
initMetadataForClass(PropertyEvent, 'PropertyEvent');
initMetadataForClass(SimpleProperties$ExposedProperty$listener$1, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(NamedPropertyListener_0, 'NamedPropertyListener', VOID, VOID, [PropertyListener]);
initMetadataForClass(ExposedProperty_0, 'ExposedProperty', VOID, VOID, [AbstractMutableProperty, MutableProperty]);
initMetadataForClass(SimpleProperties, 'SimpleProperties', SimpleProperties, VOID, [AbstractProperties, Iterable]);
initMetadataForCompanion(Companion_26);
initMetadataForClass(SimpleProperty$value$$inlined$observable$1);
initMetadataForClass(SimpleProperty, 'SimpleProperty', VOID, VOID, [AbstractMutableProperty, MutableProperty]);
initMetadataForClass(StartEnd, 'StartEnd');
initMetadataForClass(BoundedIntervalProperty$1);
initMetadataForClass(BoundedIntervalProperty, 'BoundedIntervalProperty');
initMetadataForClass(NumericTransform, 'NumericTransform');
initMetadataForObject(Probit, 'Probit');
initMetadataForClass(AbstractSelection, 'AbstractSelection', VOID, VOID, [Iterable]);
initMetadataForClass(AbstractMutableSelection, 'AbstractMutableSelection', VOID, VOID, [AbstractSelection, Iterable]);
initMetadataForClass(WeakSingleSelectionListener, 'WeakSingleSelectionListener');
initMetadataForClass(AbstractMutableSingleSelection, 'AbstractMutableSingleSelection', VOID, VOID, [AbstractMutableSelection, Iterable]);
initMetadataForClass(WeakSelectionListener, 'WeakSelectionListener');
initMetadataForClass(AbstractSelectionEvent, 'AbstractSelectionEvent');
initMetadataForClass(PropertySingleSelection$iterator$1);
initMetadataForClass(PropertySingleSelection$1, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(PropertySingleSelection, 'PropertySingleSelection', VOID, VOID, [AbstractMutableSingleSelection, Iterable]);
initMetadataForClass(SimpleSelection, 'SimpleSelection', SimpleSelection.m14, VOID, [AbstractMutableSelection, Iterable]);
initMetadataForClass(SimpleSelectionEvent, 'SimpleSelectionEvent');
initMetadataForClass(SimpleSingleSelection$iterator$1);
initMetadataForClass(SimpleSingleSelection, 'SimpleSingleSelection', SimpleSingleSelection.w14, VOID, [AbstractMutableSingleSelection, Iterable]);
initMetadataForClass(SingleSelectionEvent, 'SingleSelectionEvent');
initMetadataForClass(AbstractCPTimer, 'AbstractCPTimer');
initMetadataForClass(AbstractMutableOneDScreenTransform, 'AbstractMutableOneDScreenTransform');
initMetadataForClass(RangesScreenTransformCoordinator$xRangeListener$1);
initMetadataForClass(RangesScreenTransformCoordinator$yRangeListener$1);
initMetadataForClass(RangesScreenTransformCoordinator, 'RangesScreenTransformCoordinator');
initMetadataForClass(ScreenTransformEvent, 'ScreenTransformEvent', ScreenTransformEvent);
initMetadataForClass(SimpleOneDScreenTransform$intervalListener$1);
initMetadataForClass(SimpleOneDScreenTransform, 'SimpleOneDScreenTransform');
initMetadataForClass(Quantity, 'Quantity', VOID, VOID, [Comparable]);
initMetadataForObject(CollectionFactory, 'CollectionFactory');
initMetadataForClass(JsArrayList, 'JsArrayList');
initMetadataForClass(SoftReference, 'SoftReference');
initMetadataForClass(CallableFuture, 'CallableFuture');
initMetadataForClass(ExecutorService, 'ExecutorService', ExecutorService);
initMetadataForCompanion(Companion_27);
initMetadataForClass(Runtime, 'Runtime', Runtime);
initMetadataForCompanion(Companion_28);
initMetadataForClass(CPHelper, 'CPHelper', CPHelper);
initMetadataForClass(Timer, 'Timer');
initMetadataForClass(GWTTimer$1);
initMetadataForClass(GWTTimer, 'GWTTimer');
initMetadataForCompanion(Companion_29);
initMetadataForClass(FormatFactory$createDecimalFormat$1, VOID, VOID, VOID, [CPFormat]);
initMetadataForClass(FormatFactory, 'FormatFactory', FormatFactory);
initMetadataForObject(BigDecimals, 'BigDecimals');
initMetadataForObject(BigIntegers, 'BigIntegers');
initMetadataForClass(Timing, 'Timing', Timing);
initMetadataForClass(atomicfu$TraceBase, 'TraceBase');
initMetadataForObject(None, 'None');
initMetadataForClass(AtomicRef, 'AtomicRef');
initMetadataForClass(AtomicBoolean, 'AtomicBoolean');
initMetadataForClass(AtomicInt, 'AtomicInt');
initMetadataForClass(SchedulerTask, 'SchedulerTask');
initMetadataForClass(DispatchedTask, 'DispatchedTask');
initMetadataForClass(CancellableContinuationImpl, 'CancellableContinuationImpl');
initMetadataForInterface(NotCompleted, 'NotCompleted');
initMetadataForInterface(CancelHandler, 'CancelHandler', VOID, VOID, [NotCompleted]);
initMetadataForClass(UserSupplied, 'UserSupplied', VOID, VOID, [CancelHandler]);
initMetadataForObject(Active, 'Active', VOID, VOID, [NotCompleted]);
initMetadataForClass(CompletedContinuation, 'CompletedContinuation');
initMetadataForClass(LockFreeLinkedListNode, 'LockFreeLinkedListNode', LockFreeLinkedListNode);
initMetadataForInterface(Incomplete, 'Incomplete');
initMetadataForClass(JobNode, 'JobNode', VOID, VOID, [LockFreeLinkedListNode, Incomplete]);
initMetadataForClass(ChildContinuation, 'ChildContinuation');
initMetadataForClass(CompletedExceptionally, 'CompletedExceptionally');
initMetadataForClass(CancelledContinuation, 'CancelledContinuation');
initMetadataForObject(Key_0, 'Key');
protoOf(CoroutineDispatcher).ec = get_0;
initMetadataForClass(CoroutineDispatcher, 'CoroutineDispatcher', VOID, VOID, [AbstractCoroutineContextElement, ContinuationInterceptor]);
initMetadataForObject(Key_1, 'Key');
initMetadataForClass(EventLoop, 'EventLoop');
initMetadataForObject(ThreadLocalEventLoop, 'ThreadLocalEventLoop');
initMetadataForClass(CompletionHandlerException, 'CompletionHandlerException');
initMetadataForClass(CoroutinesInternalError, 'CoroutinesInternalError');
initMetadataForObject(Key_2, 'Key');
initMetadataForObject(NonDisposableHandle, 'NonDisposableHandle');
initMetadataForClass(Empty, 'Empty', VOID, VOID, [Incomplete]);
initMetadataForClass(LockFreeLinkedListHead, 'LockFreeLinkedListHead', LockFreeLinkedListHead);
initMetadataForClass(NodeList, 'NodeList', NodeList, VOID, [LockFreeLinkedListHead, Incomplete]);
initMetadataForClass(SynchronizedObject, 'SynchronizedObject');
initMetadataForClass(Finishing, 'Finishing', VOID, VOID, [SynchronizedObject, Incomplete]);
initMetadataForClass(JobSupport, 'JobSupport', VOID, VOID, [Element], [0]);
initMetadataForClass(InactiveNodeList, 'InactiveNodeList', VOID, VOID, [Incomplete]);
initMetadataForClass(ConcurrentLinkedListNode, 'ConcurrentLinkedListNode');
initMetadataForClass(Segment, 'Segment', VOID, VOID, [ConcurrentLinkedListNode, NotCompleted]);
initMetadataForObject(ExceptionSuccessfullyProcessed, 'ExceptionSuccessfullyProcessed');
initMetadataForClass(DispatchedContinuation, 'DispatchedContinuation');
initMetadataForClass(DispatchException, 'DispatchException');
initMetadataForClass(Symbol_0, 'Symbol');
initMetadataForClass(UnconfinedEventLoop, 'UnconfinedEventLoop', UnconfinedEventLoop);
initMetadataForClass(DiagnosticCoroutineContextException, 'DiagnosticCoroutineContextException');
initMetadataForClass(ListClosed, 'ListClosed');
initMetadataForClass(CommonThreadLocal, 'CommonThreadLocal', CommonThreadLocal);
initMetadataForClass(EventInstance, 'EventInstance');
initMetadataForObject(ReactHTML, 'ReactHTML');
initMetadataForInterface(IColor, 'IColor');
initMetadataForClass(PropertyType, 'PropertyType');
initMetadataForClass(WeakColorMapListener, 'WeakColorMapListener');
initMetadataForCompanion(Companion_30);
initMetadataForClass(AbstractColorMap, 'AbstractColorMap');
initMetadataForClass(Assignments, 'Assignments');
initMetadataForClass(ColorMapEvent, 'ColorMapEvent');
initMetadataForClass(ColorMapFactory, 'ColorMapFactory');
initMetadataForClass(Matching, 'Matching');
initMetadataForClass(SetStoreMutableProperty$1, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(SetStoreMutableProperty$2, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(SetStoreMutableProperty$3, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(SetStoreMutableProperty, 'SetStoreMutableProperty');
initMetadataForClass(SimpleColorMap$intervalListener$1);
initMetadataForClass(SimpleColorMap$paletteListener$1);
initMetadataForClass(SimpleColorMap$1, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(SimpleColorMap$2, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(SimpleColorMap$3, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(SimpleColorMap$4, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(SimpleColorMap$5, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(SimpleColorMap$6, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(SimpleColorMap$7, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(SimpleColorMap$8, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(SimpleColorMap$9, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(SimpleColorMap, 'SimpleColorMap');
initMetadataForClass(MutableColorMapOverrideProperty, 'MutableColorMapOverrideProperty');
initMetadataForClass(MutableColorMapProperty$colorMapListener$1);
initMetadataForClass(MutableColorMapProperty, 'MutableColorMapProperty');
initMetadataForClass(InteractiveComponentListeners, 'InteractiveComponentListeners', InteractiveComponentListeners);
initMetadataForClass(Posture, 'Posture');
initMetadataForClass(Weight, 'Weight');
initMetadataForCompanion(Companion_31);
initMetadataForInterface(Shape, 'Shape');
initMetadataForInterface(Rectangle2D, 'Rectangle2D', VOID, VOID, [Shape]);
protoOf(AbstractRectangle2D).g1m = getPathIterator$default;
initMetadataForClass(AbstractRectangle2D, 'AbstractRectangle2D', VOID, VOID, [Rectangle2D]);
initMetadataForCompanion(Companion_32);
initMetadataForClass(AffineTransform, 'AffineTransform', AffineTransform.z1n);
initMetadataForCompanion(Companion_33);
initMetadataForInterface(Arc2D, 'Arc2D', VOID, VOID, [Shape]);
protoOf(Double).g1m = getPathIterator$default;
protoOf(Double).v1l = get_bounds;
initMetadataForClass(Double, 'Double', VOID, VOID, [Arc2D]);
initMetadataForCompanion(Companion_34);
initMetadataForClass(ArcIterator, 'ArcIterator');
initMetadataForClass(AreaIterator, 'AreaIterator');
initMetadataForCompanion(Companion_35);
protoOf(Area).g1m = getPathIterator$default;
protoOf(Area).v1l = get_bounds;
initMetadataForClass(Area, 'Area', Area.i1r, VOID, [Shape]);
initMetadataForClass(sam$kotlin_Comparator$0_0, 'sam$kotlin_Comparator$0', VOID, VOID, [Comparator, FunctionAdapter]);
initMetadataForClass(AreaOp, 'AreaOp');
initMetadataForClass(CAGOp, 'CAGOp');
initMetadataForClass(IntOp, 'IntOp', IntOp);
initMetadataForClass(XorOp, 'XorOp', XorOp);
initMetadataForClass(NZWindOp, 'NZWindOp', NZWindOp);
initMetadataForClass(EOWindOp, 'EOWindOp', EOWindOp);
initMetadataForCompanion(Companion_36);
initMetadataForClass(ChainEnd, 'ChainEnd');
initMetadataForClass(Crossings, 'Crossings');
initMetadataForClass(EvenOdd, 'EvenOdd');
initMetadataForCompanion(Companion_37);
initMetadataForCompanion(Companion_38);
initMetadataForClass(Curve, 'Curve');
initMetadataForClass(CurveLink, 'CurveLink');
initMetadataForCompanion(Companion_39);
initMetadataForClass(Edge, 'Edge');
initMetadataForInterface(Ellipse2D, 'Ellipse2D', VOID, VOID, [Shape]);
protoOf(Double_0).g1m = getPathIterator$default;
protoOf(Double_0).v1l = get_bounds;
initMetadataForClass(Double_0, 'Double', VOID, VOID, [Ellipse2D]);
initMetadataForCompanion(Companion_40);
initMetadataForClass(EllipseIterator, 'EllipseIterator');
initMetadataForCompanion(Companion_41);
initMetadataForClass(Order0, 'Order0');
initMetadataForClass(Order1, 'Order1');
initMetadataForCompanion(Companion_42);
initMetadataForClass(Order2, 'Order2');
initMetadataForCompanion(Companion_43);
initMetadataForClass(Order3, 'Order3');
initMetadataForClass(Iterator, 'Iterator');
initMetadataForClass(CopyIterator, 'CopyIterator');
initMetadataForClass(TxIterator, 'TxIterator');
initMetadataForCompanion(Companion_44);
protoOf(Path2D).v1l = get_bounds;
protoOf(Path2D).g1m = getPathIterator$default;
initMetadataForClass(Path2D, 'Path2D', VOID, VOID, [Shape]);
initMetadataForClass(Double_1, 'Double', Double_1.j1z);
initMetadataForCompanion(Companion_45);
initMetadataForClass(Point, 'Point');
initMetadataForClass(Double_2, 'Double', Double_2.p1o);
initMetadataForClass(Float, 'Float', Float.m1o);
initMetadataForCompanion(Companion_46);
initMetadataForClass(RectIterator, 'RectIterator');
initMetadataForClass(Rectangle, 'Rectangle', Rectangle.empty);
initMetadataForCompanion(Companion_47);
initMetadataForClass(Double_3, 'Double');
initMetadataForCompanion(Companion_48);
initMetadataForClass(RoundRectIterator, 'RoundRectIterator');
initMetadataForClass(RoundRectangle2D, 'RoundRectangle2D');
initMetadataForClass(Double_4, 'Double', Double_4.u21);
initMetadataForObject(ScreenTransformHelper, 'ScreenTransformHelper');
initMetadataForClass(TextShape, 'TextShape', VOID, VOID, [Shape]);
initMetadataForCompanion(Companion_49);
initMetadataForClass(AbstractIGraphics, 'AbstractIGraphics');
initMetadataForClass(Insets, 'Insets');
initMetadataForCompanion(Companion_50);
initMetadataForClass(ContrastEnhancement, 'ContrastEnhancement');
initMetadataForObject(Off, 'Off');
initMetadataForObject(Brightness, 'Brightness');
initMetadataForObject(BlackWhite, 'BlackWhite');
initMetadataForObject(Complement, 'Complement');
initMetadataForClass(Effect, 'Effect');
initMetadataForObject(Plain, 'Plain');
initMetadataForObject(Shadow, 'Shadow');
initMetadataForObject(Glow, 'Glow');
initMetadataForObject(Outline, 'Outline');
initMetadataForObject(Emphasize, 'Emphasize');
initMetadataForClass(Rendering, 'Rendering');
initMetadataForCompanion(Companion_51);
initMetadataForClass(EnhancedLabel, 'EnhancedLabel', EnhancedLabel.z23);
initMetadataForClass(AbstractPalette, 'AbstractPalette');
initMetadataForInterface(MutablePalette, 'MutablePalette');
initMetadataForClass(AbstractMutablePalette, 'AbstractMutablePalette', VOID, VOID, [AbstractPalette, MutablePalette]);
initMetadataForClass(Mode, 'Mode');
initMetadataForClass(Entry_0, 'Entry', VOID, VOID, [Comparable]);
initMetadataForClass(sam$kotlin_Comparator$0_1, 'sam$kotlin_Comparator$0', VOID, VOID, [Comparator, FunctionAdapter]);
initMetadataForClass(CustomPalette$1, VOID, VOID, VOID, [PropertyListener]);
initMetadataForClass(DynamicPalette, 'DynamicPalette');
initMetadataForClass(CustomPalette, 'CustomPalette');
initMetadataForClass(Cycle, 'Cycle');
initMetadataForCompanion(Companion_52);
initMetadataForClass(FixedPalette, 'FixedPalette', VOID, VOID, [AbstractPalette, MutablePalette]);
initMetadataForClass(Mode_0, 'Mode');
initMetadataForClass(Entry_1, 'Entry', VOID, VOID, [Comparable]);
initMetadataForClass(sam$kotlin_Comparator$0_2, 'sam$kotlin_Comparator$0', VOID, VOID, [Comparator, FunctionAdapter]);
initMetadataForClass(sam$kotlin_Comparator$0_3, 'sam$kotlin_Comparator$0', VOID, VOID, [Comparator, FunctionAdapter]);
initMetadataForClass(InterpolatedPalette, 'InterpolatedPalette');
initMetadataForClass(PaletteEvent, 'PaletteEvent', PaletteEvent);
initMetadataForClass(Entry_2, 'Entry');
initMetadataForCompanion(Companion_53);
initMetadataForClass(PaletteFactory, 'PaletteFactory', PaletteFactory);
initMetadataForClass(PaletteType, 'PaletteType');
initMetadataForClass(ScreenTransformRubberBand, 'ScreenTransformRubberBand');
initMetadataForClass(AbstractTwoDScreenTransform, 'AbstractTwoDScreenTransform');
initMetadataForClass(AbstractMutableTwoDScreenTransform, 'AbstractMutableTwoDScreenTransform');
initMetadataForClass(SimpleTwoDScreenTransform$intervalListener$1);
initMetadataForClass(SimpleTwoDScreenTransform, 'SimpleTwoDScreenTransform');
initMetadataForClass(CPCanvas, 'CPCanvas', CPCanvas);
initMetadataForClass(FunctionalCPCanvas$timer$1);
initMetadataForClass(FunctionalCPCanvas, 'FunctionalCPCanvas');
initMetadataForClass(JSMouseEvent, 'JSMouseEvent');
initMetadataForCompanion(Companion_54);
initMetadataForClass(MkColorFactory, 'MkColorFactory', MkColorFactory);
protoOf(CPColor).l1e = toHTMLColor;
protoOf(CPColor).m1e = toJavaScriptColor;
initMetadataForClass(CPColor, 'CPColor', VOID, VOID, [IColor]);
initMetadataForClass(ElementalKeyEvent, 'ElementalKeyEvent');
initMetadataForClass(CPInteractiveHandler$registerMouseWheelListener$1$1);
initMetadataForClass(CPInteractiveHandler$registerContextMenuListener$1$1);
initMetadataForClass(CPInteractiveHandler, 'CPInteractiveHandler');
initMetadataForClass(CPPopupMenu, 'CPPopupMenu', CPPopupMenu);
initMetadataForCompanion(Companion_55);
initMetadataForClass(CPFontFactory, 'CPFontFactory', CPFontFactory);
initMetadataForClass(CPFont, 'CPFont');
initMetadataForClass(CPImage, 'CPImage');
initMetadataForObject(CPImageFactory, 'CPImageFactory');
initMetadataForClass(AbstractAggregation, 'AbstractAggregation');
initMetadataForClass(SumAggregation, 'SumAggregation');
initMetadataForCompanion(Companion_56);
initMetadataForInterface(Group, 'Group');
initMetadataForClass(ArrayGroup, 'ArrayGroup', VOID, VOID, [Group]);
initMetadataForCompanion(Companion_57);
initMetadataForClass(Dice, 'Dice');
initMetadataForCompanion(Companion_58);
initMetadataForClass(Dimensions, 'Dimensions');
initMetadataForClass(DistributiveStatistics, 'DistributiveStatistics', DistributiveStatistics.d2f);
initMetadataForObject(GroupFactory, 'GroupFactory');
initMetadataForClass(DimensionsDiceStructure, 'DimensionsDiceStructure');
initMetadataForClass(InMemoryCube$listener$1);
initMetadataForClass(InMemoryCube, 'InMemoryCube');
initMetadataForClass(LinkedGroup, 'LinkedGroup', LinkedGroup.s2f, VOID, [Group]);
initMetadataForClass(GroupColumn, 'GroupColumn');
initMetadataForClass(AbstractCuboid, 'AbstractCuboid');
initMetadataForClass(ApexCuboid$listener$1);
initMetadataForClass(ApexCuboid, 'ApexCuboid');
initMetadataForClass(Cuboid$Companion$ALL$1);
initMetadataForCompanion(Companion_59);
initMetadataForClass(WeakQueryListener, 'WeakQueryListener');
initMetadataForCompanion(Companion_60);
initMetadataForClass(AbstractQuery, 'AbstractQuery');
initMetadataForClass(CuboidQuery$queryListener$1);
initMetadataForClass(CuboidQuery$dataFrameListener$1);
initMetadataForClass(CuboidQuery, 'CuboidQuery');
initMetadataForInterface(Series, 'Series');
initMetadataForClass(AbstractSeries, 'AbstractSeries', VOID, VOID, [Series]);
initMetadataForClass(DimensionSeries, 'DimensionSeries');
initMetadataForClass(AggregationSeries, 'AggregationSeries');
initMetadataForClass(QueryDataFrame$queryListener$1);
initMetadataForInterface(DataFrame, 'DataFrame');
initMetadataForClass(AbstractDataFrame, 'AbstractDataFrame', VOID, VOID, [DataFrame]);
initMetadataForClass(QueryDataFrame, 'QueryDataFrame', VOID, VOID, [AbstractDataFrame, DataFrame]);
initMetadataForCompanion(Companion_61);
initMetadataForClass(Structure, 'Structure');
initMetadataForClass(WeakDataFrameListener, 'WeakDataFrameListener');
initMetadataForClass(ColumnSeries, 'ColumnSeries');
initMetadataForCompanion(Companion_62);
initMetadataForClass(ColumnStatistics, 'ColumnStatistics');
initMetadataForClass(DataFrameEvent, 'DataFrameEvent');
initMetadataForObject(DataFrameHelper, 'DataFrameHelper');
initMetadataForClass(DefaultDataFrame, 'DefaultDataFrame');
initMetadataForClass(AbstractUniqueIndex$keys$1$iterator$1);
initMetadataForClass(AbstractUniqueIndex$keys$1, VOID, VOID, VOID, [Iterable]);
initMetadataForClass(AbstractUniqueIndex, 'AbstractUniqueIndex');
initMetadataForClass(Lazy, 'Lazy');
initMetadataForCompanion(Companion_63);
initMetadataForClass(DefaultUniqueIndex$3);
initMetadataForClass(DefaultUniqueIndex, 'DefaultUniqueIndex');
initMetadataForClass(IntegerRangeUniqueIndex$keys$1$iterator$1);
initMetadataForClass(IntegerRangeUniqueIndex$keys$1, VOID, VOID, VOID, [Iterable]);
initMetadataForClass(IntegerRangeUniqueIndex, 'IntegerRangeUniqueIndex');
initMetadataForClass(Duplicate, 'Duplicate');
initMetadataForInterface(Graph, 'Graph');
initMetadataForInterface(MutableSeries, 'MutableSeries', VOID, VOID, [Series]);
initMetadataForClass(DefaultSeries, 'DefaultSeries', VOID, VOID, [AbstractSeries, MutableSeries]);
initMetadataForClass(DoubleSeries, 'DoubleSeries', VOID, VOID, [AbstractSeries, MutableSeries]);
initMetadataForClass(FloatSeries, 'FloatSeries', VOID, VOID, [AbstractSeries, MutableSeries]);
initMetadataForClass(IntegerSeries, 'IntegerSeries', VOID, VOID, [AbstractSeries, MutableSeries]);
initMetadataForClass(LongSeries, 'LongSeries', VOID, VOID, [AbstractSeries, MutableSeries]);
initMetadataForCompanion(Companion_64);
initMetadataForClass(SeriesFactory, 'SeriesFactory');
initMetadataForClass(JsonDataFrame, 'JsonDataFrame');
initMetadataForInterface(Scale, 'Scale');
initMetadataForClass(AbsScale, 'AbsScale', AbsScale, VOID, [Scale]);
initMetadataForInterface(Algorithm, 'Algorithm');
initMetadataForClass(AbstractAlgorithm, 'AbstractAlgorithm', VOID, VOID, [Algorithm]);
initMetadataForCompanion(Companion_65);
initMetadataForInterface(Labeling, 'Labeling');
initMetadataForClass(AbstractLabeling, 'AbstractLabeling', VOID, VOID, [Labeling]);
initMetadataForCompanion(Companion_66);
initMetadataForInterface(Nesting, 'Nesting');
initMetadataForClass(AbstractNesting, 'AbstractNesting', VOID, VOID, [Nesting]);
initMetadataForClass(AbstractNodeRenderer, 'AbstractNodeRenderer');
initMetadataForCompanion(Companion_67);
initMetadataForClass(AbstractRendering$getOrder$1, VOID, VOID, VOID, [Comparator]);
initMetadataForInterface(Rendering_0, 'Rendering');
initMetadataForClass(AbstractRendering, 'AbstractRendering', VOID, VOID, [Rendering_0]);
initMetadataForCompanion(Companion_68);
initMetadataForInterface(TreeMap, 'TreeMap');
initMetadataForClass(AbstractTreeMap, 'AbstractTreeMap', VOID, VOID, [TreeMap]);
initMetadataForCompanion(Companion_69);
initMetadataForInterface(TreeMapColumnSettings, 'TreeMapColumnSettings');
initMetadataForClass(AbstractTreeMapColumnSettings, 'AbstractTreeMapColumnSettings', VOID, VOID, [TreeMapColumnSettings]);
initMetadataForClass(Mode_1, 'Mode');
initMetadataForClass(Range, 'Range');
initMetadataForClass(DefaultMouseListener, 'DefaultMouseListener');
initMetadataForClass(AbstractTreeMapController$keyListener$1);
initMetadataForClass(AbstractTreeMapController$setView$1);
initMetadataForClass(AbstractTreeMapController$openPopupMenu$drillDownCommand$1);
initMetadataForClass(AbstractTreeMapController$openPopupMenu$drillUpCommand$1);
initMetadataForClass(AbstractTreeMapController$openPopupMenu$zoomInCommand$1);
initMetadataForClass(AbstractTreeMapController$openPopupMenu$zoomOutCommand$1);
initMetadataForClass(AbstractTreeMapController, 'AbstractTreeMapController');
initMetadataForClass(NodeField, 'NodeField');
initMetadataForClass(Worker, 'Worker');
initMetadataForCompanion(Companion_70);
initMetadataForClass(AbstractTreeMapModel$colorMapListener$1);
initMetadataForClass(AbstractTreeMapModel$colorProvider$1);
initMetadataForClass(AbstractTreeMapModel$groupByColumns$1);
initMetadataForClass(AbstractTreeMapModel$sizeColumns$1);
initMetadataForClass(AbstractTreeMapModel$colorColumns$1);
initMetadataForClass(AbstractTreeMapModel$heightColumns$1);
initMetadataForClass(AbstractTreeMapModel$labelsColumns$1);
initMetadataForClass(AbstractTreeMapModel$tooltipColumns$1);
initMetadataForClass(AbstractTreeMapModel$parentPreorderEnumeration$1, VOID, VOID, VOID, [Iterable]);
initMetadataForClass(AbstractTreeMapModel$preorderEnumeration$1, VOID, VOID, VOID, [Iterable]);
initMetadataForClass(AbstractTreeMapModel$breadthFirstIterator$1, VOID, VOID, VOID, [Iterable]);
initMetadataForClass(AbstractTreeMapModel$depthFirstIterator$1, VOID, VOID, VOID, [Iterable]);
initMetadataForClass(AbstractTreeMapModel$1);
initMetadataForClass(AbstractTreeMapModel$2);
initMetadataForClass(AbstractTreeMapModel$3);
initMetadataForClass(AbstractTreeMapModel$4);
initMetadataForClass(AbstractTreeMapModel$5);
initMetadataForClass(AbstractTreeMapModel$6);
initMetadataForClass(AbstractTreeMapModel$7, VOID, VOID, VOID, [PropertyListener]);
initMetadataForInterface(TreeMapModel, 'TreeMapModel');
initMetadataForClass(AbstractTreeMapModel, 'AbstractTreeMapModel', VOID, VOID, [TreeMapModel]);
initMetadataForClass(AbstractTreeMapNode, 'AbstractTreeMapNode');
initMetadataForCompanion(Companion_71);
initMetadataForInterface(TreeMapSettings, 'TreeMapSettings');
initMetadataForClass(AbstractTreeMapSettings, 'AbstractTreeMapSettings', VOID, VOID, [TreeMapSettings]);
initMetadataForCompanion(Companion_72);
initMetadataForClass(AbstractTreeMapToolTip, 'AbstractTreeMapToolTip');
initMetadataForClass(AbstractTreeMapView$probingListener$1);
initMetadataForClass(AbstractTreeMapView$selectionListener$1);
initMetadataForClass(AbstractTreeMapView$_treeMapListener$1);
initMetadataForClass(AbstractTreeMapView$modelPropertyChangeListener$1);
initMetadataForClass(AbstractTreeMapView$filterListener$1);
initMetadataForClass(AbstractTreeMapView$propertyChangeListener$1);
initMetadataForClass(AbstractTreeMapView$1);
initMetadataForClass(AbstractTreeMapView$2);
initMetadataForClass(AbstractTreeMapView, 'AbstractTreeMapView');
initMetadataForInterface(Aggregation, 'Aggregation');
initMetadataForCompanion(Companion_73);
initMetadataForClass(AggregationFactory, 'AggregationFactory');
initMetadataForCompanion(Companion_74);
initMetadataForClass(AlgorithmFactory, 'AlgorithmFactory');
initMetadataForClass(AverageAggregation, 'AverageAggregation', AverageAggregation, VOID, [Aggregation]);
initMetadataForClass(BackgroundParentNodeRenderer, 'BackgroundParentNodeRenderer', BackgroundParentNodeRenderer);
initMetadataForClass(BackgroundRootNodeTreeMapRenderer, 'BackgroundRootNodeTreeMapRenderer', BackgroundRootNodeTreeMapRenderer);
initMetadataForClass(Orientation, 'Orientation');
initMetadataForClass(BarAlgorithm, 'BarAlgorithm', BarAlgorithm);
initMetadataForClass(BinaryTreeAlgorithm, 'BinaryTreeAlgorithm', BinaryTreeAlgorithm);
initMetadataForClass(BorderParentNodeRenderer, 'BorderParentNodeRenderer', BorderParentNodeRenderer);
initMetadataForClass(Queue, 'Queue');
initMetadataForClass(QNode, 'QNode');
initMetadataForClass(BreadthFirstIterator, 'BreadthFirstIterator');
initMetadataForClass(Circle, 'Circle', Circle.v3e, VOID, [Comparable]);
initMetadataForClass(Complex, 'Complex');
initMetadataForCompanion(Companion_75);
initMetadataForClass(CirclePackingAlgorithm, 'CirclePackingAlgorithm', CirclePackingAlgorithm, VOID, [Algorithm]);
initMetadataForClass(Pair_0, 'Pair');
initMetadataForClass(Circle_0, 'Circle', Circle_0.c3g, VOID, [Comparable]);
initMetadataForClass(Complex_0, 'Complex');
initMetadataForCompanion(Companion_76);
initMetadataForClass(CircularAlgorithm, 'CircularAlgorithm', CircularAlgorithm);
initMetadataForClass(AscendingTreeMapNodeComparator, 'AscendingTreeMapNodeComparator', VOID, VOID, [Comparator]);
initMetadataForClass(DescendingTreeMapNodeComparator, 'DescendingTreeMapNodeComparator', VOID, VOID, [Comparator]);
initMetadataForCompanion(Companion_77);
initMetadataForInterface(Ordering, 'Ordering');
initMetadataForClass(ColorOrdering, 'ColorOrdering', ColorOrdering, VOID, [Ordering]);
initMetadataForClass(SurroundLabeling, 'SurroundLabeling', SurroundLabeling);
initMetadataForClass(ColoredSurroundLabeling, 'ColoredSurroundLabeling', ColoredSurroundLabeling);
initMetadataForObject(CombinationGenerator, 'CombinationGenerator');
initMetadataForClass(CountAggregation, 'CountAggregation', CountAggregation, VOID, [Aggregation]);
initMetadataForClass(Cushion, 'Cushion');
initMetadataForClass(CushionRendering, 'CushionRendering', CushionRendering);
initMetadataForObject(DefaultAlgorithmFactory_0, 'DefaultAlgorithmFactory');
initMetadataForClass(DefaultTreeMap, 'DefaultTreeMap', DefaultTreeMap.m3h);
initMetadataForCompanion(Companion_78);
initMetadataForClass(DefaultTreeMapColumnSettings, 'DefaultTreeMapColumnSettings');
initMetadataForClass(DefaultTreeMapController, 'DefaultTreeMapController');
initMetadataForCompanion(Companion_79);
initMetadataForClass(DefaultTreeMapHeaderRenderer, 'DefaultTreeMapHeaderRenderer', DefaultTreeMapHeaderRenderer.h3b);
initMetadataForCompanion(Companion_80);
initMetadataForClass(DefaultTreeMapLabelRenderer, 'DefaultTreeMapLabelRenderer', DefaultTreeMapLabelRenderer.i3a);
initMetadataForClass(DefaultTreeMapModel$dataFrameListener$1);
initMetadataForClass(DefaultTreeMapModel, 'DefaultTreeMapModel');
initMetadataForClass(DefaultTreeMapPopup, 'DefaultTreeMapPopup');
initMetadataForClass(DefaultTreeMapSettings$propertyChangeListener$1);
initMetadataForClass(DefaultTreeMapSettings$1);
initMetadataForClass(DefaultTreeMapSettings$2);
initMetadataForClass(SingleSelectionSettingsCoordinator, 'SingleSelectionSettingsCoordinator');
initMetadataForClass(DefaultTreeMapSettings$3);
initMetadataForClass(DefaultTreeMapSettings$4);
initMetadataForClass(DefaultTreeMapSettings$5);
initMetadataForClass(DefaultTreeMapSettings$6);
initMetadataForClass(DefaultTreeMapSettings$7);
initMetadataForClass(DefaultTreeMapSettings$8);
initMetadataForClass(DefaultTreeMapSettings$9);
initMetadataForClass(DefaultTreeMapSettings$10);
initMetadataForClass(DefaultTreeMapSettings$11);
initMetadataForClass(DefaultTreeMapSettings$12);
initMetadataForClass(DefaultTreeMapSettings$13);
initMetadataForClass(DefaultTreeMapSettings, 'DefaultTreeMapSettings');
initMetadataForClass(DefaultTreeMapToolTip, 'DefaultTreeMapToolTip');
initMetadataForCompanion(Companion_81);
initMetadataForClass(DefaultTreeMapTooltipRenderer, 'DefaultTreeMapTooltipRenderer', DefaultTreeMapTooltipRenderer.f3c);
initMetadataForClass(DefaultTreeMapView$timer$2$1);
initMetadataForClass(DefaultTreeMapView$1);
initMetadataForClass(DefaultTreeMapView$2);
initMetadataForClass(DefaultTreeMapView, 'DefaultTreeMapView', DefaultTreeMapView);
initMetadataForInterface(Depth, 'Depth');
initMetadataForCompanion(Companion_82);
initMetadataForClass(DepthFactory, 'DepthFactory');
initMetadataForObject(EqualCirclesInCircle, 'EqualCirclesInCircle');
initMetadataForClass(Exp10Scale, 'Exp10Scale', Exp10Scale, VOID, [Scale]);
initMetadataForClass(ExpScale, 'ExpScale', ExpScale, VOID, [Scale]);
initMetadataForClass(ExpandLabeling, 'ExpandLabeling', ExpandLabeling);
initMetadataForClass(FixedNesting, 'FixedNesting', FixedNesting);
initMetadataForClass(FlatRendering, 'FlatRendering', FlatRendering);
initMetadataForClass(FlatNoBorderRendering, 'FlatNoBorderRendering', FlatNoBorderRendering);
initMetadataForClass(AscendingTreeMapNodeComparator_0, 'AscendingTreeMapNodeComparator', VOID, VOID, [Comparator]);
initMetadataForClass(DescendingTreeMapNodeComparator_0, 'DescendingTreeMapNodeComparator', VOID, VOID, [Comparator]);
initMetadataForClass(HeightOrdering, 'HeightOrdering', HeightOrdering, VOID, [Ordering]);
initMetadataForClass(HighlightParentNodeRenderer, 'HighlightParentNodeRenderer', HighlightParentNodeRenderer);
initMetadataForClass(IcicleRectangle2D, 'IcicleRectangle2D');
initMetadataForClass(IcicleAlgorithm, 'IcicleAlgorithm', IcicleAlgorithm);
initMetadataForClass(InfiniteDepth, 'InfiniteDepth', InfiniteDepth, VOID, [Depth]);
initMetadataForClass(InverseScale, 'InverseScale', InverseScale, VOID, [Scale]);
initMetadataForClass(Itertools$combinations$1$iterator$1);
initMetadataForClass(Itertools$combinations$1, VOID, VOID, VOID, [Iterable]);
initMetadataForObject(Itertools, 'Itertools');
initMetadataForCompanion(Companion_83);
initMetadataForClass(LabelingFactory, 'LabelingFactory');
initMetadataForClass(LeafNodeRenderer, 'LeafNodeRenderer');
initMetadataForClass(LeafTreeMapNode, 'LeafTreeMapNode', VOID, VOID, [AbstractTreeMapNode, Comparable]);
initMetadataForClass(Log1pScale, 'Log1pScale', Log1pScale, VOID, [Scale]);
initMetadataForClass(LogScale, 'LogScale', LogScale, VOID, [Scale]);
initMetadataForCompanion(Companion_84);
initMetadataForClass(MatrixAlgorithm, 'MatrixAlgorithm', MatrixAlgorithm);
initMetadataForClass(MaxAggregation, 'MaxAggregation', MaxAggregation, VOID, [Aggregation]);
initMetadataForClass(MaxScale, 'MaxScale', MaxScale, VOID, [Scale]);
initMetadataForClass(MinAggregation, 'MinAggregation', MinAggregation, VOID, [Aggregation]);
initMetadataForClass(MinScale, 'MinScale', MinScale, VOID, [Scale]);
initMetadataForClass(MutableAlgorithmOverrideProperty, 'MutableAlgorithmOverrideProperty');
initMetadataForClass(MutableAlgorithmProperty$propertiesListener$1);
initMetadataForClass(MutableAlgorithmProperty, 'MutableAlgorithmProperty');
initMetadataForCompanion(Companion_85);
initMetadataForClass(NestingFactory, 'NestingFactory');
initMetadataForCompanion(Companion_86);
initMetadataForClass(NodesTreeMapRenderer, 'NodesTreeMapRenderer');
initMetadataForClass(NoneAggregation, 'NoneAggregation', NoneAggregation, VOID, [Aggregation]);
initMetadataForClass(NoneLabeling, 'NoneLabeling', NoneLabeling);
initMetadataForClass(NoneNesting, 'NoneNesting', NoneNesting);
initMetadataForClass(NumericTransformScale, 'NumericTransformScale', VOID, VOID, [Scale]);
initMetadataForClass(SortOrder, 'SortOrder');
initMetadataForCompanion(Companion_87);
initMetadataForClass(OrderingFactory, 'OrderingFactory');
initMetadataForCompanion(Companion_88);
initMetadataForClass(OriginalOrdering, 'OriginalOrdering', OriginalOrdering, VOID, [Ordering]);
initMetadataForClass(OriginalScale, 'OriginalScale', OriginalScale, VOID, [Scale]);
initMetadataForClass(OverlayLabeling, 'OverlayLabeling', OverlayLabeling);
initMetadataForClass(OverridingTreeMapColumnSettings$1);
initMetadataForClass(OverridingTreeMapColumnSettings, 'OverridingTreeMapColumnSettings');
initMetadataForClass(ParentPreorderIterator, 'ParentPreorderIterator');
initMetadataForClass(ParentTreeMapNode, 'ParentTreeMapNode');
initMetadataForClass(PieAlgorithm, 'PieAlgorithm', PieAlgorithm);
initMetadataForClass(SplitSize, 'SplitSize', SplitSize);
initMetadataForClass(PivotByAlgorithm, 'PivotByAlgorithm', PivotByAlgorithm);
initMetadataForClass(PostorderIterator, 'PostorderIterator');
initMetadataForClass(PreorderIterator, 'PreorderIterator');
initMetadataForClass(Progressive, 'Progressive');
initMetadataForClass(Type, 'Type');
initMetadataForCompanion(Companion_89);
initMetadataForClass(ProportionalNesting, 'ProportionalNesting', ProportionalNesting);
initMetadataForCompanion(Companion_90);
initMetadataForClass(RectangularTransform, 'RectangularTransform', RectangularTransform.u2q);
initMetadataForCompanion(Companion_91);
initMetadataForClass(RenderingFactory, 'RenderingFactory');
initMetadataForCompanion(Companion_92);
initMetadataForClass(ScaleFactory, 'ScaleFactory');
initMetadataForClass(SelectionNodeRenderer, 'SelectionNodeRenderer', SelectionNodeRenderer);
initMetadataForClass(DescendingTreeMapNodeComparator_1, 'DescendingTreeMapNodeComparator', VOID, VOID, [Comparator]);
initMetadataForClass(AscendingTreeMapNodeComparator_1, 'AscendingTreeMapNodeComparator', VOID, VOID, [Comparator]);
initMetadataForClass(SizeOrdering, 'SizeOrdering', SizeOrdering, VOID, [Ordering]);
initMetadataForClass(SumAggregation_0, 'SumAggregation', SumAggregation_0, VOID, [Aggregation]);
initMetadataForClass(SizeWeightedAggregation, 'SizeWeightedAggregation', SizeWeightedAggregation);
initMetadataForClass(AlternateOrientationStrategy, 'AlternateOrientationStrategy', AlternateOrientationStrategy);
initMetadataForClass(SliceAndDiceAlgorithm, 'SliceAndDiceAlgorithm', SliceAndDiceAlgorithm);
initMetadataForCompanion(Companion_93);
initMetadataForClass(SplitAlgorithm, 'SplitAlgorithm', SplitAlgorithm);
initMetadataForCompanion(Companion_94);
initMetadataForClass(SquarifiedAlgorithm, 'SquarifiedAlgorithm', SquarifiedAlgorithm);
initMetadataForCompanion(Companion_95);
initMetadataForClass(SquarifiedPlusAlgorithm, 'SquarifiedPlusAlgorithm', SquarifiedPlusAlgorithm);
initMetadataForClass(StdDevAggregation, 'StdDevAggregation', StdDevAggregation, VOID, [Aggregation]);
initMetadataForClass(StripAlgorithm, 'StripAlgorithm', StripAlgorithm);
initMetadataForClass(Arc, 'Arc');
initMetadataForClass(SunburstAlgorithm, 'SunburstAlgorithm', SunburstAlgorithm);
initMetadataForCompanion(Companion_96);
initMetadataForClass(TextParentNodeRenderer, 'TextParentNodeRenderer', TextParentNodeRenderer);
initMetadataForClass(ThresholdDepth, 'ThresholdDepth', VOID, VOID, [Depth]);
initMetadataForCompanion(Companion_97);
initMetadataForClass(ToolTipTreeMapRenderer, 'ToolTipTreeMapRenderer', ToolTipTreeMapRenderer);
initMetadataForClass(TreeMapEvent, 'TreeMapEvent');
initMetadataForClass(TreeMapSettingsEvent, 'TreeMapSettingsEvent');
initMetadataForClass(ToolTipType, 'ToolTipType');
initMetadataForClass(XPlus1Scale, 'XPlus1Scale', XPlus1Scale, VOID, [Scale]);
initMetadataForObject(DataFrameColorMapFactory, 'DataFrameColorMapFactory');
initMetadataForCompanion(Companion_98);
initMetadataForClass(AbstractTGraphics, 'AbstractTGraphics');
initMetadataForClass(SingleSelectionSettingsCoordinator$1);
initMetadataForClass(SingleSelectionSettingsCoordinator$2);
initMetadataForClass(JsTreeMap, 'JsTreeMap');
initMetadataForClass(CanvasRenderingContext2DIGraphics, 'CanvasRenderingContext2DIGraphics');
initMetadataForClass(CanvasRenderingContext2DTGraphics$sizeLabel$1);
initMetadataForClass(CanvasRenderingContext2DTGraphics, 'CanvasRenderingContext2DTGraphics');
initMetadataForClass(Headless$sizeLabel$1);
initMetadataForClass(Headless, 'Headless', Headless);
initMetadataForClass(TreeMapCanvas$addLayer$1);
initMetadataForClass(TreeMapCanvas, 'TreeMapCanvas');
//endregion
//region block: init
Companion_instance_0 = new Companion_0();
Companion_instance_1 = new Companion_1();
Companion_instance_2 = new Companion_2();
Unit_instance = new Unit();
_stableSortingIsSupported = null;
Companion_instance_5 = new Companion_5();
Companion_instance_7 = new Companion_7();
Companion_instance_8 = new Companion_8();
Companion_instance_9 = new Companion_9();
EmptyIterator_instance = new EmptyIterator();
EmptySequence_instance = new EmptySequence();
NaturalOrderComparator_instance = new NaturalOrderComparator();
Key_instance = new Key();
Delegates_instance = new Delegates();
Companion_instance_13 = new Companion_13();
State_instance = new State();
UNINITIALIZED_VALUE_instance = new UNINITIALIZED_VALUE();
Companion_instance_14 = new Companion_14();
Iterables_instance = new Iterables();
Companion_instance_24 = new Companion_24();
Companion_instance_25 = new Companion_25();
PropertyDelegates_instance = new PropertyDelegates();
Companion_instance_26 = new Companion_26();
Probit_instance = new Probit();
CollectionFactory_instance = new CollectionFactory();
WeakHashMap_Ids = 0;
Companion_instance_27 = new Companion_27();
Active_instance = new Active();
Key_instance_1 = new Key_1();
Key_instance_2 = new Key_2();
NonDisposableHandle_instance = new NonDisposableHandle();
counter = 0;
DEBUG = false;
index_0 = 0;
ReactHTML_instance = new ReactHTML();
org_mkui_canvas_AbstractAveragingLayer$stable = 8;
org_mkui_canvas_AbstractDensityLayer$stable = 8;
org_mkui_coloring_implementation_AbstractColoring$stable = 8;
org_mkui_coloring_implementation_SimpleColoring$stable = 8;
org_mkui_coloring_implementation_SimpleColoringEvent$stable = 8;
org_mkui_colormap_AbstractColorMap$stable = 8;
Companion_instance_30 = new Companion_30();
org_mkui_colormap_ColorMapEvent$stable = 8;
org_mkui_colormap_ColorMapFactory$stable = 8;
org_mkui_colormap_SetStoreMutableProperty$stable = 8;
org_mkui_colormap_SimpleColorMap$stable = 8;
org_mkui_colormap_editor_AbstractCategoricalColorMapEditor$stable = 8;
org_mkui_colormap_editor_AbstractColorMapPanel$stable = 8;
org_mkui_colormap_editor_AbstractCustomColorMapEditor$stable = 8;
org_mkui_colormap_editor_AbstractPredefinedColorMapEditor$stable = 8;
org_mkui_colormap_property_MutableColorMapOverrideProperty$stable = 0;
org_mkui_colormap_property_MutableColorMapProperty$stable = 8;
org_mkui_colormapping_AbstractColorMapping$stable = 8;
org_mkui_component_InteractiveComponentListeners$stable = 8;
org_mkui_component_VerticalPanelBuilder$stable = 8;
org_mkui_component_button_CPButtonProperties$stable = 8;
org_mkui_component_menu_ToggleGroup$stable = 8;
org_mkui_component_panel_Row$stable = 0;
org_mkui_geom_AbstractRectangle2D$stable = 0;
Companion_instance_31 = new Companion_31();
org_mkui_geom_AffineTransform$stable = 8;
org_mkui_geom_Arc2D_Double$stable = 0;
Companion_instance_33 = new Companion_33();
org_mkui_geom_ArcIterator$stable = 8;
Companion_instance_34 = new Companion_34();
corg_mkui_geom_Area_AreaIterator$stable = 8;
corg_mkui_geom_Area$stable = 8;
org_mkui_geom_AreaOp_CAGOp$stable = 8;
org_mkui_geom_AreaOp_AddOp$stable = 0;
org_mkui_geom_AreaOp_SubOp$stable = 0;
org_mkui_geom_AreaOp_IntOp$stable = 0;
org_mkui_geom_AreaOp_XorOp$stable = 0;
org_mkui_geom_AreaOp_NZWindOp$stable = 8;
org_mkui_geom_AreaOp_EOWindOp$stable = 8;
org_mkui_geom_AreaOp$stable = 0;
org_mkui_geom_ChainEnd$stable = 8;
org_mkui_geom_Crossings_EvenOdd$stable = 0;
org_mkui_geom_Crossings_NonZero$stable = 8;
org_mkui_geom_Crossings$stable = 8;
Companion_instance_37 = new Companion_37();
org_mkui_geom_CubicCurve2D$stable = 0;
org_mkui_geom_Curve$stable = 0;
Companion_instance_38 = new Companion_38();
org_mkui_geom_CurveLink$stable = 8;
org_mkui_geom_Edge$stable = 8;
Companion_instance_39 = new Companion_39();
org_mkui_geom_Ellipse$stable = 8;
org_mkui_geom_Ellipse2D_Double$stable = 0;
org_mkui_geom_EllipseIterator$stable = 8;
org_mkui_geom_FlatteningPathIterator$stable = 8;
org_mkui_geom_GeneralPath$stable = 0;
org_mkui_geom_Line2D_Double$stable = 8;
org_mkui_geom_Line2D$stable = 0;
Companion_instance_41 = new Companion_41();
org_mkui_geom_LineIterator$stable = 8;
org_mkui_geom_NoninvertibleTransformException$stable = 0;
org_mkui_geom_Order0$stable = 0;
org_mkui_geom_Order1$stable = 8;
org_mkui_geom_Order2$stable = 0;
Companion_instance_42 = new Companion_42();
org_mkui_geom_Order3$stable = 8;
Companion_instance_43 = new Companion_43();
org_mkui_geom_Path$stable = 8;
org_mkui_geom_Path2D_Double_CopyIterator$stable = 8;
org_mkui_geom_Path2D_Double_TxIterator$stable = 8;
org_mkui_geom_Path2D_Double$stable = 8;
org_mkui_geom_Path2D_Iterator$stable = 8;
org_mkui_geom_Path2D$stable = 8;
Companion_instance_45 = new Companion_45();
org_mkui_geom_Point$stable = 8;
org_mkui_geom_Point2D_Double$stable = 8;
org_mkui_geom_Point2D_Float$stable = 8;
org_mkui_geom_Polygon_PolygonPathIterator$stable = 8;
org_mkui_geom_Polygon$stable = 8;
org_mkui_geom_QuadCurve2D_Double$stable = 8;
org_mkui_geom_QuadCurve2D$stable = 0;
Companion_instance_46 = new Companion_46();
org_mkui_geom_QuadIterator$stable = 8;
org_mkui_geom_RectIterator$stable = 8;
org_mkui_geom_Rectangle$stable = 8;
org_mkui_geom_Rectangle2D_Double$stable = 0;
Companion_instance_47 = new Companion_47();
org_mkui_geom_Rectangle2DHelper$stable = 0;
org_mkui_geom_RoundRectIterator$stable = 8;
org_mkui_geom_RoundRectangle2D_Double$stable = 8;
org_mkui_geom_RoundRectangle2D$stable = 0;
org_mkui_geom_ScreenTransformHelper$stable = 0;
ScreenTransformHelper_instance = new ScreenTransformHelper();
org_mkui_geom_Segment$stable = 8;
org_mkui_geom_TextShape$stable = 8;
org_mkui_geom_curve_BSpline$stable = 8;
org_mkui_geom_curve_Bag$stable = 8;
org_mkui_geom_curve_BezierCurve$stable = 8;
org_mkui_geom_curve_BinaryCurveApproximationAlgorithm$stable = 0;
org_mkui_geom_curve_CardinalSpline$stable = 8;
org_mkui_geom_curve_CatmullRomSpline$stable = 8;
org_mkui_geom_curve_ControlPath$stable = 8;
org_mkui_geom_curve_CubicBSpline$stable = 8;
org_mkui_geom_curve_Curve$stable = 8;
org_mkui_geom_curve_Geom$stable = 8;
org_mkui_geom_curve_GroupIterator$stable = 8;
org_mkui_geom_curve_LagrangeCurve$stable = 8;
org_mkui_geom_curve_MultiPath$stable = 8;
org_mkui_geom_curve_NURBSpline$stable = 8;
org_mkui_geom_curve_NaturalCubicSpline$stable = 8;
org_mkui_geom_curve_ParametricCurve$stable = 0;
org_mkui_geom_curve_PascalsTriangle$stable = 8;
org_mkui_geom_curve_ShapeMultiPath$stable = 0;
org_mkui_geom_curve_ShapeMultiPathIterator$stable = 8;
org_mkui_geom_curve_ValueVector$stable = 8;
org_mkui_graphics_AbstractIDrawing$stable = 8;
org_mkui_graphics_AbstractIGraphics$stable = 8;
Companion_instance_49 = new Companion_49();
org_mkui_graphics_Edge$stable = 8;
org_mkui_graphics_Insets$stable = 8;
org_mkui_graphics_colortheme_AbstractColorTheme$stable = 0;
org_mkui_graphics_colortheme_LightColorTheme$stable = 8;
org_mkui_graphics_line_BresenhamLineDrawer$stable = 0;
org_mkui_graphics_line_TwoStepLineDrawer$stable = 0;
org_mkui_graphics_pressure_LinearPressure$stable = 0;
org_mkui_graphics_pressure_LogPressure$stable = 0;
org_mkui_labeling_ContrastEnhancement_Off$stable = 0;
org_mkui_labeling_ContrastEnhancement_Brightness$stable = 0;
org_mkui_labeling_ContrastEnhancement_BlackWhite$stable = 0;
org_mkui_labeling_ContrastEnhancement_Complement$stable = 0;
org_mkui_labeling_ContrastEnhancement$stable = 0;
Companion_instance_51 = new Companion_51();
org_mkui_palette_AbstractMutablePalette$stable = 8;
org_mkui_palette_AbstractPalette$stable = 8;
org_mkui_palette_CustomPalette_Entry$stable = 0;
org_mkui_palette_CustomPalette$stable = 8;
org_mkui_palette_DynamicPalette$stable = 8;
org_mkui_palette_FixedPalette$stable = 8;
Companion_instance_52 = new Companion_52();
org_mkui_palette_InterpolatedPalette_Entry$stable = 0;
org_mkui_palette_InterpolatedPalette$stable = 8;
org_mkui_palette_PaletteEvent$stable = 0;
org_mkui_palette_PaletteFactory_Entry$stable = 8;
org_mkui_palette_PaletteFactory$stable = 8;
org_mkui_property_ObservableManager$stable = 8;
org_mkui_property_ObservableValue$stable = 8;
org_mkui_property_Observable$stable = 8;
org_mkui_rubberband_RubberbandDrawing$stable = 8;
org_mkui_rubberband_ScreenTransformRubberBand$stable = 8;
org_mkui_rubberband_SimpleRubberBand$stable = 8;
org_mkui_transform_AbstractMutableTwoDScreenTransform$stable = 8;
org_mkui_transform_AbstractTwoDScreenTransform$stable = 0;
org_mkui_transform_SimpleTwoDScreenTransform$stable = 8;
org_mkui_visual_AbstractVisual$stable = 0;
org_mkui_canvas_CPCanvas$stable = 8;
com_macrofocus_crossplatform_client_layer_ElementalAveragingGWTLayer$stable = 8;
org_mkui_canvas_ElementalBufferedGWTLayer$stable = 8;
org_mkui_canvas_ElementalCanvasHandler_ElementalMouseEvent$stable = 8;
org_mkui_canvas_ElementalCanvasHandler_ElementalKeyEvent$stable = 0;
org_mkui_canvas_ElementalCanvasHandler$stable = 8;
com_macrofocus_crossplatform_client_layer_ElementalDensityGWTLayer$stable = 8;
org_mkui_canvas_ElementalDirectGWTLayer$stable = 8;
org_mkui_canvas_ElementalFontMetrics$stable = 8;
org_mkui_canvas_ElementalIGraphics$stable = 8;
org_mkui_canvas_FunctionalCPCanvas$stable = 8;
org_mkui_canvas_JSMouseEvent$stable = 8;
org_mkui_canvas_ResizeObserver$stable = 0;
org_mkui_color_MkColorFactory$stable = 8;
org_mkui_color_crossplatform_CPColor$stable = 0;
org_mkui_component_CPComponentWrapper$stable = 8;
org_mkui_component_CPInteractiveHandler_ElementalMouseEvent$stable = 8;
org_mkui_component_CPInteractiveHandler_ElementalKeyEvent$stable = 0;
org_mkui_component_CPInteractiveHandler$stable = 8;
org_mkui_component_CPSeparator$stable = 8;
org_mkui_component_ReactComponent$stable = 8;
org_mkui_component_absolute_AbsoluteCPContainer$stable = 8;
org_mkui_component_button_CPButton$stable = 8;
org_mkui_component_button_CPCheckBox$stable = 8;
org_mkui_component_button_CPCollapseButton$stable = 8;
org_mkui_component_button_CPComboBox$stable = 8;
org_mkui_component_button_CPRadioButtons$stable = 8;
org_mkui_component_button_CPSplitMenuButton$stable = 8;
org_mkui_component_button_CPSwitch$stable = 8;
org_mkui_component_input_CPColorPicker$stable = 8;
org_mkui_component_input_CPFontPicker$stable = 8;
org_mkui_component_input_CPSlider$stable = 8;
org_mkui_component_input_CPSpinner$stable = 8;
org_mkui_component_label_CPLabel$stable = 8;
org_mkui_component_list_CPCheckBoxList$stable = 8;
org_mkui_component_menu_CPMenu$stable = 8;
org_mkui_component_menu_CPMenuBar$stable = 8;
org_mkui_component_menu_CPPopupMenu$stable = 8;
org_mkui_component_panel_CPCollapse$stable = 8;
org_mkui_component_panel_CPFillMiddlePanel$stable = 8;
org_mkui_component_panel_CPFormPanel$stable = 8;
org_mkui_component_panel_CPGridPanel$stable = 8;
org_mkui_component_panel_CPOverlayPanel$stable = 8;
org_mkui_component_panel_CPVerticalFlowPanel$stable = 8;
org_mkui_component_panel_CPVerticalPanel$stable = 8;
org_mkui_font_CPFontFactory$stable = 0;
org_mkui_font_crossplatform_CPFont$stable = 8;
org_mkui_graphics_CPGraphics$stable = 8;
org_mkui_graphics_CPGraphicsContext2D$stable = 8;
org_mkui_graphics_CPImage$stable = 8;
org_mkui_graphics_CPImageFactory$stable = 8;
org_mkui_graphics_CanvasRenderingContext2DTextMetrics$stable = 8;
org_mkui_react_ReactStateInstance$stable = 8;
org_mkui_window_CPWindow$stable = 8;
Companion_instance_56 = new Companion_56();
Companion_instance_57 = new Companion_57();
Companion_instance_58 = new Companion_58();
GroupFactory_instance = new GroupFactory();
Companion_instance_60 = new Companion_60();
Companion_instance_61 = new Companion_61();
Companion_instance_62 = new Companion_62();
DataFrameHelper_instance = new DataFrameHelper();
Companion_instance_63 = new Companion_63();
com_treemap_AbsScale$stable = 0;
com_treemap_AbstractAlgorithm$stable = 0;
com_treemap_AbstractLabeling$stable = 0;
Companion_instance_65 = new Companion_65();
com_treemap_AbstractNesting$stable = 0;
Companion_instance_66 = new Companion_66();
com_treemap_AbstractNodeRenderer$stable = 0;
com_treemap_AbstractRendering$stable = 0;
Companion_instance_67 = new Companion_67();
com_treemap_AbstractTreeMap$stable = 8;
Companion_instance_68 = new Companion_68();
com_treemap_AbstractTreeMapColumnSettings$stable = 0;
Companion_instance_69 = new Companion_69();
com_treemap_AbstractTreeMapController$stable = 8;
com_treemap_AbstractTreeMapModel$stable = 8;
Companion_instance_70 = new Companion_70();
com_treemap_AbstractTreeMapNode$stable = 8;
com_treemap_AbstractTreeMapSettings$stable = 8;
Companion_instance_71 = new Companion_71();
com_treemap_AbstractTreeMapToolTip$stable = 8;
Companion_instance_72 = new Companion_72();
com_treemap_AbstractTreeMapView$stable = 8;
com_treemap_AggregationFactory$stable = 8;
com_treemap_AlgorithmFactory$stable = 8;
com_treemap_AverageAggregation$stable = 0;
com_treemap_BackgroundParentNodeRenderer$stable = 0;
com_treemap_BackgroundRootNodeTreeMapRenderer$stable = 0;
com_treemap_BarAlgorithm$stable = 0;
com_treemap_BinaryTreeAlgorithm$stable = 0;
com_treemap_BorderParentNodeRenderer$stable = 0;
com_treemap_BreadthFirstIterator$stable = 8;
com_treemap_CirclePackingAlgorithm_Circle$stable = 8;
com_treemap_CirclePackingAlgorithm$stable = 8;
Companion_instance_75 = new Companion_75();
com_treemap_CircularAlgorithm$stable = 8;
Companion_instance_76 = new Companion_76();
com_treemap_ColorOrdering$stable = 0;
Companion_instance_77 = new Companion_77();
com_treemap_ColoredSurroundLabeling$stable = 0;
com_treemap_CombinationGenerator$stable = 0;
CombinationGenerator_instance = new CombinationGenerator();
com_treemap_CountAggregation$stable = 0;
com_treemap_Cushion$stable = 8;
com_treemap_CushionRendering$stable = 0;
com_treemap_DefaultAlgorithmFactory$stable = 0;
DefaultAlgorithmFactory_instance = new DefaultAlgorithmFactory_0();
com_treemap_DefaultTreeMap$stable = 0;
com_treemap_DefaultTreeMapColumnSettings$stable = 8;
Companion_instance_78 = new Companion_78();
com_treemap_DefaultTreeMapController$stable = 0;
com_treemap_DefaultTreeMapHeaderRenderer$stable = 8;
com_treemap_DefaultTreeMapLabelRenderer$stable = 0;
com_treemap_DefaultTreeMapModel$stable = 8;
com_treemap_DefaultTreeMapPopup$stable = 8;
com_treemap_DefaultTreeMapSettings$stable = 8;
com_treemap_DefaultTreeMapToolTip$stable = 8;
com_treemap_DefaultTreeMapTooltipRenderer$stable = 0;
com_treemap_DefaultTreeMapView$stable = 8;
com_treemap_DepthFactory$stable = 8;
com_treemap_EqualCirclesInCircle$stable = 8;
com_treemap_Exp10Scale$stable = 0;
com_treemap_ExpScale$stable = 0;
com_treemap_ExpandLabeling$stable = 0;
com_treemap_FieldOrdering$stable = 0;
com_treemap_FixedNesting$stable = 0;
com_treemap_FlatNoBorderRendering$stable = 0;
com_treemap_FlatRendering$stable = 8;
com_treemap_HeightOrdering$stable = 0;
com_treemap_HighlightParentNodeRenderer$stable = 0;
com_treemap_IcicleAlgorithm$stable = 8;
com_treemap_InfiniteDepth$stable = 0;
com_treemap_InverseScale$stable = 0;
com_treemap_Itertools$stable = 0;
Itertools_instance = new Itertools();
com_treemap_LabelingFactory$stable = 8;
com_treemap_LeafNodeRenderer$stable = 0;
com_treemap_LeafTreeMapNode$stable = 0;
com_treemap_Log1pScale$stable = 0;
com_treemap_LogScale$stable = 0;
com_treemap_MatrixAlgorithm$stable = 0;
Companion_instance_84 = new Companion_84();
com_treemap_MaxAggregation$stable = 0;
com_treemap_MaxScale$stable = 0;
com_treemap_MinAggregation$stable = 0;
com_treemap_MinScale$stable = 0;
com_treemap_MutableAlgorithmOverrideProperty$stable = 8;
com_treemap_MutableAlgorithmProperty$stable = 8;
com_treemap_NestingFactory$stable = 8;
com_treemap_NodesTreeMapRenderer$stable = 8;
Companion_instance_86 = new Companion_86();
com_treemap_NoneAggregation$stable = 0;
com_treemap_NoneLabeling$stable = 0;
com_treemap_NoneNesting$stable = 0;
com_treemap_NumericTransformScale$stable = 0;
com_treemap_OneLevelIterator$stable = 0;
com_treemap_OrderingFactory$stable = 8;
com_treemap_OriginalOrdering$stable = 0;
Companion_instance_88 = new Companion_88();
com_treemap_OriginalScale$stable = 0;
com_treemap_OverlayLabeling$stable = 0;
com_treemap_OverridingTreeMapColumnSettings$stable = 8;
com_treemap_Pair$stable = 0;
com_treemap_ParentPreorderIterator$stable = 8;
com_treemap_ParentTreeMapNode$stable = 8;
com_treemap_PermutationGenerator$stable = 0;
com_treemap_PieAlgorithm$stable = 0;
com_treemap_PivotByAlgorithm_Biggest$stable = 0;
com_treemap_PivotByAlgorithm_Middle$stable = 0;
com_treemap_PivotByAlgorithm_SplitSize$stable = 0;
com_treemap_PivotByAlgorithm$stable = 8;
com_treemap_PostorderIterator$stable = 8;
com_treemap_PreorderIterator$stable = 8;
com_treemap_ProportionalNesting$stable = 0;
com_treemap_RectangularTransform$stable = 8;
Companion_instance_90 = new Companion_90();
com_treemap_RenderingFactory$stable = 8;
com_treemap_ScaleFactory$stable = 8;
com_treemap_SelectionNodeRenderer$stable = 0;
com_treemap_SizeOrColorOrdering$stable = 0;
com_treemap_SizeOrdering$stable = 0;
com_treemap_SizeWeightedAggregation$stable = 0;
com_treemap_SliceAndDiceAlgorithm_VerticalOrientationStrategy$stable = 0;
com_treemap_SliceAndDiceAlgorithm_HoritzonalOrientationStrategy$stable = 0;
com_treemap_SliceAndDiceAlgorithm_BestOrientationStrategy$stable = 0;
com_treemap_SliceAndDiceAlgorithm_AlternateOrientationStrategy$stable = 0;
com_treemap_SliceAndDiceAlgorithm$stable = 8;
com_treemap_SplitAlgorithm$stable = 0;
Companion_instance_93 = new Companion_93();
com_treemap_SquarifiedAlgorithm$stable = 8;
Companion_instance_94 = new Companion_94();
com_treemap_SquarifiedPlusAlgorithm$stable = 8;
Companion_instance_95 = new Companion_95();
com_treemap_StdDevAggregation$stable = 0;
com_treemap_StripAlgorithm$stable = 0;
com_treemap_SumAggregation$stable = 0;
com_treemap_SunburstAlgorithm$stable = 8;
com_treemap_SurroundLabeling$stable = 8;
Companion_instance_96 = new Companion_96();
com_treemap_TextParentNodeRenderer$stable = 0;
com_treemap_ThresholdDepth$stable = 0;
Companion_instance_97 = new Companion_97();
com_treemap_TreeMapColorMapPanelModel$stable = 8;
com_treemap_TreeMapEvent$stable = 0;
com_treemap_TreeMapFilterCoordinator$stable = 8;
com_treemap_TreeMapProbingCoordinator$stable = 8;
com_treemap_TreeMapSelectionCoordinator$stable = 8;
com_treemap_TreeMapSettingsEvent$stable = 0;
com_treemap_XPlus1Scale$stable = 0;
com_treemap_colormap_DataFrameColorMapFactory$stable = 0;
DataFrameColorMapFactory_instance = new DataFrameColorMapFactory();
com_treemap_crossplatform_AbstractTGraphics$stable = 8;
Companion_instance_98 = new Companion_98();
com_treemap_details_DetailsDataFrame$stable = 8;
com_treemap_legacy_SingleSelectionSettingsCoordinator$stable = 0;
com_treemap_tagcloud_AbstractTagCloudAlgorithm$stable = 8;
com_treemap_tagcloud_ArchimedeanSpiral$stable = 0;
com_treemap_tagcloud_DefaultWord$stable = 8;
com_treemap_tagcloud_HierarchicalBoundingBox$stable = 8;
com_treemap_tagcloud_HierarchicalBoundingBoxPair$stable = 8;
com_treemap_tagcloud_HierarchicalBoundingBoxes$stable = 8;
com_treemap_tagcloud_Interpolator$stable = 0;
com_treemap_tagcloud_LinearizedPathIterator$stable = 8;
com_treemap_tagcloud_Point2d$stable = 0;
com_treemap_tagcloud_PointPlusAccumulatedDistance$stable = 0;
com_treemap_tagcloud_PositionIterator$stable = 8;
com_treemap_tagcloud_RectangularTextShape$stable = 8;
com_treemap_tagcloud_Tuple2d$stable = 8;
com_treemap_tagcloud_Vector2d$stable = 0;
com_treemap_treeplot_Spoint$stable = 8;
com_treemap_JsTreeMap$stable = 0;
com_treemap_crossplatform_CanvasRenderingContext2DFontMetrics$stable = 8;
com_treemap_crossplatform_CanvasRenderingContext2DIGraphics$stable = 8;
com_treemap_crossplatform_CanvasRenderingContext2DTGraphics$stable = 8;
com_treemap_crossplatform_Headless$stable = 0;
com_treemap_crossplatform_TreeMapCanvas$stable = 8;
//endregion
//region block: exports
var KtList = {getInstance: Companion_getInstance_0};
var KtSet = {getInstance: Companion_getInstance_1};
var BigDecimal = {getInstance: Companion_getInstance_16};
var BigInteger = {getInstance: Companion_getInstance_17};
defineProp(MathContext, 'Companion', Companion_getInstance_22);
RoundingMode.values = values;
RoundingMode.valueOf = valueOf;
defineProp(RoundingMode, 'UP', RoundingMode_UP_getInstance);
defineProp(RoundingMode, 'DOWN', RoundingMode_DOWN_getInstance);
defineProp(RoundingMode, 'CEILING', RoundingMode_CEILING_getInstance);
defineProp(RoundingMode, 'FLOOR', RoundingMode_FLOOR_getInstance);
defineProp(RoundingMode, 'HALF_UP', RoundingMode_HALF_UP_getInstance);
defineProp(RoundingMode, 'HALF_DOWN', RoundingMode_HALF_DOWN_getInstance);
defineProp(RoundingMode, 'HALF_EVEN', RoundingMode_HALF_EVEN_getInstance);
defineProp(RoundingMode, 'UNNECESSARY', RoundingMode_UNNECESSARY_getInstance);
defineProp(RoundingMode, 'Companion', Companion_getInstance_24);
defineProp(SimpleProperty, 'Companion', Companion_getInstance_26);
EnhancedLabel.Rendering = Rendering;
EnhancedLabel.Rendering.values = values_1;
EnhancedLabel.Rendering.valueOf = valueOf_0;
defineProp(EnhancedLabel.Rendering, 'Truncate', Rendering_Truncate_getInstance);
defineProp(EnhancedLabel.Rendering, 'Clip', Rendering_Clip_getInstance);
defineProp(EnhancedLabel.Rendering, 'WordWrap', Rendering_WordWrap_getInstance);
EnhancedLabel.Effect = Effect;
defineProp(EnhancedLabel.Effect, 'Plain', Plain_getInstance);
defineProp(EnhancedLabel.Effect, 'Shadow', Shadow_getInstance);
defineProp(EnhancedLabel.Effect, 'Glow', Glow_getInstance);
defineProp(EnhancedLabel.Effect, 'Outline', Outline_getInstance);
defineProp(EnhancedLabel.Effect, 'Emphasize', Emphasize_getInstance);
defineProp(EnhancedLabel, 'Companion', Companion_getInstance_51);
InterpolatedPalette.Entry = Entry_1;
PaletteFactory.Entry = Entry_2;
defineProp(PaletteFactory, 'Companion', Companion_getInstance_53);
defineProp(AlgorithmFactory, 'Companion', Companion_getInstance_74);
var DefaultAlgorithmFactory = {getInstance: DefaultAlgorithmFactory_getInstance};
defineProp(DefaultTreeMapColumnSettings, 'Companion', Companion_getInstance_78);
defineProp(RenderingFactory, 'Companion', Companion_getInstance_91);
var TreeMapComponent = {get: get_TreeMapComponent};
export {
  KtList as KtList,
  KtSet as KtSet,
  BigDecimal as BigDecimal,
  BigInteger as BigInteger,
  BigIntegerRange as BigIntegerRange,
  MathContext as MathContext,
  RoundingMode as RoundingMode,
  PropertyEvent as PropertyEvent,
  SimpleProperty as SimpleProperty,
  JsArrayList as JsArrayList,
  bigInteger as bigInteger,
  bigDecimal as bigDecimal,
  EnhancedLabel as EnhancedLabel,
  InterpolatedPalette as InterpolatedPalette,
  PaletteFactory as PaletteFactory,
  colorOf as colorOf,
  DefaultDataFrame as DefaultDataFrame,
  JsonDataFrame as JsonDataFrame,
  AlgorithmFactory as AlgorithmFactory,
  CushionRendering as CushionRendering,
  DefaultAlgorithmFactory as DefaultAlgorithmFactory,
  DefaultTreeMapColumnSettings as DefaultTreeMapColumnSettings,
  DefaultTreeMapModel as DefaultTreeMapModel,
  DefaultTreeMapSettings as DefaultTreeMapSettings,
  FlatNoBorderRendering as FlatNoBorderRendering,
  FlatRendering as FlatRendering,
  OverridingTreeMapColumnSettings as OverridingTreeMapColumnSettings,
  RenderingFactory as RenderingFactory,
  JsTreeMap as JsTreeMap,
  TreeMapComponent as TreeMapComponent,
  getTreeMapComponent as getTreeMapComponent,
};
//endregion

//# sourceMappingURL=macrofocus-treemap.mjs.map
